import { Component, Host, State, h, Listen, Prop, Method, Watch, } from '@stencil/core';
export class PeVideoPlayer {
  constructor() {
    this.videoElements = [];
    this.debugEnabled = false;
    this.isPreparing = true;
    this.eventSourceStream = '';
    this.isPlaying = false;
    this.isBusy = true;
    this.isMuted = false;
    this.isFullscreen = false;
    this.canMobileVideoPlayThrough = false;
    this.canScreenshareVideoPlayThrough = false;
    this.canWebcamVideoPlayThrough = false;
    this.playbackRate = 1.0;
    this.currentTime = 0.0;
    this.totalDuration = 0.0;
    this.videoDurations = {};
    this.mobileVideoIndex = 0;
    this.screenshareVideoIndex = 0;
    this.webcamVideoIndex = 0;
    this.mobileVideoDurations = [];
    this.screenshareVideoDurations = [];
    this.webcamVideoDurations = [];
    this.mobileVideoStartTimes = [];
    this.screenshareVideoStartTimes = [];
    this.webcamVideoStartTimes = [];
    this.determineVideoDuration = uri => new Promise((resolve, reject) => {
      try {
        let video = document.createElement('video');
        video.src = uri;
        video.preload = 'metadata';
        video.onloadedmetadata = () => {
          resolve(video.duration);
        };
      }
      catch (e) {
        reject(e);
      }
    });
  }
  mobileVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.mobileVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.mobileVideoUris = [];
    }
    this.calculateVideoDurations(this.mobileVideoUris);
  }
  screenshareVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.screenshareVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.screenshareVideoUris = [];
    }
    this.calculateVideoDurations(this.screenshareVideoUris);
  }
  webcamVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.webcamVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.webcamVideoUris = [];
    }
    this.calculateVideoDurations(this.webcamVideoUris);
  }
  peVideoOnWaitingHandler(event) {
    var _a, _b;
    const id = (_b = (_a = event === null || event === void 0 ? void 0 : event.detail) === null || _a === void 0 ? void 0 : _a.target) === null || _b === void 0 ? void 0 : _b.id;
    switch (id) {
      case 'mobile-video':
        this.canMobileVideoPlayThrough = false;
        break;
      case 'screenshare-video':
        this.canScreenshareVideoPlayThrough = false;
        break;
      case 'webcam-video':
        this.canWebcamVideoPlayThrough = false;
        break;
      default:
        console.error('Unknown onWaiting event.');
        break;
    }
    this.determineIsBusy();
  }
  peVideoSourceChangedHandler() {
    this.setCurrentTimeForEachStream();
  }
  peVideoCanPlayThroughHandler(event) {
    var _a, _b;
    const id = (_b = (_a = event === null || event === void 0 ? void 0 : event.detail) === null || _a === void 0 ? void 0 : _a.target) === null || _b === void 0 ? void 0 : _b.id;
    switch (id) {
      case 'mobile-video':
        this.canMobileVideoPlayThrough = true;
        break;
      case 'screenshare-video':
        this.canScreenshareVideoPlayThrough = true;
        break;
      case 'webcam-video':
        this.canWebcamVideoPlayThrough = true;
        break;
      default:
        console.error('Unknown canPlayThrough event.');
        break;
    }
    this.determineIsBusy();
  }
  peVideoPlayHandler(event) {
    this.isPlaying = event.detail;
  }
  peVideoRewindHandler(event) {
    const timeToRewind = event.detail;
    const time = this.currentTime + timeToRewind < 0 ? 0 : this.currentTime + timeToRewind;
    this.setCurrentTime(time);
  }
  peVideoMuteHandler() {
    this.isMuted = !this.isMuted;
  }
  peVideoSpeedHandler(event) {
    const playbackRate = event.detail;
    this.playbackRate = playbackRate;
  }
  peVideoEndedHandler(event) {
    const id = event.detail.target.id;
    switch (id) {
      case 'mobile-video':
        if (this.mobileVideoUris[this.mobileVideoIndex + 1] !== undefined)
          this.mobileVideoIndex = this.mobileVideoIndex + 1;
        break;
      case 'screenshare-video':
        if (this.screenshareVideoUris[this.screenshareVideoIndex + 1] !==
          undefined)
          this.screenshareVideoIndex = this.screenshareVideoIndex + 1;
        break;
      case 'webcam-video':
        if (this.webcamVideoUris[this.webcamVideoIndex + 1] !== undefined)
          this.webcamVideoIndex = this.webcamVideoIndex + 1;
        break;
      default:
        console.error('Unknown peVideoEnded event.');
        break;
    }
  }
  peVideoTimeUpdateHandler(event) {
    const time = event.detail.target.currentTime || 0;
    if (time < 0.01) {
      return;
    } // magic :(
    let calculatedCurrentTime;
    switch (this.eventSourceStream) {
      case 'mobile':
        calculatedCurrentTime =
          this.mobileVideoIndex > 0
            ? this.mobileVideoStartTimes[this.mobileVideoIndex] + time
            : time;
        break;
      case 'webcam':
        calculatedCurrentTime =
          this.webcamVideoIndex > 0
            ? this.webcamVideoStartTimes[this.webcamVideoIndex] + time
            : time;
        break;
      case 'screenshare':
        calculatedCurrentTime =
          this.screenshareVideoIndex > 0
            ? this.screenshareVideoStartTimes[this.screenshareVideoIndex] + time
            : time;
        break;
    }
    this.currentTime = calculatedCurrentTime;
  }
  peVideoLoadedDataHandler() {
    this.setCurrentTimeForEachStream();
  }
  peVideoSeekHandler(event) {
    const time = event.detail;
    this.setCurrentTime(time);
  }
  peVideoFullscreenHandler(event) {
    this.isFullscreen = event.detail;
    if (this.isFullscreen == true && document.fullscreenElement == null) {
      this.videoPlayerElement.requestFullscreen();
    }
    else if (this.isFullscreen == false &&
      document.fullscreenElement != null) {
      document.exitFullscreen();
    }
  }
  /**
   * Moves clicked video to highlighted area.
   * Nothing happens if clicked on already highlighted video.
   */
  peVideoClickHandler(event) {
    const videoElement = event.detail.target;
    if (videoElement === this.highlightedVideo)
      return;
    const previouslyHighlightedVideo = this.highlightedVideo;
    this.highlightedVideo = videoElement;
    const indexOfSelected = Array.from(videoElement.parentElement.children).indexOf(videoElement);
    previouslyHighlightedVideo.after(videoElement);
    if (indexOfSelected == 0) {
      this.smallVideoContainer.insertAdjacentElement('afterbegin', previouslyHighlightedVideo);
    }
    else {
      this.smallVideoContainer.insertAdjacentElement('beforeend', previouslyHighlightedVideo);
    }
    this.handleBoxSizeChanges({
      inlineSize: this.videoPlayerElement.parentElement.clientWidth,
      blockSize: this.videoPlayerElement.parentElement.clientHeight,
    });
  }
  /**
   * @param time
   */
  async setCurrentTime(time) {
    const wasPlaying = this.isPlaying;
    // Stopping player first
    this.isPlaying = false;
    // Setting current time
    this.currentTime = time;
    // Calculate current time for each stream
    this.setCurrentTimeForEachStream();
    // Playing video again after seek finished
    // only if it was already playing
    if (wasPlaying)
      this.isPlaying = true;
  }
  /**
   * Returns current time from seekbar
   */
  async getCurrentTime() {
    return this.currentTime;
  }
  async setCurrentTimeForEachStream() {
    if (this.mobileVideoStartTimes.length === 0 &&
      this.webcamVideoStartTimes.length === 0 &&
      this.screenshareVideoStartTimes.length === 0)
      return;
    // Set correct index for each stream
    const newMobileVideoIndex = this.mobileVideoStartTimes.indexOf(this.mobileVideoStartTimes
      .filter(range => this.currentTime >= range)
      .at(-1));
    const newWebcamVideoIndex = this.webcamVideoStartTimes.indexOf(this.webcamVideoStartTimes
      .filter(range => this.currentTime >= range)
      .at(-1));
    const newScreenshareVideoIndex = this.screenshareVideoStartTimes.indexOf(this.screenshareVideoStartTimes
      .filter(range => this.currentTime >= range)
      .at(-1));
    const atLeastOneSourceChanged = newMobileVideoIndex != this.mobileVideoIndex ||
      newWebcamVideoIndex != this.webcamVideoIndex ||
      newScreenshareVideoIndex != this.screenshareVideoIndex;
    if (newMobileVideoIndex != this.mobileVideoIndex) {
      this.mobileVideoIndex = newMobileVideoIndex;
    }
    if (newWebcamVideoIndex != this.webcamVideoIndex) {
      this.webcamVideoIndex = newWebcamVideoIndex;
    }
    if (newScreenshareVideoIndex != this.screenshareVideoIndex) {
      this.screenshareVideoIndex = newScreenshareVideoIndex;
    }
    if (atLeastOneSourceChanged) {
      await this.waitEvent('peVideoSourceChanged');
    }
    // Calculate correct current time for each stream
    const mobileVideoTime = this.mobileVideoIndex == 0
      ? this.currentTime
      : this.currentTime - this.mobileVideoStartTimes[this.mobileVideoIndex];
    const webcamVideoTime = this.webcamVideoIndex == 0
      ? this.currentTime
      : this.currentTime - this.webcamVideoStartTimes[this.webcamVideoIndex];
    const screenshareVideoTime = this.screenshareVideoIndex == 0
      ? this.currentTime
      : this.currentTime -
        this.screenshareVideoStartTimes[this.screenshareVideoIndex];
    // Set correct current time for each stream
    this.videoElements.forEach(videoElement => {
      switch (videoElement.name) {
        case 'mobile-video':
          videoElement.setCurrentTime(mobileVideoTime);
          break;
        case 'screenshare-video':
          videoElement.setCurrentTime(screenshareVideoTime);
          break;
        case 'webcam-video':
          videoElement.setCurrentTime(webcamVideoTime);
          break;
        default:
          console.error('Unknown peVideoEnded event.');
          break;
      }
    });
  }
  /**
   * Checks if all provided medias are ready to play,
   * and then sets 'isBusy' state.
   */
  determineIsBusy() {
    var _a, _b, _c, _d;
    if (((_a = this.webcamVideoUris) === null || _a === void 0 ? void 0 : _a.length) > 0 && ((_b = this.mobileVideoUris) === null || _b === void 0 ? void 0 : _b.length) > 0) {
      this.isBusy = !(this.canMobileVideoPlayThrough &&
        this.canScreenshareVideoPlayThrough &&
        this.canWebcamVideoPlayThrough);
    }
    else if (((_c = this.webcamVideoUris) === null || _c === void 0 ? void 0 : _c.length) > 0) {
      this.isBusy = !(this.canScreenshareVideoPlayThrough && this.canWebcamVideoPlayThrough);
    }
    else if (((_d = this.mobileVideoUris) === null || _d === void 0 ? void 0 : _d.length) > 0) {
      this.isBusy = !(this.canScreenshareVideoPlayThrough && this.canMobileVideoPlayThrough);
    }
    else {
      this.isBusy = !this.canScreenshareVideoPlayThrough;
    }
  }
  calculateVideoDurations(videoUris) {
    videoUris.forEach(uri => {
      if (this.videoDurations.hasOwnProperty(uri))
        return;
      this.determineVideoDuration(uri).then(duration => {
        this.videoDurations[uri] = duration;
        if (Object.keys(this.videoDurations).length ===
          [
            ...new Set([
              ...this.screenshareVideoUris,
              ...this.webcamVideoUris,
              ...this.mobileVideoUris,
            ]),
          ].length) {
          this.mobileVideoDurations = this.mobileVideoUris.map(key => this.videoDurations[key]);
          this.webcamVideoDurations = this.webcamVideoUris.map(key => this.videoDurations[key]);
          this.screenshareVideoDurations = this.screenshareVideoUris.map(key => this.videoDurations[key]);
          this.calculateVideoStartTimes();
        }
      });
    });
  }
  calculateVideoStartTimes() {
    // determine starting time for each mobile video source
    this.mobileVideoStartTimes = [
      ...[0],
      ...Array.from(this.mobileVideoDurations, (_item, index) => this.mobileVideoDurations.slice(0, index + 1).reduce((a, b) => a + b)).slice(0, -1),
    ];
    // determine starting time for each webcam video source
    this.webcamVideoStartTimes = [
      ...[0],
      ...Array.from(this.webcamVideoDurations, (_item, index) => this.webcamVideoDurations.slice(0, index + 1).reduce((a, b) => a + b)).slice(0, -1),
    ];
    // determine starting time for each screenshare video source
    this.screenshareVideoStartTimes = [
      ...[0],
      ...Array.from(this.screenshareVideoDurations, (_item, index) => this.screenshareVideoDurations
        .slice(0, index + 1)
        .reduce((a, b) => a + b)).slice(0, -1),
    ];
    this.calculateTotalDuration();
    this.determineEventSource();
    this.determineIsPreparing();
  }
  determineIsPreparing() {
    const startTimesCalculated = [
      ...this.mobileVideoStartTimes,
      ...this.webcamVideoStartTimes,
      ...this.screenshareVideoStartTimes,
    ].length >=
      [
        ...this.mobileVideoUris,
        ...this.webcamVideoUris,
        ...this.screenshareVideoUris,
      ].length;
    if (startTimesCalculated) {
      this.isPreparing = false;
      this.setupResizeObserver();
    }
    else {
      this.isPreparing = true;
    }
  }
  calculateTotalDuration() {
    this.totalDuration = Math.max(this.mobileVideoStartTimes.at(-1) + this.mobileVideoDurations.at(-1) || 0, this.webcamVideoStartTimes.at(-1) + this.webcamVideoDurations.at(-1) || 0, this.screenshareVideoStartTimes.at(-1) +
      this.screenshareVideoDurations.at(-1) || 0, ...[0]);
  }
  handleBoxSizeChanges(boxSize) {
    const width = boxSize.inlineSize;
    const height = boxSize.blockSize;
    let bottomGap = 0;
    let actualHeight = 0;
    if (this.isFullscreen) {
      // fullscreen mode
      bottomGap = this.videoControls.clientHeight + 20 + 25;
      actualHeight = height - bottomGap;
      this.highlightedVideo.style.height = actualHeight.toString() + 'px';
      this.highlightedVideo.style.width = '80%';
      this.smallVideoContainer
        .querySelectorAll('pe-video')
        .forEach(videoElement => {
        videoElement.style.height = '25%';
        videoElement.style.width = '100%';
      });
    }
    else {
      // default view
      bottomGap = this.videoControls.clientHeight + 20 + 25 + 15;
      actualHeight = height - bottomGap;
      this.highlightedVideo.style.height =
        (actualHeight * 0.75).toString() + 'px';
      this.highlightedVideo.style.width = '100%';
      this.smallVideoContainer
        .querySelectorAll('pe-video')
        .forEach(videoElement => {
        videoElement.style.height = (actualHeight * 0.25).toString() + 'px';
        videoElement.style.width = (width * 0.35).toString() + 'px';
      });
    }
  }
  determineEventSource() {
    const durationSums = [
      [...[0], ...this.mobileVideoDurations].reduce((a, b) => a + b),
      [...[0], ...this.screenshareVideoDurations].reduce((a, b) => a + b),
      [...[0], ...this.webcamVideoDurations].reduce((a, b) => a + b),
    ];
    const streamTypes = ['mobile', 'screenshare', 'webcam'];
    this.eventSourceStream =
      streamTypes[durationSums.indexOf(Math.max(...durationSums))];
  }
  setupResizeObserver() {
    const parentElement = this.videoPlayerElement.parentElement;
    const resizeObserver = new ResizeObserver(entries => {
      for (let entry of entries) {
        if (entry.contentBoxSize !== null) {
          const contentBoxSize = Array.isArray(entry.contentBoxSize)
            ? entry.contentBoxSize[0]
            : entry.contentBoxSize;
          this.handleBoxSizeChanges(contentBoxSize);
        }
      }
    });
    resizeObserver.observe(parentElement);
    // Set highlighted video only once in here.
    this.highlightedVideo = this.screenshareVideo;
    // Add all available videos to video elements array
    if (this.screenshareVideo != undefined)
      this.videoElements.push(this.screenshareVideo);
    if (this.mobileVideo != undefined)
      this.videoElements.push(this.mobileVideo);
    if (this.webcamVideo != undefined)
      this.videoElements.push(this.webcamVideo);
  }
  async waitEvent(name) {
    return new Promise(function (resolve) {
      document.addEventListener(name, function () {
        resolve(true); // resolves when the event fires
      });
    });
  }
  componentWillLoad() {
    this.mobileVideoUrisChanged(this.mobileVideoUris);
    this.webcamVideoUrisChanged(this.webcamVideoUris);
    this.screenshareVideoUrisChanged(this.screenshareVideoUris);
  }
  componentDidLoad() {
    // set feature flags
    const params = new URLSearchParams(location.search);
    this.debugEnabled = params.has('debugger');
  }
  render() {
    var _a, _b, _c, _d;
    return (h(Host, { class: this.isPreparing ? 'loading' : '', ref: el => (this.videoPlayerElement = el) },
      ((_a = this.screenshareVideoUris) === null || _a === void 0 ? void 0 : _a.length) > 0 && (h("span", { class: this.isFullscreen ? 'fullscreen' : '' },
        h("div", { id: "video-container" },
          h("pe-video", { ref: el => (this.screenshareVideo = el), name: "screenshare-video", tag: "Screenshare", playbackRate: this.playbackRate, isMuted: true, isPlaying: this.isBusy ? false : this.isPlaying, isEventSource: this.eventSourceStream == 'screenshare', source: this.screenshareVideoUris[this.screenshareVideoIndex] }),
          h("div", { ref: el => (this.smallVideoContainer = el), id: "small-video-container" },
            ((_b = this.webcamVideoUris) === null || _b === void 0 ? void 0 : _b.length) > 0 && (h("pe-video", { ref: el => (this.webcamVideo = el), name: "webcam-video", tag: "Webcam", playbackRate: this.playbackRate, isMuted: this.isMuted, isPlaying: this.isBusy ? false : this.isPlaying, isEventSource: this.eventSourceStream == 'webcam', source: this.webcamVideoUris[this.webcamVideoIndex] })),
            ((_c = this.mobileVideoUris) === null || _c === void 0 ? void 0 : _c.length) > 0 && (h("pe-video", { ref: el => (this.mobileVideo = el), name: "mobile-video", tag: "Mobile", playbackRate: this.playbackRate, isMuted: true, isPlaying: this.isBusy ? false : this.isPlaying, isEventSource: this.eventSourceStream == 'mobile', source: this.mobileVideoUris[this.mobileVideoIndex] })))),
        h("pe-video-controls", { ref: el => (this.videoControls = el), currentTime: this.currentTime, totalDuration: this.totalDuration, isFullscreen: this.isFullscreen }))),
      ((_d = this.screenshareVideoUris) === null || _d === void 0 ? void 0 : _d.length) == 0 && (h("h1", null, "Screensharing source is required.")),
      this.debugEnabled && (h("pe-debug-panel", { content: {
          screenshareVideoUris: this.screenshareVideoUris,
          webcamVideoUris: this.webcamVideoUris,
          mobileVideoUris: this.mobileVideoUris,
          videoDurations: [
            `screenshare: ${this.screenshareVideoDurations}`,
            `webcam: ${this.webcamVideoDurations}`,
            `mobile: ${this.mobileVideoDurations}`,
          ],
          videoIndexes: [
            `screenshare: ${this.screenshareVideoIndex}`,
            `webcam: ${this.webcamVideoIndex}`,
            `mobile: ${this.mobileVideoIndex}`,
          ],
          videoCanPlayThrough: [
            `screenshare: ${this.canScreenshareVideoPlayThrough}`,
            `webcam: ${this.canWebcamVideoPlayThrough}`,
            `mobile: ${this.canMobileVideoPlayThrough}`,
          ],
          eventSource: [this.eventSourceStream],
        } }))));
  }
  static get is() { return "pe-video-player"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["pe-video-player.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["pe-video-player.css"]
  }; }
  static get properties() { return {
    "mobileVideoUris": {
      "type": "any",
      "mutable": true,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Uri(s) for mobile video source(s)."
      },
      "attribute": "mobile-video-uris",
      "reflect": false
    },
    "screenshareVideoUris": {
      "type": "any",
      "mutable": true,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Uri(s) for screenshare video source(s)."
      },
      "attribute": "screenshare-video-uris",
      "reflect": false
    },
    "webcamVideoUris": {
      "type": "any",
      "mutable": true,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Uri(s) for webcam video source(s)."
      },
      "attribute": "webcam-video-uris",
      "reflect": false
    }
  }; }
  static get states() { return {
    "debugEnabled": {},
    "isPreparing": {},
    "eventSourceStream": {},
    "isPlaying": {},
    "isBusy": {},
    "isMuted": {},
    "isFullscreen": {},
    "canMobileVideoPlayThrough": {},
    "canScreenshareVideoPlayThrough": {},
    "canWebcamVideoPlayThrough": {},
    "playbackRate": {},
    "currentTime": {},
    "totalDuration": {},
    "videoDurations": {},
    "mobileVideoIndex": {},
    "screenshareVideoIndex": {},
    "webcamVideoIndex": {},
    "mobileVideoDurations": {},
    "screenshareVideoDurations": {},
    "webcamVideoDurations": {},
    "mobileVideoStartTimes": {},
    "screenshareVideoStartTimes": {},
    "webcamVideoStartTimes": {}
  }; }
  static get methods() { return {
    "setCurrentTime": {
      "complexType": {
        "signature": "(time: number) => Promise<void>",
        "parameters": [{
            "tags": [{
                "name": "param",
                "text": "time"
              }],
            "text": ""
          }],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<void>"
      },
      "docs": {
        "text": "",
        "tags": [{
            "name": "param",
            "text": "time"
          }]
      }
    },
    "getCurrentTime": {
      "complexType": {
        "signature": "() => Promise<number>",
        "parameters": [],
        "references": {
          "Promise": {
            "location": "global"
          }
        },
        "return": "Promise<number>"
      },
      "docs": {
        "text": "Returns current time from seekbar",
        "tags": []
      }
    }
  }; }
  static get watchers() { return [{
      "propName": "mobileVideoUris",
      "methodName": "mobileVideoUrisChanged"
    }, {
      "propName": "screenshareVideoUris",
      "methodName": "screenshareVideoUrisChanged"
    }, {
      "propName": "webcamVideoUris",
      "methodName": "webcamVideoUrisChanged"
    }]; }
  static get listeners() { return [{
      "name": "peVideoOnWaiting",
      "method": "peVideoOnWaitingHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoSourceChanged",
      "method": "peVideoSourceChangedHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoCanPlayThrough",
      "method": "peVideoCanPlayThroughHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoPlay",
      "method": "peVideoPlayHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoRewind",
      "method": "peVideoRewindHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoMute",
      "method": "peVideoMuteHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoSpeed",
      "method": "peVideoSpeedHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoEnded",
      "method": "peVideoEndedHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoTimeUpdate",
      "method": "peVideoTimeUpdateHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoLoadedData",
      "method": "peVideoLoadedDataHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoSeek",
      "method": "peVideoSeekHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoFullscreen",
      "method": "peVideoFullscreenHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }, {
      "name": "peVideoClick",
      "method": "peVideoClickHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}
