import { Component, h, Prop, Watch, State, Host } from '@stencil/core';
export class PeButton {
  constructor() {
    /**
     * enable/disable a button
     */
    this.disabled = false;
    /**
     * pass this if empty button to show button in best style shape
     */
    this.iconOnly = false;
    /**
     * changing the look to a button
     */
    this.circled = false;
    /**
     * varients
     */
    this.variant = 'ghost';
    /**
     * colors
     */
    this.color = 'basic';
    /**
     * size
     */
    this.size = 'normal';
  }
  iconNameChanged(newIconName) {
    this.iconState = newIconName;
  }
  componentWillLoad() {
    this.iconState = this.iconName;
  }
  render() {
    return (h(Host, null,
      h("button", { class: `${this.variant || 'ghost'} ${this.size} ${this.color} ${this.circled ? 'circle' : ''} ${this.class || ''}`, disabled: this.disabled },
        this.iconState && (h("pe-icon", { class: `${this.iconOnly && 'icon-only'}`, name: this.iconState })),
        !this.iconOnly && (this.text || h("slot", null)))));
  }
  static get is() { return "pe-button"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["pe-button.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["pe-button.css"]
  }; }
  static get properties() { return {
    "disabled": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "enable/disable a button"
      },
      "attribute": "disabled",
      "reflect": true,
      "defaultValue": "false"
    },
    "iconOnly": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "pass this if empty button to show button in best style shape"
      },
      "attribute": "icon-only",
      "reflect": true,
      "defaultValue": "false"
    },
    "circled": {
      "type": "boolean",
      "mutable": true,
      "complexType": {
        "original": "boolean",
        "resolved": "boolean",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "changing the look to a button"
      },
      "attribute": "circled",
      "reflect": true,
      "defaultValue": "false"
    },
    "variant": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "| 'filled'\n    | 'outline'\n    | 'ghost'",
        "resolved": "\"filled\" | \"ghost\" | \"outline\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "varients"
      },
      "attribute": "variant",
      "reflect": true,
      "defaultValue": "'ghost'"
    },
    "color": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "| 'primary'\n    | 'basic'\n    | 'action'\n    | 'player'",
        "resolved": "\"action\" | \"basic\" | \"player\" | \"primary\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "colors"
      },
      "attribute": "color",
      "reflect": true,
      "defaultValue": "'basic'"
    },
    "size": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "'normal' | 'large'",
        "resolved": "\"large\" | \"normal\"",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "size"
      },
      "attribute": "size",
      "reflect": true,
      "defaultValue": "'normal'"
    },
    "class": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "pass extra class if you want to do extra style"
      },
      "attribute": "class",
      "reflect": true
    },
    "text": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "button text to overide what pass as a child to the <slot>"
      },
      "attribute": "text",
      "reflect": true
    },
    "iconName": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "add icon to the button"
      },
      "attribute": "icon-name",
      "reflect": true
    }
  }; }
  static get states() { return {
    "iconState": {}
  }; }
  static get watchers() { return [{
      "propName": "iconName",
      "methodName": "iconNameChanged"
    }]; }
}
