import { Component, Host, State, h, Prop, Watch } from '@stencil/core';
export class PeDebugPanel {
  constructor() {
    this.xOffset = 0;
    this.yOffset = 0;
  }
  handleContentChanged(newValue) {
    if (typeof newValue == 'string') {
      this.content = JSON.parse(newValue);
    }
    else {
      this.content = newValue;
    }
  }
  handleMouseDown(e) {
    if (e.type === 'touchstart') {
      this.initialX = e.touches[0].clientX - this.xOffset;
      this.initialY = e.touches[0].clientY - this.yOffset;
    }
    else {
      this.initialX = e.clientX - this.xOffset;
      this.initialY = e.clientY - this.yOffset;
    }
    this.isMouseDown = true;
  }
  handleMouseMove(e) {
    if (this.isMouseDown) {
      e.preventDefault();
      if (e.type === 'touchmove') {
        this.currentX = e.touches[0].clientX - this.initialX;
        this.currentY = e.touches[0].clientY - this.initialY;
      }
      else {
        this.currentX = e.clientX - this.initialX;
        this.currentY = e.clientY - this.initialY;
      }
      this.xOffset = this.currentX;
      this.yOffset = this.currentY;
      this.setTranslate(this.currentX, this.currentY, this.draggableElement);
    }
  }
  handleMouseUp() {
    this.initialX = this.currentX;
    this.initialY = this.currentY;
    this.draggableElement.style.cursor = 'default';
    this.isMouseDown = false;
  }
  handleClose() {
    this.draggableElement.style.display = 'none';
  }
  setTranslate(xPos, yPos, el) {
    el.style.cursor = 'move';
    el.style.transform = 'translate3d(' + xPos + 'px, ' + yPos + 'px, 0)';
  }
  connectedCallback() {
    this.handleMouseDown = this.handleMouseDown.bind(this);
    this.handleMouseUp = this.handleMouseUp.bind(this);
    this.handleMouseMove = this.handleMouseMove.bind(this);
    this.handleClose = this.handleClose.bind(this);
  }
  componentDidLoad() {
    this.height = this.draggableElement.offsetHeight;
    this.width = this.draggableElement.offsetWidth;
    this.handleContentChanged(this.content);
  }
  render() {
    return (h(Host, null,
      h("div", { ref: el => (this.draggableElement = el), onMouseDown: this.handleMouseDown, onMouseMove: this.handleMouseMove, onMouseUp: this.handleMouseUp, class: "draggable" },
        h("h2", null,
          "Debug Panel ",
          h("small", null, "(you can drag me)"),
          " \u00A0",
          ' ',
          h("button", { onClick: this.handleClose }, "X")),
        h("table", null, Object.keys(this.content).map(key => {
          return (h("tr", null,
            h("td", null,
              h("pre", null, key)),
            h("td", null, this.content[key].map(item => {
              return h("pre", null, item);
            }))));
        })))));
  }
  static get is() { return "pe-debug-panel"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["pe-debug-panel.css"]
  }; }
  static get styleUrls() { return {
    "$": ["pe-debug-panel.css"]
  }; }
  static get properties() { return {
    "content": {
      "type": "any",
      "mutable": true,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Content that will be rendered in debug panel.\nEach key rendered in a new row.\n{ exampleKey: [1,2,3,4] }"
      },
      "attribute": "content",
      "reflect": false
    }
  }; }
  static get states() { return {
    "isMouseDown": {},
    "currentX": {},
    "currentY": {},
    "initialX": {},
    "initialY": {},
    "xOffset": {},
    "yOffset": {},
    "height": {},
    "width": {}
  }; }
  static get watchers() { return [{
      "propName": "content",
      "methodName": "handleContentChanged"
    }]; }
}
