import { Component, Host, h, Element, Prop } from '@stencil/core';
export class PeTypography {
  constructor() {
    /**
     * Tag name to render the typography inside
     */
    this.tag = 'span';
    /**
     * Font type
     */
    this.type = 'body';
    /**
     * Font weight
     */
    this.weight = 'w-normal';
    /**
     * Font Size
     */
    this.size = 'medium';
    /**
     * Letter-spacing
     */
    this.spacing = 'letter-spacing-normal';
  }
  async componentDidRender() {
    const shadowDOM = this.el.shadowRoot;
    const node = document.createElement(this.tag);
    node.classList.add(this.type, this.weight, this.size, this.spacing);
    const slot = document.createElement('slot');
    node.appendChild(slot);
    shadowDOM.append(node);
  }
  render() {
    return h(Host, null);
  }
  static get is() { return "pe-typography"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["pe-typography.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["pe-typography.css"]
  }; }
  static get properties() { return {
    "tag": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "string",
        "resolved": "string",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Tag name to render the typography inside"
      },
      "attribute": "tag",
      "reflect": true,
      "defaultValue": "'span'"
    },
    "type": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "| 'display'\n    | 'headline'\n    | 'title'\n    | 'label'\n    | 'body'",
        "resolved": "\"body\" | \"display\" | \"headline\" | \"label\" | \"title\"",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Font type"
      },
      "attribute": "type",
      "reflect": true,
      "defaultValue": "'body'"
    },
    "weight": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "| 'w-normal'\n    | 'w-medium'\n    | 'w-semibold'",
        "resolved": "\"w-medium\" | \"w-normal\" | \"w-semibold\"",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Font weight"
      },
      "attribute": "weight",
      "reflect": true,
      "defaultValue": "'w-normal'"
    },
    "size": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "'large' | 'medium' | 'small'",
        "resolved": "\"large\" | \"medium\" | \"small\"",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Font Size"
      },
      "attribute": "size",
      "reflect": true,
      "defaultValue": "'medium'"
    },
    "spacing": {
      "type": "string",
      "mutable": true,
      "complexType": {
        "original": "| 'letter-spacing-neg-2'\n    | 'letter-spacing-neg-1'\n    | 'letter-spacing-normal'\n    | 'letter-spacing-1'\n    | 'letter-spacing-2'",
        "resolved": "\"letter-spacing-1\" | \"letter-spacing-2\" | \"letter-spacing-neg-1\" | \"letter-spacing-neg-2\" | \"letter-spacing-normal\"",
        "references": {}
      },
      "required": false,
      "optional": true,
      "docs": {
        "tags": [],
        "text": "Letter-spacing"
      },
      "attribute": "spacing",
      "reflect": true,
      "defaultValue": "'letter-spacing-normal'"
    }
  }; }
  static get elementRef() { return "el"; }
}
