import { Component, Host, Prop, h, Listen, State, Watch } from '@stencil/core';
import axiosInstance, { API } from '../../../config/axios';
export class PeReviewStudio {
  constructor() {
    this.isFullscreen = false;
    /**
     * changing the active Tab
     */
    this.activeTab = 'incident';
    /**
     * incident List content
     */
    this.content = [];
    /**
     * breachDictionaryItems
     */
    this.breachDictionaryItems = [];
  }
  connectedCallback() {
    this.changeTab = this.changeTab.bind(this);
  }
  mobileVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.mobileVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.mobileVideoUris = [];
    }
  }
  screenshareVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.screenshareVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.screenshareVideoUris = [];
    }
  }
  webcamVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.webcamVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.webcamVideoUris = [];
    }
  }
  peVideoFullscreenHandler(event) {
    this.isFullscreen = event.detail;
  }
  changeTab(event) {
    const tabName = event.target.dataset['tab'];
    this.activeTab = tabName;
  }
  setCurrentTime(time) {
    const videos = document
      .querySelector('pe-review-studio')
      .shadowRoot.querySelector('pe-video-player');
    videos.setCurrentTime(time);
  }
  editIncident(id) {
    // to write the logic for editing incident
    console.log(id);
  }
  componentWillLoad() {
    this.mobileVideoUrisChanged(this.mobileVideoUris);
    this.webcamVideoUrisChanged(this.webcamVideoUris);
    this.screenshareVideoUrisChanged(this.screenshareVideoUris);
    const that = this;
    const incidentList = axiosInstance.get(API.incidentList);
    const breachDictionaryItems = axiosInstance.get(API.breachDictionaryItems);
    return Promise.all([incidentList, breachDictionaryItems]).then(values => {
      // this is the final code when we have the final API
      // that.breachDictionaryItems = values[1].data.breachDictionaryItems;
      // that.content = values[0].data.incidents.map(incident => {
      //   return {
      //     ...incident,
      //     breachDictionaryItem: values[1].data.breachDictionaryItems.find(item => item.id === incident.breachDictionaryId)
      //   }
      // })
      // this code to handle fake api as it's not the same as the final strucure as the service is limited
      that.breachDictionaryItems = values[1].data;
      that.content = values[0].data.map(incident => {
        return Object.assign(Object.assign({}, incident), { breachDictionaryItem: values[1].data.find(item => item.id === incident.breachDictionaryId) });
      });
    });
  }
  render() {
    return (h(Host, null,
      h("div", { id: "container" },
        h("div", { id: "navbar" },
          h("pe-navbar", null)),
        h("div", { id: "sidebar" },
          h("button", { "data-tab": "incident", onClick: this.changeTab, class: `sidebar-tab ${this.activeTab == 'incident' ? 'active' : ''}` },
            h("span", null,
              h("pe-icon", { name: "comment" }))),
          h("button", { "data-tab": "info", onClick: this.changeTab, class: `sidebar-tab ${this.activeTab == 'info' ? 'active' : ''}` },
            h("span", null,
              h("pe-icon", { name: "information_outline" }))),
          h("button", { "data-tab": "shortcuts", onClick: this.changeTab, class: `sidebar-tab ${this.activeTab == 'shortcuts' ? 'active' : ''}` },
            h("span", null,
              h("pe-icon", { name: "keyboard_outline" }))),
          h("button", { "data-tab": "help", onClick: this.changeTab, class: `sidebar-tab ${this.activeTab == 'help' ? 'active' : ''}` },
            h("span", null,
              h("pe-icon", { name: "help_outline" })))),
        h("div", { id: "side-panel" },
          this.activeTab == 'incident' && (h("div", null,
            h("pe-incident-list", { incidentList: this.content, handleEdit: this.editIncident, jumptoIncidentTime: this.setCurrentTime }))),
          this.activeTab == 'info' && (h("div", null, "Session Information Component goes here")),
          this.activeTab == 'shortcuts' && h("div", null, "Shortcuts"),
          this.activeTab == 'help' && h("div", null, "Help Component goes here")),
        h("div", { id: "video-player", class: this.isFullscreen ? 'fullscreen' : '' },
          h("pe-video-player", { webcamVideoUris: this.webcamVideoUris, screenshareVideoUris: this.screenshareVideoUris, mobileVideoUris: this.mobileVideoUris })))));
  }
  static get is() { return "pe-review-studio"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() { return {
    "$": ["pe-review-studio.scss"]
  }; }
  static get styleUrls() { return {
    "$": ["pe-review-studio.css"]
  }; }
  static get properties() { return {
    "mobileVideoUris": {
      "type": "any",
      "mutable": true,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Uri(s) for mobile video source(s)."
      },
      "attribute": "mobile-video-uris",
      "reflect": false
    },
    "screenshareVideoUris": {
      "type": "any",
      "mutable": true,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": true,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Uri(s) for screenshare video source(s)."
      },
      "attribute": "screenshare-video-uris",
      "reflect": false
    },
    "webcamVideoUris": {
      "type": "any",
      "mutable": true,
      "complexType": {
        "original": "any",
        "resolved": "any",
        "references": {}
      },
      "required": false,
      "optional": false,
      "docs": {
        "tags": [],
        "text": "Uri(s) for webcam video source(s)."
      },
      "attribute": "webcam-video-uris",
      "reflect": false
    }
  }; }
  static get states() { return {
    "isFullscreen": {},
    "activeTab": {},
    "content": {},
    "breachDictionaryItems": {}
  }; }
  static get watchers() { return [{
      "propName": "mobileVideoUris",
      "methodName": "mobileVideoUrisChanged"
    }, {
      "propName": "screenshareVideoUris",
      "methodName": "screenshareVideoUrisChanged"
    }, {
      "propName": "webcamVideoUris",
      "methodName": "webcamVideoUrisChanged"
    }]; }
  static get listeners() { return [{
      "name": "peVideoFullscreen",
      "method": "peVideoFullscreenHandler",
      "target": undefined,
      "capture": false,
      "passive": false
    }]; }
}
