import { HTMLElement, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
import { d as defineCustomElement$1 } from './pe-icon2.js';

const peButtonCss = ":host{display:-ms-flexbox;display:flex}button{background:transparent;color:#2d2d2d;fill:#2d2d2d;padding:5px 8px;height:32px;border-radius:4px;border:1px solid transparent;cursor:pointer;text-transform:capitalize;font-style:normal;font-weight:600;display:-ms-inline-flexbox;display:inline-flex;-ms-flex-align:center;align-items:center;font-weight:500;font-size:16px;line-height:22px}.outline{background:#fff;color:#1a5059;fill:#1a5059;border-color:#cdcdcd}.filled{background-color:#f3f3f3;border-color:#cdcdcd}.filled.action{background:#1a5059;border-color:#1a5059;color:#fff;fill:#fff}.filled.primary{color:#2d2d2d;fill:#2d2d2d}.filled.player{background:#0095ff;border-color:#0095ff;fill:#fff}.filled.action:hover,.filled.action.hover{background:#003c46;border-color:#003c46}.outline.action:hover,.outline.action.hover{background:#e5e5e5;border-color:#cdcdcd}.filled.primary:hover,.filled.primary.hover{background:#e5e5e5;border-color:#cdcdcd}.filled.player:hover,.filled.player.hover{background:#0095ff;border-color:#0095ff}.ghost:hover,.ghost.hover{background:#e5e5e5;border-color:#e5e5e5}.filled.action:active,.filled.action.active{background:#1a5059;border-color:#1a5059}.outline.action:active,.outline.action.active{background:#e5ebec;border-color:#cdcdcd}.filled.primary:active,.filled.primary.active{background:#e5ebec;border-color:#cdcdcd}.filled.player:active,.filled.player.active{background:#1a5059;border-color:#1a5059}.ghost:active,.ghost.active{background:#e5ebec;border-color:#e5ebec}button:focus,button.focus{outline:3px solid #0096ff;outline-offset:2px}.filled.action:focus,.filled.action.focus{background:#003c46;border-color:#003c46}.outline.action:focus,.outline.action.focus,.outline.primary:focus,.outline.primary.focus{background:#e5e5e5;border-color:#cdcdcd}.ghost:focus,.ghost.focus{background:#e5e5e5;border-color:#e5e5e5}button:disabled,.filled:disabled{background:#e5e5e5;pointer-events:none;color:#aeaeae;fill:#aeaeae;border-color:#e5e5e5}pe-icon{fill:inherit;width:18px;height:18px;margin-right:8px}pe-icon.icon-only{margin-right:0}.circle{width:34px;height:34px;border-radius:50%;padding:0px;display:-ms-inline-flexbox;display:inline-flex;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;align-items:center}button.large::part(icon){width:24px;height:24px}button.circle pe-icon{width:24px;height:24px;margin-right:0}button.circle::part(icon),.large{padding:8px 12px;height:40px}button.large::part(icon){width:24px;height:24px}button:disabled{background:#e5e5e5;pointer-events:none;color:#aeaeae;fill:#aeaeae;border-color:#e5e5e5}";

let PeButton = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /**
     * enable/disable a button
     */
    this.disabled = false;
    /**
     * pass this if empty button to show button in best style shape
     */
    this.iconOnly = false;
    /**
     * changing the look to a button
     */
    this.circled = false;
    /**
     * varients
     */
    this.variant = 'ghost';
    /**
     * colors
     */
    this.color = 'basic';
    /**
     * size
     */
    this.size = 'normal';
  }
  iconNameChanged(newIconName) {
    this.iconState = newIconName;
  }
  componentWillLoad() {
    this.iconState = this.iconName;
  }
  render() {
    return (h(Host, null, h("button", { class: `${this.variant || 'ghost'} ${this.size} ${this.color} ${this.circled ? 'circle' : ''} ${this.class || ''}`, disabled: this.disabled }, this.iconState && (h("pe-icon", { class: `${this.iconOnly && 'icon-only'}`, name: this.iconState })), !this.iconOnly && (this.text || h("slot", null)))));
  }
  static get watchers() { return {
    "iconName": ["iconNameChanged"]
  }; }
  static get style() { return peButtonCss; }
};
PeButton = /*@__PURE__*/ proxyCustomElement(PeButton, [1, "pe-button", {
    "disabled": [1540],
    "iconOnly": [1540, "icon-only"],
    "circled": [1540],
    "variant": [1537],
    "color": [1537],
    "size": [1537],
    "class": [1537],
    "text": [1537],
    "iconName": [1537, "icon-name"],
    "iconState": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["pe-button", "pe-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "pe-button":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, PeButton);
      }
      break;
    case "pe-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}
defineCustomElement();

export { PeButton as P, defineCustomElement as d };
