import { HTMLElement, h, Host, proxyCustomElement } from '@stencil/core/internal/client';

const peDebugPanelCss = ":host{display:block}.draggable{position:absolute;left:0;top:0;z-index:9999999;background-color:#fff;border:2px solid #000;padding:5px}table,th,td{border:1px solid #000}";

let PeDebugPanel = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.xOffset = 0;
    this.yOffset = 0;
  }
  handleContentChanged(newValue) {
    if (typeof newValue == 'string') {
      this.content = JSON.parse(newValue);
    }
    else {
      this.content = newValue;
    }
  }
  handleMouseDown(e) {
    if (e.type === 'touchstart') {
      this.initialX = e.touches[0].clientX - this.xOffset;
      this.initialY = e.touches[0].clientY - this.yOffset;
    }
    else {
      this.initialX = e.clientX - this.xOffset;
      this.initialY = e.clientY - this.yOffset;
    }
    this.isMouseDown = true;
  }
  handleMouseMove(e) {
    if (this.isMouseDown) {
      e.preventDefault();
      if (e.type === 'touchmove') {
        this.currentX = e.touches[0].clientX - this.initialX;
        this.currentY = e.touches[0].clientY - this.initialY;
      }
      else {
        this.currentX = e.clientX - this.initialX;
        this.currentY = e.clientY - this.initialY;
      }
      this.xOffset = this.currentX;
      this.yOffset = this.currentY;
      this.setTranslate(this.currentX, this.currentY, this.draggableElement);
    }
  }
  handleMouseUp() {
    this.initialX = this.currentX;
    this.initialY = this.currentY;
    this.draggableElement.style.cursor = 'default';
    this.isMouseDown = false;
  }
  handleClose() {
    this.draggableElement.style.display = 'none';
  }
  setTranslate(xPos, yPos, el) {
    el.style.cursor = 'move';
    el.style.transform = 'translate3d(' + xPos + 'px, ' + yPos + 'px, 0)';
  }
  connectedCallback() {
    this.handleMouseDown = this.handleMouseDown.bind(this);
    this.handleMouseUp = this.handleMouseUp.bind(this);
    this.handleMouseMove = this.handleMouseMove.bind(this);
    this.handleClose = this.handleClose.bind(this);
  }
  componentDidLoad() {
    this.height = this.draggableElement.offsetHeight;
    this.width = this.draggableElement.offsetWidth;
    this.handleContentChanged(this.content);
  }
  render() {
    return (h(Host, null, h("div", { ref: el => (this.draggableElement = el), onMouseDown: this.handleMouseDown, onMouseMove: this.handleMouseMove, onMouseUp: this.handleMouseUp, class: "draggable" }, h("h2", null, "Debug Panel ", h("small", null, "(you can drag me)"), " \u00A0", ' ', h("button", { onClick: this.handleClose }, "X")), h("table", null, Object.keys(this.content).map(key => {
      return (h("tr", null, h("td", null, h("pre", null, key)), h("td", null, this.content[key].map(item => {
        return h("pre", null, item);
      }))));
    })))));
  }
  static get watchers() { return {
    "content": ["handleContentChanged"]
  }; }
  static get style() { return peDebugPanelCss; }
};
PeDebugPanel = /*@__PURE__*/ proxyCustomElement(PeDebugPanel, [1, "pe-debug-panel", {
    "content": [1032],
    "isMouseDown": [32],
    "currentX": [32],
    "currentY": [32],
    "initialX": [32],
    "initialY": [32],
    "xOffset": [32],
    "yOffset": [32],
    "height": [32],
    "width": [32]
  }]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["pe-debug-panel"];
  components.forEach(tagName => { switch (tagName) {
    case "pe-debug-panel":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, PeDebugPanel);
      }
      break;
  } });
}
defineCustomElement();

export { PeDebugPanel as P, defineCustomElement as d };
