import { HTMLElement, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
import { d as defineCustomElement$2 } from './pe-icon2.js';

const iconsList = [
  'accessible',
  'drag_handle',
  'perspn',
  'account-outline',
  'edit-outline',
  'plagiarism-outline',
  'account',
  'edit',
  'plagiarism',
  'add',
  'email-outline',
  'play',
  'add_circle-outline',
  'email',
  'preview',
  'add_circle',
  'error-outline',
  'print-outline',
  'alarm-outline',
  'error',
  'print',
  'alarm',
  'expand',
  'push_pin-outline',
  'analytics-outline',
  'export',
  'push_pin',
  'analytics',
  'filter-outline',
  'radio_selected',
  'apps',
  'filter',
  'radio_unselected',
  'archive-outline',
  'flag-outline',
  'redo',
  'archive',
  'flag',
  'refresh',
  'arrow_back',
  'folder_shared-outline',
  'remove',
  'arrow_down',
  'folder_shared',
  'remove_circle-outline',
  'arrow_drop_down',
  'foldor-outline',
  'remove_circle',
  'arrow_drop_up',
  'foldor',
  'reorder',
  'arrow_forward',
  'format_align_center',
  'rewindX10',
  'arrow_left',
  'format_align_left',
  'save-outline',
  'arrow_right',
  'format_align_right',
  'save',
  'arrow_up',
  'format_bold',
  'schedule-outline',
  'attach_file',
  'format_italic',
  'schedule',
  'attachment',
  'format_quote',
  'school-outline',
  'auto_awesome-outline',
  'forwardX10',
  'school',
  'auto_awesome',
  'fullscreen',
  'search',
  'auto_fix-outline',
  'fullscreenExit',
  'settings-outline',
  'auto_fix',
  'functions',
  'settings',
  'bar_graph',
  'group-outline',
  'share-outline',
  'block',
  'group',
  'share',
  'bolt',
  'groups-outline',
  'smartphone',
  'bookmark-outline',
  'groups',
  'sort_ascending',
  'bookmark',
  'headphones-outline',
  'sort_descending',
  'business-outline',
  'headphones',
  'speedX1',
  'business',
  'heart-outline',
  'speedX2',
  'calculate-outline',
  'comment',
  'heart',
  'speedX3',
  'calculate',
  'help-outline',
  'speedX4',
  'calender-outline',
  'help',
  'speedX5',
  'calender',
  'history',
  'speedX6',
  'camera-outline',
  'home-outline',
  'speedX7',
  'camera',
  'home',
  'speedX8',
  'chat-outline',
  'hourglass-outline',
  'star-outline',
  'chat',
  'hourglass',
  'star',
  'check',
  'image-outline',
  'success-outline',
  'checkbox_indeterminate',
  'image',
  'success',
  'checkbox_selected',
  'import',
  'support',
  'checkbox_unselected',
  'information-outline',
  'swap_horizontal',
  'chevron_down',
  'information',
  'swap_vertical',
  'chevron_left',
  'insights',
  'sync',
  'chevron_right',
  'keyboard-outline',
  'table_chart-outline',
  'chevron_up',
  'keyboard',
  'table_chart',
  'clear-outline',
  'label-outline',
  'tag',
  'clear',
  'label',
  'thumbs_down-outline',
  'close',
  'language',
  'thumbs_down',
  'cloud-outline',
  'laptop_computer',
  'thumbs_up-outline',
  'cloud',
  'light_mode-outline',
  'thumbs_up',
  'cloud_done-outline',
  'light_mode',
  'translate',
  'cloud_done',
  'link',
  'trophy-outline',
  'cloud_download-outline',
  'link_add',
  'trophy',
  'cloud_download',
  'list',
  'unarchive-outline',
  'cloud_upload-outline',
  'location-outline',
  'unarchive',
  'cloud_upload',
  'location',
  'undo',
  'code',
  'lock-outline',
  'upload',
  'collapse',
  'lock',
  'visibility-outline',
  'column-outline',
  'lock_clock-outline',
  'visibility',
  'column',
  'lock_clock',
  'visibility_off-outline',
  'copy-outline',
  'lock_open-outline',
  'visibility_off',
  'copy',
  'lock_open',
  'volumeOff',
  'dark_mode-outline',
  'logout',
  'volumeUp',
  'dark_mode',
  'menu',
  'warning-outline',
  'dashboard-outline',
  'microphone-outline',
  'warning',
  'dashboard',
  'microphone',
  'wifi',
  'delete-outline',
  'more',
  'wifi_locked',
  'delete',
  'notes',
  'wifi_off',
  'desktop_computer',
  'notification-outline',
  'work-outline',
  'document-outline',
  'notification',
  'work',
  'document',
  'open_new_window',
  'zoom-in',
  'download',
  'pause',
  'zoom-out',
  'drag-indicator',
  'person-outline',
];

const peIconsListCss = ":host{display:block}.iconContainer{float:left;width:150px;height:150px;margin:5px;display:-ms-flexbox;display:flex;border:1px dashed #ccc;-ms-flex-direction:column;flex-direction:column;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;align-items:center;row-gap:10px}.iconContainer .icon{width:32px;height:32px;fill:#333}.iconContainer code{background:#edebeb;border:1px solid #ccc;padding:3px 5px;font-size:12px;white-space:nowrap;border-radius:3px}";

let PeIconsList$1 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
  }
  render() {
    const sortedIcons = iconsList.sort((a, b) => a !== b ? (a < b ? -1 : 1) : 0);
    return (h(Host, null, sortedIcons.map(iconName => (h("div", { class: "iconContainer" }, h("pe-icon", { class: "icon", name: iconName }), h("code", null, iconName, " "))))));
  }
  static get style() { return peIconsListCss; }
};
PeIconsList$1 = /*@__PURE__*/ proxyCustomElement(PeIconsList$1, [1, "pe-icons-list"]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["pe-icons-list", "pe-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "pe-icons-list":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, PeIconsList$1);
      }
      break;
    case "pe-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
  } });
}
defineCustomElement$1();

const PeIconsList = PeIconsList$1;
const defineCustomElement = defineCustomElement$1;

export { PeIconsList, defineCustomElement };
