import { HTMLElement, h, Host, proxyCustomElement } from '@stencil/core/internal/client';

const peTypographyCss = ":host{display:block}.display,.headline{font-family:\"Lexend Deca\", sans-serif;line-height:1.3}.title,label,.body{font-family:\"Noto Sans\", sans-serif;line-height:1.5}.w-normal{font-weight:400}.w-medium{font-weight:500}.w-semibold{font-weight:600}.display.large{font-size:56px}.display.medium{font-size:48px}.display.small{font-size:40px}.headline.large{font-size:34px}.headline.medium{font-size:28px}.headline.small{font-size:24px}.title.large{font-size:20px}.title.medium{font-size:18px}.title.small{font-size:16px}label.large{font-size:16px}label.medium{font-size:14px}label.small{font-size:12px}.body.large,.code.large{font-size:16px}.body.medium,.code.medium{font-size:14px}.body.small,.code.small{font-size:12px}.letter-spacing-neg-2{letter-spacing:-1px}.letter-spacing-neg-1{letter-spacing:-0.5px}.letter-spacing-normal{letter-spacing:0}.letter-spacing-1{letter-spacing:0.15px}.letter-spacing-2{letter-spacing:0.25px}";

let PeTypography$1 = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    /**
     * Tag name to render the typography inside
     */
    this.tag = 'span';
    /**
     * Font type
     */
    this.type = 'body';
    /**
     * Font weight
     */
    this.weight = 'w-normal';
    /**
     * Font Size
     */
    this.size = 'medium';
    /**
     * Letter-spacing
     */
    this.spacing = 'letter-spacing-normal';
  }
  async componentDidRender() {
    const shadowDOM = this.el.shadowRoot;
    const node = document.createElement(this.tag);
    node.classList.add(this.type, this.weight, this.size, this.spacing);
    const slot = document.createElement('slot');
    node.appendChild(slot);
    shadowDOM.append(node);
  }
  render() {
    return h(Host, null);
  }
  get el() { return this; }
  static get style() { return peTypographyCss; }
};
PeTypography$1 = /*@__PURE__*/ proxyCustomElement(PeTypography$1, [1, "pe-typography", {
    "tag": [1537],
    "type": [1537],
    "weight": [1537],
    "size": [1537],
    "spacing": [1537]
  }]);
function defineCustomElement$1() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["pe-typography"];
  components.forEach(tagName => { switch (tagName) {
    case "pe-typography":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, PeTypography$1);
      }
      break;
  } });
}
defineCustomElement$1();

const PeTypography = PeTypography$1;
const defineCustomElement = defineCustomElement$1;

export { PeTypography, defineCustomElement };
