import { HTMLElement, createEvent, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
import { s as secondsToHours } from './utils.js';
import { d as defineCustomElement$2 } from './pe-button2.js';
import { d as defineCustomElement$1 } from './pe-icon2.js';

const peVideoControlsCss = ":host{display:block;background-color:white;}#controls-container{display:-ms-flexbox;display:flex;-ms-flex:1;flex:1;-ms-flex-pack:justify;justify-content:space-between}#progress-container progress{width:100%}#progress-container input{width:100%}#time-container{display:-ms-flexbox;display:flex;-ms-flex:1;flex:1;-ms-flex-pack:justify;justify-content:space-between}div#controls-container{margin-top:20px;margin-bottom:15px}div#time-container{margin-top:5px}span.btn-group{display:-ms-inline-flexbox;display:inline-flex;-webkit-column-gap:10px;-moz-column-gap:10px;column-gap:10px}input[type=range]{height:4px;-webkit-appearance:none}input[type=range]{--range:calc(var(--max) - var(--min));--ratio:calc((var(--value) - var(--min)) / var(--range));--sx:calc(0.5 * 14px + var(--ratio) * (100% - 14px))}input[type=range]:focus{outline:none}input[type=range]::-webkit-slider-thumb{-webkit-appearance:none;width:14px;height:14px;border-radius:1000px;background:#fff;border:4px solid #0095ff;-webkit-box-shadow:0 0 2px black;box-shadow:0 0 2px black;margin-top:-5px}input[type=range]::-webkit-slider-runnable-track{height:4px;border:none;border-radius:0;background:#e5e5e5;-webkit-box-shadow:none;box-shadow:none}input[type=range]::-webkit-slider-thumb:hover{background:#fff}input[type=range]:hover::-webkit-slider-runnable-track{background:#e5e5e5}input[type=range]::-webkit-slider-thumb:active{background:#fff}input[type=range]:active::-webkit-slider-runnable-track{background:#e5e5e5}input[type=range]::-webkit-slider-runnable-track{background:-webkit-gradient(linear, left top, left bottom, from(#0095ff), to(#0095ff)) 0/var(--sx) 100% no-repeat, #e5e5e5;background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]:hover::-webkit-slider-runnable-track{background:-webkit-gradient(linear, left top, left bottom, from(#0095ff), to(#0095ff)) 0/var(--sx) 100% no-repeat, #e5e5e5;background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]:active::-webkit-slider-runnable-track{background:-webkit-gradient(linear, left top, left bottom, from(#0095ff), to(#0095ff)) 0/var(--sx) 100% no-repeat, #e5e5e5;background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]::-moz-range-thumb{width:6px;height:6px;border-radius:1000px;background:#fff;border:4px solid #0095ff;box-shadow:0 0 2px black}input[type=range]::-moz-range-track{height:4px;border:none;border-radius:0;background:#e5e5e5;box-shadow:none}input[type=range]::-moz-range-thumb:hover{background:#fff}input[type=range]:hover::-moz-range-track{background:#e5e5e5}input[type=range]::-moz-range-thumb:active{background:#fff}input[type=range]:active::-moz-range-track{background:#e5e5e5}input[type=range]::-moz-range-track{background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]:hover::-moz-range-track{background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]:active::-moz-range-track{background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]::-ms-fill-upper{background:transparent;border-color:transparent}input[type=range]::-ms-fill-lower{background:transparent;border-color:transparent}input[type=range]::-ms-thumb{width:14px;height:14px;border-radius:1000px;background:#fff;border:4px solid #0095ff;box-shadow:0 0 2px black;margin-top:0;box-sizing:border-box}input[type=range]::-ms-track{height:4px;border-radius:0;background:#e5e5e5;border:none;box-shadow:none;box-sizing:border-box}input[type=range]::-ms-thumb:hover{background:#fff}input[type=range]:hover::-ms-track{background:#e5e5e5}input[type=range]::-ms-thumb:active{background:#fff}input[type=range]:active::-ms-track{background:#e5e5e5}input[type=range]::-ms-fill-lower{height:4px;border-radius:0px 0 0 0px;margin:-undefined 0 -undefined -undefined;background:#0095ff;border:none;border-right-width:0}input[type=range]:hover::-ms-fill-lower{background:#0095ff}input[type=range]:active::-ms-fill-lower{background:#0095ff}";

let PeVideoControls = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.peVideoPlay = createEvent(this, "peVideoPlay", 7);
    this.peVideoRewind = createEvent(this, "peVideoRewind", 7);
    this.peVideoSpeed = createEvent(this, "peVideoSpeed", 7);
    this.peVideoMute = createEvent(this, "peVideoMute", 7);
    this.peVideoSeek = createEvent(this, "peVideoSeek", 7);
    this.peVideoFullscreen = createEvent(this, "peVideoFullscreen", 7);
    this.speedIndex = 0;
    this.isMuted = false;
    this.isPlaying = false;
    /**
     * Determines current value of fullscreen toggle.
     */
    this.isFullscreen = false;
    /**
     * Determines current time of progress bar.
     */
    this.currentTime = 0.0;
    /**
     * Determines total duration of progress bar.
     */
    this.totalDuration = 0.0;
    /**
     * Determines available playback speeds.
     */
    this.availableSpeeds = [1, 2, 4, 6];
  }
  connectedCallback() {
    this.handleClickPlay = this.handleClickPlay.bind(this);
    this.handleClickRewind = this.handleClickRewind.bind(this);
    this.handleClickSpeed = this.handleClickSpeed.bind(this);
    this.handleInputSeek = this.handleInputSeek.bind(this);
    this.handleClickFullscreen = this.handleClickFullscreen.bind(this);
    this.handleClickMute = this.handleClickMute.bind(this);
  }
  currentTimeChanged() {
    this.updateInputStyle();
  }
  totalDurationChanged() {
    this.updateInputStyle();
  }
  availableSpeedsChanged(newAvailableSpeeds) {
    if (typeof newAvailableSpeeds === 'string') {
      this.availableSpeeds = JSON.parse(newAvailableSpeeds);
    }
    else if (newAvailableSpeeds === null ||
      newAvailableSpeeds === undefined) {
      this.availableSpeeds = [1, 2, 4, 6];
    }
    else {
      this.availableSpeeds = newAvailableSpeeds;
    }
  }
  peVideoPlayHandler(isPlaying) {
    this.peVideoPlay.emit(isPlaying);
  }
  peVideoRewindHandler(time) {
    this.peVideoRewind.emit(time);
  }
  peVideoSpeedHandler(speed) {
    this.peVideoSpeed.emit(speed);
  }
  peVideoMuteHandler(isMuted) {
    this.peVideoMute.emit(isMuted);
  }
  peVideoSeekHandler(time) {
    this.peVideoSeek.emit(time);
  }
  peVideoFullscreenHandler(isFullscreen) {
    this.peVideoFullscreen.emit(isFullscreen);
  }
  fullscreenchangeHandler() {
    if (document.fullscreenElement == null) {
      this.peVideoFullscreen.emit(false);
    }
  }
  // Click handlers
  handleClickMute() {
    this.isMuted = !this.isMuted;
    this.peVideoMuteHandler(this.isMuted);
  }
  handleClickRewind(event) {
    const time = event.target.dataset['time'];
    this.peVideoRewindHandler(+time);
  }
  handleClickPlay() {
    this.isPlaying = !this.isPlaying;
    this.peVideoPlayHandler(this.isPlaying);
  }
  handleClickFullscreen() {
    this.peVideoFullscreenHandler(!this.isFullscreen);
  }
  handleClickSpeed() {
    this.speedIndex = (this.speedIndex + 1) % this.availableSpeeds.length;
    this.peVideoSpeedHandler(this.availableSpeeds[this.speedIndex]);
  }
  // Input handlers
  handleInputSeek(event) {
    const time = event.target.value;
    this.peVideoSeekHandler(time);
  }
  updateInputStyle() {
    // to style progress of range input
    if (this.totalDuration !== 0.0) {
      this.inputElement.style.setProperty('--value', this.inputElement.value);
      this.inputElement.style.setProperty('--max', ['', '0'].includes(this.inputElement.max)
        ? '100'
        : this.inputElement.max);
      this.inputElement.style.setProperty('--min', this.inputElement.min == '' ? '0' : this.inputElement.min);
      this.inputElement.addEventListener('input', () => this.inputElement.style.setProperty('--value', this.inputElement.value));
    }
  }
  componentWillLoad() {
    this.availableSpeedsChanged(this.availableSpeeds);
  }
  componentDidLoad() {
    this.updateInputStyle();
  }
  componentDidUpdate() {
    this.updateInputStyle();
  }
  render() {
    return (h(Host, null, h("div", { id: "controls-container" }, h("span", null, h("pe-button", { id: "mute-btn", iconName: this.isMuted ? 'volumeOff' : 'volumeUp', color: "primary", variant: "filled", circled: true, iconOnly: true, onClick: this.handleClickMute })), h("span", { class: "btn-group" }, h("pe-button", { id: "rewind-btn", iconName: "rewindX15", color: "primary", variant: "filled", circled: true, iconOnly: true, "data-time": -15, onClick: this.handleClickRewind }), h("pe-button", { id: "play-btn", iconName: this.isPlaying ? 'pause' : 'play', color: "player", variant: "filled", circled: true, iconOnly: true, onClick: this.handleClickPlay }), h("pe-button", { id: "forward-btn", iconName: "forwardX15", color: "primary", variant: "filled", circled: true, iconOnly: true, "data-time": 15, onClick: this.handleClickRewind }), h("pe-button", { id: "speed-btn", iconName: `speedX${this.availableSpeeds[this.speedIndex].toString()}`, color: "primary", variant: "filled", circled: true, iconOnly: true, onClick: this.handleClickSpeed })), h("span", null, h("pe-button", { id: "fullscreen-btn", iconName: this.isFullscreen ? 'fullscreenExit' : 'fullscreen', color: "primary", variant: "filled", circled: true, iconOnly: true, onClick: this.handleClickFullscreen }))), h("div", { id: "progress-container" }, h("input", { ref: el => (this.inputElement = el), onInput: this.handleInputSeek, type: "range", max: this.totalDuration, value: this.currentTime })), h("div", { id: "time-container" }, h("span", { id: "current-time-text" }, secondsToHours(this.currentTime)), h("span", { id: "total-duration-text" }, secondsToHours(this.totalDuration)))));
  }
  static get watchers() { return {
    "currentTime": ["currentTimeChanged"],
    "totalDuration": ["totalDurationChanged"],
    "availableSpeeds": ["availableSpeedsChanged"]
  }; }
  static get style() { return peVideoControlsCss; }
};
PeVideoControls = /*@__PURE__*/ proxyCustomElement(PeVideoControls, [1, "pe-video-controls", {
    "isFullscreen": [1028, "is-fullscreen"],
    "currentTime": [1026, "current-time"],
    "totalDuration": [1026, "total-duration"],
    "availableSpeeds": [1040],
    "speedIndex": [32],
    "isMuted": [32],
    "isPlaying": [32]
  }, [[8, "fullscreenchange", "fullscreenchangeHandler"]]]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["pe-video-controls", "pe-button", "pe-icon"];
  components.forEach(tagName => { switch (tagName) {
    case "pe-video-controls":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, PeVideoControls);
      }
      break;
    case "pe-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "pe-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}
defineCustomElement();

export { PeVideoControls as P, defineCustomElement as d };
