import { HTMLElement, h, Host, proxyCustomElement } from '@stencil/core/internal/client';
import { d as defineCustomElement$5 } from './pe-button2.js';
import { d as defineCustomElement$4 } from './pe-debug-panel2.js';
import { d as defineCustomElement$3 } from './pe-icon2.js';
import { d as defineCustomElement$2 } from './pe-video2.js';
import { d as defineCustomElement$1 } from './pe-video-controls2.js';

const peVideoPlayerCss = ":host{display:block;background-color:white;padding:10px}:host(.loading){-webkit-filter:blur(10px);filter:blur(10px);pointer-events:none}div#video-container pe-video{-webkit-animation:bottom-to-top 0.2s;animation:bottom-to-top 0.2s}div#small-video-container pe-video{-webkit-animation:top-to-bottom 0.2s;animation:top-to-bottom 0.2s}@-webkit-keyframes bottom-to-top{from{-webkit-transform:translateY(10%);transform:translateY(10%)}}@keyframes bottom-to-top{from{-webkit-transform:translateY(10%);transform:translateY(10%)}}@-webkit-keyframes top-to-bottom{from{-webkit-transform:translateY(-10%);transform:translateY(-10%)}}@keyframes top-to-bottom{from{-webkit-transform:translateY(-10%);transform:translateY(-10%)}}#video-container{display:-ms-flexbox;display:flex;-ms-flex-direction:row;flex-direction:row;-ms-flex-wrap:wrap;flex-wrap:wrap;gap:12px}#small-video-container{display:-ms-flexbox;display:flex;-ms-flex-direction:row;flex-direction:row;gap:12px}#video-container>pe-video:nth-of-type(1){width:100%}#small-video-container>pe-video:nth-of-type(1){width:35%}#small-video-container>pe-video:nth-of-type(2){width:35%}.fullscreen #small-video-container{-ms-flex:1;flex:1;display:-ms-flexbox;display:flex;-ms-flex-direction:column;flex-direction:column}.fullscreen #video-container>pe-video:nth-of-type(1){width:80%}.fullscreen #small-video-container>pe-video:nth-of-type(1){width:100%;height:25%}.fullscreen #small-video-container>pe-video:nth-of-type(2){width:100%;height:25%}.fullscreen div#video-container pe-video{-webkit-animation:left-to-right 0.2s;animation:left-to-right 0.2s}.fullscreen div#small-video-container pe-video{-webkit-animation:right-to-left 0.2s;animation:right-to-left 0.2s}@-webkit-keyframes left-to-right{from{-webkit-transform:translateX(10%);transform:translateX(10%)}}@keyframes left-to-right{from{-webkit-transform:translateX(10%);transform:translateX(10%)}}@-webkit-keyframes right-to-left{from{-webkit-transform:translateX(-10%);transform:translateX(-10%)}}@keyframes right-to-left{from{-webkit-transform:translateX(-10%);transform:translateX(-10%)}}";

let PeVideoPlayer = class extends HTMLElement {
  constructor() {
    super();
    this.__registerHost();
    this.__attachShadow();
    this.videoElements = [];
    this.debugEnabled = false;
    this.isPreparing = true;
    this.eventSourceStream = '';
    this.isPlaying = false;
    this.isBusy = true;
    this.isMuted = false;
    this.isFullscreen = false;
    this.canMobileVideoPlayThrough = false;
    this.canScreenshareVideoPlayThrough = false;
    this.canWebcamVideoPlayThrough = false;
    this.playbackRate = 1.0;
    this.currentTime = 0.0;
    this.totalDuration = 0.0;
    this.videoDurations = {};
    this.mobileVideoIndex = 0;
    this.screenshareVideoIndex = 0;
    this.webcamVideoIndex = 0;
    this.mobileVideoDurations = [];
    this.screenshareVideoDurations = [];
    this.webcamVideoDurations = [];
    this.mobileVideoStartTimes = [];
    this.screenshareVideoStartTimes = [];
    this.webcamVideoStartTimes = [];
    this.determineVideoDuration = uri => new Promise((resolve, reject) => {
      try {
        let video = document.createElement('video');
        video.src = uri;
        video.preload = 'metadata';
        video.onloadedmetadata = () => {
          resolve(video.duration);
        };
      }
      catch (e) {
        reject(e);
      }
    });
  }
  mobileVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.mobileVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.mobileVideoUris = [];
    }
    this.calculateVideoDurations(this.mobileVideoUris);
  }
  screenshareVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.screenshareVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.screenshareVideoUris = [];
    }
    this.calculateVideoDurations(this.screenshareVideoUris);
  }
  webcamVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.webcamVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.webcamVideoUris = [];
    }
    this.calculateVideoDurations(this.webcamVideoUris);
  }
  peVideoOnWaitingHandler(event) {
    var _a, _b;
    const id = (_b = (_a = event === null || event === void 0 ? void 0 : event.detail) === null || _a === void 0 ? void 0 : _a.target) === null || _b === void 0 ? void 0 : _b.id;
    switch (id) {
      case 'mobile-video':
        this.canMobileVideoPlayThrough = false;
        break;
      case 'screenshare-video':
        this.canScreenshareVideoPlayThrough = false;
        break;
      case 'webcam-video':
        this.canWebcamVideoPlayThrough = false;
        break;
      default:
        console.error('Unknown onWaiting event.');
        break;
    }
    this.determineIsBusy();
  }
  peVideoSourceChangedHandler() {
    this.setCurrentTimeForEachStream();
  }
  peVideoCanPlayThroughHandler(event) {
    var _a, _b;
    const id = (_b = (_a = event === null || event === void 0 ? void 0 : event.detail) === null || _a === void 0 ? void 0 : _a.target) === null || _b === void 0 ? void 0 : _b.id;
    switch (id) {
      case 'mobile-video':
        this.canMobileVideoPlayThrough = true;
        break;
      case 'screenshare-video':
        this.canScreenshareVideoPlayThrough = true;
        break;
      case 'webcam-video':
        this.canWebcamVideoPlayThrough = true;
        break;
      default:
        console.error('Unknown canPlayThrough event.');
        break;
    }
    this.determineIsBusy();
  }
  peVideoPlayHandler(event) {
    this.isPlaying = event.detail;
  }
  peVideoRewindHandler(event) {
    const timeToRewind = event.detail;
    const time = this.currentTime + timeToRewind < 0 ? 0 : this.currentTime + timeToRewind;
    this.setCurrentTime(time);
  }
  peVideoMuteHandler() {
    this.isMuted = !this.isMuted;
  }
  peVideoSpeedHandler(event) {
    const playbackRate = event.detail;
    this.playbackRate = playbackRate;
  }
  peVideoEndedHandler(event) {
    const id = event.detail.target.id;
    switch (id) {
      case 'mobile-video':
        if (this.mobileVideoUris[this.mobileVideoIndex + 1] !== undefined)
          this.mobileVideoIndex = this.mobileVideoIndex + 1;
        break;
      case 'screenshare-video':
        if (this.screenshareVideoUris[this.screenshareVideoIndex + 1] !==
          undefined)
          this.screenshareVideoIndex = this.screenshareVideoIndex + 1;
        break;
      case 'webcam-video':
        if (this.webcamVideoUris[this.webcamVideoIndex + 1] !== undefined)
          this.webcamVideoIndex = this.webcamVideoIndex + 1;
        break;
      default:
        console.error('Unknown peVideoEnded event.');
        break;
    }
  }
  peVideoTimeUpdateHandler(event) {
    const time = event.detail.target.currentTime || 0;
    if (time < 0.01) {
      return;
    } // magic :(
    let calculatedCurrentTime;
    switch (this.eventSourceStream) {
      case 'mobile':
        calculatedCurrentTime =
          this.mobileVideoIndex > 0
            ? this.mobileVideoStartTimes[this.mobileVideoIndex] + time
            : time;
        break;
      case 'webcam':
        calculatedCurrentTime =
          this.webcamVideoIndex > 0
            ? this.webcamVideoStartTimes[this.webcamVideoIndex] + time
            : time;
        break;
      case 'screenshare':
        calculatedCurrentTime =
          this.screenshareVideoIndex > 0
            ? this.screenshareVideoStartTimes[this.screenshareVideoIndex] + time
            : time;
        break;
    }
    this.currentTime = calculatedCurrentTime;
  }
  peVideoLoadedDataHandler() {
    this.setCurrentTimeForEachStream();
  }
  peVideoSeekHandler(event) {
    const time = event.detail;
    this.setCurrentTime(time);
  }
  peVideoFullscreenHandler(event) {
    this.isFullscreen = event.detail;
    if (this.isFullscreen == true && document.fullscreenElement == null) {
      this.videoPlayerElement.requestFullscreen();
    }
    else if (this.isFullscreen == false &&
      document.fullscreenElement != null) {
      document.exitFullscreen();
    }
  }
  /**
   * Moves clicked video to highlighted area.
   * Nothing happens if clicked on already highlighted video.
   */
  peVideoClickHandler(event) {
    const videoElement = event.detail.target;
    if (videoElement === this.highlightedVideo)
      return;
    const previouslyHighlightedVideo = this.highlightedVideo;
    this.highlightedVideo = videoElement;
    const indexOfSelected = Array.from(videoElement.parentElement.children).indexOf(videoElement);
    previouslyHighlightedVideo.after(videoElement);
    if (indexOfSelected == 0) {
      this.smallVideoContainer.insertAdjacentElement('afterbegin', previouslyHighlightedVideo);
    }
    else {
      this.smallVideoContainer.insertAdjacentElement('beforeend', previouslyHighlightedVideo);
    }
    this.handleBoxSizeChanges({
      inlineSize: this.videoPlayerElement.parentElement.clientWidth,
      blockSize: this.videoPlayerElement.parentElement.clientHeight,
    });
  }
  /**
   * @param time
   */
  async setCurrentTime(time) {
    const wasPlaying = this.isPlaying;
    // Stopping player first
    this.isPlaying = false;
    // Setting current time
    this.currentTime = time;
    // Calculate current time for each stream
    this.setCurrentTimeForEachStream();
    // Playing video again after seek finished
    // only if it was already playing
    if (wasPlaying)
      this.isPlaying = true;
  }
  /**
   * Returns current time from seekbar
   */
  async getCurrentTime() {
    return this.currentTime;
  }
  async setCurrentTimeForEachStream() {
    if (this.mobileVideoStartTimes.length === 0 &&
      this.webcamVideoStartTimes.length === 0 &&
      this.screenshareVideoStartTimes.length === 0)
      return;
    // Set correct index for each stream
    const newMobileVideoIndex = this.mobileVideoStartTimes.indexOf(this.mobileVideoStartTimes
      .filter(range => this.currentTime >= range)
      .at(-1));
    const newWebcamVideoIndex = this.webcamVideoStartTimes.indexOf(this.webcamVideoStartTimes
      .filter(range => this.currentTime >= range)
      .at(-1));
    const newScreenshareVideoIndex = this.screenshareVideoStartTimes.indexOf(this.screenshareVideoStartTimes
      .filter(range => this.currentTime >= range)
      .at(-1));
    const atLeastOneSourceChanged = newMobileVideoIndex != this.mobileVideoIndex ||
      newWebcamVideoIndex != this.webcamVideoIndex ||
      newScreenshareVideoIndex != this.screenshareVideoIndex;
    if (newMobileVideoIndex != this.mobileVideoIndex) {
      this.mobileVideoIndex = newMobileVideoIndex;
    }
    if (newWebcamVideoIndex != this.webcamVideoIndex) {
      this.webcamVideoIndex = newWebcamVideoIndex;
    }
    if (newScreenshareVideoIndex != this.screenshareVideoIndex) {
      this.screenshareVideoIndex = newScreenshareVideoIndex;
    }
    if (atLeastOneSourceChanged) {
      await this.waitEvent('peVideoSourceChanged');
    }
    // Calculate correct current time for each stream
    const mobileVideoTime = this.mobileVideoIndex == 0
      ? this.currentTime
      : this.currentTime - this.mobileVideoStartTimes[this.mobileVideoIndex];
    const webcamVideoTime = this.webcamVideoIndex == 0
      ? this.currentTime
      : this.currentTime - this.webcamVideoStartTimes[this.webcamVideoIndex];
    const screenshareVideoTime = this.screenshareVideoIndex == 0
      ? this.currentTime
      : this.currentTime -
        this.screenshareVideoStartTimes[this.screenshareVideoIndex];
    // Set correct current time for each stream
    this.videoElements.forEach(videoElement => {
      switch (videoElement.name) {
        case 'mobile-video':
          videoElement.setCurrentTime(mobileVideoTime);
          break;
        case 'screenshare-video':
          videoElement.setCurrentTime(screenshareVideoTime);
          break;
        case 'webcam-video':
          videoElement.setCurrentTime(webcamVideoTime);
          break;
        default:
          console.error('Unknown peVideoEnded event.');
          break;
      }
    });
  }
  /**
   * Checks if all provided medias are ready to play,
   * and then sets 'isBusy' state.
   */
  determineIsBusy() {
    var _a, _b, _c, _d;
    if (((_a = this.webcamVideoUris) === null || _a === void 0 ? void 0 : _a.length) > 0 && ((_b = this.mobileVideoUris) === null || _b === void 0 ? void 0 : _b.length) > 0) {
      this.isBusy = !(this.canMobileVideoPlayThrough &&
        this.canScreenshareVideoPlayThrough &&
        this.canWebcamVideoPlayThrough);
    }
    else if (((_c = this.webcamVideoUris) === null || _c === void 0 ? void 0 : _c.length) > 0) {
      this.isBusy = !(this.canScreenshareVideoPlayThrough && this.canWebcamVideoPlayThrough);
    }
    else if (((_d = this.mobileVideoUris) === null || _d === void 0 ? void 0 : _d.length) > 0) {
      this.isBusy = !(this.canScreenshareVideoPlayThrough && this.canMobileVideoPlayThrough);
    }
    else {
      this.isBusy = !this.canScreenshareVideoPlayThrough;
    }
  }
  calculateVideoDurations(videoUris) {
    videoUris.forEach(uri => {
      if (this.videoDurations.hasOwnProperty(uri))
        return;
      this.determineVideoDuration(uri).then(duration => {
        this.videoDurations[uri] = duration;
        if (Object.keys(this.videoDurations).length ===
          [
            ...new Set([
              ...this.screenshareVideoUris,
              ...this.webcamVideoUris,
              ...this.mobileVideoUris,
            ]),
          ].length) {
          this.mobileVideoDurations = this.mobileVideoUris.map(key => this.videoDurations[key]);
          this.webcamVideoDurations = this.webcamVideoUris.map(key => this.videoDurations[key]);
          this.screenshareVideoDurations = this.screenshareVideoUris.map(key => this.videoDurations[key]);
          this.calculateVideoStartTimes();
        }
      });
    });
  }
  calculateVideoStartTimes() {
    // determine starting time for each mobile video source
    this.mobileVideoStartTimes = [
      ...[0],
      ...Array.from(this.mobileVideoDurations, (_item, index) => this.mobileVideoDurations.slice(0, index + 1).reduce((a, b) => a + b)).slice(0, -1),
    ];
    // determine starting time for each webcam video source
    this.webcamVideoStartTimes = [
      ...[0],
      ...Array.from(this.webcamVideoDurations, (_item, index) => this.webcamVideoDurations.slice(0, index + 1).reduce((a, b) => a + b)).slice(0, -1),
    ];
    // determine starting time for each screenshare video source
    this.screenshareVideoStartTimes = [
      ...[0],
      ...Array.from(this.screenshareVideoDurations, (_item, index) => this.screenshareVideoDurations
        .slice(0, index + 1)
        .reduce((a, b) => a + b)).slice(0, -1),
    ];
    this.calculateTotalDuration();
    this.determineEventSource();
    this.determineIsPreparing();
  }
  determineIsPreparing() {
    const startTimesCalculated = [
      ...this.mobileVideoStartTimes,
      ...this.webcamVideoStartTimes,
      ...this.screenshareVideoStartTimes,
    ].length >=
      [
        ...this.mobileVideoUris,
        ...this.webcamVideoUris,
        ...this.screenshareVideoUris,
      ].length;
    if (startTimesCalculated) {
      this.isPreparing = false;
      this.setupResizeObserver();
    }
    else {
      this.isPreparing = true;
    }
  }
  calculateTotalDuration() {
    this.totalDuration = Math.max(this.mobileVideoStartTimes.at(-1) + this.mobileVideoDurations.at(-1) || 0, this.webcamVideoStartTimes.at(-1) + this.webcamVideoDurations.at(-1) || 0, this.screenshareVideoStartTimes.at(-1) +
      this.screenshareVideoDurations.at(-1) || 0, ...[0]);
  }
  handleBoxSizeChanges(boxSize) {
    const width = boxSize.inlineSize;
    const height = boxSize.blockSize;
    let bottomGap = 0;
    let actualHeight = 0;
    if (this.isFullscreen) {
      // fullscreen mode
      bottomGap = this.videoControls.clientHeight + 20 + 25;
      actualHeight = height - bottomGap;
      this.highlightedVideo.style.height = actualHeight.toString() + 'px';
      this.highlightedVideo.style.width = '80%';
      this.smallVideoContainer
        .querySelectorAll('pe-video')
        .forEach(videoElement => {
        videoElement.style.height = '25%';
        videoElement.style.width = '100%';
      });
    }
    else {
      // default view
      bottomGap = this.videoControls.clientHeight + 20 + 25 + 15;
      actualHeight = height - bottomGap;
      this.highlightedVideo.style.height =
        (actualHeight * 0.75).toString() + 'px';
      this.highlightedVideo.style.width = '100%';
      this.smallVideoContainer
        .querySelectorAll('pe-video')
        .forEach(videoElement => {
        videoElement.style.height = (actualHeight * 0.25).toString() + 'px';
        videoElement.style.width = (width * 0.35).toString() + 'px';
      });
    }
  }
  determineEventSource() {
    const durationSums = [
      [...[0], ...this.mobileVideoDurations].reduce((a, b) => a + b),
      [...[0], ...this.screenshareVideoDurations].reduce((a, b) => a + b),
      [...[0], ...this.webcamVideoDurations].reduce((a, b) => a + b),
    ];
    const streamTypes = ['mobile', 'screenshare', 'webcam'];
    this.eventSourceStream =
      streamTypes[durationSums.indexOf(Math.max(...durationSums))];
  }
  setupResizeObserver() {
    const parentElement = this.videoPlayerElement.parentElement;
    const resizeObserver = new ResizeObserver(entries => {
      for (let entry of entries) {
        if (entry.contentBoxSize !== null) {
          const contentBoxSize = Array.isArray(entry.contentBoxSize)
            ? entry.contentBoxSize[0]
            : entry.contentBoxSize;
          this.handleBoxSizeChanges(contentBoxSize);
        }
      }
    });
    resizeObserver.observe(parentElement);
    // Set highlighted video only once in here.
    this.highlightedVideo = this.screenshareVideo;
    // Add all available videos to video elements array
    if (this.screenshareVideo != undefined)
      this.videoElements.push(this.screenshareVideo);
    if (this.mobileVideo != undefined)
      this.videoElements.push(this.mobileVideo);
    if (this.webcamVideo != undefined)
      this.videoElements.push(this.webcamVideo);
  }
  async waitEvent(name) {
    return new Promise(function (resolve) {
      document.addEventListener(name, function () {
        resolve(true); // resolves when the event fires
      });
    });
  }
  componentWillLoad() {
    this.mobileVideoUrisChanged(this.mobileVideoUris);
    this.webcamVideoUrisChanged(this.webcamVideoUris);
    this.screenshareVideoUrisChanged(this.screenshareVideoUris);
  }
  componentDidLoad() {
    // set feature flags
    const params = new URLSearchParams(location.search);
    this.debugEnabled = params.has('debugger');
  }
  render() {
    var _a, _b, _c, _d;
    return (h(Host, { class: this.isPreparing ? 'loading' : '', ref: el => (this.videoPlayerElement = el) }, ((_a = this.screenshareVideoUris) === null || _a === void 0 ? void 0 : _a.length) > 0 && (h("span", { class: this.isFullscreen ? 'fullscreen' : '' }, h("div", { id: "video-container" }, h("pe-video", { ref: el => (this.screenshareVideo = el), name: "screenshare-video", tag: "Screenshare", playbackRate: this.playbackRate, isMuted: true, isPlaying: this.isBusy ? false : this.isPlaying, isEventSource: this.eventSourceStream == 'screenshare', source: this.screenshareVideoUris[this.screenshareVideoIndex] }), h("div", { ref: el => (this.smallVideoContainer = el), id: "small-video-container" }, ((_b = this.webcamVideoUris) === null || _b === void 0 ? void 0 : _b.length) > 0 && (h("pe-video", { ref: el => (this.webcamVideo = el), name: "webcam-video", tag: "Webcam", playbackRate: this.playbackRate, isMuted: this.isMuted, isPlaying: this.isBusy ? false : this.isPlaying, isEventSource: this.eventSourceStream == 'webcam', source: this.webcamVideoUris[this.webcamVideoIndex] })), ((_c = this.mobileVideoUris) === null || _c === void 0 ? void 0 : _c.length) > 0 && (h("pe-video", { ref: el => (this.mobileVideo = el), name: "mobile-video", tag: "Mobile", playbackRate: this.playbackRate, isMuted: true, isPlaying: this.isBusy ? false : this.isPlaying, isEventSource: this.eventSourceStream == 'mobile', source: this.mobileVideoUris[this.mobileVideoIndex] })))), h("pe-video-controls", { ref: el => (this.videoControls = el), currentTime: this.currentTime, totalDuration: this.totalDuration, isFullscreen: this.isFullscreen }))), ((_d = this.screenshareVideoUris) === null || _d === void 0 ? void 0 : _d.length) == 0 && (h("h1", null, "Screensharing source is required.")), this.debugEnabled && (h("pe-debug-panel", { content: {
        screenshareVideoUris: this.screenshareVideoUris,
        webcamVideoUris: this.webcamVideoUris,
        mobileVideoUris: this.mobileVideoUris,
        videoDurations: [
          `screenshare: ${this.screenshareVideoDurations}`,
          `webcam: ${this.webcamVideoDurations}`,
          `mobile: ${this.mobileVideoDurations}`,
        ],
        videoIndexes: [
          `screenshare: ${this.screenshareVideoIndex}`,
          `webcam: ${this.webcamVideoIndex}`,
          `mobile: ${this.mobileVideoIndex}`,
        ],
        videoCanPlayThrough: [
          `screenshare: ${this.canScreenshareVideoPlayThrough}`,
          `webcam: ${this.canWebcamVideoPlayThrough}`,
          `mobile: ${this.canMobileVideoPlayThrough}`,
        ],
        eventSource: [this.eventSourceStream],
      } }))));
  }
  static get watchers() { return {
    "mobileVideoUris": ["mobileVideoUrisChanged"],
    "screenshareVideoUris": ["screenshareVideoUrisChanged"],
    "webcamVideoUris": ["webcamVideoUrisChanged"]
  }; }
  static get style() { return peVideoPlayerCss; }
};
PeVideoPlayer = /*@__PURE__*/ proxyCustomElement(PeVideoPlayer, [1, "pe-video-player", {
    "mobileVideoUris": [1032, "mobile-video-uris"],
    "screenshareVideoUris": [1032, "screenshare-video-uris"],
    "webcamVideoUris": [1032, "webcam-video-uris"],
    "debugEnabled": [32],
    "isPreparing": [32],
    "eventSourceStream": [32],
    "isPlaying": [32],
    "isBusy": [32],
    "isMuted": [32],
    "isFullscreen": [32],
    "canMobileVideoPlayThrough": [32],
    "canScreenshareVideoPlayThrough": [32],
    "canWebcamVideoPlayThrough": [32],
    "playbackRate": [32],
    "currentTime": [32],
    "totalDuration": [32],
    "videoDurations": [32],
    "mobileVideoIndex": [32],
    "screenshareVideoIndex": [32],
    "webcamVideoIndex": [32],
    "mobileVideoDurations": [32],
    "screenshareVideoDurations": [32],
    "webcamVideoDurations": [32],
    "mobileVideoStartTimes": [32],
    "screenshareVideoStartTimes": [32],
    "webcamVideoStartTimes": [32],
    "setCurrentTime": [64],
    "getCurrentTime": [64]
  }, [[0, "peVideoOnWaiting", "peVideoOnWaitingHandler"], [0, "peVideoSourceChanged", "peVideoSourceChangedHandler"], [0, "peVideoCanPlayThrough", "peVideoCanPlayThroughHandler"], [0, "peVideoPlay", "peVideoPlayHandler"], [0, "peVideoRewind", "peVideoRewindHandler"], [0, "peVideoMute", "peVideoMuteHandler"], [0, "peVideoSpeed", "peVideoSpeedHandler"], [0, "peVideoEnded", "peVideoEndedHandler"], [0, "peVideoTimeUpdate", "peVideoTimeUpdateHandler"], [0, "peVideoLoadedData", "peVideoLoadedDataHandler"], [0, "peVideoSeek", "peVideoSeekHandler"], [0, "peVideoFullscreen", "peVideoFullscreenHandler"], [0, "peVideoClick", "peVideoClickHandler"]]]);
function defineCustomElement() {
  if (typeof customElements === "undefined") {
    return;
  }
  const components = ["pe-video-player", "pe-button", "pe-debug-panel", "pe-icon", "pe-video", "pe-video-controls"];
  components.forEach(tagName => { switch (tagName) {
    case "pe-video-player":
      if (!customElements.get(tagName)) {
        customElements.define(tagName, PeVideoPlayer);
      }
      break;
    case "pe-button":
      if (!customElements.get(tagName)) {
        defineCustomElement$5();
      }
      break;
    case "pe-debug-panel":
      if (!customElements.get(tagName)) {
        defineCustomElement$4();
      }
      break;
    case "pe-icon":
      if (!customElements.get(tagName)) {
        defineCustomElement$3();
      }
      break;
    case "pe-video":
      if (!customElements.get(tagName)) {
        defineCustomElement$2();
      }
      break;
    case "pe-video-controls":
      if (!customElements.get(tagName)) {
        defineCustomElement$1();
      }
      break;
  } });
}
defineCustomElement();

export { PeVideoPlayer as P, defineCustomElement as d };
