import { p as plt, w as win, d as doc, N as NAMESPACE, a as promiseResolve, b as bootstrapLazy } from './index-a0ad7b78.js';

/*
 Stencil Client Patch Browser v2.13.0 | MIT Licensed | https://stenciljs.com
 */
const getDynamicImportFunction = (namespace) => `__sc_import_${namespace.replace(/\s|-/g, '_')}`;
const patchBrowser = () => {
    {
        // shim css vars
        plt.$cssShim$ = win.__cssshim;
    }
    // @ts-ignore
    const scriptElm = Array.from(doc.querySelectorAll('script')).find((s) => new RegExp(`\/${NAMESPACE}(\\.esm)?\\.js($|\\?|#)`).test(s.src) ||
            s.getAttribute('data-stencil-namespace') === NAMESPACE)
        ;
    const opts = scriptElm['data-opts'] || {} ;
    if ('onbeforeload' in scriptElm && !history.scrollRestoration /* IS_ESM_BUILD */) {
        // Safari < v11 support: This IF is true if it's Safari below v11.
        // This fn cannot use async/await since Safari didn't support it until v11,
        // however, Safari 10 did support modules. Safari 10 also didn't support "nomodule",
        // so both the ESM file and nomodule file would get downloaded. Only Safari
        // has 'onbeforeload' in the script, and "history.scrollRestoration" was added
        // to Safari in v11. Return a noop then() so the async/await ESM code doesn't continue.
        // IS_ESM_BUILD is replaced at build time so this check doesn't happen in systemjs builds.
        return {
            then() {
                /* promise noop */
            },
        };
    }
    {
        opts.resourcesUrl = new URL('.', new URL(scriptElm.getAttribute('data-resources-url') || scriptElm.src, win.location.href)).href;
        {
            patchDynamicImport(opts.resourcesUrl, scriptElm);
        }
        if (!win.customElements) {
            // module support, but no custom elements support (Old Edge)
            // @ts-ignore
            return import(/* webpackChunkName: "polyfills-dom" */ './dom-c5ed0ba5.js').then(() => opts);
        }
    }
    return promiseResolve(opts);
};
const patchDynamicImport = (base, orgScriptElm) => {
    const importFunctionName = getDynamicImportFunction(NAMESPACE);
    try {
        // test if this browser supports dynamic imports
        // There is a caching issue in V8, that breaks using import() in Function
        // By generating a random string, we can workaround it
        // Check https://bugs.chromium.org/p/chromium/issues/detail?id=990810 for more info
        win[importFunctionName] = new Function('w', `return import(w);//${Math.random()}`);
    }
    catch (e) {
        // this shim is specifically for browsers that do support "esm" imports
        // however, they do NOT support "dynamic" imports
        // basically this code is for old Edge, v18 and below
        const moduleMap = new Map();
        win[importFunctionName] = (src) => {
            const url = new URL(src, base).href;
            let mod = moduleMap.get(url);
            if (!mod) {
                const script = doc.createElement('script');
                script.type = 'module';
                script.crossOrigin = orgScriptElm.crossOrigin;
                script.src = URL.createObjectURL(new Blob([`import * as m from '${url}'; window.${importFunctionName}.m = m;`], {
                    type: 'application/javascript',
                }));
                mod = new Promise((resolve) => {
                    script.onload = () => {
                        resolve(win[importFunctionName].m);
                        script.remove();
                    };
                });
                moduleMap.set(url, mod);
                doc.head.appendChild(script);
            }
            return mod;
        };
    }
};

patchBrowser().then(options => {
  return bootstrapLazy([["pe-button_9",[[1,"pe-review-studio",{"mobileVideoUris":[1032,"mobile-video-uris"],"screenshareVideoUris":[1032,"screenshare-video-uris"],"webcamVideoUris":[1032,"webcam-video-uris"],"isFullscreen":[32],"activeTab":[32],"content":[32],"breachDictionaryItems":[32]},[[0,"peVideoFullscreen","peVideoFullscreenHandler"]]],[1,"pe-video-player",{"mobileVideoUris":[1032,"mobile-video-uris"],"screenshareVideoUris":[1032,"screenshare-video-uris"],"webcamVideoUris":[1032,"webcam-video-uris"],"debugEnabled":[32],"isPreparing":[32],"eventSourceStream":[32],"isPlaying":[32],"isBusy":[32],"isMuted":[32],"isFullscreen":[32],"canMobileVideoPlayThrough":[32],"canScreenshareVideoPlayThrough":[32],"canWebcamVideoPlayThrough":[32],"playbackRate":[32],"currentTime":[32],"totalDuration":[32],"videoDurations":[32],"mobileVideoIndex":[32],"screenshareVideoIndex":[32],"webcamVideoIndex":[32],"mobileVideoDurations":[32],"screenshareVideoDurations":[32],"webcamVideoDurations":[32],"mobileVideoStartTimes":[32],"screenshareVideoStartTimes":[32],"webcamVideoStartTimes":[32],"setCurrentTime":[64],"getCurrentTime":[64]},[[0,"peVideoOnWaiting","peVideoOnWaitingHandler"],[0,"peVideoSourceChanged","peVideoSourceChangedHandler"],[0,"peVideoCanPlayThrough","peVideoCanPlayThroughHandler"],[0,"peVideoPlay","peVideoPlayHandler"],[0,"peVideoRewind","peVideoRewindHandler"],[0,"peVideoMute","peVideoMuteHandler"],[0,"peVideoSpeed","peVideoSpeedHandler"],[0,"peVideoEnded","peVideoEndedHandler"],[0,"peVideoTimeUpdate","peVideoTimeUpdateHandler"],[0,"peVideoLoadedData","peVideoLoadedDataHandler"],[0,"peVideoSeek","peVideoSeekHandler"],[0,"peVideoFullscreen","peVideoFullscreenHandler"],[0,"peVideoClick","peVideoClickHandler"]]],[1,"pe-incident-list",{"incidentList":[1040],"handleEdit":[1040],"jumptoIncidentTime":[1040]}],[1,"pe-navbar"],[1,"pe-video-controls",{"isFullscreen":[1028,"is-fullscreen"],"currentTime":[1026,"current-time"],"totalDuration":[1026,"total-duration"],"availableSpeeds":[1040],"speedIndex":[32],"isMuted":[32],"isPlaying":[32]},[[8,"fullscreenchange","fullscreenchangeHandler"]]],[1,"pe-debug-panel",{"content":[1032],"isMouseDown":[32],"currentX":[32],"currentY":[32],"initialX":[32],"initialY":[32],"xOffset":[32],"yOffset":[32],"height":[32],"width":[32]}],[1,"pe-video",{"name":[513],"source":[1025],"tag":[1],"isEventSource":[1028,"is-event-source"],"isPlaying":[1540,"is-playing"],"isMuted":[1028,"is-muted"],"playbackRate":[1026,"playback-rate"],"seek":[64],"setCurrentTime":[64]}],[1,"pe-button",{"disabled":[1540],"iconOnly":[1540,"icon-only"],"circled":[1540],"variant":[1537],"color":[1537],"size":[1537],"class":[1537],"text":[1537],"iconName":[1537,"icon-name"],"iconState":[32]}],[1,"pe-icon",{"name":[1537]}]]],["pe-icons-list",[[1,"pe-icons-list"]]],["pe-typography",[[1,"pe-typography",{"tag":[1537],"type":[1537],"weight":[1537],"size":[1537],"spacing":[1537]}]]]], options);
});
