import { EventEmitter } from '../../../stencil-public-runtime';
export declare class PeVideo {
  private videoElement;
  connectedCallback(): void;
  componentDidLoad(): void;
  /**
   * Unique name identifies video
   */
  readonly name: string;
  /**
   * Determines video source url.
   * Example public url: https://components-staging.proctorexam.com/_testing-assets/landscape_sample.webm
   */
  source: string;
  handleSourceChanged(newValue: any): Promise<void>;
  /**
   * Overlay text will be shown on top of video
   */
  readonly tag: string;
  /**
   * Determines if this is the component responsible for bubble events.
   */
  isEventSource: boolean;
  /**
   * Determines media playback.
   * Triggers play() or pause() on HTMLMediaElement.
   */
  isPlaying: boolean;
  watchIsPlayingHandler(newIsPlaying: boolean): Promise<void>;
  /**
   * Determines audio is muted or not.
   * Sets muted property of HTMLMediaElement.
   */
  isMuted: boolean;
  watchIsMutedHandler(newIsMuted: boolean): void;
  /**
   * Determines playback speed for video.
   * Sets playbackRate of HTMLMediaElement.
   */
  playbackRate: number;
  watchPlaybackRateHandler(newPlaybackRate: number): void;
  /**
   * Bubbles timeUpdate event of HTMLMediaElement
   */
  peVideoTimeUpdate: EventEmitter<CustomEvent>;
  private peVideoTimeUpdateHandler;
  /**
   * Bubbles loadedData event of HTMLMediaElement
   */
  peVideoLoadedData: EventEmitter<CustomEvent>;
  private peVideoLoadedDataHandler;
  /**
   * Bubbles canPlayThrough event of HTMLMediaElement
   */
  peVideoCanPlayThrough: EventEmitter<CustomEvent>;
  private peVideoCanPlayThroughHandler;
  /**
   * Bubbles onWaiting event of HTMLMediaElement
   */
  peVideoOnWaiting: EventEmitter<CustomEvent>;
  private peVideoOnWaitingHandler;
  /**
   * Emits when video source changed.
   */
  peVideoSourceChanged: EventEmitter<string>;
  /**
   * Bubbles click event of HTMLMediaElement
   */
  peVideoClick: EventEmitter<CustomEvent>;
  private peVideoClickHandler;
  /**
   * Bubbles video ended event of HTMLMediaElement
   */
  peVideoEnded: EventEmitter<CustomEvent>;
  private peVideoEndedHandler;
  /**
   * @param time
   */
  seek(time: number): Promise<void>;
  /**
   * @param time
   */
  setCurrentTime(time: number): Promise<void>;
  private handleClick;
  private handleWaiting;
  private handleCanPlayThrough;
  private handleTimeUpdate;
  private handleLoadedData;
  private handleEnded;
  private handleSuspend;
  private handleStalled;
  private fixStuckVideo;
  render(): any;
}
