import { r as registerInstance, h, H as Host, g as getAssetPath, c as createEvent } from './index-a0ad7b78.js';

const peButtonCss = ":host{display:-ms-flexbox;display:flex}button{background:transparent;color:#2d2d2d;fill:#2d2d2d;padding:5px 8px;height:32px;border-radius:4px;border:1px solid transparent;cursor:pointer;text-transform:capitalize;font-style:normal;font-weight:600;display:-ms-inline-flexbox;display:inline-flex;-ms-flex-align:center;align-items:center;font-weight:500;font-size:16px;line-height:22px}.outline{background:#fff;color:#1a5059;fill:#1a5059;border-color:#cdcdcd}.filled{background-color:#f3f3f3;border-color:#cdcdcd}.filled.action{background:#1a5059;border-color:#1a5059;color:#fff;fill:#fff}.filled.primary{color:#2d2d2d;fill:#2d2d2d}.filled.player{background:#0095ff;border-color:#0095ff;fill:#fff}.filled.action:hover,.filled.action.hover{background:#003c46;border-color:#003c46}.outline.action:hover,.outline.action.hover{background:#e5e5e5;border-color:#cdcdcd}.filled.primary:hover,.filled.primary.hover{background:#e5e5e5;border-color:#cdcdcd}.filled.player:hover,.filled.player.hover{background:#0095ff;border-color:#0095ff}.ghost:hover,.ghost.hover{background:#e5e5e5;border-color:#e5e5e5}.filled.action:active,.filled.action.active{background:#1a5059;border-color:#1a5059}.outline.action:active,.outline.action.active{background:#e5ebec;border-color:#cdcdcd}.filled.primary:active,.filled.primary.active{background:#e5ebec;border-color:#cdcdcd}.filled.player:active,.filled.player.active{background:#1a5059;border-color:#1a5059}.ghost:active,.ghost.active{background:#e5ebec;border-color:#e5ebec}button:focus,button.focus{outline:3px solid #0096ff;outline-offset:2px}.filled.action:focus,.filled.action.focus{background:#003c46;border-color:#003c46}.outline.action:focus,.outline.action.focus,.outline.primary:focus,.outline.primary.focus{background:#e5e5e5;border-color:#cdcdcd}.ghost:focus,.ghost.focus{background:#e5e5e5;border-color:#e5e5e5}button:disabled,.filled:disabled{background:#e5e5e5;pointer-events:none;color:#aeaeae;fill:#aeaeae;border-color:#e5e5e5}pe-icon{fill:inherit;width:18px;height:18px;margin-right:8px}pe-icon.icon-only{margin-right:0}.circle{width:34px;height:34px;border-radius:50%;padding:0px;display:-ms-inline-flexbox;display:inline-flex;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;align-items:center}button.large::part(icon){width:24px;height:24px}button.circle pe-icon{width:24px;height:24px;margin-right:0}button.circle::part(icon),.large{padding:8px 12px;height:40px}button.large::part(icon){width:24px;height:24px}button:disabled{background:#e5e5e5;pointer-events:none;color:#aeaeae;fill:#aeaeae;border-color:#e5e5e5}";

let PeButton = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    /**
     * enable/disable a button
     */
    this.disabled = false;
    /**
     * pass this if empty button to show button in best style shape
     */
    this.iconOnly = false;
    /**
     * changing the look to a button
     */
    this.circled = false;
    /**
     * varients
     */
    this.variant = 'ghost';
    /**
     * colors
     */
    this.color = 'basic';
    /**
     * size
     */
    this.size = 'normal';
  }
  iconNameChanged(newIconName) {
    this.iconState = newIconName;
  }
  componentWillLoad() {
    this.iconState = this.iconName;
  }
  render() {
    return (h(Host, null, h("button", { class: `${this.variant || 'ghost'} ${this.size} ${this.color} ${this.circled ? 'circle' : ''} ${this.class || ''}`, disabled: this.disabled }, this.iconState && (h("pe-icon", { class: `${this.iconOnly && 'icon-only'}`, name: this.iconState })), !this.iconOnly && (this.text || h("slot", null)))));
  }
  static get watchers() { return {
    "iconName": ["iconNameChanged"]
  }; }
};
PeButton.style = peButtonCss;

const peDebugPanelCss = ":host{display:block}.draggable{position:absolute;left:0;top:0;z-index:9999999;background-color:#fff;border:2px solid #000;padding:5px}table,th,td{border:1px solid #000}";

let PeDebugPanel = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.xOffset = 0;
    this.yOffset = 0;
  }
  handleContentChanged(newValue) {
    if (typeof newValue == 'string') {
      this.content = JSON.parse(newValue);
    }
    else {
      this.content = newValue;
    }
  }
  handleMouseDown(e) {
    if (e.type === 'touchstart') {
      this.initialX = e.touches[0].clientX - this.xOffset;
      this.initialY = e.touches[0].clientY - this.yOffset;
    }
    else {
      this.initialX = e.clientX - this.xOffset;
      this.initialY = e.clientY - this.yOffset;
    }
    this.isMouseDown = true;
  }
  handleMouseMove(e) {
    if (this.isMouseDown) {
      e.preventDefault();
      if (e.type === 'touchmove') {
        this.currentX = e.touches[0].clientX - this.initialX;
        this.currentY = e.touches[0].clientY - this.initialY;
      }
      else {
        this.currentX = e.clientX - this.initialX;
        this.currentY = e.clientY - this.initialY;
      }
      this.xOffset = this.currentX;
      this.yOffset = this.currentY;
      this.setTranslate(this.currentX, this.currentY, this.draggableElement);
    }
  }
  handleMouseUp() {
    this.initialX = this.currentX;
    this.initialY = this.currentY;
    this.draggableElement.style.cursor = 'default';
    this.isMouseDown = false;
  }
  handleClose() {
    this.draggableElement.style.display = 'none';
  }
  setTranslate(xPos, yPos, el) {
    el.style.cursor = 'move';
    el.style.transform = 'translate3d(' + xPos + 'px, ' + yPos + 'px, 0)';
  }
  connectedCallback() {
    this.handleMouseDown = this.handleMouseDown.bind(this);
    this.handleMouseUp = this.handleMouseUp.bind(this);
    this.handleMouseMove = this.handleMouseMove.bind(this);
    this.handleClose = this.handleClose.bind(this);
  }
  componentDidLoad() {
    this.height = this.draggableElement.offsetHeight;
    this.width = this.draggableElement.offsetWidth;
    this.handleContentChanged(this.content);
  }
  render() {
    return (h(Host, null, h("div", { ref: el => (this.draggableElement = el), onMouseDown: this.handleMouseDown, onMouseMove: this.handleMouseMove, onMouseUp: this.handleMouseUp, class: "draggable" }, h("h2", null, "Debug Panel ", h("small", null, "(you can drag me)"), " \u00A0", ' ', h("button", { onClick: this.handleClose }, "X")), h("table", null, Object.keys(this.content).map(key => {
      return (h("tr", null, h("td", null, h("pre", null, key)), h("td", null, this.content[key].map(item => {
        return h("pre", null, item);
      }))));
    })))));
  }
  static get watchers() { return {
    "content": ["handleContentChanged"]
  }; }
};
PeDebugPanel.style = peDebugPanelCss;

const edit_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14.06 9.02L14.98 9.94L5.92 19H5V18.08L14.06 9.02ZM17.66 3C17.41 3 17.15 3.1 16.96 3.29L15.13 5.12L18.88 8.87L20.71 7.04C21.1 6.65 21.1 6.02 20.71 5.63L18.37 3.29C18.17 3.09 17.92 3 17.66 3ZM14.06 6.19L3 17.25V21H6.75L17.81 9.94L14.06 6.19Z" />
</svg>
`;

const push_pin = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M19 12.87C19 12.4 18.66 12.02 18.2 11.89C16.93 11.54 16 10.38 16 9V4H17C17.55 4 18 3.55 18 3C18 2.45 17.55 2 17 2H7C6.45 2 6 2.45 6 3C6 3.55 6.45 4 7 4H8V9C8 10.38 7.07 11.54 5.8 11.89C5.34 12.02 5 12.4 5 12.87V13C5 13.55 5.45 14 6 14H10.98L11 21C11 21.55 11.45 22 12 22C12.55 22 13 21.55 13 21L12.98 14H18C18.55 14 19 13.55 19 13V12.87Z" />
</svg>
`;

const auto_awesome_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20.255 6.25246L19.465 8.00246C19.285 8.39246 18.725 8.39246 18.545 8.00246L17.755 6.24246L16.005 5.45246C15.615 5.27246 15.615 4.72246 16.005 4.54246L17.765 3.75246L18.555 2.00246C18.735 1.61246 19.285 1.61246 19.465 2.00246L20.255 3.76246L22.005 4.55246C22.395 4.73246 22.395 5.28246 22.005 5.46246L20.255 6.25246Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M9.915 6.00246L11.505 9.50246L15.005 11.0925C15.785 11.4425 15.785 12.5525 15.005 12.9125L11.505 14.5025L9.915 18.0025C9.565 18.7825 8.455 18.7825 8.095 18.0025L6.505 14.5025L3.005 12.9125C2.225 12.5625 2.225 11.4525 3.005 11.0925L6.505 9.50246L8.095 6.00246C8.445 5.22246 9.565 5.22246 9.915 6.00246ZM10.08 13.0101L9.09 15.1901L8.1 13.0101L5.92 12.0201L8.1 11.0301L9.09 8.8501L10.08 11.0301L12.26 12.0201L10.08 13.0101Z" />
<path d="M17.755 17.7525L18.545 16.0025C18.725 15.6125 19.285 15.6125 19.465 16.0025L20.255 17.7625L22.005 18.5525C22.395 18.7325 22.395 19.2825 22.005 19.4625L20.245 20.2525L19.455 22.0025C19.275 22.3925 18.725 22.3925 18.545 22.0025L17.755 20.2425L16.005 19.4525C15.615 19.2725 15.615 18.7225 16.005 18.5425L17.755 17.7525Z" />
</svg>
`;

const search = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15.4999 14H14.7099L14.4299 13.73C15.6299 12.33 16.2499 10.42 15.9099 8.39C15.4399 5.61 13.1199 3.39 10.3199 3.05C6.08989 2.53 2.52989 6.09 3.04989 10.32C3.38989 13.12 5.60989 15.44 8.38989 15.91C10.4199 16.25 12.3299 15.63 13.7299 14.43L13.9999 14.71V15.5L18.2499 19.75C18.6599 20.16 19.3299 20.16 19.7399 19.75C20.1499 19.34 20.1499 18.67 19.7399 18.26L15.4999 14ZM9.49989 14C7.00989 14 4.99989 11.99 4.99989 9.5C4.99989 7.01 7.00989 5 9.49989 5C11.9899 5 13.9999 7.01 13.9999 9.5C13.9999 11.99 11.9899 14 9.49989 14Z" />
</svg>
`;

const notes = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 11H4C3.45 11 3 11.45 3 12C3 12.55 3.45 13 4 13H20C20.55 13 21 12.55 21 12C21 11.45 20.55 11 20 11ZM4 18H14C14.55 18 15 17.55 15 17C15 16.45 14.55 16 14 16H4C3.45 16 3 16.45 3 17C3 17.55 3.45 18 4 18ZM20 6H4C3.45 6 3 6.45 3 7V7.01C3 7.56 3.45 8.01 4 8.01H20C20.55 8.01 21 7.56 21 7.01V7C21 6.45 20.55 6 20 6Z" />
</svg>
`;

const light_mode = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 7C9.24 7 7 9.24 7 12C7 14.76 9.24 17 12 17C14.76 17 17 14.76 17 12C17 9.24 14.76 7 12 7ZM2 13H4C4.55 13 5 12.55 5 12C5 11.45 4.55 11 4 11H2C1.45 11 1 11.45 1 12C1 12.55 1.45 13 2 13ZM20 13H22C22.55 13 23 12.55 23 12C23 11.45 22.55 11 22 11H20C19.45 11 19 11.45 19 12C19 12.55 19.45 13 20 13ZM11 2V4C11 4.55 11.45 5 12 5C12.55 5 13 4.55 13 4V2C13 1.45 12.55 1 12 1C11.45 1 11 1.45 11 2ZM11 20V22C11 22.55 11.45 23 12 23C12.55 23 13 22.55 13 22V20C13 19.45 12.55 19 12 19C11.45 19 11 19.45 11 20ZM5.99 4.58C5.6 4.19 4.96 4.19 4.58 4.58C4.19 4.97 4.19 5.61 4.58 5.99L5.64 7.05C6.03 7.44 6.67 7.44 7.05 7.05C7.43 6.66 7.44 6.02 7.05 5.64L5.99 4.58ZM18.36 16.95C17.97 16.56 17.33 16.56 16.95 16.95C16.56 17.34 16.56 17.98 16.95 18.36L18.01 19.42C18.4 19.81 19.04 19.81 19.42 19.42C19.81 19.03 19.81 18.39 19.42 18.01L18.36 16.95ZM19.42 5.99C19.81 5.6 19.81 4.96 19.42 4.58C19.03 4.19 18.39 4.19 18.01 4.58L16.95 5.64C16.56 6.03 16.56 6.67 16.95 7.05C17.34 7.43 17.98 7.44 18.36 7.05L19.42 5.99ZM7.05 18.36C7.44 17.97 7.44 17.33 7.05 16.95C6.66 16.56 6.02 16.56 5.64 16.95L4.58 18.01C4.19 18.4 4.19 19.04 4.58 19.42C4.97 19.8 5.61 19.81 5.99 19.42L7.05 18.36Z" />
</svg>
`;

const link_add = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M8.99995 11H15C15.55 11 16 11.45 16 12C16 12.55 15.55 13 15 13H8.99995C8.44995 13 7.99995 12.55 7.99995 12C7.99995 11.45 8.44995 11 8.99995 11ZM20.93 12C21.55 12 22 11.41 21.86 10.81C21.32 8.62 19.35 7 17 7H13.95C13.43 7 13 7.43 13 7.95C13 8.47 13.43 8.9 13.95 8.9H17C18.45 8.9 19.67 9.9 20.01 11.24C20.12 11.68 20.48 12 20.93 12ZM3.95995 11.38C4.23995 9.91 5.61995 8.9 7.11995 8.9H10.05C10.57 8.9 11 8.47 11 7.95C11 7.43 10.57 7 10.05 7H7.21995C4.60995 7 2.27995 8.91 2.02995 11.51C1.73995 14.49 4.07995 17 6.99995 17H10.05C10.57 17 11 16.57 11 16.05C11 15.53 10.57 15.1 10.05 15.1H6.99995C5.08995 15.1 3.57995 13.36 3.95995 11.38ZM18 12C17.45 12 17 12.45 17 13V15H15C14.45 15 14 15.45 14 16C14 16.55 14.45 17 15 17H17V19C17 19.55 17.45 20 18 20C18.55 20 19 19.55 19 19V17H21C21.55 17 22 16.55 22 16C22 15.45 21.55 15 21 15H19V13C19 12.45 18.55 12 18 12Z" />
</svg>
`;

const list = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M4 13C4.55 13 5 12.55 5 12C5 11.45 4.55 11 4 11C3.45 11 3 11.45 3 12C3 12.55 3.45 13 4 13ZM4 17C4.55 17 5 16.55 5 16C5 15.45 4.55 15 4 15C3.45 15 3 15.45 3 16C3 16.55 3.45 17 4 17ZM4 9C4.55 9 5 8.55 5 8C5 7.45 4.55 7 4 7C3.45 7 3 7.45 3 8C3 8.55 3.45 9 4 9ZM8 13H20C20.55 13 21 12.55 21 12C21 11.45 20.55 11 20 11H8C7.45 11 7 11.45 7 12C7 12.55 7.45 13 8 13ZM8 17H20C20.55 17 21 16.55 21 16C21 15.45 20.55 15 20 15H8C7.45 15 7 15.45 7 16C7 16.55 7.45 17 8 17ZM7 8C7 8.55 7.45 9 8 9H20C20.55 9 21 8.55 21 8C21 7.45 20.55 7 20 7H8C7.45 7 7 7.45 7 8ZM4 13C4.55 13 5 12.55 5 12C5 11.45 4.55 11 4 11C3.45 11 3 11.45 3 12C3 12.55 3.45 13 4 13ZM4 17C4.55 17 5 16.55 5 16C5 15.45 4.55 15 4 15C3.45 15 3 15.45 3 16C3 16.55 3.45 17 4 17ZM4 9C4.55 9 5 8.55 5 8C5 7.45 4.55 7 4 7C3.45 7 3 7.45 3 8C3 8.55 3.45 9 4 9ZM8 13H20C20.55 13 21 12.55 21 12C21 11.45 20.55 11 20 11H8C7.45 11 7 11.45 7 12C7 12.55 7.45 13 8 13ZM8 17H20C20.55 17 21 16.55 21 16C21 15.45 20.55 15 20 15H8C7.45 15 7 15.45 7 16C7 16.55 7.45 17 8 17ZM7 8C7 8.55 7.45 9 8 9H20C20.55 9 21 8.55 21 8C21 7.45 20.55 7 20 7H8C7.45 7 7 7.45 7 8Z" />
</svg>
`;

const bookmark_outline = `<svg viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
<path d="M17 3H7C5.9 3 5 3.9 5 5V21L12 18L19 21V5C19 3.9 18.1 3 17 3ZM17 18L12 15.82L7 18V6C7 5.45 7.45 5 8 5H16C16.55 5 17 5.45 17 6V18Z" />
</svg>
`;

const auto_fix = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9.44 4.94002L8.95 6.00002C8.78 6.39002 8.22 6.39002 8.05 6.00002L7.56 4.95002L6.5 4.46002C6.11 4.28002 6.11 3.73002 6.5 3.55002L7.56 3.06002L8.05 2.00002C8.22 1.61002 8.78 1.61002 8.95 2.00002L9.44 3.06002L10.5 3.54002C10.89 3.72002 10.89 4.27002 10.5 4.45002L9.44 4.94002Z" />
<path d="M20.94 4.94002L20.45 6.00002C20.28 6.39002 19.72 6.39002 19.55 6.00002L19.06 4.95002L18 4.46002C17.61 4.28002 17.61 3.73002 18 3.55002L19.05 3.06002L19.54 2.00002C19.72 1.61002 20.27 1.61002 20.45 2.00002L20.94 3.05002L22 3.54002C22.39 3.72002 22.39 4.27002 22 4.45002L20.94 4.94002Z" />
<path d="M19.55 13.5001L19.06 14.5601L18 15.0501C17.61 15.2301 17.61 15.7801 18 15.9601L19.06 16.4501L19.55 17.5101C19.73 17.9001 20.28 17.9001 20.46 17.5101L20.95 16.4501L22 15.9501C22.39 15.7701 22.39 15.2201 22 15.0401L20.94 14.5501L20.45 13.4901C20.28 13.1101 19.72 13.1101 19.55 13.5001Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M14.88 6.29006L17.71 9.12006C18.1 9.51006 18.1 10.1501 17.7 10.5301L6.53 21.7001C6.14 22.0901 5.51 22.0901 5.12 21.7001L2.29 18.8701C1.9 18.4801 1.9 17.8501 2.29 17.4601L13.47 6.29006C13.86 5.90006 14.49 5.90006 14.88 6.29006ZM12.8 9.80006L14.21 11.2101L15.59 9.83006L14.18 8.42006L12.8 9.80006Z" />
</svg>
`;

const light_mode_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 9C13.65 9 15 10.35 15 12C15 13.65 13.65 15 12 15C10.35 15 9 13.65 9 12C9 10.35 10.35 9 12 9ZM12 7C9.24 7 7 9.24 7 12C7 14.76 9.24 17 12 17C14.76 17 17 14.76 17 12C17 9.24 14.76 7 12 7ZM2 13H4C4.55 13 5 12.55 5 12C5 11.45 4.55 11 4 11H2C1.45 11 1 11.45 1 12C1 12.55 1.45 13 2 13ZM20 13H22C22.55 13 23 12.55 23 12C23 11.45 22.55 11 22 11H20C19.45 11 19 11.45 19 12C19 12.55 19.45 13 20 13ZM11 2V4C11 4.55 11.45 5 12 5C12.55 5 13 4.55 13 4V2C13 1.45 12.55 1 12 1C11.45 1 11 1.45 11 2ZM11 20V22C11 22.55 11.45 23 12 23C12.55 23 13 22.55 13 22V20C13 19.45 12.55 19 12 19C11.45 19 11 19.45 11 20ZM5.99 4.58C5.6 4.19 4.96 4.19 4.58 4.58C4.19 4.97 4.19 5.61 4.58 5.99L5.64 7.05C6.03 7.44 6.67 7.44 7.05 7.05C7.43 6.66 7.44 6.02 7.05 5.64L5.99 4.58ZM18.36 16.95C17.97 16.56 17.33 16.56 16.95 16.95C16.56 17.34 16.56 17.98 16.95 18.36L18.01 19.42C18.4 19.81 19.04 19.81 19.42 19.42C19.81 19.03 19.81 18.39 19.42 18.01L18.36 16.95ZM19.42 5.99C19.81 5.6 19.81 4.96 19.42 4.58C19.03 4.19 18.39 4.19 18.01 4.58L16.95 5.64C16.56 6.03 16.56 6.67 16.95 7.05C17.34 7.43 17.98 7.44 18.36 7.05L19.42 5.99ZM7.05 18.36C7.44 17.97 7.44 17.33 7.05 16.95C6.66 16.56 6.02 16.56 5.64 16.95L4.58 18.01C4.19 18.4 4.19 19.04 4.58 19.42C4.97 19.8 5.61 19.81 5.99 19.42L7.05 18.36Z" />
</svg>
`;

const information = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM12 17C11.45 17 11 16.55 11 16V12C11 11.45 11.45 11 12 11C12.55 11 13 11.45 13 12V16C13 16.55 12.55 17 12 17ZM13 9H11V7H13V9Z" />
</svg>
`;

const arrow_drop_up = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M8.70999 12.29L11.3 9.69997C11.69 9.30997 12.32 9.30997 12.71 9.69997L15.3 12.29C15.93 12.92 15.48 14 14.59 14H9.40999C8.51999 14 8.07999 12.92 8.70999 12.29Z" />
</svg>
`;

const cloud_download_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M10.995 10L10.9949 12H9.19495C8.75495 12 8.53495 12.54 8.84495 12.85L11.6349 15.64C11.8349 15.84 12.1449 15.84 12.3449 15.64L15.1349 12.85C15.4549 12.54 15.2349 12 14.7849 12H12.9949L12.995 10C12.995 9.45004 12.5449 9.00004 11.995 9.00004C11.445 9.00004 10.995 9.45004 10.995 10Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M19.35 10.04C18.67 6.59 15.64 4 12 4C9.11 4 6.6 5.64 5.35 8.04C2.34 8.36 0 10.91 0 14C0 17.31 2.69 20 6 20H19C21.76 20 24 17.76 24 15C24 12.36 21.95 10.22 19.35 10.04ZM19 18H6C3.79 18 2 16.21 2 14C2 11.95 3.53 10.24 5.56 10.03L6.63 9.92L7.13 8.97C8.08 7.14 9.94 6 12 6C14.62 6 16.88 7.86 17.39 10.43L17.69 11.93L19.22 12.04C20.78 12.14 22 13.45 22 15C22 16.65 20.65 18 19 18Z" />
</svg>
`;

const hourglass = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M6 4V7.17C6 7.7 6.21 8.21 6.59 8.59L10 12L6.58 15.42C6.21 15.8 6 16.31 6 16.84V20C6 21.1 6.9 22 8 22H16C17.1 22 18 21.1 18 20V16.84C18 16.31 17.79 15.8 17.42 15.43L14 12L17.41 8.6C17.79 8.22 18 7.71 18 7.18V4C18 2.9 17.1 2 16 2H8C6.9 2 6 2.9 6 4Z" />
</svg>
`;

const schedule_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11.99 2C6.47 2 2 6.48 2 12C2 17.52 6.47 22 11.99 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 11.99 2ZM12 20C7.58 20 4 16.42 4 12C4 7.58 7.58 4 12 4C16.42 4 20 7.58 20 12C20 16.42 16.42 20 12 20ZM11.78 7H11.72C11.32 7 11 7.32 11 7.72V12.44C11 12.79 11.18 13.12 11.49 13.3L15.64 15.79C15.98 15.99 16.42 15.89 16.62 15.55C16.83 15.21 16.72 14.76 16.37 14.56L12.5 12.26V7.72C12.5 7.32 12.18 7 11.78 7Z" />
</svg>
`;

const translate = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12.65 15.67C12.79 15.31 12.7 14.9 12.42 14.62L10.33 12.56L10.36 12.53C12.1 10.59 13.34 8.36 14.07 6H16.01C16.55 6 17 5.55 17 5.01V4.99C17 4.45 16.55 4 16.01 4H10V3C10 2.45 9.55 2 9 2C8.45 2 8 2.45 8 3V4H1.99C1.45 4 1 4.45 1 4.99C1 5.54 1.45 5.98 1.99 5.98H12.17C11.5 7.92 10.44 9.75 9 11.35C8.19 10.46 7.51 9.49 6.94 8.47C6.78 8.18 6.49 8 6.16 8C5.47 8 5.03 8.75 5.37 9.35C6 10.48 6.77 11.56 7.67 12.56L3.3 16.87C2.9 17.26 2.9 17.9 3.3 18.29C3.69 18.68 4.32 18.68 4.72 18.29L9 14L11.02 16.02C11.53 16.53 12.4 16.34 12.65 15.67ZM17.5 10C16.9 10 16.36 10.37 16.15 10.94L12.48 20.74C12.24 21.35 12.7 22 13.35 22C13.74 22 14.09 21.76 14.23 21.39L15.12 19H19.87L20.77 21.39C20.91 21.75 21.26 22 21.65 22C22.3 22 22.76 21.35 22.53 20.74L18.86 10.94C18.64 10.37 18.1 10 17.5 10ZM15.88 17L17.5 12.67L19.12 17H15.88Z" />
</svg>
`;

const visibility_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 6C15.79 6 19.17 8.13 20.82 11.5C19.17 14.87 15.79 17 12 17C8.21 17 4.83 14.87 3.18 11.5C4.83 8.13 8.21 6 12 6ZM12 4C7 4 2.73 7.11 1 11.5C2.73 15.89 7 19 12 19C17 19 21.27 15.89 23 11.5C21.27 7.11 17 4 12 4ZM12 9C13.38 9 14.5 10.12 14.5 11.5C14.5 12.88 13.38 14 12 14C10.62 14 9.5 12.88 9.5 11.5C9.5 10.12 10.62 9 12 9ZM12 7C9.52 7 7.5 9.02 7.5 11.5C7.5 13.98 9.52 16 12 16C14.48 16 16.5 13.98 16.5 11.5C16.5 9.02 14.48 7 12 7Z" />
</svg>
`;

const chat_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M17 8H7C6.45 8 6 7.55 6 7C6 6.45 6.45 6 7 6H17C17.55 6 18 6.45 18 7C18 7.55 17.55 8 17 8Z" />
<path d="M17 9H7C6.45 9 6 9.45 6 10C6 10.55 6.45 11 7 11H17C17.55 11 18 10.55 18 10C18 9.45 17.55 9 17 9Z" />
<path d="M7 14H13C13.55 14 14 13.55 14 13C14 12.45 13.55 12 13 12H7C6.45 12 6 12.45 6 13C6 13.55 6.45 14 7 14Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M20 2H4C2.9 2 2.01 2.9 2.01 4L2 22L6 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2ZM20 4H4V17.17L5.17 16H20V4Z" />
</svg>
`;

const laptop_computer = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 18C21.1 18 21.99 17.1 21.99 16L22 6C22 4.9 21.1 4 20 4H4C2.9 4 2 4.9 2 6V16C2 17.1 2.9 18 4 18H1C0.45 18 0 18.45 0 19C0 19.55 0.45 20 1 20H23C23.55 20 24 19.55 24 19C24 18.45 23.55 18 23 18H20ZM5 6H19C19.55 6 20 6.45 20 7V15C20 15.55 19.55 16 19 16H5C4.45 16 4 15.55 4 15V7C4 6.45 4.45 6 5 6Z" />
</svg>
`;

const account = `<svg viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM12 5C13.66 5 15 6.34 15 8C15 9.66 13.66 11 12 11C10.34 11 9 9.66 9 8C9 6.34 10.34 5 12 5ZM12 19.2C9.5 19.2 7.29 17.92 6 15.98C6.03 13.99 10 12.9 12 12.9C13.99 12.9 17.97 13.99 18 15.98C16.71 17.92 14.5 19.2 12 19.2Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const fullscreen = `<svg viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M6 14C5.73478 14 5.48043 14.1054 5.29289 14.2929C5.10536 14.4804 5 14.7348 5 15V18C5 18.2652 5.10536 18.5196 5.29289 18.7071C5.48043 18.8946 5.73478 19 6 19H9C9.26522 19 9.51957 18.8946 9.70711 18.7071C9.89464 18.5196 10 18.2652 10 18C10 17.7348 9.89464 17.4804 9.70711 17.2929C9.51957 17.1054 9.26522 17 9 17H7V15C7 14.7348 6.89464 14.4804 6.70711 14.2929C6.51957 14.1054 6.26522 14 6 14ZM6 10C6.26522 10 6.51957 9.89464 6.70711 9.70711C6.89464 9.51957 7 9.26522 7 9V7H9C9.26522 7 9.51957 6.89464 9.70711 6.70711C9.89464 6.51957 10 6.26522 10 6C10 5.73478 9.89464 5.48043 9.70711 5.29289C9.51957 5.10536 9.26522 5 9 5H6C5.73478 5 5.48043 5.10536 5.29289 5.29289C5.10536 5.48043 5 5.73478 5 6V9C5 9.26522 5.10536 9.51957 5.29289 9.70711C5.48043 9.89464 5.73478 10 6 10ZM17 17H15C14.7348 17 14.4804 17.1054 14.2929 17.2929C14.1054 17.4804 14 17.7348 14 18C14 18.2652 14.1054 18.5196 14.2929 18.7071C14.4804 18.8946 14.7348 19 15 19H18C18.2652 19 18.5196 18.8946 18.7071 18.7071C18.8946 18.5196 19 18.2652 19 18V15C19 14.7348 18.8946 14.4804 18.7071 14.2929C18.5196 14.1054 18.2652 14 18 14C17.7348 14 17.4804 14.1054 17.2929 14.2929C17.1054 14.4804 17 14.7348 17 15V17ZM14 6C14 6.26522 14.1054 6.51957 14.2929 6.70711C14.4804 6.89464 14.7348 7 15 7H17V9C17 9.26522 17.1054 9.51957 17.2929 9.70711C17.4804 9.89464 17.7348 10 18 10C18.2652 10 18.5196 9.89464 18.7071 9.70711C18.8946 9.51957 19 9.26522 19 9V6C19 5.73478 18.8946 5.48043 18.7071 5.29289C18.5196 5.10536 18.2652 5 18 5H15C14.7348 5 14.4804 5.10536 14.2929 5.29289C14.1054 5.48043 14 5.73478 14 6Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const remove_circle_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M7 12C7 12.55 7.45 13 8 13H16C16.55 13 17 12.55 17 12C17 11.45 16.55 11 16 11H8C7.45 11 7 11.45 7 12ZM12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM12 20C7.59 20 4 16.41 4 12C4 7.59 7.59 4 12 4C16.41 4 20 7.59 20 12C20 16.41 16.41 20 12 20Z" />
</svg>
`;

const speedX8 = `<svg viewBox="0 0 36 36"  xmlns="http://www.w3.org/2000/svg">
<path d="M17.1479 17.2573C17.46 16.7643 17.6216 16.1909 17.6129 15.6073C17.638 15.1122 17.5513 14.6177 17.3592 14.1607C17.167 13.7036 16.8743 13.2957 16.5029 12.9673C15.6223 12.2853 14.5249 11.9444 13.4129 12.0073C12.3299 11.9555 11.2645 12.2964 10.4129 12.9673C10.0342 13.2914 9.73467 13.6978 9.53709 14.1553C9.33951 14.6129 9.24912 15.1095 9.27285 15.6073C9.26407 16.1909 9.42567 16.7643 9.73786 17.2573C10.0636 17.7411 10.5077 18.1336 11.0279 18.3973C10.4212 18.6638 9.90149 19.0951 9.52786 19.6423C9.17558 20.1814 8.99274 20.8135 9.00286 21.4573C8.98163 21.9694 9.07887 22.4794 9.287 22.9477C9.49514 23.416 9.80856 23.83 10.2029 24.1573C11.1434 24.8726 12.3082 25.2289 13.4879 25.1623C14.6562 25.2312 15.8107 24.8801 16.7429 24.1723C17.1356 23.8412 17.4468 23.424 17.6523 22.9532C17.8578 22.4823 17.9521 21.9705 17.9279 21.4573C17.9425 20.8014 17.7539 20.1569 17.3879 19.6123C17.004 19.0819 16.4864 18.6627 15.8879 18.3973C16.3998 18.1333 16.834 17.7404 17.1479 17.2573ZM14.4929 20.0023C14.7816 20.3388 14.9269 20.775 14.8979 21.2173C14.9269 21.6597 14.7816 22.0959 14.4929 22.4323C14.3597 22.5815 14.1951 22.6993 14.011 22.7771C13.8268 22.8549 13.6276 22.8909 13.4279 22.8823C13.2244 22.8855 13.0223 22.8473 12.8341 22.7699C12.6458 22.6926 12.4753 22.5777 12.3329 22.4323C12.0442 22.095 11.8941 21.6609 11.9129 21.2173C11.8895 20.7731 12.0402 20.3373 12.3329 20.0023C12.6283 19.7336 13.0134 19.5846 13.4129 19.5846C13.8123 19.5846 14.1974 19.7336 14.4929 20.0023ZM12.9024 14.3775C13.0585 14.3099 13.228 14.2791 13.3979 14.2873C13.5725 14.2755 13.7476 14.3046 13.909 14.3723C14.0705 14.44 14.2139 14.5445 14.3279 14.6773C14.5517 14.9915 14.6627 15.3721 14.6429 15.7573C14.6616 16.1496 14.5566 16.5379 14.3429 16.8673C14.2377 17.0084 14.0989 17.1208 13.939 17.1942C13.7791 17.2675 13.6033 17.2996 13.4279 17.2873C13.2502 17.2994 13.0724 17.2674 12.9101 17.1941C12.7479 17.1208 12.6062 17.0086 12.4979 16.8673C12.2718 16.5429 12.1609 16.1521 12.1829 15.7573C12.163 15.3721 12.2741 14.9915 12.4979 14.6773C12.608 14.5477 12.7464 14.4452 12.9024 14.3775ZM24.7679 15.4723L23.2679 18.0973L22.0229 15.4723H18.9029L21.4079 20.1073L18.7679 24.9823H21.7679L23.2679 22.1773L24.7679 24.9823H27.8879L25.2629 20.1073L27.7679 15.4723H24.7679Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const copy_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15 20H5V7C5 6.45 4.55 6 4 6C3.45 6 3 6.45 3 7V20C3 21.1 3.9 22 5 22H15C15.55 22 16 21.55 16 21C16 20.45 15.55 20 15 20ZM20 16V4C20 2.9 19.1 2 18 2H9C7.9 2 7 2.9 7 4V16C7 17.1 7.9 18 9 18H18C19.1 18 20 17.1 20 16ZM18 16H9V4H18V16Z" />
</svg>
`;

const desktop_computer = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M21 2H3C1.9 2 1 2.9 1 4V16C1 17.1 1.9 18 3 18H10V20H9C8.45 20 8 20.45 8 21C8 21.55 8.45 22 9 22H15C15.55 22 16 21.55 16 21C16 20.45 15.55 20 15 20H14V18H21C22.1 18 23 17.1 23 16V4C23 2.9 22.1 2 21 2ZM20 16H4C3.45 16 3 15.55 3 15V5C3 4.45 3.45 4 4 4H20C20.55 4 21 4.45 21 5V15C21 15.55 20.55 16 20 16Z" />
</svg>
`;

const home = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9.99998 19V14H14V19C14 19.55 14.45 20 15 20H18C18.55 20 19 19.55 19 19V12H20.7C21.16 12 21.38 11.43 21.03 11.13L12.67 3.6C12.29 3.26 11.71 3.26 11.33 3.6L2.96998 11.13C2.62998 11.43 2.83998 12 3.29998 12H4.99998V19C4.99998 19.55 5.44998 20 5.99998 20H8.99998C9.54998 20 9.99998 19.55 9.99998 19Z" />
</svg>
`;

const smartphone = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M17 1.01L7 1C5.9 1 5 1.9 5 3V21C5 22.1 5.9 23 7 23H17C18.1 23 19 22.1 19 21V3C19 1.9 18.1 1.01 17 1.01ZM17 19H7V5H17V19Z" />
</svg>
`;

const format_align_center = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M7 16C7 16.55 7.45 17 8 17H16C16.55 17 17 16.55 17 16C17 15.45 16.55 15 16 15H8C7.45 15 7 15.45 7 16ZM4 21H20C20.55 21 21 20.55 21 20C21 19.45 20.55 19 20 19H4C3.45 19 3 19.45 3 20C3 20.55 3.45 21 4 21ZM4 13H20C20.55 13 21 12.55 21 12C21 11.45 20.55 11 20 11H4C3.45 11 3 11.45 3 12C3 12.55 3.45 13 4 13ZM7 8C7 8.55 7.45 9 8 9H16C16.55 9 17 8.55 17 8C17 7.45 16.55 7 16 7H8C7.45 7 7 7.45 7 8ZM3 4C3 4.55 3.45 5 4 5H20C20.55 5 21 4.55 21 4C21 3.45 20.55 3 20 3H4C3.45 3 3 3.45 3 4Z" />
</svg>
`;

const logout = `<svg viewBox="0 0 18 18"  xmlns="http://www.w3.org/2000/svg">
<path d="M3.75 3.75H8.25C8.44891 3.75 8.63968 3.67098 8.78033 3.53033C8.92098 3.38968 9 3.19891 9 3C9 2.80109 8.92098 2.61032 8.78033 2.46967C8.63968 2.32902 8.44891 2.25 8.25 2.25H3.75C3.35218 2.25 2.97064 2.40804 2.68934 2.68934C2.40804 2.97064 2.25 3.35218 2.25 3.75V14.25C2.25 14.6478 2.40804 15.0294 2.68934 15.3107C2.97064 15.592 3.35218 15.75 3.75 15.75H8.25C8.44891 15.75 8.63968 15.671 8.78033 15.5303C8.92098 15.3897 9 15.1989 9 15C9 14.8011 8.92098 14.6103 8.78033 14.4697C8.63968 14.329 8.44891 14.25 8.25 14.25H3.75V3.75Z" fill-rule="nonzero" stroke="none"/>
<path d="M15.4875 8.73754L13.395 6.64504C13.343 6.59107 13.276 6.55393 13.2027 6.53841C13.1293 6.52288 13.0531 6.52968 12.9836 6.55794C12.9142 6.58619 12.8549 6.6346 12.8132 6.69691C12.7716 6.75923 12.7495 6.83259 12.75 6.90754V8.25004H7.5C7.30109 8.25004 7.11032 8.32906 6.96967 8.46971C6.82902 8.61036 6.75 8.80113 6.75 9.00004C6.75 9.19895 6.82902 9.38972 6.96967 9.53037C7.11032 9.67102 7.30109 9.75004 7.5 9.75004H12.75V11.0925C12.7472 11.1676 12.7676 11.2417 12.8082 11.3049C12.8489 11.368 12.9079 11.4172 12.9773 11.4458C13.0468 11.4744 13.1233 11.481 13.1967 11.4648C13.27 11.4486 13.3366 11.4103 13.3875 11.355L15.48 9.26254C15.5154 9.22882 15.5437 9.18838 15.5633 9.14358C15.5829 9.09877 15.5934 9.05051 15.5941 9.00162C15.5948 8.95272 15.5857 8.90418 15.5674 8.85884C15.5491 8.81349 15.5219 8.77225 15.4875 8.73754Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const group_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9 13.75C6.66 13.75 2 14.92 2 17.25V19H16V17.25C16 14.92 11.34 13.75 9 13.75ZM4.34 17C5.18 16.42 7.21 15.75 9 15.75C10.79 15.75 12.82 16.42 13.66 17H4.34ZM9 12C10.93 12 12.5 10.43 12.5 8.5C12.5 6.57 10.93 5 9 5C7.07 5 5.5 6.57 5.5 8.5C5.5 10.43 7.07 12 9 12ZM9 7C9.83 7 10.5 7.67 10.5 8.5C10.5 9.33 9.83 10 9 10C8.17 10 7.5 9.33 7.5 8.5C7.5 7.67 8.17 7 9 7ZM16.04 13.81C17.2 14.65 18 15.77 18 17.25V19H22V17.25C22 15.23 18.5 14.08 16.04 13.81ZM15 12C16.93 12 18.5 10.43 18.5 8.5C18.5 6.57 16.93 5 15 5C14.46 5 13.96 5.13 13.5 5.35C14.13 6.24 14.5 7.33 14.5 8.5C14.5 9.67 14.13 10.76 13.5 11.65C13.96 11.87 14.46 12 15 12Z" />
</svg>
`;

const thumbs_up = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M13.1201 2.06L7.5901 7.6C7.2201 7.97 7.0101 8.48 7.0101 9.01L7.0101 19C7.0101 20.1 7.9101 21 9.0101 21L18.0001 21C18.8001 21 19.5201 20.52 19.8301 19.79L23.0901 12.18C23.9401 10.2 22.4901 8 20.3401 8L14.6901 8L15.6401 3.42C15.7401 2.92 15.5901 2.41 15.2301 2.05C14.6401 1.47 13.7001 1.47 13.1201 2.06ZM3.0001 21C4.1001 21 5.0001 20.1 5.0001 19L5.0001 11C5.0001 9.9 4.1001 9 3.0001 9C1.9001 9 1.0001 9.9 1.0001 11L1.0001 19C1.0001 20.1 1.9001 21 3.0001 21Z" />
</svg>
`;

const radio_unselected = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM12 20C7.58 20 4 16.42 4 12C4 7.58 7.58 4 12 4C16.42 4 20 7.58 20 12C20 16.42 16.42 20 12 20Z" />
</svg>
`;

const person_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M16 8C16 10.21 14.21 12 12 12C9.79 12 8 10.21 8 8C8 5.79 9.79 4 12 4C14.21 4 16 5.79 16 8ZM12 6C13.1 6 14 6.9 14 8C14 9.1 13.1 10 12 10C10.9 10 10 9.1 10 8C10 6.9 10.9 6 12 6Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M4 18C4 15.34 9.33 14 12 14C14.67 14 20 15.34 20 18V19C20 19.55 19.55 20 19 20H5C4.45 20 4 19.55 4 19V18ZM12 16C14.7 16 17.8 17.29 18 18H6C6.23 17.28 9.31 16 12 16Z" />
</svg>
`;

const export_icon = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M5 19H17V18.5C17 17.95 17.45 17.5 18 17.5C18.55 17.5 19 17.95 19 18.5V19C19 20.1 18.11 21 17 21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3H17C18.1 3 19 3.9 19 5V5.5C19 6.05 18.55 6.5 18 6.5C17.45 6.5 17 6.05 17 5.5V5H5V19Z" />
<path d="M15.71 16.29C16.1 16.68 16.73 16.68 17.12 16.29L20.71 12.7C21.1 12.31 21.1 11.68 20.71 11.29L17.12 7.69997C16.73 7.30997 16.1 7.30997 15.71 7.69997C15.32 8.08997 15.32 8.71997 15.71 9.10997L17.59 11H8.92004C8.37004 11 7.92004 11.45 7.92004 12C7.92004 12.55 8.37004 13 8.92004 13H17.59L15.71 14.88C15.32 15.27 15.33 15.91 15.71 16.29Z" />
</svg>
`;

const tag = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 9C20 8.45 19.55 8 19 8H16V5C16 4.45 15.55 4 15 4C14.45 4 14 4.45 14 5V8H10V5C10 4.45 9.55 4 9 4C8.45 4 8 4.45 8 5V8H5C4.45 8 4 8.45 4 9C4 9.55 4.45 10 5 10H8V14H5C4.45 14 4 14.45 4 15C4 15.55 4.45 16 5 16H8V19C8 19.55 8.45 20 9 20C9.55 20 10 19.55 10 19V16H14V19C14 19.55 14.45 20 15 20C15.55 20 16 19.55 16 19V16H19C19.55 16 20 15.55 20 15C20 14.45 19.55 14 19 14H16V10H19C19.55 10 20 9.55 20 9ZM14 14H10V10H14V14Z" />
</svg>
`;

const dashboard_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M10 13H4C3.45 13 3 12.55 3 12V4C3 3.45 3.45 3 4 3H10C10.55 3 11 3.45 11 4V12C11 12.55 10.55 13 10 13ZM9 5V11H5V5H9Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M10 21H4C3.45 21 3 20.55 3 20V16C3 15.45 3.45 15 4 15H10C10.55 15 11 15.45 11 16V20C11 20.55 10.55 21 10 21ZM9 17V19H5V17H9Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M20 21H14C13.45 21 13 20.55 13 20V12C13 11.45 13.45 11 14 11H20C20.55 11 21 11.45 21 12V20C21 20.55 20.55 21 20 21ZM19 19V13H15V19H19Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M13 8V4C13 3.45 13.45 3 14 3H20C20.55 3 21 3.45 21 4V8C21 8.55 20.55 9 20 9H14C13.45 9 13 8.55 13 8ZM19 5V7H15V5H19Z" />
</svg>
`;

const arrow_back = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19 11H7.83L12.71 6.11997C13.1 5.72997 13.1 5.08997 12.71 4.69997C12.32 4.30997 11.69 4.30997 11.3 4.69997L4.71 11.29C4.32 11.68 4.32 12.31 4.71 12.7L11.3 19.29C11.69 19.68 12.32 19.68 12.71 19.29C13.1 18.9 13.1 18.27 12.71 17.88L7.83 13H19C19.55 13 20 12.55 20 12C20 11.45 19.55 11 19 11Z" />
</svg>
`;

const visibility = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 4C7 4 2.73 7.11 1 11.5C2.73 15.89 7 19 12 19C17 19 21.27 15.89 23 11.5C21.27 7.11 17 4 12 4ZM12 16.5C9.24 16.5 7 14.26 7 11.5C7 8.74 9.24 6.5 12 6.5C14.76 6.5 17 8.74 17 11.5C17 14.26 14.76 16.5 12 16.5ZM12 8.5C10.34 8.5 9 9.84 9 11.5C9 13.16 10.34 14.5 12 14.5C13.66 14.5 15 13.16 15 11.5C15 9.84 13.66 8.5 12 8.5Z" />
</svg>
`;

const cloud_download = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M19.35 10.04C18.67 6.59 15.64 4 12 4C9.11 4 6.6 5.64 5.35 8.04C2.34 8.36 0 10.91 0 14C0 17.31 2.69 20 6 20H19C21.76 20 24 17.76 24 15C24 12.36 21.95 10.22 19.35 10.04ZM10.995 10L10.9949 12H9.19495C8.75495 12 8.53495 12.54 8.84495 12.85L11.6349 15.64C11.8349 15.84 12.1449 15.84 12.3449 15.64L15.1349 12.85C15.4549 12.54 15.2349 12 14.7849 12H12.9949L12.995 10C12.995 9.45004 12.5449 9.00004 11.995 9.00004C11.445 9.00004 10.995 9.45004 10.995 10Z" />
</svg>
`;

const analytics_outline = `<svg viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9 16V13C9 12.4477 8.55228 12 8 12C7.44772 12 7 12.4477 7 13V16C7 16.5523 7.44772 17 8 17C8.55228 17 9 16.5523 9 16Z" />
<path d="M16 7C16.5523 7 17 7.44772 17 8V16C17 16.5523 16.5523 17 16 17C15.4477 17 15 16.5523 15 16V8C15 7.44772 15.4477 7 16 7Z" />
<path d="M13 16V15C13 14.4477 12.5523 14 12 14C11.4477 14 11 14.4477 11 15V16C11 16.5523 11.4477 17 12 17C12.5523 17 13 16.5523 13 16Z" />
<path d="M12 12C11.4477 12 11 11.5523 11 11C11 10.4477 11.4477 10 12 10C12.5523 10 13 10.4477 13 11C13 11.5523 12.5523 12 12 12Z" />
<path d="M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3ZM5 19V5H19V19H5Z" />
</svg>
`;

const wifi_locked = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M12 4C16.3 4 20.22 5.6 23.21 8.24C23.65 8.63 23.68 9.3 23.28 9.71L21.99 11H19.05C17.29 11 15.82 12.14 15.28 13.71C15.14 14.12 15.05 14.55 15.05 15V17.95L12.71 20.29C12.31 20.68 11.68 20.68 11.29 20.29L6.35001 15.34L0.730011 9.71C0.320011 9.3 0.350011 8.63 0.790011 8.24C3.78001 5.6 7.70001 4 12 4ZM22 15V16C22.55 16 23 16.45 23 17V20C23 20.55 22.55 21 22 21H18C17.45 21 17 20.55 17 20V17C17 16.45 17.45 16 18 16V15C18 13.9 18.9 13 20 13C21.1 13 22 13.9 22 15ZM19 16H21V15C21 14.45 20.55 14 20 14C19.45 14 19 14.45 19 15V16Z" />
</svg>
`;

const label = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M17.63 5.84C17.27 5.33 16.67 5 16 5L5 5.01C3.9 5.01 3 5.9 3 7V17C3 18.1 3.9 18.99 5 18.99L16 19C16.67 19 17.27 18.67 17.63 18.16L21.59 12.58C21.84 12.23 21.84 11.77 21.59 11.42L17.63 5.84Z" />
</svg>
`;

const microphone = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 15C13.66 15 14.99 13.66 14.99 12L15 6C15 4.34 13.66 3 12 3C10.34 3 8.99998 4.34 8.99998 6V12C8.99998 13.66 10.34 15 12 15ZM18.08 12C17.66 12 17.31 12.3 17.25 12.71C16.88 15.32 14.53 17.1 12 17.1C9.46998 17.1 7.11998 15.33 6.74998 12.71C6.68998 12.3 6.32998 12 5.91998 12C5.39998 12 4.99998 12.46 5.06998 12.97C5.52998 15.94 8.02998 18.27 11 18.72V21C11 21.55 11.45 22 12 22C12.55 22 13 21.55 13 21V18.72C15.96 18.29 18.47 15.94 18.93 12.97C19 12.46 18.6 12 18.08 12Z" />
</svg>
`;

const zoom_in = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15.4999 14H14.7099L14.4299 13.73C15.6299 12.33 16.2499 10.42 15.9099 8.39C15.4399 5.61 13.1199 3.39 10.3199 3.05C6.0899 2.53 2.5399 6.09 3.0499 10.32C3.3899 13.12 5.6099 15.44 8.3899 15.91C10.4199 16.25 12.3299 15.63 13.7299 14.43L13.9999 14.71V15.5L18.2599 19.75C18.6699 20.16 19.3299 20.16 19.7399 19.75L19.7499 19.74C20.1599 19.33 20.1599 18.67 19.7499 18.26L15.4999 14ZM9.4999 14C7.0099 14 4.9999 11.99 4.9999 9.5C4.9999 7.01 7.0099 5 9.4999 5C11.9899 5 13.9999 7.01 13.9999 9.5C13.9999 11.99 11.9899 14 9.4999 14ZM9.4999 7C9.2199 7 8.9999 7.22 8.9999 7.5V9H7.4999C7.2199 9 6.9999 9.22 6.9999 9.5C6.9999 9.78 7.2199 10 7.4999 10H8.9999V11.5C8.9999 11.78 9.2199 12 9.4999 12C9.7799 12 9.9999 11.78 9.9999 11.5V10H11.4999C11.7799 10 11.9999 9.78 11.9999 9.5C11.9999 9.22 11.7799 9 11.4999 9H9.9999V7.5C9.9999 7.22 9.7799 7 9.4999 7Z" />
</svg>
`;

const format_align_left = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14 15H4C3.45 15 3 15.45 3 16C3 16.55 3.45 17 4 17H14C14.55 17 15 16.55 15 16C15 15.45 14.55 15 14 15ZM14 7H4C3.45 7 3 7.45 3 8C3 8.55 3.45 9 4 9H14C14.55 9 15 8.55 15 8C15 7.45 14.55 7 14 7ZM4 13H20C20.55 13 21 12.55 21 12C21 11.45 20.55 11 20 11H4C3.45 11 3 11.45 3 12C3 12.55 3.45 13 4 13ZM4 21H20C20.55 21 21 20.55 21 20C21 19.45 20.55 19 20 19H4C3.45 19 3 19.45 3 20C3 20.55 3.45 21 4 21ZM3 4C3 4.55 3.45 5 4 5H20C20.55 5 21 4.55 21 4C21 3.45 20.55 3 20 3H4C3.45 3 3 3.45 3 4Z" />
</svg>
`;

const clear = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.47 2 2 6.47 2 12C2 17.53 6.47 22 12 22C17.53 22 22 17.53 22 12C22 6.47 17.53 2 12 2ZM16.3 16.3C15.91 16.69 15.28 16.69 14.89 16.3L12 13.41L9.11 16.3C8.72 16.69 8.09 16.69 7.7 16.3C7.31 15.91 7.31 15.28 7.7 14.89L10.59 12L7.7 9.11C7.31 8.72 7.31 8.09 7.7 7.7C8.09 7.31 8.72 7.31 9.11 7.7L12 10.59L14.89 7.7C15.28 7.31 15.91 7.31 16.3 7.7C16.69 8.09 16.69 8.72 16.3 9.11L13.41 12L16.3 14.89C16.68 15.27 16.68 15.91 16.3 16.3Z" />
</svg>
`;

const format_quote = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M7.17 17C7.68 17 8.15 16.71 8.37 16.26L9.79 13.42C9.93 13.14 10 12.84 10 12.53V8C10 7.45 9.55 7 9 7H5C4.45 7 4 7.45 4 8V12C4 12.55 4.45 13 5 13H7L5.97 15.06C5.52 15.95 6.17 17 7.17 17ZM17.17 17C17.68 17 18.15 16.71 18.37 16.26L19.79 13.42C19.93 13.14 20 12.84 20 12.53V8C20 7.45 19.55 7 19 7H15C14.45 7 14 7.45 14 8V12C14 12.55 14.45 13 15 13H17L15.97 15.06C15.52 15.95 16.17 17 17.17 17Z" />
</svg>
`;

const calculate_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14.62 6.52756C14.33 6.23756 13.85 6.23756 13.56 6.52756C13.26 6.81756 13.26 7.29756 13.56 7.59756L14.44 8.47756L13.56 9.35756C13.27 9.64756 13.27 10.1276 13.56 10.4176C13.85 10.7076 14.33 10.7076 14.62 10.4176L15.5 9.53756L16.38 10.4076C16.67 10.6976 17.15 10.6976 17.44 10.4076C17.73 10.1176 17.73 9.63756 17.44 9.34756L16.56 8.46756L17.44 7.58756C17.73 7.29756 17.73 6.81756 17.44 6.52756C17.15 6.23756 16.67 6.23756 16.38 6.52756L15.5 7.40756L14.62 6.52756Z" />
<path d="M10.5 7.71756H7C6.59 7.71756 6.25 8.05756 6.25 8.46756C6.25 8.87756 6.59 9.21756 7 9.21756H10.5C10.91 9.21756 11.25 8.87756 11.25 8.46756C11.25 8.05756 10.91 7.71756 10.5 7.71756Z" />
<path d="M10.75 15.9976H9.5V17.2476C9.5 17.6576 9.16 17.9976 8.75 17.9976C8.34 17.9976 8 17.6576 8 17.2476V15.9976H6.75C6.34 15.9976 6 15.6576 6 15.2476C6 14.8376 6.34 14.4976 6.75 14.4976H8V13.2476C8 12.8376 8.34 12.4976 8.75 12.4976C9.16 12.4976 9.5 12.8376 9.5 13.2476V14.4976H10.75C11.16 14.4976 11.5 14.8376 11.5 15.2476C11.5 15.6576 11.16 15.9976 10.75 15.9976Z" />
<path d="M17.25 17.2476C17.66 17.2476 18 16.9076 18 16.4976C18 16.0876 17.66 15.7476 17.25 15.7476H13.75C13.34 15.7476 13 16.0876 13 16.4976C13 16.9076 13.34 17.2476 13.75 17.2476H17.25Z" />
<path d="M17.25 14.7476H13.75C13.34 14.7476 13 14.4076 13 13.9976C13 13.5876 13.34 13.2476 13.75 13.2476H17.25C17.66 13.2476 18 13.5876 18 13.9976C18 14.4076 17.66 14.7476 17.25 14.7476Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M5 3H19C20.1 3 21 3.9 21 5V19C21 20.1 20.1 21 19 21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3ZM5 19H19V5H5V19Z" />
</svg>
`;

const cloud_done = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19.35 10.04C18.67 6.59 15.64 4 12 4C9.11 4 6.6 5.64 5.35 8.04C2.34 8.36 0 10.91 0 14C0 17.31 2.69 20 6 20H19C21.76 20 24 17.76 24 15C24 12.36 21.95 10.22 19.35 10.04ZM10.71 16.29C10.32 16.68 9.69 16.68 9.3 16.29L7.2 14.2C6.81 13.81 6.81 13.18 7.2 12.79C7.59 12.4 8.22 12.4 8.61 12.79L10 14.18L14.48 9.7C14.87 9.31 15.5 9.31 15.89 9.7C16.28 10.09 16.28 10.72 15.89 11.11L10.71 16.29Z" />
</svg>
`;

const keyboard = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 5H4C2.9 5 2.01 5.9 2.01 7L2 17C2 18.1 2.9 19 4 19H20C21.1 19 22 18.1 22 17V7C22 5.9 21.1 5 20 5ZM11 8H13V10H11V8ZM11 11H13V13H11V11ZM8 8H10V10H8V8ZM8 11H10V13H8V11ZM7 13H5V11H7V13ZM7 10H5V8H7V10ZM15 16H9C8.45 16 8 15.55 8 15C8 14.45 8.45 14 9 14H15C15.55 14 16 14.45 16 15C16 15.55 15.55 16 15 16ZM16 13H14V11H16V13ZM16 10H14V8H16V10ZM19 13H17V11H19V13ZM19 10H17V8H19V10Z" />
</svg>
`;

const lock = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 8H17V6C17 3.24 14.76 1 12 1C9.24 1 7 3.24 7 6V8H6C4.9 8 4 8.9 4 10V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V10C20 8.9 19.1 8 18 8ZM12 17C10.9 17 10 16.1 10 15C10 13.9 10.9 13 12 13C13.1 13 14 13.9 14 15C14 16.1 13.1 17 12 17ZM9 8V6C9 4.34 10.34 3 12 3C13.66 3 15 4.34 15 6V8H9Z" />
</svg>
`;

const plagiarism_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M15.7462 17.7475C15.3562 18.1375 14.7262 18.1375 14.3362 17.7475L13.1562 16.5675C11.8262 17.2775 10.1462 17.0975 9.02624 15.9775C7.50624 14.4575 7.67624 11.8975 9.52624 10.6075C10.6862 9.7975 12.3062 9.7975 13.4762 10.6075C15.0262 11.6875 15.3762 13.6475 14.5662 15.1575L15.7462 16.3375C16.1362 16.7275 16.1362 17.3575 15.7462 17.7475ZM11.5 15C12.3284 15 13 14.3284 13 13.5C13 12.6716 12.3284 12 11.5 12C10.6716 12 10 12.6716 10 13.5C10 14.3284 10.6716 15 11.5 15Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M14.5 2.5C14.5 2.5 14 2 13.3 2C12.6 2 6 2 6 2C4.9 2 4 2.9 4 4V20C4 21.1 4.89 22 5.99 22H18C19.1 22 20 21.1 20 20C20 20 20 9.36187 20 8.72C20 8.07812 19.5 7.5 19.5 7.5L14.5 2.5ZM18 20H6V4H13V8.09091C13 8.59091 13.4091 9 13.9091 9H18V20Z" />
</svg>
`;

const rewindX10 = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11.9485 5.29794V2.50794C11.9522 2.40786 11.9251 2.30906 11.8709 2.22485C11.8167 2.14063 11.738 2.07504 11.6454 2.03691C11.5528 1.99878 11.4507 1.98994 11.3529 2.01158C11.2552 2.03322 11.1664 2.0843 11.0985 2.15794L7.29849 5.94794C7.25163 5.99442 7.21443 6.04972 7.18905 6.11065C7.16366 6.17158 7.15059 6.23694 7.15059 6.30294C7.15059 6.36895 7.16366 6.4343 7.18905 6.49523C7.21443 6.55616 7.25163 6.61146 7.29849 6.65794L11.0885 10.4479C11.1578 10.5199 11.2472 10.5694 11.3449 10.5901C11.4427 10.6108 11.5444 10.6017 11.637 10.5641C11.7295 10.5264 11.8087 10.4619 11.8642 10.3788C11.9197 10.2957 11.9491 10.1979 11.9485 10.0979V7.29794C13.0989 7.29804 14.225 7.62884 15.1926 8.25093C16.1603 8.87302 16.9287 9.76017 17.4063 10.8067C17.884 11.8532 18.0507 13.015 17.8867 14.1536C17.7226 15.2922 17.2347 16.3597 16.481 17.2288C15.7274 18.0979 14.7397 18.732 13.6358 19.0556C12.5319 19.3793 11.3582 19.3787 10.2546 19.054C9.15102 18.7294 8.16401 18.0943 7.41119 17.2245C6.65836 16.3546 6.17146 15.2867 6.00849 14.1479C5.97233 13.9095 5.85121 13.6921 5.66744 13.5359C5.48368 13.3797 5.24965 13.2952 5.00849 13.2979C4.86548 13.2967 4.72387 13.3262 4.59321 13.3844C4.46256 13.4426 4.34591 13.5281 4.25113 13.6352C4.15635 13.7423 4.08564 13.8685 4.04379 14.0052C4.00193 14.142 3.98989 14.2861 4.00849 14.4279C4.22505 15.9457 4.87318 17.3693 5.87572 18.5292C6.87826 19.6891 8.19298 20.5366 9.6634 20.9706C11.1338 21.4047 12.698 21.4071 14.1697 20.9775C15.6415 20.5479 16.9588 19.7045 17.9648 18.5477C18.9709 17.3908 19.6234 15.9692 19.8446 14.4521C20.0658 12.935 19.8464 11.3863 19.2125 9.99034C18.5786 8.59438 17.557 7.40995 16.2692 6.57805C14.9814 5.74615 13.4816 5.30181 11.9485 5.29794ZM10.8485 16.2979H9.94849V13.0379L8.94849 13.3479V12.6579L10.7185 12.0279H10.8085L10.8485 16.2979ZM15.1285 14.5379C15.1362 14.8147 15.1025 15.0911 15.0285 15.3579C14.9666 15.5637 14.8684 15.7568 14.7385 15.9279C14.6187 16.0741 14.4639 16.1877 14.2885 16.2579C14.1002 16.3293 13.8998 16.3632 13.6985 16.3579C13.4973 16.3623 13.2971 16.3283 13.1085 16.2579C12.9301 16.188 12.7719 16.0746 12.6485 15.9279C12.5094 15.7612 12.4072 15.567 12.3485 15.3579C12.2716 15.0915 12.2345 14.8152 12.2385 14.5379V13.7979C12.2308 13.5212 12.2645 13.2448 12.3385 12.9779C12.4004 12.7722 12.4986 12.5791 12.6285 12.4079C12.7482 12.2617 12.9031 12.1482 13.0785 12.0779C13.2668 12.0066 13.4672 11.9726 13.6685 11.9779C13.8697 11.9736 14.0699 12.0076 14.2585 12.0779C14.4369 12.1479 14.5951 12.2613 14.7185 12.4079C14.8576 12.5747 14.9598 12.7689 15.0185 12.9779C15.0954 13.2444 15.1325 13.5207 15.1285 13.7979V14.5379ZM14.2785 13.6779C14.2959 13.5184 14.2959 13.3575 14.2785 13.1979C14.2561 13.0886 14.2155 12.9839 14.1585 12.8879C14.116 12.8116 14.0491 12.7517 13.9685 12.7179C13.8889 12.6861 13.8042 12.6692 13.7185 12.6679C13.6327 12.6682 13.5478 12.6852 13.4685 12.7179C13.3898 12.7546 13.3237 12.8138 13.2785 12.8879C13.2215 12.9839 13.1809 13.0886 13.1585 13.1979C13.1411 13.3575 13.1411 13.5184 13.1585 13.6779V14.6779C13.1411 14.8375 13.1411 14.9984 13.1585 15.1579C13.1811 15.2703 13.2216 15.3784 13.2785 15.4779C13.321 15.5543 13.3879 15.6142 13.4685 15.6479C13.5511 15.6629 13.6358 15.6629 13.7185 15.6479C13.8011 15.6639 13.8859 15.6639 13.9685 15.6479C14.0472 15.6113 14.1133 15.5521 14.1585 15.4779C14.216 15.3796 14.2534 15.2708 14.2685 15.1579C14.281 14.9982 14.281 14.8377 14.2685 14.6779V13.6779H14.2785Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const hourglass_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M8 2C6.9 2 6 2.9 6 4V7.17C6 7.7 6.21 8.21 6.59 8.59L10 12L6.58 15.42C6.21 15.8 6 16.31 6 16.84V20C6 21.1 6.9 22 8 22H16C17.1 22 18 21.1 18 20V16.84C18 16.31 17.79 15.8 17.42 15.43L14 12L17.41 8.6C17.79 8.22 18 7.71 18 7.18V4C18 2.9 17.1 2 16 2H8ZM16 16.5V19C16 19.55 15.55 20 15 20H9C8.45 20 8 19.55 8 19V16.5L12 12.5L16 16.5ZM12 11.5L8 7.5V5C8 4.45 8.45 4 9 4H15C15.55 4 16 4.45 16 5V7.5L12 11.5Z" />
</svg>
`;

const calender = `<svg viewBox="0 0 20 22"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 2H17V0H15V2H5V0H3V2H2C0.9 2 0 2.9 0 4V20C0 21.1 0.9 22 2 22H18C19.1 22 20 21.1 20 20V4C20 2.9 19.1 2 18 2ZM18 20H2V7H18V20Z"/>
</svg>
`;

const alarm_outline = `<svg viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15.87 15.25L12.5 13.25V8.72C12.5 8.32 12.18 8 11.78 8H11.72C11.32 8 11 8.32 11 8.72V13.44C11 13.79 11.18 14.12 11.49 14.3L15.14 16.49C15.48 16.69 15.92 16.59 16.12 16.25C16.33 15.9 16.22 15.45 15.87 15.25ZM21.18 5.01L18.1 2.45C17.68 2.1 17.05 2.15 16.69 2.58C16.34 3 16.4 3.63 16.82 3.99L19.89 6.55C20.31 6.9 20.94 6.85 21.3 6.42C21.66 6 21.6 5.37 21.18 5.01ZM4.10001 6.55L7.17001 3.99C7.60001 3.63 7.66001 3 7.30001 2.58C6.95001 2.15 6.32001 2.1 5.90001 2.45L2.82001 5.01C2.40001 5.37 2.34001 6 2.70001 6.42C3.05001 6.85 3.68001 6.9 4.10001 6.55ZM12 4C7.03001 4 3.00001 8.03 3.00001 13C3.00001 17.97 7.03001 22 12 22C16.97 22 21 17.97 21 13C21 8.03 16.97 4 12 4ZM12 20C8.14001 20 5.00001 16.86 5.00001 13C5.00001 9.14 8.14001 6 12 6C15.86 6 19 9.14 19 13C19 16.86 15.86 20 12 20Z" />
</svg>
`;

const arrow_left = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12.29 8.71005L9.69997 11.3001C9.30997 11.6901 9.30997 12.3201 9.69997 12.7101L12.29 15.3001C12.92 15.9301 14 15.4801 14 14.5901V9.41005C14 8.52005 12.92 8.08005 12.29 8.71005Z" />
</svg>
`;

const plagiarism = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M13 14.5C13 15.3284 12.3284 16 11.5 16C10.6716 16 10 15.3284 10 14.5C10 13.6716 10.6716 13 11.5 13C12.3284 13 13 13.6716 13 14.5Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M14.58 2.58L19.41 7.41C19.79 7.79 20 8.3 20 8.83V20C20 21.1 19.1 22 18 22H6C4.9 22 4 21.1 4 20V4C4 2.9 4.9 2 6 2H13.17C13.7 2 14.21 2.21 14.58 2.58ZM14.33 18.74C14.72 19.13 15.35 19.13 15.74 18.74C16.13 18.35 16.13 17.72 15.74 17.33L14.56 16.15C15.37 14.64 15.02 12.68 13.47 11.6C12.3 10.79 10.68 10.79 9.52 11.6C7.67 12.89 7.5 15.45 9.02 16.97C10.14 18.09 11.82 18.27 13.15 17.56L14.33 18.74ZM13 8C13 8.55 13.45 9 14 9H18.5L13 3.5V8Z" />
</svg>
`;

const link = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M17 7H14C13.45 7 13 7.45 13 8C13 8.55 13.45 9 14 9H17C18.65 9 20 10.35 20 12C20 13.65 18.65 15 17 15H14C13.45 15 13 15.45 13 16C13 16.55 13.45 17 14 17H17C19.76 17 22 14.76 22 12C22 9.24 19.76 7 17 7ZM8 12C8 12.55 8.45 13 9 13H15C15.55 13 16 12.55 16 12C16 11.45 15.55 11 15 11H9C8.45 11 8 11.45 8 12ZM10 15H7C5.35 15 4 13.65 4 12C4 10.35 5.35 9 7 9H10C10.55 9 11 8.55 11 8C11 7.45 10.55 7 10 7H7C4.24 7 2 9.24 2 12C2 14.76 4.24 17 7 17H10C10.55 17 11 16.55 11 16C11 15.45 10.55 15 10 15Z" />
</svg>
`;

const forwardX10 = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18.92 13.29C18.6773 13.2876 18.4421 13.3735 18.2581 13.5318C18.0741 13.69 17.9539 13.9097 17.92 14.15C17.8052 14.9867 17.515 15.7898 17.0684 16.5067C16.6219 17.2236 16.029 17.8381 15.3286 18.31C14.6282 18.782 13.8361 19.1008 13.004 19.2455C12.1719 19.3903 11.3186 19.3577 10.5 19.15C9.41134 18.8945 8.41894 18.3318 7.64074 17.5287C6.86253 16.7257 6.33123 15.7161 6.10999 14.62C5.90952 13.7382 5.91095 12.8226 6.11418 11.9414C6.31741 11.0603 6.71717 10.2365 7.28358 9.5316C7.85 8.82671 8.56841 8.25896 9.38513 7.87079C10.2018 7.48263 11.0957 7.28409 12 7.29001V10.08C11.9963 10.1801 12.0234 10.2789 12.0776 10.3631C12.1318 10.4473 12.2105 10.5129 12.3031 10.551C12.3957 10.5892 12.4978 10.598 12.5955 10.5764C12.6933 10.5547 12.7821 10.5037 12.85 10.43L16.64 6.64001C16.6868 6.59353 16.724 6.53823 16.7494 6.4773C16.7748 6.41637 16.7879 6.35101 16.7879 6.28501C16.7879 6.219 16.7748 6.15365 16.7494 6.09272C16.724 6.03179 16.6868 5.97649 16.64 5.93001L12.85 2.14001C12.7795 2.0709 12.6901 2.02422 12.5931 2.00582C12.4961 1.98743 12.3959 1.99816 12.305 2.03666C12.2141 2.07516 12.1366 2.1397 12.0823 2.22216C12.0281 2.30462 11.9994 2.40129 12 2.50001V5.29001C10.8136 5.28977 9.64193 5.55341 8.56997 6.06186C7.498 6.5703 6.55255 7.3108 5.8021 8.22973C5.05164 9.14866 4.51497 10.223 4.23095 11.3749C3.94694 12.5269 3.9227 13.7275 4.15998 14.89C4.4373 16.3989 5.15506 17.7919 6.22281 18.8934C7.29056 19.995 8.66051 20.7558 10.16 21.08C11.2434 21.3372 12.3685 21.3654 13.4634 21.1628C14.5584 20.9602 15.5989 20.5313 16.5186 19.9035C17.4382 19.2756 18.2166 18.4627 18.8041 17.5168C19.3915 16.5708 19.775 15.5127 19.93 14.41C19.9472 14.2681 19.9337 14.1242 19.8906 13.988C19.8474 13.8517 19.7756 13.7263 19.6799 13.6202C19.5842 13.514 19.4668 13.4296 19.3357 13.3727C19.2046 13.3157 19.0629 13.2875 18.92 13.29ZM10.92 16.29V12.02H10.83L8.99999 12.65V13.34L9.99999 13.03V16.29H10.92ZM14.34 12.07C13.958 11.9366 13.542 11.9366 13.16 12.07C12.9832 12.1378 12.8278 12.2518 12.71 12.4C12.5742 12.5675 12.4754 12.7617 12.42 12.97C12.3516 13.2379 12.318 13.5135 12.32 13.79V14.53C12.3152 14.8073 12.3523 15.0838 12.43 15.35C12.4911 15.5581 12.5931 15.7519 12.73 15.92C12.8534 16.0666 13.0115 16.1801 13.19 16.25C13.572 16.3834 13.988 16.3834 14.37 16.25C14.5468 16.1822 14.7022 16.0682 14.82 15.92C14.9518 15.7501 15.0502 15.5566 15.11 15.35C15.1832 15.083 15.2169 14.8068 15.21 14.53V13.79C15.2147 13.5127 15.1776 13.2363 15.1 12.97C15.0389 12.7619 14.9369 12.5682 14.8 12.4C14.6687 12.2532 14.5041 12.14 14.32 12.07H14.34ZM14.34 14.64C14.3574 14.7995 14.3574 14.9605 14.34 15.12C14.3204 15.2318 14.2832 15.3398 14.23 15.44C14.1875 15.5164 14.1206 15.5762 14.04 15.61C13.9573 15.625 13.8726 15.625 13.79 15.61C13.7074 15.6259 13.6226 15.6259 13.54 15.61C13.4613 15.5733 13.3952 15.5142 13.35 15.44C13.2931 15.3405 13.2526 15.2324 13.23 15.12C13.2126 14.9605 13.2126 14.7995 13.23 14.64V13.64C13.2126 13.4805 13.2126 13.3195 13.23 13.16C13.2478 13.0494 13.2887 12.9438 13.35 12.85C13.3952 12.7758 13.4613 12.7167 13.54 12.68C13.6196 12.6482 13.7043 12.6312 13.79 12.63C13.8758 12.6303 13.9607 12.6473 14.04 12.68C14.1187 12.7167 14.1848 12.7758 14.23 12.85C14.287 12.9459 14.3276 13.0507 14.35 13.16C14.3674 13.3195 14.3674 13.4805 14.35 13.64V14.64H14.34Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const cloud_upload = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M12 4C15.64 4 18.67 6.59 19.35 10.04C21.95 10.22 24 12.36 24 15C24 17.76 21.76 20 19 20H6C2.69 20 0 17.31 0 14C0 10.91 2.34 8.36 5.35 8.04C6.6 5.64 9.11 4 12 4ZM12.9915 12.79V14.79C12.9915 15.34 12.5415 15.79 11.9915 15.79C11.4415 15.79 10.9915 15.34 10.9915 14.79V12.79H9.20153C8.75153 12.79 8.53153 12.25 8.85153 11.94L11.6415 9.15C11.8415 8.95 12.1515 8.95 12.3515 9.15L15.1415 11.94C15.4515 12.25 15.2315 12.79 14.7915 12.79H12.9915Z" />
</svg>
`;

const table_chart_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H20C21.1 21 22 20.1 22 19V5C22 3.9 21.1 3 20 3ZM20 5V8H5V5H20ZM15 19H10V10H15V19ZM5 10H8V19H5V10ZM17 19V10H20V19H17Z" />
</svg>
`;

const group = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9 13.75C6.66 13.75 2 14.92 2 17.25V19H16V17.25C16 14.92 11.34 13.75 9 13.75ZM9 12C10.93 12 12.5 10.43 12.5 8.5C12.5 6.57 10.93 5 9 5C7.07 5 5.5 6.57 5.5 8.5C5.5 10.43 7.07 12 9 12ZM16.04 13.81C17.2 14.65 18 15.77 18 17.25V19H22V17.25C22 15.23 18.5 14.08 16.04 13.81ZM15 12C16.93 12 18.5 10.43 18.5 8.5C18.5 6.57 16.93 5 15 5C14.46 5 13.96 5.13 13.5 5.35C14.13 6.24 14.5 7.33 14.5 8.5C14.5 9.67 14.13 10.76 13.5 11.65C13.96 11.87 14.46 12 15 12Z" />
</svg>
`;

const settings = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19.4999 12C19.4999 11.77 19.4899 11.55 19.4699 11.32L21.3299 9.91C21.7299 9.61 21.8399 9.05 21.5899 8.61L19.7199 5.38C19.4699 4.94 18.9299 4.76 18.4699 4.96L16.3199 5.87C15.9499 5.61 15.5599 5.38 15.1499 5.19L14.8599 2.88C14.7999 2.38 14.3699 2 13.8699 2H10.1399C9.62991 2 9.19991 2.38 9.13991 2.88L8.84991 5.19C8.43991 5.38 8.04991 5.61 7.67991 5.87L5.52991 4.96C5.06991 4.76 4.52991 4.94 4.27991 5.38L2.40991 8.62C2.15991 9.06 2.26991 9.61 2.66991 9.92L4.52991 11.33C4.50991 11.55 4.49991 11.77 4.49991 12C4.49991 12.23 4.50991 12.45 4.52991 12.68L2.66991 14.09C2.26991 14.39 2.15991 14.95 2.40991 15.39L4.27991 18.62C4.52991 19.06 5.06991 19.24 5.52991 19.04L7.67991 18.13C8.04991 18.39 8.43991 18.62 8.84991 18.81L9.13991 21.12C9.19991 21.62 9.62991 22 10.1299 22H13.8599C14.3599 22 14.7899 21.62 14.8499 21.12L15.1399 18.81C15.5499 18.62 15.9399 18.39 16.3099 18.13L18.4599 19.04C18.9199 19.24 19.4599 19.06 19.7099 18.62L21.5799 15.39C21.8299 14.95 21.7199 14.4 21.3199 14.09L19.4599 12.68C19.4899 12.45 19.4999 12.23 19.4999 12ZM12.0399 15.5C10.1099 15.5 8.53991 13.93 8.53991 12C8.53991 10.07 10.1099 8.5 12.0399 8.5C13.9699 8.5 15.5399 10.07 15.5399 12C15.5399 13.93 13.9699 15.5 12.0399 15.5Z" />
</svg>
`;

const perspn = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 12C14.21 12 16 10.21 16 8C16 5.79 14.21 4 12 4C9.79 4 8 5.79 8 8C8 10.21 9.79 12 12 12ZM12 14C9.33 14 4 15.34 4 18V19C4 19.55 4.45 20 5 20H19C19.55 20 20 19.55 20 19V18C20 15.34 14.67 14 12 14Z" />
</svg>
`;

const format_italic = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M10 5.5C10 6.33 10.67 7 11.5 7H12.21L8.79 15H7.5C6.67 15 6 15.67 6 16.5C6 17.33 6.67 18 7.5 18H12.5C13.33 18 14 17.33 14 16.5C14 15.67 13.33 15 12.5 15H11.79L15.21 7H16.5C17.33 7 18 6.33 18 5.5C18 4.67 17.33 4 16.5 4H11.5C10.67 4 10 4.67 10 5.5Z" />
</svg>
`;

const archive = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M20.54 5.23L19.15 3.55C18.88 3.21 18.47 3 18 3H6C5.53 3 5.12 3.21 4.84 3.55L3.46 5.23C3.17 5.57 3 6.02 3 6.5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V6.5C21 6.02 20.83 5.57 20.54 5.23ZM6.24 5H17.76L18.57 5.97H5.44L6.24 5ZM14.4652 13.3353H13.612V10.5559C13.612 10.2501 13.3705 10 13.0753 10H10.9287C10.6336 10 10.3921 10.2501 10.3921 10.5559V13.3353H9.5388C9.06118 13.3353 8.81969 13.9357 9.15778 14.2859L11.621 16.8374C11.8303 17.0542 12.1684 17.0542 12.3777 16.8374L14.8409 14.2859C15.179 13.9357 14.9429 13.3353 14.4652 13.3353Z" />
</svg>
`;

const add_circle_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 7C11.45 7 11 7.45 11 8V11H8C7.45 11 7 11.45 7 12C7 12.55 7.45 13 8 13H11V16C11 16.55 11.45 17 12 17C12.55 17 13 16.55 13 16V13H16C16.55 13 17 12.55 17 12C17 11.45 16.55 11 16 11H13V8C13 7.45 12.55 7 12 7ZM12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM12 20C7.59 20 4 16.41 4 12C4 7.59 7.59 4 12 4C16.41 4 20 7.59 20 12C20 16.41 16.41 20 12 20Z" />
</svg>
`;

const school = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M5 13.18V15.99C5 16.72 5.4 17.4 6.04 17.75L11.04 20.48C11.64 20.81 12.36 20.81 12.96 20.48L17.96 17.75C18.6 17.4 19 16.72 19 15.99V13.18L12.96 16.48C12.36 16.81 11.64 16.81 11.04 16.48L5 13.18ZM11.04 3.52003L2.61 8.12003C1.92 8.50003 1.92 9.50003 2.61 9.88003L11.04 14.48C11.64 14.81 12.36 14.81 12.96 14.48L21 10.09V16C21 16.55 21.45 17 22 17C22.55 17 23 16.55 23 16V9.59003C23 9.22003 22.8 8.89003 22.48 8.71003L12.96 3.52003C12.36 3.20003 11.64 3.20003 11.04 3.52003Z" />
</svg>
`;

const download = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M7.70754 10.79C7.31754 11.18 7.31754 11.81 7.70754 12.2L11.2975 15.79C11.6875 16.18 12.3175 16.18 12.7075 15.79L16.2975 12.2C16.6875 11.81 16.6875 11.18 16.2975 10.79C15.9075 10.4 15.2775 10.4 14.8875 10.79L12.9975 12.67V4C12.9975 3.45 12.5475 3 11.9975 3C11.4475 3 10.9975 3.45 10.9975 4L10.9975 12.67L9.11754 10.79C8.72754 10.4 8.08754 10.41 7.70754 10.79Z" />
<path d="M18 16C18 15.4477 18.4477 15 19 15C19.5523 15 20 15.4477 20 16V18C20 19.1 19.1 20 18 20H6C4.9 20 4 19.1 4 18V16C4 15.4477 4.44772 15 5 15C5.55228 15 6 15.4477 6 16V18H18V16Z" />
</svg>
`;

const expand = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11.9999 5.82997L14.4599 8.28997C14.8499 8.67997 15.4799 8.67997 15.8699 8.28997C16.2599 7.89997 16.2599 7.26997 15.8699 6.87997L12.6999 3.69997C12.3099 3.30997 11.6799 3.30997 11.2899 3.69997L8.11989 6.87997C7.72989 7.26997 7.72989 7.89997 8.11989 8.28997C8.50989 8.67997 9.13989 8.67997 9.52989 8.28997L11.9999 5.82997ZM11.9999 18.17L9.53989 15.71C9.14989 15.32 8.51989 15.32 8.12989 15.71C7.73989 16.1 7.73989 16.73 8.12989 17.12L11.2999 20.3C11.6899 20.69 12.3199 20.69 12.7099 20.3L15.8799 17.13C16.2699 16.74 16.2699 16.11 15.8799 15.72C15.4899 15.33 14.8599 15.33 14.4699 15.72L11.9999 18.17Z" />
</svg>
`;

const import_icon = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19 5L7 5L7 8C7 8.55 6.55 9 6 9C5.45 9 5 8.55 5 8L5 5C5 3.9 5.89 3 7 3L19 3C20.1 3 21 3.9 21 5L21 19C21 20.1 20.1 21 19 21L7 21C5.9 21 5 20.1 5 19L5 16C5 15.45 5.45 15 6 15C6.55 15 7 15.45 7 16L7 19L19 19L19 5Z" />
<path d="M10.79 16.29C11.18 16.68 11.81 16.68 12.2 16.29L15.79 12.7C16.18 12.31 16.18 11.68 15.79 11.29L12.2 7.69997C11.81 7.30997 11.18 7.30997 10.79 7.69997C10.4 8.08997 10.4 8.71997 10.79 9.10997L12.67 11H4C3.45 11 3 11.45 3 12C3 12.55 3.45 13 4 13H12.67L10.79 14.88C10.4 15.27 10.41 15.91 10.79 16.29Z" />
</svg>
`;

const apps = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 8C13.1046 8 14 7.10457 14 6C14 4.89543 13.1046 4 12 4C10.8954 4 10 4.89543 10 6C10 7.10457 10.8954 8 12 8Z" />
<path d="M6 20C7.10457 20 8 19.1046 8 18C8 16.8954 7.10457 16 6 16C4.89543 16 4 16.8954 4 18C4 19.1046 4.89543 20 6 20Z" />
<path d="M14 18C14 19.1046 13.1046 20 12 20C10.8954 20 10 19.1046 10 18C10 16.8954 10.8954 16 12 16C13.1046 16 14 16.8954 14 18Z" />
<path d="M18 20C19.1046 20 20 19.1046 20 18C20 16.8954 19.1046 16 18 16C16.8954 16 16 16.8954 16 18C16 19.1046 16.8954 20 18 20Z" />
<path d="M8 12C8 13.1046 7.10457 14 6 14C4.89543 14 4 13.1046 4 12C4 10.8954 4.89543 10 6 10C7.10457 10 8 10.8954 8 12Z" />
<path d="M12 14C13.1046 14 14 13.1046 14 12C14 10.8954 13.1046 10 12 10C10.8954 10 10 10.8954 10 12C10 13.1046 10.8954 14 12 14Z" />
<path d="M20 12C20 13.1046 19.1046 14 18 14C16.8954 14 16 13.1046 16 12C16 10.8954 16.8954 10 18 10C19.1046 10 20 10.8954 20 12Z" />
<path d="M6 8C7.10457 8 8 7.10457 8 6C8 4.89543 7.10457 4 6 4C4.89543 4 4 4.89543 4 6C4 7.10457 4.89543 8 6 8Z" />
<path d="M20 6C20 7.10457 19.1046 8 18 8C16.8954 8 16 7.10457 16 6C16 4.89543 16.8954 4 18 4C19.1046 4 20 4.89543 20 6Z" />
</svg>
`;

const flag_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14 6L13.28 4.55C13.11 4.21 12.76 4 12.38 4H6C5.45 4 5 4.45 5 5V20C5 20.55 5.45 21 6 21C6.55 21 7 20.55 7 20V14H12L12.72 15.45C12.89 15.79 13.24 16 13.61 16H19C19.55 16 20 15.55 20 15V7C20 6.45 19.55 6 19 6H14ZM18 14H14L13 12H7V6H12L13 8H18V14Z" />
</svg>
`;

const bolt = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M10.67 21C10.32 21 10.05 20.69 10.1 20.34L11 14H7.49997C6.61997 14 7.16997 13.25 7.18997 13.22C8.44997 10.99 10.34 7.69 12.84 3.29C12.94 3.11 13.14 3 13.34 3C13.69 3 13.96 3.31 13.91 3.66L13.01 10H16.52C16.92 10 17.14 10.19 16.92 10.66C13.63 16.4 11.72 19.75 11.17 20.71C11.07 20.89 10.88 21 10.67 21Z" />
</svg>
`;

const cloud_done_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M10.71 16.29C10.32 16.68 9.69 16.68 9.3 16.29L7.2 14.2C6.81 13.81 6.81 13.18 7.2 12.79C7.59 12.4 8.22 12.4 8.61 12.79L10 14.18L14.48 9.69997C14.87 9.30997 15.5 9.30997 15.89 9.69997C16.28 10.09 16.28 10.72 15.89 11.11L10.71 16.29Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M12 4C15.64 4 18.67 6.59 19.35 10.04C21.95 10.22 24 12.36 24 15C24 17.76 21.76 20 19 20H6C2.69 20 0 17.31 0 14C0 10.91 2.34 8.36 5.35 8.04C6.6 5.64 9.11 4 12 4ZM6 18H19C20.65 18 22 16.65 22 15C22 13.45 20.78 12.14 19.22 12.04L17.69 11.93L17.39 10.43C16.88 7.86 14.62 6 12 6C9.94 6 8.08 7.14 7.13 8.97L6.63 9.92L5.56 10.03C3.53 10.24 2 11.95 2 14C2 16.21 3.79 18 6 18Z" />
</svg>
`;

const checkbox_unselected = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 19H6C5.45 19 5 18.55 5 18V6C5 5.45 5.45 5 6 5H18C18.55 5 19 5.45 19 6V18C19 18.55 18.55 19 18 19ZM19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3Z" />
</svg>
`;

const collapse = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M8.12001 19.3C8.51001 19.69 9.14001 19.69 9.53001 19.3L12 16.83L14.47 19.3C14.86 19.69 15.49 19.69 15.88 19.3C16.27 18.91 16.27 18.28 15.88 17.89L12.71 14.72C12.32 14.33 11.69 14.33 11.3 14.72L8.13001 17.89C7.73001 18.27 7.73001 18.91 8.12001 19.3ZM15.88 4.69997C15.49 4.30997 14.86 4.30997 14.47 4.69997L12 7.16997L9.53001 4.69997C9.14001 4.30997 8.51001 4.30997 8.12001 4.69997C7.73001 5.08997 7.73001 5.72997 8.12001 6.11997L11.29 9.28997C11.68 9.67997 12.31 9.67997 12.7 9.28997L15.87 6.11997C16.27 5.72997 16.27 5.08997 15.88 4.69997Z" />
</svg>
`;

const print_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 12.5C17.45 12.5 17 12.05 17 11.5C17 10.95 17.45 10.5 18 10.5C18.55 10.5 19 10.95 19 11.5C19 12.05 18.55 12.5 18 12.5Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M18 4V8H19C20.66 8 22 9.34 22 11V16C22 16.55 21.55 17 21 17H18V19C18 20.1 17.1 21 16 21H8C6.9 21 6 20.1 6 19V17H3C2.45 17 2 16.55 2 16V11C2 9.34 3.34 8 5 8H6V4C6 3.45 6.45 3 7 3H17C17.55 3 18 3.45 18 4ZM8 5H16V8H8V5ZM8 15H16V19H8V15ZM18 13V15H20V11C20 10.45 19.55 10 19 10H5C4.45 10 4 10.45 4 11V15H6V13H18Z" />
</svg>
`;

const arrow_up = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M13 19V7.82998L17.88 12.71C18.27 13.1 18.91 13.1 19.3 12.71C19.69 12.32 19.69 11.69 19.3 11.3L12.71 4.70998C12.32 4.31998 11.69 4.31998 11.3 4.70998L4.69997 11.29C4.30997 11.68 4.30997 12.31 4.69997 12.7C5.08997 13.09 5.71997 13.09 6.10997 12.7L11 7.82998V19C11 19.55 11.45 20 12 20C12.55 20 13 19.55 13 19Z" />
</svg>
`;

const foldor_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M9.17 4C9.7 4 10.21 4.21 10.59 4.59L12 6H20C21.1 6 22 6.9 22 8V18C22 19.1 21.1 20 20 20H4C2.9 20 2 19.1 2 18L2.01 6C2.01 4.9 2.9 4 4 4H9.17ZM9.17 6L11.17 8H20V18H4V6H9.17Z" />
</svg>
`;

const error_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 7C12.55 7 13 7.45 13 8V12C13 12.55 12.55 13 12 13C11.45 13 11 12.55 11 12V8C11 7.45 11.45 7 12 7ZM11.99 2C6.47 2 2 6.48 2 12C2 17.52 6.47 22 11.99 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 11.99 2ZM12 20C7.58 20 4 16.42 4 12C4 7.58 7.58 4 12 4C16.42 4 20 7.58 20 12C20 16.42 16.42 20 12 20ZM13 17H11V15H13V17Z" />
</svg>
`;

const calculate = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3ZM13.56 6.53C13.85 6.24 14.33 6.24 14.62 6.53L15.5 7.41L16.38 6.53C16.67 6.24 17.15 6.24 17.44 6.53C17.73 6.82 17.73 7.3 17.44 7.59L16.56 8.47L17.44 9.35C17.73 9.64 17.73 10.12 17.44 10.41C17.15 10.7 16.67 10.7 16.38 10.41L15.5 9.54L14.62 10.42C14.33 10.71 13.85 10.71 13.56 10.42C13.27 10.13 13.27 9.65 13.56 9.36L14.44 8.48L13.56 7.6C13.26 7.3 13.26 6.82 13.56 6.53ZM7 7.72H10.5C10.91 7.72 11.25 8.06 11.25 8.47C11.25 8.88 10.91 9.22 10.5 9.22H7C6.59 9.22 6.25 8.88 6.25 8.47C6.25 8.06 6.59 7.72 7 7.72ZM10.75 16H9.5V17.25C9.5 17.66 9.16 18 8.75 18C8.34 18 8 17.66 8 17.25V16H6.75C6.34 16 6 15.66 6 15.25C6 14.84 6.34 14.5 6.75 14.5H8V13.25C8 12.84 8.34 12.5 8.75 12.5C9.16 12.5 9.5 12.84 9.5 13.25V14.5H10.75C11.16 14.5 11.5 14.84 11.5 15.25C11.5 15.66 11.16 16 10.75 16ZM17.25 17.25H13.75C13.34 17.25 13 16.91 13 16.5C13 16.09 13.34 15.75 13.75 15.75H17.25C17.66 15.75 18 16.09 18 16.5C18 16.91 17.66 17.25 17.25 17.25ZM17.25 14.75H13.75C13.34 14.75 13 14.41 13 14C13 13.59 13.34 13.25 13.75 13.25H17.25C17.66 13.25 18 13.59 18 14C18 14.41 17.66 14.75 17.25 14.75Z" />
</svg>
`;

const camera_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M7 12C7 9.24 9.24 7 12 7C14.76 7 17 9.24 17 12C17 14.76 14.76 17 12 17C9.24 17 7 14.76 7 12ZM15 12C15 10.35 13.65 9 12 9C10.35 9 9 10.35 9 12C9 13.65 10.35 15 12 15C13.65 15 15 13.65 15 12Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M16.83 4H20C21.1 4 22 4.9 22 6V18C22 19.1 21.1 20 20 20H4C2.9 20 2 19.1 2 18V6C2 4.9 2.9 4 4 4H7.17L8.4 2.65C8.78 2.24 9.32 2 9.88 2H14.12C14.68 2 15.22 2.24 15.59 2.65L16.83 4ZM15.95 6L14.12 4H9.88L8.05 6H4V18H20V6H15.95Z" />
</svg>
`;

const cloud_upload_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12.9915 12.79V14.79C12.9915 15.34 12.5415 15.79 11.9915 15.79C11.4415 15.79 10.9915 15.34 10.9915 14.79V12.79H9.20153C8.75153 12.79 8.53153 12.25 8.85153 11.94L11.6415 9.15C11.8415 8.95 12.1515 8.95 12.3515 9.15L15.1415 11.94C15.4515 12.25 15.2315 12.79 14.7915 12.79H12.9915Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M12 4C15.64 4 18.67 6.59 19.35 10.04C21.95 10.22 24 12.36 24 15C24 17.76 21.76 20 19 20H6C2.69 20 0 17.31 0 14C0 10.91 2.34 8.36 5.35 8.04C6.6 5.64 9.11 4 12 4ZM6 18H19C20.65 18 22 16.65 22 15C22 13.45 20.78 12.14 19.22 12.04L17.69 11.93L17.39 10.43C16.88 7.86 14.62 6 12 6C9.94 6 8.08 7.14 7.13 8.97L6.63 9.92L5.56 10.03C3.53 10.24 2 11.95 2 14C2 16.21 3.79 18 6 18Z" />
</svg>
`;

const dashboard = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M4 13H10C10.55 13 11 12.55 11 12V4C11 3.45 10.55 3 10 3H4C3.45 3 3 3.45 3 4V12C3 12.55 3.45 13 4 13ZM4 21H10C10.55 21 11 20.55 11 20V16C11 15.45 10.55 15 10 15H4C3.45 15 3 15.45 3 16V20C3 20.55 3.45 21 4 21ZM14 21H20C20.55 21 21 20.55 21 20V12C21 11.45 20.55 11 20 11H14C13.45 11 13 11.45 13 12V20C13 20.55 13.45 21 14 21ZM13 4V8C13 8.55 13.45 9 14 9H20C20.55 9 21 8.55 21 8V4C21 3.45 20.55 3 20 3H14C13.45 3 13 3.45 13 4Z" />
</svg>
`;

const chevron_right = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9.29006 6.71002C8.90006 7.10002 8.90006 7.73002 9.29006 8.12002L13.1701 12L9.29006 15.88C8.90006 16.27 8.90006 16.9 9.29006 17.29C9.68006 17.68 10.3101 17.68 10.7001 17.29L15.2901 12.7C15.6801 12.31 15.6801 11.68 15.2901 11.29L10.7001 6.70002C10.3201 6.32002 9.68006 6.32002 9.29006 6.71002Z" />
</svg>
`;

const code = `<svg viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
<path d="M8.69998 15.9L4.79998 12L8.69998 8.1C9.08998 7.71 9.08998 7.09 8.69998 6.7C8.30998 6.31 7.68998 6.31 7.29998 6.7L2.70998 11.29C2.31998 11.68 2.31998 12.31 2.70998 12.7L7.29998 17.3C7.68998 17.69 8.30998 17.69 8.69998 17.3C9.08998 16.91 9.08998 16.29 8.69998 15.9ZM15.3 15.9L19.2 12L15.3 8.1C14.91 7.71 14.91 7.09 15.3 6.7C15.69 6.31 16.31 6.31 16.7 6.7L21.29 11.29C21.68 11.68 21.68 12.31 21.29 12.7L16.7 17.3C16.31 17.69 15.69 17.69 15.3 17.3C14.91 16.91 14.91 16.29 15.3 15.9Z"/>
</svg>
`;

const flag = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14 6L13.28 4.55C13.11 4.21 12.76 4 12.38 4H6C5.45 4 5 4.45 5 5V20C5 20.55 5.45 21 6 21C6.55 21 7 20.55 7 20V14H12L12.72 15.45C12.89 15.79 13.24 16 13.61 16H19C19.55 16 20 15.55 20 15V7C20 6.45 19.55 6 19 6H14Z" />
</svg>
`;

const chevron_left = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14.71 6.70998C14.32 6.31998 13.69 6.31998 13.3 6.70998L8.70998 11.3C8.31998 11.69 8.31998 12.32 8.70998 12.71L13.3 17.3C13.69 17.69 14.32 17.69 14.71 17.3C15.1 16.91 15.1 16.28 14.71 15.89L10.83 12L14.71 8.11998C15.1 7.72998 15.09 7.08998 14.71 6.70998Z" />
</svg>
`;

const preview = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19 3H5C3.89 3 3 3.9 3 5V19C3 20.1 3.89 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.11 3 19 3ZM19 19H5V7H19V19ZM13.5 13C13.5 13.83 12.83 14.5 12 14.5C11.17 14.5 10.5 13.83 10.5 13C10.5 12.17 11.17 11.5 12 11.5C12.83 11.5 13.5 12.17 13.5 13ZM12 9C9.27 9 6.94 10.66 6 13C6.94 15.34 9.27 17 12 17C14.73 17 17.06 15.34 18 13C17.06 10.66 14.73 9 12 9ZM12 15.5C10.62 15.5 9.5 14.38 9.5 13C9.5 11.62 10.62 10.5 12 10.5C13.38 10.5 14.5 11.62 14.5 13C14.5 14.38 13.38 15.5 12 15.5Z" />
</svg>
`;

const push_pin_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M18.2 11.89C18.66 12.02 19 12.4 19 12.87V13C19 13.55 18.55 14 18 14H12.98L13 21C13 21.55 12.55 22 12 22C11.45 22 11 21.55 11 21L10.98 14H6C5.45 14 5 13.55 5 13V12.87C5 12.4 5.34 12.02 5.8 11.89C7.07 11.54 8 10.38 8 9V4H7C6.45 4 6 3.55 6 3C6 2.45 6.45 2 7 2H17C17.55 2 18 2.45 18 3C18 3.55 17.55 4 17 4H16V9C16 10.38 16.93 11.54 18.2 11.89ZM14 4V9C14 10.12 14.37 11.16 15 12H9C9.65 11.14 10 10.1 10 9V4H14Z" />
</svg>
`;

const dark_mode = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11.01 3.05001C6.51 3.54001 3 7.36001 3 12C3 16.97 7.03 21 12 21C16.63 21 20.45 17.5 20.95 13C21.04 12.21 20.17 11.58 19.41 12.05C18.57 12.59 17.57 12.9 16.5 12.9C13.52 12.9 11.1 10.48 11.1 7.50001C11.1 6.44001 11.41 5.44001 11.94 4.61001C12.39 3.94001 11.9 2.98001 11.01 3.05001Z" />
</svg>
`;

const arrow_right = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11.71 15.29L14.3 12.7C14.69 12.31 14.69 11.68 14.3 11.29L11.71 8.69997C11.08 8.07997 10 8.51997 10 9.40997V14.58C10 15.48 11.08 15.92 11.71 15.29Z" />
</svg>
`;

const support = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM19.46 9.12L16.68 10.27C16.17 8.91 15.1 7.83 13.73 7.33L14.88 4.55C16.98 5.35 18.65 7.02 19.46 9.12ZM12 15C10.34 15 9 13.66 9 12C9 10.34 10.34 9 12 9C13.66 9 15 10.34 15 12C15 13.66 13.66 15 12 15ZM9.13 4.54L10.3 7.32C8.92 7.82 7.83 8.91 7.32 10.29L4.54 9.13C5.35 7.02 7.02 5.35 9.13 4.54ZM4.54 14.87L7.32 13.72C7.83 15.1 8.91 16.18 10.29 16.68L9.12 19.46C7.02 18.65 5.35 16.98 4.54 14.87ZM14.88 19.46L13.73 16.68C15.1 16.17 16.18 15.09 16.68 13.71L19.46 14.88C18.65 16.98 16.98 18.65 14.88 19.46Z" />
</svg>
`;

const work = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 6H16V4C16 2.89 15.11 2 14 2H10C8.89 2 8 2.89 8 4V6H4C2.89 6 2.01 6.89 2.01 8L2 19C2 20.11 2.89 21 4 21H20C21.11 21 22 20.11 22 19V8C22 6.89 21.11 6 20 6ZM14 6H10V4H14V6Z" />
</svg>
`;

const settings_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M7.99994 12C7.99994 9.79 9.78994 8 11.9999 8C14.2099 8 15.9999 9.79 15.9999 12C15.9999 14.21 14.2099 16 11.9999 16C9.78994 16 7.99994 14.21 7.99994 12ZM13.9999 12C13.9999 13.1046 13.1045 14 11.9999 14C10.8954 14 9.99994 13.1046 9.99994 12C9.99994 10.8954 10.8954 10 11.9999 10C13.1045 10 13.9999 10.8954 13.9999 12Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M19.4999 12C19.4999 11.77 19.4899 11.55 19.4699 11.32L21.3299 9.91C21.7299 9.61 21.8399 9.05 21.5899 8.61L19.7199 5.38C19.4699 4.94 18.9299 4.76 18.4699 4.96L16.3199 5.87C15.9499 5.61 15.5599 5.38 15.1499 5.19L14.8599 2.88C14.7999 2.38 14.3699 2 13.8699 2H10.1399C9.62991 2 9.19991 2.38 9.13991 2.88L8.84991 5.19C8.43991 5.38 8.04991 5.61 7.67991 5.87L5.52991 4.96C5.06991 4.76 4.52991 4.94 4.27991 5.38L2.40991 8.62C2.15991 9.06 2.26991 9.61 2.66991 9.92L4.52991 11.33C4.50991 11.55 4.49991 11.77 4.49991 12C4.49991 12.23 4.50991 12.45 4.52991 12.68L2.66991 14.09C2.26991 14.39 2.15991 14.95 2.40991 15.39L4.27991 18.62C4.52991 19.06 5.06991 19.24 5.52991 19.04L7.67991 18.13C8.04991 18.39 8.43991 18.62 8.84991 18.81L9.13991 21.12C9.19991 21.62 9.62991 22 10.1299 22H13.8599C14.3599 22 14.7899 21.62 14.8499 21.12L15.1399 18.81C15.5499 18.62 15.9399 18.39 16.3099 18.13L18.4599 19.04C18.9199 19.24 19.4599 19.06 19.7099 18.62L21.5799 15.39C21.8299 14.95 21.7199 14.4 21.3199 14.09L19.4599 12.68C19.4899 12.45 19.4999 12.23 19.4999 12ZM17.5199 12C17.5199 11.79 17.5099 11.58 17.4699 11.27L17.3299 10.14L18.2199 9.44L19.2899 8.59L18.5899 7.38L17.3199 7.89L16.2599 8.32L15.3499 7.62C14.9499 7.32 14.5499 7.09 14.1199 6.91L13.0599 6.48L12.7099 4H11.3199L11.1199 5.35L10.9599 6.48L9.89993 6.91C9.48993 7.08 9.07993 7.32 8.64993 7.64L7.74993 8.32L6.70993 7.9L5.43993 7.39L4.73993 8.6L5.81993 9.44L6.70993 10.14L6.56993 11.27C6.53993 11.57 6.51993 11.8 6.51993 12C6.51993 12.2 6.53993 12.43 6.56993 12.74L6.70993 13.87L5.81993 14.57L4.73993 15.41L5.43993 16.62L6.70993 16.11L7.76993 15.68L8.67993 16.38C9.07993 16.68 9.47993 16.91 9.90993 17.09L10.9699 17.52L11.3199 20H12.7199L12.9199 18.65L13.0799 17.52L14.1399 17.09C14.5499 16.92 14.9599 16.68 15.3899 16.36L16.2899 15.68L17.3299 16.1L18.5999 16.61L19.2999 15.4L18.2199 14.56L17.3299 13.86L17.4699 12.73C17.4999 12.43 17.5199 12.21 17.5199 12Z" />
</svg>
`;

const account_outline = `<svg  viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM7.07 18.28C7.5 17.38 10.12 16.5 12 16.5C13.88 16.5 16.51 17.38 16.93 18.28C15.57 19.36 13.86 20 12 20C10.14 20 8.43 19.36 7.07 18.28ZM18.36 16.83C16.93 15.09 13.46 14.5 12 14.5C10.54 14.5 7.07 15.09 5.64 16.83C4.62 15.49 4 13.82 4 12C4 7.59 7.59 4 12 4C16.41 4 20 7.59 20 12C20 13.82 19.38 15.49 18.36 16.83ZM12 6C10.06 6 8.5 7.56 8.5 9.5C8.5 11.44 10.06 13 12 13C13.94 13 15.5 11.44 15.5 9.5C15.5 7.56 13.94 6 12 6ZM12 11C11.17 11 10.5 10.33 10.5 9.5C10.5 8.67 11.17 8 12 8C12.83 8 13.5 8.67 13.5 9.5C13.5 10.33 12.83 11 12 11Z" />
</svg>
`;

const trophy = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19 5H17V4C17 3.45 16.55 3 16 3H8C7.45 3 7 3.45 7 4V5H5C3.9 5 3 5.9 3 7V8C3 10.55 4.92 12.63 7.39 12.94C8.02 14.44 9.37 15.57 11 15.9V19H8C7.45 19 7 19.45 7 20C7 20.55 7.45 21 8 21H16C16.55 21 17 20.55 17 20C17 19.45 16.55 19 16 19H13V15.9C14.63 15.57 15.98 14.44 16.61 12.94C19.08 12.63 21 10.55 21 8V7C21 5.9 20.1 5 19 5ZM5 8V7H7V10.82C5.84 10.4 5 9.3 5 8ZM19 8C19 9.3 18.16 10.4 17 10.82V7H19V8Z" />
</svg>
`;

const document$1 = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14.59 2.59C14.21 2.21 13.7 2 13.17 2H6C4.9 2 4 2.9 4 4V20C4 21.1 4.89 22 5.99 22H18C19.1 22 20 21.1 20 20V8.83C20 8.3 19.79 7.79 19.41 7.42L14.59 2.59ZM15 18H9C8.45 18 8 17.55 8 17C8 16.45 8.45 16 9 16H15C15.55 16 16 16.45 16 17C16 17.55 15.55 18 15 18ZM15 14H9C8.45 14 8 13.55 8 13C8 12.45 8.45 12 9 12H15C15.55 12 16 12.45 16 13C16 13.55 15.55 14 15 14ZM13 8V3.5L18.5 9H14C13.45 9 13 8.55 13 8Z" />
</svg>
`;

const check = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9.00001 16.1701L5.53001 12.7001C5.14002 12.3101 4.51001 12.3101 4.12001 12.7001C3.73001 13.0901 3.73001 13.7201 4.12001 14.1101L8.30001 18.2901C8.69001 18.6801 9.32001 18.6801 9.71001 18.2901L20.29 7.71007C20.68 7.32007 20.68 6.69007 20.29 6.30007C19.9 5.91007 19.27 5.91007 18.88 6.30007L9.00001 16.1701Z" />
</svg>
`;

const table_chart = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M10 10.02H15V21H10V10.02ZM17 21H20C21.1 21 22 20.1 22 19V10H17V21ZM20 3H5C3.9 3 3 3.9 3 5V8H22V5C22 3.9 21.1 3 20 3ZM3 19C3 20.1 3.9 21 5 21H8V10H3V19Z" />
</svg>
`;

const warning = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M2.27137 17.0075C1.50137 18.3375 2.46137 20.0075 4.00137 20.0075H19.0614C20.6014 20.0075 21.5614 18.3375 20.7914 17.0075L13.2614 3.9975C12.4914 2.6675 10.5714 2.6675 9.80137 3.9975L2.27137 17.0075ZM10.53 10.01V12.01C10.53 12.56 10.98 13.01 11.53 13.01C12.08 13.01 12.53 12.56 12.53 12.01V10.01C12.53 9.46001 12.08 9.01001 11.53 9.01001C10.98 9.01001 10.53 9.46001 10.53 10.01ZM10.53 17.01V15.01H12.53V17.01H10.53Z" />
</svg>
`;

const rewindX15 = `<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
<g clip-path="url(#clip0_13_580)">
<path d="M11.93 5.29V2.5C11.9337 2.39992 11.9066 2.30112 11.8524 2.2169C11.7982 2.13269 11.7195 2.0671 11.6269 2.02897C11.5343 1.99084 11.4322 1.982 11.3345 2.00363C11.2367 2.02527 11.1479 2.07636 11.08 2.15L7.29001 5.94C7.24314 5.98648 7.20595 6.04178 7.18056 6.10271C7.15518 6.16364 7.14211 6.22899 7.14211 6.295C7.14211 6.36101 7.15518 6.42636 7.18056 6.48729C7.20595 6.54822 7.24314 6.60352 7.29001 6.65L11.08 10.44C11.1499 10.5085 11.2384 10.555 11.3344 10.5737C11.4305 10.5925 11.5299 10.5826 11.6204 10.5453C11.7109 10.5081 11.7885 10.445 11.8435 10.3641C11.8986 10.2832 11.9286 10.1879 11.93 10.09V7.29C13.0808 7.28818 14.2078 7.61735 15.1768 8.23825C16.1457 8.85916 16.9156 9.74561 17.3947 10.7919C17.8739 11.8382 18.042 13.0003 17.8791 14.1395C17.7161 15.2787 17.229 16.347 16.4758 17.2171C15.7226 18.0871 14.7351 18.7222 13.6309 19.0466C12.5268 19.3711 11.3527 19.3711 10.2486 19.0468C9.1444 18.7225 8.15681 18.0875 7.40352 17.2175C6.65024 16.3475 6.16304 15.2792 6.00001 14.14C5.96385 13.9015 5.84272 13.6842 5.65896 13.528C5.4752 13.3718 5.24117 13.2873 5.00001 13.29C4.85699 13.2888 4.71538 13.3183 4.58473 13.3764C4.45408 13.4346 4.33743 13.5201 4.24265 13.6272C4.14786 13.7343 4.07716 13.8605 4.0353 13.9973C3.99345 14.1341 3.98141 14.2782 4.00001 14.42C4.21662 15.9382 4.86504 17.3621 5.86804 18.5222C6.87104 19.6823 8.18634 20.5297 9.6573 20.9634C11.1283 21.3971 12.6929 21.3989 14.1648 20.9685C15.6368 20.5382 16.954 19.6938 17.9596 18.536C18.9653 17.3782 19.6169 15.9557 19.837 14.438C20.0571 12.9203 19.8363 11.3714 19.2009 9.9756C18.5656 8.57983 17.5424 7.3961 16.2533 6.56538C14.9643 5.73466 13.4636 5.29196 11.93 5.29Z" fill="#191919"/>
<path d="M10.85 16.29H10V13L9 13.3V12.61L10.76 12H10.85V16.29Z" fill="#191919"/>
<path d="M12.38 14.17L12.62 12H15V12.71H13.33L13.22 13.64C13.4195 13.5321 13.6432 13.477 13.87 13.48C14.0547 13.4625 14.2409 13.4876 14.4143 13.5535C14.5877 13.6194 14.7436 13.7242 14.87 13.86C15.1221 14.1572 15.2478 14.5413 15.22 14.93C15.2228 15.1899 15.1646 15.4468 15.05 15.68C14.9338 15.8964 14.7564 16.0738 14.54 16.19C14.3026 16.3139 14.0377 16.3758 13.77 16.37C13.5025 16.3741 13.238 16.3123 13 16.19C12.7862 16.095 12.6028 15.9427 12.47 15.75C12.3385 15.5551 12.2688 15.3251 12.27 15.09H13.11C13.119 15.2487 13.1867 15.3985 13.3 15.51C13.4155 15.6121 13.5659 15.6658 13.72 15.66C13.8066 15.6653 13.8931 15.6489 13.9717 15.6122C14.0503 15.5755 14.1185 15.5198 14.17 15.45C14.289 15.2773 14.3455 15.0692 14.33 14.86C14.3433 14.6572 14.2789 14.457 14.15 14.3C14.0827 14.2313 14.0015 14.1779 13.9118 14.1434C13.8221 14.1089 13.726 14.0941 13.63 14.1C13.4533 14.0963 13.2805 14.1527 13.14 14.26L13.06 14.34L12.38 14.17Z" fill="#191919"/>
</g>
<defs>
<clipPath id="clip0_13_580">
<rect width="15.93" height="19.3" fill="white" transform="translate(4 2)"/>
</clipPath>
</defs>
</svg>
`;

const format_align_right = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M4 21H20C20.55 21 21 20.55 21 20C21 19.45 20.55 19 20 19H4C3.45 19 3 19.45 3 20C3 20.55 3.45 21 4 21ZM10 17H20C20.55 17 21 16.55 21 16C21 15.45 20.55 15 20 15H10C9.45 15 9 15.45 9 16C9 16.55 9.45 17 10 17ZM4 13H20C20.55 13 21 12.55 21 12C21 11.45 20.55 11 20 11H4C3.45 11 3 11.45 3 12C3 12.55 3.45 13 4 13ZM10 9H20C20.55 9 21 8.55 21 8C21 7.45 20.55 7 20 7H10C9.45 7 9 7.45 9 8C9 8.55 9.45 9 10 9ZM3 4C3 4.55 3.45 5 4 5H20C20.55 5 21 4.55 21 4C21 3.45 20.55 3 20 3H4C3.45 3 3 3.45 3 4Z" />
</svg>
`;

const headphones = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M3 12V19C3 20.1 3.9 21 5 21H7C8.1 21 9 20.1 9 19V15C9 13.9 8.1 13 7 13H5V12C5 8.13 8.13 5 12 5C15.87 5 19 8.13 19 12V13H17C15.9 13 15 13.9 15 15V19C15 20.1 15.9 21 17 21H19C20.1 21 21 20.1 21 19V12C21 7.03 16.97 3 12 3C7.03 3 3 7.03 3 12Z" />
</svg>
`;

const functions = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M16.5 4H7.56C6.7 4 6 4.7 6 5.56C6 5.84 6.12 6.11 6.32 6.3L12.5 12L6.32 17.7C6.12 17.89 6 18.16 6 18.44C6 19.3 6.7 20 7.56 20H16.5C17.33 20 18 19.33 18 18.5C18 17.67 17.33 17 16.5 17H11L14.59 13.41C15.37 12.63 15.37 11.36 14.59 10.58L11 7H16.5C17.33 7 18 6.33 18 5.5C18 4.67 17.33 4 16.5 4Z" />
</svg>
`;

const lock_open = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M17 8H18C19.1 8 20 8.9 20 10V20C20 21.1 19.1 22 18 22H6C4.9 22 4 21.1 4 20V10C4 8.9 4.9 8 6 8H15V6C15 4.35 13.65 3 12 3C10.63 3 9.44 3.93 9.1 5.25C8.96 5.79 8.41 6.11 7.88 5.97C7.34 5.83 7.02 5.29 7.16 4.75C7.73 2.54 9.72 1 12 1C14.76 1 17 3.24 17 6V8ZM10 15C10 13.9 10.9 13 12 13C13.1 13 14 13.9 14 15C14 16.1 13.1 17 12 17C10.9 17 10 16.1 10 15Z" />
</svg>
`;

const open_new_window = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 19H6C5.45 19 5 18.55 5 18V6C5 5.45 5.45 5 6 5H11C11.55 5 12 4.55 12 4C12 3.45 11.55 3 11 3H5C3.89 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V13C21 12.45 20.55 12 20 12C19.45 12 19 12.45 19 13V18C19 18.55 18.55 19 18 19ZM14 4C14 4.55 14.45 5 15 5H17.59L8.46 14.13C8.07 14.52 8.07 15.15 8.46 15.54C8.85 15.93 9.48 15.93 9.87 15.54L19 6.41V9C19 9.55 19.45 10 20 10C20.55 10 21 9.55 21 9V4C21 3.45 20.55 3 20 3H15C14.45 3 14 3.45 14 4Z" />
</svg>
`;

const email = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 4H4C2.9 4 2 4.9 2 6V18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V6C22 4.9 21.1 4 20 4ZM19.6 8.25L13.06 12.34C12.41 12.75 11.59 12.75 10.94 12.34L4.4 8.25C4.15 8.09 4 7.82 4 7.53C4 6.86 4.73 6.46 5.3 6.81L12 11L18.7 6.81C19.27 6.46 20 6.86 20 7.53C20 7.82 19.85 8.09 19.6 8.25Z" />
</svg>
`;

const wifi = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M2.05999 10.06C2.56999 10.57 3.37999 10.62 3.92999 10.16C8.59999 6.32002 15.38 6.32002 20.06 10.15C20.62 10.61 21.44 10.57 21.95 10.06C22.54 9.47002 22.5 8.49002 21.85 7.96002C16.14 3.29002 7.87999 3.29002 2.15999 7.96002C1.50999 8.48002 1.45999 9.46002 2.05999 10.06ZM9.81999 17.82L11.29 19.29C11.68 19.68 12.31 19.68 12.7 19.29L14.17 17.82C14.64 17.35 14.54 16.54 13.94 16.23C12.72 15.6 11.26 15.6 10.03 16.23C9.45999 16.54 9.34999 17.35 9.81999 17.82ZM6.08999 14.09C6.57999 14.58 7.34999 14.63 7.91999 14.22C10.36 12.49 13.64 12.49 16.08 14.22C16.65 14.62 17.42 14.58 17.91 14.09L17.92 14.08C18.52 13.48 18.48 12.46 17.79 11.97C14.35 9.48002 9.65999 9.48002 6.20999 11.97C5.51999 12.47 5.47999 13.48 6.08999 14.09Z" />
</svg>
`;

const forwardX15 = `<svg width="24" height="24" viewBox="0 0 24 24" fill="none" xmlns="http://www.w3.org/2000/svg">
<g clip-path="url(#clip0_13_503)">
<path d="M18.92 13.29C18.6773 13.2876 18.4421 13.3735 18.2581 13.5318C18.0741 13.69 17.9539 13.9097 17.92 14.15C17.8052 14.9867 17.515 15.7898 17.0684 16.5067C16.6219 17.2236 16.029 17.8381 15.3286 18.31C14.6282 18.782 13.8361 19.1008 13.004 19.2455C12.1719 19.3903 11.3186 19.3577 10.5 19.15C9.41134 18.8945 8.41894 18.3318 7.64074 17.5287C6.86253 16.7257 6.33123 15.7161 6.10998 14.62C5.90952 13.7382 5.91095 12.8226 6.11418 11.9414C6.31741 11.0603 6.71717 10.2365 7.28358 9.5316C7.85 8.82671 8.56841 8.25896 9.38513 7.87079C10.2018 7.48263 11.0957 7.28409 12 7.29001V10.08C11.9963 10.1801 12.0234 10.2789 12.0776 10.3631C12.1318 10.4473 12.2105 10.5129 12.3031 10.551C12.3957 10.5892 12.4978 10.598 12.5955 10.5764C12.6933 10.5547 12.7821 10.5037 12.85 10.43L16.64 6.64001C16.6868 6.59353 16.724 6.53823 16.7494 6.4773C16.7748 6.41637 16.7879 6.35101 16.7879 6.28501C16.7879 6.219 16.7748 6.15365 16.7494 6.09272C16.724 6.03179 16.6868 5.97649 16.64 5.93001L12.85 2.14001C12.7795 2.0709 12.6901 2.02422 12.5931 2.00582C12.4961 1.98743 12.3959 1.99816 12.305 2.03666C12.2141 2.07516 12.1366 2.1397 12.0823 2.22216C12.0281 2.30462 11.9994 2.40129 12 2.50001V5.29001C10.8136 5.28977 9.64193 5.55341 8.56997 6.06186C7.498 6.5703 6.55255 7.3108 5.8021 8.22973C5.05164 9.14866 4.51497 10.223 4.23095 11.3749C3.94694 12.5269 3.9227 13.7275 4.15998 14.89C4.4373 16.3989 5.15506 17.7919 6.22281 18.8934C7.29056 19.995 8.66051 20.7558 10.16 21.08C11.2434 21.3372 12.3685 21.3654 13.4634 21.1628C14.5584 20.9602 15.5989 20.5313 16.5186 19.9035C17.4382 19.2756 18.2166 18.4627 18.8041 17.5168C19.3915 16.5708 19.775 15.5127 19.93 14.41C19.9472 14.2681 19.9337 14.1242 19.8906 13.988C19.8474 13.8517 19.7756 13.7263 19.6799 13.6202C19.5842 13.514 19.4668 13.4296 19.3357 13.3727C19.2046 13.3157 19.0629 13.2875 18.92 13.29Z" fill="#191919"/>
<path d="M10.92 16.29H10.06V13L9.06 13.32V12.62L10.82 12H10.92V16.29Z" fill="#191919"/>
<path d="M12.44 14.17L12.69 12H15.11V12.71H13.4L13.29 13.64C13.4895 13.5321 13.7132 13.477 13.94 13.48C14.1245 13.4647 14.31 13.4909 14.4831 13.5566C14.6561 13.6224 14.8122 13.726 14.94 13.86C15.1912 14.1577 15.3167 14.5414 15.29 14.93C15.2928 15.1899 15.2346 15.4468 15.12 15.68C15.0038 15.8964 14.8264 16.0738 14.61 16.19C14.3758 16.3019 14.1195 16.3599 13.86 16.3599C13.6004 16.3599 13.3442 16.3019 13.11 16.19C12.8962 16.095 12.7128 15.9427 12.58 15.75C12.4482 15.5547 12.3753 15.3256 12.37 15.09H13.22C13.229 15.2487 13.2967 15.3985 13.41 15.51C13.5255 15.6121 13.6759 15.6658 13.83 15.66C13.9164 15.6644 14.0027 15.6476 14.0811 15.611C14.1596 15.5744 14.2278 15.5191 14.28 15.45C14.3936 15.2749 14.4496 15.0685 14.44 14.86C14.4533 14.6572 14.3889 14.457 14.26 14.3C14.192 14.2323 14.1106 14.1796 14.0211 14.1452C13.9315 14.1107 13.8358 14.0954 13.74 14.1C13.563 14.0946 13.3897 14.1512 13.25 14.26L13.17 14.34L12.44 14.17Z" fill="#191919"/>
</g>
<defs>
<clipPath id="clip0_13_503">
<rect width="15.93" height="19.29" fill="white" transform="translate(4 2)"/>
</clipPath>
</defs>
</svg>
`;

const drag_indicator = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11 18C11 19.1 10.1 20 9 20C7.9 20 7 19.1 7 18C7 16.9 7.9 16 9 16C10.1 16 11 16.9 11 18ZM9 10C7.9 10 7 10.9 7 12C7 13.1 7.9 14 9 14C10.1 14 11 13.1 11 12C11 10.9 10.1 10 9 10ZM9 4C7.9 4 7 4.9 7 6C7 7.1 7.9 8 9 8C10.1 8 11 7.1 11 6C11 4.9 10.1 4 9 4ZM15 8C16.1 8 17 7.1 17 6C17 4.9 16.1 4 15 4C13.9 4 13 4.9 13 6C13 7.1 13.9 8 15 8ZM15 10C13.9 10 13 10.9 13 12C13 13.1 13.9 14 15 14C16.1 14 17 13.1 17 12C17 10.9 16.1 10 15 10ZM15 16C13.9 16 13 16.9 13 18C13 19.1 13.9 20 15 20C16.1 20 17 19.1 17 18C17 16.9 16.1 16 15 16Z" />
</svg>
`;

const heart_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19.66 3.99C17.02 2.19 13.76 3.03 12 5.09C10.24 3.03 6.97997 2.18 4.33997 3.99C2.93997 4.95 2.05997 6.57 1.99997 8.28C1.85997 12.16 5.29997 15.27 10.55 20.04L10.65 20.13C11.41 20.82 12.58 20.82 13.34 20.12L13.45 20.02C18.7 15.26 22.13 12.15 22 8.27C21.94 6.57 21.06 4.95 19.66 3.99ZM12.1 18.55L12 18.65L11.9 18.55C7.13997 14.24 3.99997 11.39 3.99997 8.5C3.99997 6.5 5.49997 5 7.49997 5C9.03997 5 10.54 5.99 11.07 7.36H12.94C13.46 5.99 14.96 5 16.5 5C18.5 5 20 6.5 20 8.5C20 11.39 16.86 14.24 12.1 18.55Z" />
</svg>
`;

const add = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 13H13V18C13 18.55 12.55 19 12 19C11.45 19 11 18.55 11 18V13H6C5.45 13 5 12.55 5 12C5 11.45 5.45 11 6 11H11V6C11 5.45 11.45 5 12 5C12.55 5 13 5.45 13 6V11H18C18.55 11 19 11.45 19 12C19 12.55 18.55 13 18 13Z" />
</svg>
`;

const bar_graph = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M6.4 9.2H6.6C7.37 9.2 8 9.83 8 10.6V17.6C8 18.37 7.37 19 6.6 19H6.4C5.63 19 5 18.37 5 17.6V10.6C5 9.83 5.63 9.2 6.4 9.2ZM12 5C12.77 5 13.4 5.63 13.4 6.4V17.6C13.4 18.37 12.77 19 12 19C11.23 19 10.6 18.37 10.6 17.6V6.4C10.6 5.63 11.23 5 12 5ZM17.6 13C18.37 13 19 13.63 19 14.4V17.6C19 18.37 18.37 19 17.6 19C16.83 19 16.2 18.37 16.2 17.6V14.4C16.2 13.63 16.83 13 17.6 13Z" />
</svg>
`;

const close = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18.3 5.70997C17.91 5.31997 17.28 5.31997 16.89 5.70997L12 10.59L7.10997 5.69997C6.71997 5.30997 6.08997 5.30997 5.69997 5.69997C5.30997 6.08997 5.30997 6.71997 5.69997 7.10997L10.59 12L5.69997 16.89C5.30997 17.28 5.30997 17.91 5.69997 18.3C6.08997 18.69 6.71997 18.69 7.10997 18.3L12 13.41L16.89 18.3C17.28 18.69 17.91 18.69 18.3 18.3C18.69 17.91 18.69 17.28 18.3 16.89L13.41 12L18.3 7.10997C18.68 6.72997 18.68 6.08997 18.3 5.70997Z" />
</svg>
`;

const trophy_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M17 5H19C20.1 5 21 5.9 21 7V8C21 10.55 19.08 12.63 16.61 12.94C15.98 14.44 14.63 15.57 13 15.9V19H16C16.55 19 17 19.45 17 20C17 20.55 16.55 21 16 21H8C7.45 21 7 20.55 7 20C7 19.45 7.45 19 8 19H11V15.9C9.37 15.57 8.02 14.44 7.39 12.94C4.92 12.63 3 10.55 3 8V7C3 5.9 3.9 5 5 5H7V4C7 3.45 7.45 3 8 3H16C16.55 3 17 3.45 17 4V5ZM5 7V8C5 9.3 5.84 10.4 7 10.82V7H5ZM17 10.82C18.16 10.4 19 9.3 19 8V7H17V10.82ZM12 14C10.35 14 9 12.65 9 11V5H15V11C15 12.65 13.65 14 12 14Z" />
</svg>
`;

const auto_awesome = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19.46 8.00002L20.25 6.25002L22 5.46002C22.39 5.28002 22.39 4.73002 22 4.55002L20.25 3.76002L19.46 2.00002C19.28 1.61002 18.73 1.61002 18.55 2.00002L17.76 3.75002L16 4.54002C15.61 4.72002 15.61 5.27002 16 5.45002L17.75 6.24002L18.54 8.00002C18.72 8.39002 19.28 8.39002 19.46 8.00002ZM11.5 9.50002L9.91 6.00002C9.56 5.22002 8.44 5.22002 8.09 6.00002L6.5 9.50002L3 11.09C2.22 11.45 2.22 12.56 3 12.91L6.5 14.5L8.09 18C8.45 18.78 9.56 18.78 9.91 18L11.5 14.5L15 12.91C15.78 12.55 15.78 11.44 15 11.09L11.5 9.50002ZM18.54 16L17.75 17.75L16 18.54C15.61 18.72 15.61 19.27 16 19.45L17.75 20.24L18.54 22C18.72 22.39 19.27 22.39 19.45 22L20.24 20.25L22 19.46C22.39 19.28 22.39 18.73 22 18.55L20.25 17.76L19.46 16C19.28 15.61 18.72 15.61 18.54 16Z" />
</svg>
`;

const delete_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M6 19C6 20.1 6.9 21 8 21H16C17.1 21 18 20.1 18 19V9C18 7.9 17.1 7 16 7H8C6.9 7 6 7.9 6 9V19ZM9 9H15C15.55 9 16 9.45 16 10V18C16 18.55 15.55 19 15 19H9C8.45 19 8 18.55 8 18V10C8 9.45 8.45 9 9 9ZM15.5 4L14.79 3.29C14.61 3.11 14.35 3 14.09 3H9.91C9.65 3 9.39 3.11 9.21 3.29L8.5 4H6C5.45 4 5 4.45 5 5C5 5.55 5.45 6 6 6H18C18.55 6 19 5.55 19 5C19 4.45 18.55 4 18 4H15.5Z" />
</svg>
`;

const email_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 4H4C2.9 4 2.01 4.9 2.01 6L2 18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V6C22 4.9 21.1 4 20 4ZM19 18H5C4.45 18 4 17.55 4 17V8L10.94 12.34C11.59 12.75 12.41 12.75 13.06 12.34L20 8V17C20 17.55 19.55 18 19 18ZM12 11L4 6H20L12 11Z" />
</svg>
`;

const copy = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15 20H5V7C5 6.45 4.55 6 4 6C3.45 6 3 6.45 3 7V20C3 21.1 3.9 22 5 22H15C15.55 22 16 21.55 16 21C16 20.45 15.55 20 15 20ZM20 16V4C20 2.9 19.1 2 18 2H9C7.9 2 7 2.9 7 4V16C7 17.1 7.9 18 9 18H18C19.1 18 20 17.1 20 16Z" />
</svg>
`;

const refresh = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M17.65 6.34999C16.02 4.71999 13.71 3.77999 11.17 4.03999C7.50002 4.40999 4.48002 7.38999 4.07002 11.06C3.52002 15.91 7.27002 20 12 20C15.19 20 17.93 18.13 19.21 15.44C19.53 14.77 19.05 14 18.31 14C17.94 14 17.59 14.2 17.43 14.53C16.3 16.96 13.59 18.5 10.63 17.84C8.41002 17.35 6.62002 15.54 6.15002 13.32C5.31002 9.43999 8.26002 5.99999 12 5.99999C13.66 5.99999 15.14 6.68999 16.22 7.77999L14.71 9.28999C14.08 9.91999 14.52 11 15.41 11H19C19.55 11 20 10.55 20 9.99999V6.40999C20 5.51999 18.92 5.06999 18.29 5.69999L17.65 6.34999Z" />
</svg>
`;

const checkbox_selected = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3ZM10.71 16.29C10.32 16.68 9.69 16.68 9.3 16.29L5.71 12.7C5.32 12.31 5.32 11.68 5.71 11.29C6.1 10.9 6.73 10.9 7.12 11.29L10 14.17L16.88 7.29C17.27 6.9 17.9 6.9 18.29 7.29C18.68 7.68 18.68 8.31 18.29 8.7L10.71 16.29Z" />
</svg>
`;

const calender_outline = `<svg viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 3H19V1H17V3H7V1H5V3H4C2.9 3 2 3.9 2 5V21C2 22.1 2.9 23 4 23H20C21.1 23 22 22.1 22 21V5C22 3.9 21.1 3 20 3ZM20 21H4V10H20V21ZM20 8H4V5H20V8Z"/>
</svg>
`;

const image = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3ZM11.1398 15.6805L9.36174 13.4548C9.18394 13.2349 8.86219 13.2437 8.70132 13.4724L6.59304 16.2874C6.3729 16.5777 6.56764 17 6.92326 17H17.0751C17.4223 17 17.6255 16.5865 17.4138 16.2962L14.4419 12.1793C14.2726 11.9417 13.9339 11.9417 13.7646 12.1705L11.1398 15.6805Z" />
</svg>
`;

const sort_descending = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M13 18H11C10.45 18 10 17.55 10 17C10 16.45 10.45 16 11 16L13 16C13.55 16 14 16.45 14 17C14 17.55 13.55 18 13 18Z" />
<path d="M11 8C10.45 8 10 7.55 10 7C10 6.45 10.45 6 11 6L21 6C21.55 6 22 6.45 22 7C22 7.55 21.55 8 21 8L11 8Z" />
<path d="M17 13L11 13C10.45 13 10 12.55 10 12C10 11.45 10.45 11 11 11L17 11C17.55 11 18 11.45 18 12C18 12.55 17.55 13 17 13Z" />
<path d="M8.83887 15.0159L5.87217 17.855C5.67013 18.0483 5.32987 18.0483 5.12783 17.855L2.16113 15.0159C1.82086 14.7004 2.0548 14.1509 2.5333 14.1509H4.43667L4.43667 7.0176C4.43667 6.45792 4.91517 6 5.5 6C6.08484 6 6.56334 6.45792 6.56334 7.0176L6.56333 14.1509H8.4667C8.9452 14.1509 9.17914 14.7004 8.83887 15.0159Z" />
</svg>
`;

const save = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M16.17 3C16.7 3 17.21 3.21 17.59 3.59L20.41 6.42C20.79 6.79 21 7.3 21 7.83V19C21 20.1 20.1 21 19 21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.89 3 5 3H16.17ZM14 10H8C6.9 10 6 9.1 6 8C6 6.9 6.9 6 8 6H14C15.1 6 16 6.9 16 8C16 9.1 15.1 10 14 10ZM12 18C10.34 18 9 16.66 9 15C9 13.34 10.34 12 12 12C13.66 12 15 13.34 15 15C15 16.66 13.66 18 12 18Z" />
</svg>
`;

const chevron_up = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11.29 8.70998L6.69997 13.3C6.30997 13.69 6.30997 14.32 6.69997 14.71C7.08997 15.1 7.71997 15.1 8.10997 14.71L12 10.83L15.88 14.71C16.27 15.1 16.9 15.1 17.29 14.71C17.68 14.32 17.68 13.69 17.29 13.3L12.7 8.70998C12.32 8.31998 11.68 8.31998 11.29 8.70998Z" />
</svg>
`;

const arrow_drop_down = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M8.70999 11.71L11.3 14.3C11.69 14.69 12.32 14.69 12.71 14.3L15.3 11.71C15.93 11.08 15.48 10 14.59 10H9.40999C8.51999 10 8.07999 11.08 8.70999 11.71Z" />
</svg>
`;

const share_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 16.08C17.24 16.08 16.56 16.38 16.04 16.85L8.91 12.7C8.96 12.47 9 12.24 9 12C9 11.76 8.96 11.53 8.91 11.3L15.96 7.19C16.5 7.69 17.21 8 18 8C19.66 8 21 6.66 21 5C21 3.34 19.66 2 18 2C16.34 2 15 3.34 15 5C15 5.24 15.04 5.47 15.09 5.7L8.04 9.81C7.5 9.31 6.79 9 6 9C4.34 9 3 10.34 3 12C3 13.66 4.34 15 6 15C6.79 15 7.5 14.69 8.04 14.19L15.16 18.35C15.11 18.56 15.08 18.78 15.08 19C15.08 20.61 16.39 21.92 18 21.92C19.61 21.92 20.92 20.61 20.92 19C20.92 17.39 19.61 16.08 18 16.08ZM18 4C18.55 4 19 4.45 19 5C19 5.55 18.55 6 18 6C17.45 6 17 5.55 17 5C17 4.45 17.45 4 18 4ZM6 13C5.45 13 5 12.55 5 12C5 11.45 5.45 11 6 11C6.55 11 7 11.45 7 12C7 12.55 6.55 13 6 13ZM18 20.02C17.45 20.02 17 19.57 17 19.02C17 18.47 17.45 18.02 18 18.02C18.55 18.02 19 18.47 19 19.02C19 19.57 18.55 20.02 18 20.02Z" />
</svg>
`;

const swap_vertical = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M16 17.01V11C16 10.45 15.55 10 15 10C14.45 10 14 10.45 14 11V17.01H12.21C11.76 17.01 11.54 17.55 11.86 17.86L14.65 20.64C14.85 20.83 15.16 20.83 15.36 20.64L18.15 17.86C18.47 17.55 18.24 17.01 17.8 17.01H16ZM8.65003 3.35002L5.86003 6.14002C5.54003 6.45002 5.76003 6.99002 6.21003 6.99002H8.00003V13C8.00003 13.55 8.45003 14 9.00003 14C9.55003 14 10 13.55 10 13V6.99002H11.79C12.24 6.99002 12.46 6.45002 12.14 6.14002L9.35003 3.35002C9.16003 3.16002 8.84003 3.16002 8.65003 3.35002Z" />
</svg>
`;

const folder_shared = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 6H12L10.59 4.59C10.21 4.21 9.7 4 9.17 4H4C2.9 4 2.01 4.9 2.01 6L2 18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V8C22 6.9 21.1 6 20 6ZM15 9C16.1 9 17 9.9 17 11C17 12.1 16.1 13 15 13C13.9 13 13 12.1 13 11C13 9.9 13.9 9 15 9ZM19 17H11V16C11 14.67 13.67 14 15 14C16.33 14 19 14.67 19 16V17Z" />
</svg>
`;

const column_outline = `<svg viewBox="0 0 18 14" xmlns="http://www.w3.org/2000/svg">
<path d="M1 0C0.447716 0 0 0.447715 0 1V13C0 13.5523 0.447715 14 1 14H17C17.5523 14 18 13.5523 18 13V1C18 0.447716 17.5523 0 17 0H1ZM5.33 12H2V2H5.33V12ZM10.67 12H7.34V2H10.67V12ZM16 12H12.67V2H16V12Z" />
</svg>
`;

const image_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9.36174 13.4548L11.1398 15.6805L13.7646 12.1705C13.9339 11.9417 14.2726 11.9417 14.4419 12.1793L17.4138 16.2962C17.6255 16.5865 17.4223 17 17.0751 17H6.92326C6.56764 17 6.3729 16.5777 6.59304 16.2874L8.70132 13.4724C8.86219 13.2437 9.18394 13.2349 9.36174 13.4548Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M5 3H19C20.1 3 21 3.9 21 5V19C21 20.1 20.1 21 19 21H5C3.9 21 3 20.1 3 19V5C3 3.9 3.9 3 5 3ZM19 19V5H5V19H19Z" />
</svg>
`;

const arrow_down = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11 5V16.17L6.12 11.29C5.73 10.9 5.09 10.9 4.7 11.29C4.31 11.68 4.31 12.31 4.7 12.7L11.29 19.29C11.68 19.68 12.31 19.68 12.7 19.29L19.29 12.7C19.68 12.31 19.68 11.68 19.29 11.29C18.9 10.9 18.27 10.9 17.88 11.29L13 16.17V5C13 4.45 12.55 4 12 4C11.45 4 11 4.45 11 5Z" />
</svg>
`;

const play = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M8 6.82046V17.1805C8.00382 17.3581 8.05492 17.5316 8.14804 17.6829C8.24115 17.8343 8.37292 17.9581 8.52978 18.0416C8.68663 18.1251 8.86291 18.1654 9.04047 18.1581C9.21803 18.1509 9.39046 18.0965 9.54 18.0005L17.68 12.8205C17.8225 12.7303 17.9399 12.6055 18.0212 12.4578C18.1026 12.31 18.1452 12.1441 18.1452 11.9755C18.1452 11.8068 18.1026 11.6409 18.0212 11.4932C17.9399 11.3454 17.8225 11.2207 17.68 11.1305L9.54 6.00046C9.39046 5.90446 9.21803 5.85004 9.04047 5.84281C8.86291 5.83558 8.68663 5.87579 8.52978 5.95931C8.37292 6.04283 8.24115 6.16664 8.14804 6.318C8.05492 6.46936 8.00382 6.6428 8 6.82046Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const radio_selected = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M17 12C17 14.7614 14.7614 17 12 17C9.23858 17 7 14.7614 7 12C7 9.23858 9.23858 7 12 7C14.7614 7 17 9.23858 17 12Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M2 12C2 6.48 6.48 2 12 2C17.52 2 22 6.48 22 12C22 17.52 17.52 22 12 22C6.48 22 2 17.52 2 12ZM4 12C4 16.42 7.58 20 12 20C16.42 20 20 16.42 20 12C20 7.58 16.42 4 12 4C7.58 4 4 7.58 4 12Z" />
</svg>
`;

const chat = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20 2H4C2.9 2 2.01 2.9 2.01 4L2 22L6 18H20C21.1 18 22 17.1 22 16V4C22 2.9 21.1 2 20 2ZM7 9H17C17.55 9 18 9.45 18 10C18 10.55 17.55 11 17 11H7C6.45 11 6 10.55 6 10C6 9.45 6.45 9 7 9ZM13 14H7C6.45 14 6 13.55 6 13C6 12.45 6.45 12 7 12H13C13.55 12 14 12.45 14 13C14 13.55 13.55 14 13 14ZM17 8H7C6.45 8 6 7.55 6 7C6 6.45 6.45 6 7 6H17C17.55 6 18 6.45 18 7C18 7.55 17.55 8 17 8Z" />
</svg>
`;

const notification = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12.5865 21.5C13.6865 21.5 14.5865 20.6 14.5865 19.5H10.5865C10.5865 20.6 11.4765 21.5 12.5865 21.5ZM18.5865 15.5V10.5C18.5865 7.43 16.9465 4.86 14.0865 4.18V3.5C14.0865 2.67 13.4165 2 12.5865 2C11.7565 2 11.0865 2.67 11.0865 3.5V4.18C8.21649 4.86 6.58649 7.42 6.58649 10.5V15.5L5.29649 16.79C4.66649 17.42 5.10649 18.5 5.99649 18.5H19.1665C20.0565 18.5 20.5065 17.42 19.8765 16.79L18.5865 15.5Z" />
</svg>
`;

const work_outline = `<svg  viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
<path d="M14 6V4H10V6H14ZM4 9V18C4 18.55 4.45 19 5 19H19C19.55 19 20 18.55 20 18V9C20 8.45 19.55 8 19 8H5C4.45 8 4 8.45 4 9ZM20 6C21.11 6 22 6.89 22 8V19C22 20.11 21.11 21 20 21H4C2.89 21 2 20.11 2 19L2.01 8C2.01 6.89 2.89 6 4 6H8V4C8 2.89 8.89 2 10 2H14C15.11 2 16 2.89 16 4V6H20Z" />
</svg>
`;

const save_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14 10H8C6.9 10 6 9.1 6 8C6 6.9 6.9 6 8 6H14C15.1 6 16 6.9 16 8C16 9.1 15.1 10 14 10Z" />
<path d="M12 18C10.34 18 9 16.66 9 15C9 13.34 10.34 12 12 12C13.66 12 15 13.34 15 15C15 16.66 13.66 18 12 18Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M17.59 3.59C17.21 3.21 16.7 3 16.17 3H5C3.89 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V7.83C21 7.3 20.79 6.79 20.41 6.42L17.59 3.59ZM5 5V19H19V7.83L16.17 5H5Z" />
</svg>
`;

const camera = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15 12C15 13.6569 13.6569 15 12 15C10.3431 15 9 13.6569 9 12C9 10.3431 10.3431 9 12 9C13.6569 9 15 10.3431 15 12Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M16.83 4H20C21.1 4 22 4.9 22 6V18C22 19.1 21.1 20 20 20H4C2.9 20 2 19.1 2 18V6C2 4.9 2.9 4 4 4H7.17L8.4 2.65C8.78 2.24 9.32 2 9.88 2H14.12C14.68 2 15.22 2.24 15.59 2.65L16.83 4ZM7 12C7 14.76 9.24 17 12 17C14.76 17 17 14.76 17 12C17 9.24 14.76 7 12 7C9.24 7 7 9.24 7 12Z" />
</svg>
`;

const checkbox_indeterminate = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3ZM16 13H8C7.45 13 7 12.55 7 12C7 11.45 7.45 11 8 11H16C16.55 11 17 11.45 17 12C17 12.55 16.55 13 16 13Z" />
</svg>
`;

const redo = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18.4 10.6C16.55 8.99 14.15 8 11.5 8C7.34004 8 3.76004 10.42 2.06004 13.93C1.74004 14.6 2.10004 15.4 2.81004 15.64C3.40004 15.84 4.04004 15.56 4.31004 15C5.61004 12.34 8.34004 10.5 11.5 10.5C13.45 10.5 15.23 11.22 16.62 12.38L14.71 14.29C14.08 14.92 14.52 16 15.41 16H21C21.55 16 22 15.55 22 15V9.41C22 8.52 20.92 8.07 20.29 8.7L18.4 10.6Z" />
</svg>
`;

const groups = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 12.75C13.63 12.75 15.07 13.14 16.24 13.65C17.32 14.13 18 15.21 18 16.38V18H6V16.39C6 15.21 6.68 14.13 7.76 13.66C8.93 13.14 10.37 12.75 12 12.75ZM4 13C5.1 13 6 12.1 6 11C6 9.9 5.1 9 4 9C2.9 9 2 9.9 2 11C2 12.1 2.9 13 4 13ZM5.13 14.1C4.76 14.04 4.39 14 4 14C3.01 14 2.07 14.21 1.22 14.58C0.48 14.9 0 15.62 0 16.43V18H4.5V16.39C4.5 15.56 4.73 14.78 5.13 14.1ZM20 13C21.1 13 22 12.1 22 11C22 9.9 21.1 9 20 9C18.9 9 18 9.9 18 11C18 12.1 18.9 13 20 13ZM24 16.43C24 15.62 23.52 14.9 22.78 14.58C21.93 14.21 20.99 14 20 14C19.61 14 19.24 14.04 18.87 14.1C19.27 14.78 19.5 15.56 19.5 16.39V18H24V16.43ZM12 6C13.66 6 15 7.34 15 9C15 10.66 13.66 12 12 12C10.34 12 9 10.66 9 9C9 7.34 10.34 6 12 6Z" />
</svg>
`;

const more = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 8C13.1 8 14 7.1 14 6C14 4.9 13.1 4 12 4C10.9 4 10 4.9 10 6C10 7.1 10.9 8 12 8ZM12 10C10.9 10 10 10.9 10 12C10 13.1 10.9 14 12 14C13.1 14 14 13.1 14 12C14 10.9 13.1 10 12 10ZM12 16C10.9 16 10 16.9 10 18C10 19.1 10.9 20 12 20C13.1 20 14 19.1 14 18C14 16.9 13.1 16 12 16Z" />
</svg>
`;

const headphones_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M3 19V12C3 7.03 7.03 3 12 3C16.97 3 21 7.03 21 12V19C21 20.1 20.1 21 19 21H17C15.9 21 15 20.1 15 19V15C15 13.9 15.9 13 17 13H19V12C19 8.13 15.87 5 12 5C8.13 5 5 8.13 5 12V13H7C8.1 13 9 13.9 9 15V19C9 20.1 8.1 21 7 21H5C3.9 21 3 20.1 3 19ZM7 15V19H5V15H7ZM19 19H17V15H19V19Z" />
</svg>
`;

const attachment = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M17.75 16H7.17001C5.08001 16 3.22001 14.47 3.02001 12.39C2.79001 10.01 4.66001 8 7.00001 8H19.36C20.67 8 21.86 8.94 21.99 10.24C22.14 11.74 20.97 13 19.5 13H9.00001C8.45001 13 8.00001 12.55 8.00001 12C8.00001 11.45 8.45001 11 9.00001 11H17.75C18.16 11 18.5 10.66 18.5 10.25C18.5 9.84 18.16 9.5 17.75 9.5H9.14001C7.83001 9.5 6.64001 10.44 6.51001 11.74C6.36001 13.24 7.53001 14.5 9.00001 14.5H19.33C21.42 14.5 23.28 12.97 23.48 10.89C23.71 8.5 21.84 6.5 19.5 6.5H7.23001C4.36001 6.5 1.79001 8.6 1.52001 11.46C1.22001 14.75 3.78001 17.5 7.00001 17.5H17.75C18.16 17.5 18.5 17.16 18.5 16.75C18.5 16.34 18.16 16 17.75 16Z" />
</svg>
`;

const lock_open_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 13C10.9 13 10 13.9 10 15C10 16.1 10.9 17 12 17C13.1 17 14 16.1 14 15C14 13.9 13.1 13 12 13ZM18 8H17V6C17 3.24 14.76 1 12 1C9.72 1 7.73 2.54 7.16 4.75C7.02 5.29 7.34 5.83 7.88 5.97C8.41 6.11 8.96 5.79 9.1 5.25C9.44 3.93 10.63 3 12 3C13.65 3 15 4.35 15 6V8H6C4.9 8 4 8.9 4 10V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V10C20 8.9 19.1 8 18 8ZM18 19C18 19.55 17.55 20 17 20H7C6.45 20 6 19.55 6 19V11C6 10.45 6.45 10 7 10H17C17.55 10 18 10.45 18 11V19Z" />
</svg>
`;

const dark_mode_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M3 11.9536C3 7.31362 6.50999 3.49361 11.01 3.00362C11.9 2.93361 12.39 3.89361 11.94 4.56362C11.41 5.39361 11.1 6.39361 11.1 7.4536C11.1 10.4336 13.52 12.8536 16.5 12.8536C17.57 12.8536 18.57 12.5436 19.41 12.0036C20.17 11.5336 21.04 12.1636 20.95 12.9536C20.45 17.4536 16.63 20.9536 12 20.9536C7.03 20.9536 3 16.9236 3 11.9536ZM9.37 5.51C9.19 6.15002 9.10001 6.82 9.10001 7.49999C9.10001 11.58 12.42 14.9 16.5 14.9C17.18 14.9 17.85 14.81 18.49 14.63C17.45 17.19 14.93 19 12 19C8.14 19 5 15.86 5 12C5 9.07 6.81 6.55001 9.37 5.51Z" />
</svg>
`;

const business_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 7V5C12 3.9 11.1 3 10 3H4C2.9 3 2 3.9 2 5V19C2 20.1 2.9 21 4 21H20C21.1 21 22 20.1 22 19V9C22 7.9 21.1 7 20 7H12ZM6 19H4V17H6V19ZM6 15H4V13H6V15ZM6 11H4V9H6V11ZM6 7H4V5H6V7ZM10 19H8V17H10V19ZM10 15H8V13H10V15ZM10 11H8V9H10V11ZM10 7H8V5H10V7ZM19 19H12V17H14V15H12V13H14V11H12V9H19C19.55 9 20 9.45 20 10V18C20 18.55 19.55 19 19 19ZM18 11H16V13H18V11ZM18 15H16V17H18V15Z" />
</svg>
`;

const microphone_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M14.99 12C14.99 13.66 13.66 15 12 15C10.34 15 8.99998 13.66 8.99998 12V6C8.99998 4.34 10.34 3 12 3C13.66 3 15 4.34 15 6L14.99 12ZM10.8 5.89995C10.8 5.23995 11.34 4.69995 12 4.69995C12.66 4.69995 13.2 5.23995 13.2 5.89995L13.19 12.1C13.19 12.76 12.66 13.3 12 13.3C11.34 13.3 10.8 12.76 10.8 12.1V5.89995Z" />
<path d="M17.25 12.71C17.31 12.3 17.66 12 18.08 12C18.6 12 19 12.46 18.93 12.97C18.47 15.94 15.96 18.29 13 18.72V21C13 21.55 12.55 22 12 22C11.45 22 11 21.55 11 21V18.72C8.02998 18.27 5.52998 15.94 5.06998 12.97C4.99998 12.46 5.39998 12 5.91998 12C6.32998 12 6.68998 12.3 6.74998 12.71C7.11998 15.33 9.46998 17.1 12 17.1C14.53 17.1 16.88 15.32 17.25 12.71Z" />
</svg>
`;

const star_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19.6501 9.04L14.8101 8.62L12.9201 4.17C12.5801 3.36 11.4201 3.36 11.0801 4.17L9.19007 8.63L4.36007 9.04C3.48007 9.11 3.12007 10.21 3.79007 10.79L7.46007 13.97L6.36007 18.69C6.16007 19.55 7.09007 20.23 7.85007 19.77L12.0001 17.27L16.1501 19.78C16.9101 20.24 17.8401 19.56 17.6401 18.7L16.5401 13.97L20.2101 10.79C20.8801 10.21 20.5301 9.11 19.6501 9.04ZM12.0001 15.4L8.24007 17.67L9.24007 13.39L5.92007 10.51L10.3001 10.13L12.0001 6.1L13.7101 10.14L18.0901 10.52L14.7701 13.4L15.7701 17.68L12.0001 15.4Z" />
</svg>
`;

const success_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM12 20C7.59 20 4 16.41 4 12C4 7.59 7.59 4 12 4C16.41 4 20 7.59 20 12C20 16.41 16.41 20 12 20ZM15.88 8.29L10 14.17L8.12 12.29C7.73 11.9 7.1 11.9 6.71 12.29C6.32 12.68 6.32 13.31 6.71 13.7L9.3 16.29C9.69 16.68 10.32 16.68 10.71 16.29L17.3 9.7C17.69 9.31 17.69 8.68 17.3 8.29C16.91 7.9 16.27 7.9 15.88 8.29Z" />
</svg>
`;

const accessible = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14 4C14 5.10457 13.1046 6 12 6C10.8954 6 10 5.10457 10 4C10 2.89543 10.8954 2 12 2C13.1046 2 14 2.89543 14 4Z" />
<path d="M18.16 10.93C18.64 11.01 19 11.41 19 11.9C19 12.53 18.42 13 17.8 12.87C16.4 12.59 15 11.88 14 11.05V14.5H17C18.1 14.5 19 15.4 19 16.5V21C19 21.55 18.55 22 18 22C17.45 22 17 21.55 17 21V17H12C10.9 17 10 16.1 10 15V9.10004C10 8.07004 10.73 7.15004 11.75 7.03004C12.22 6.97004 12.63 7.07004 13 7.28004H13.01C13.015 7.28004 13.0175 7.28254 13.02 7.28504C13.0225 7.28754 13.025 7.29004 13.03 7.29004C13.26 7.40004 13.47 7.55004 13.64 7.74004L14.93 9.17004C15.73 10.05 16.91 10.72 18.16 10.93Z" />
<path d="M10 20C11.31 20 12.42 19.16 12.83 18H14.9C14.44 20.28 12.42 22 10 22C7.24 22 5 19.76 5 17C5 14.58 6.72 12.56 9 12.1V14.17C7.84 14.59 7 15.69 7 17C7 18.66 8.34 20 10 20Z" />
</svg>
`;

const star = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14.8101 8.62L19.6501 9.04C20.5301 9.11 20.8801 10.21 20.2101 10.79L16.5401 13.97L17.6401 18.7C17.8401 19.56 16.9101 20.24 16.1501 19.78L12.0001 17.27L7.85007 19.77C7.09007 20.23 6.16007 19.55 6.36007 18.69L7.46007 13.97L3.79007 10.79C3.12007 10.21 3.48007 9.11 4.36007 9.04L9.19007 8.63L11.0801 4.17C11.4201 3.36 12.5801 3.36 12.9201 4.17L14.8101 8.62Z" />
</svg>
`;

const column = `<svg viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14.67 6V18C14.67 18.55 14.22 19 13.67 19H10.34C9.79 19 9.34 18.55 9.34 18V6C9.34 5.45 9.79 5 10.34 5H13.67C14.22 5 14.67 5.45 14.67 6ZM16.67 19H20C20.55 19 21 18.55 21 18V6C21 5.45 20.55 5 20 5H16.67C16.12 5 15.67 5.45 15.67 6V18C15.67 18.55 16.11 19 16.67 19ZM8.33 18V6C8.33 5.45 7.88 5 7.33 5H4C3.45 5 3 5.45 3 6V18C3 18.55 3.45 19 4 19H7.33C7.89 19 8.33 18.55 8.33 18Z" />
</svg>
`;

const visibility_off = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 6.49999C14.76 6.49999 17 8.73999 17 11.5C17 12.01 16.9 12.5 16.76 12.96L19.82 16.02C21.21 14.79 22.31 13.25 23 11.49C21.27 7.10999 17 3.99999 12 3.99999C10.73 3.99999 9.51 4.19999 8.36 4.56999L10.53 6.73999C11 6.59999 11.49 6.49999 12 6.49999ZM2.71 3.15999C2.32 3.54999 2.32 4.17999 2.71 4.56999L4.68 6.53999C3.06 7.82999 1.77 9.52999 1 11.5C2.73 15.89 7 19 12 19C13.52 19 14.97 18.7 16.31 18.18L19.03 20.9C19.42 21.29 20.05 21.29 20.44 20.9C20.83 20.51 20.83 19.88 20.44 19.49L4.13 3.15999C3.74 2.76999 3.1 2.76999 2.71 3.15999ZM12 16.5C9.24 16.5 7 14.26 7 11.5C7 10.73 7.18 9.99999 7.49 9.35999L9.06 10.93C9.03 11.11 9 11.3 9 11.5C9 13.16 10.34 14.5 12 14.5C12.2 14.5 12.38 14.47 12.57 14.43L14.14 16C13.49 16.32 12.77 16.5 12 16.5ZM14.97 11.17C14.82 9.76999 13.72 8.67999 12.33 8.52999L14.97 11.17Z" />
</svg>
`;

const edit = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M3 17.2501V21.0001H6.75L17.81 9.94006L14.06 6.19006L3 17.2501ZM20.71 7.04006C21.1 6.65006 21.1 6.02006 20.71 5.63006L18.37 3.29006C17.98 2.90006 17.35 2.90006 16.96 3.29006L15.13 5.12006L18.88 8.87006L20.71 7.04006Z" />
</svg>
`;

const foldor = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M10.59 4.59C10.21 4.21 9.7 4 9.17 4H4C2.9 4 2.01 4.9 2.01 6L2 18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V8C22 6.9 21.1 6 20 6H12L10.59 4.59Z" />
</svg>
`;

const chevron_down = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15.88 9.29006L12 13.1701L8.11998 9.29006C7.72998 8.90006 7.09998 8.90006 6.70998 9.29006C6.31998 9.68006 6.31998 10.3101 6.70998 10.7001L11.3 15.2901C11.69 15.6801 12.32 15.6801 12.71 15.2901L17.3 10.7001C17.69 10.3101 17.69 9.68006 17.3 9.29006C16.91 8.91006 16.27 8.90006 15.88 9.29006Z" />
</svg>
`;

const filter_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M6.99993 6H16.9999L11.9899 12.3L6.99993 6ZM4.24993 5.61C6.26993 8.2 9.99993 13 9.99993 13V19C9.99993 19.55 10.4499 20 10.9999 20H12.9999C13.5499 20 13.9999 19.55 13.9999 19V13C13.9999 13 17.7199 8.2 19.7399 5.61C20.2499 4.95 19.7799 4 18.9499 4H5.03993C4.20993 4 3.73993 4.95 4.24993 5.61Z" />
</svg>
`;

const lock_clock = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M20 11.29C19.37 11.1 18.7 11 18 11C14.13 11 11 14.13 11 18C11 19.49 11.47 20.87 12.26 22H6C4.9 22 4 21.1 4 20V10C4 8.9 4.9 8 6 8H7V6C7 3.24 9.24 1 12 1C14.76 1 17 3.24 17 6V8H18C19.1 8 20 8.9 20 10V11.29ZM12 3C10.34 3 9 4.34 9 6V8H15V6C15 4.34 13.66 3 12 3Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M13 18C13 15.24 15.24 13 18 13C20.76 13 23 15.24 23 18C23 20.76 20.76 23 18 23C15.24 23 13 20.76 13 18ZM19.29 20C19.49 20.2 19.8 20.2 20 20C20.2 19.8 20.2 19.49 19.99 19.29L18.49 17.79V15.5C18.49 15.22 18.27 15 17.99 15C17.71 15 17.49 15.22 17.49 15.5V18C17.49 18.13 17.55 18.26 17.64 18.35L19.29 20Z" />
</svg>
`;

const archive_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M13.612 13.3353H14.4652C14.9429 13.3353 15.179 13.9357 14.8409 14.2859L12.3777 16.8374C12.1684 17.0542 11.8303 17.0542 11.621 16.8374L9.15778 14.2859C8.81969 13.9357 9.06118 13.3353 9.5388 13.3353H10.3921V10.5559C10.3921 10.2501 10.6336 10 10.9287 10H13.0753C13.3705 10 13.612 10.2501 13.612 10.5559V13.3353Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M19.15 3.55L20.54 5.23C20.83 5.57 21 6.02 21 6.5V19C21 20.1 20.1 21 19 21H5C3.9 21 3 20.1 3 19V6.5C3 6.02 3.17 5.57 3.46 5.23L4.84 3.55C5.12 3.21 5.53 3 6 3H18C18.47 3 18.88 3.21 19.15 3.55ZM17.76 5H6.24L5.44 5.97H18.57L17.76 5ZM5 8V19H19V8H5Z" />
</svg>
`;

const attach_file = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M16.5 6.75002V17.33C16.5 19.42 14.97 21.28 12.89 21.48C10.5 21.71 8.5 19.84 8.5 17.5V5.14002C8.5 3.83002 9.44 2.64002 10.74 2.51002C12.24 2.36002 13.5 3.53002 13.5 5.00002V15.5C13.5 16.05 13.05 16.5 12.5 16.5C11.95 16.5 11.5 16.05 11.5 15.5V6.75002C11.5 6.34002 11.16 6.00002 10.75 6.00002C10.34 6.00002 10 6.34002 10 6.75002V15.36C10 16.67 10.94 17.86 12.24 17.99C13.74 18.14 15 16.97 15 15.5V5.17002C15 3.08002 13.47 1.22002 11.39 1.02002C9.01 0.790024 7 2.66002 7 5.00002V17.27C7 20.14 9.1 22.71 11.96 22.98C15.25 23.28 18 20.72 18 17.5V6.75002C18 6.34002 17.66 6.00002 17.25 6.00002C16.84 6.00002 16.5 6.34002 16.5 6.75002Z" />
</svg>
`;

const language = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11.99 2C6.47 2 2 6.48 2 12C2 17.52 6.47 22 11.99 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 11.99 2ZM18.92 8H15.97C15.65 6.75 15.19 5.55 14.59 4.44C16.43 5.07 17.96 6.35 18.92 8ZM12 4.04C12.83 5.24 13.48 6.57 13.91 8H10.09C10.52 6.57 11.17 5.24 12 4.04ZM4.26 14C4.1 13.36 4 12.69 4 12C4 11.31 4.1 10.64 4.26 10H7.64C7.56 10.66 7.5 11.32 7.5 12C7.5 12.68 7.56 13.34 7.64 14H4.26ZM5.08 16H8.03C8.35 17.25 8.81 18.45 9.41 19.56C7.57 18.93 6.04 17.66 5.08 16ZM8.03 8H5.08C6.04 6.34 7.57 5.07 9.41 4.44C8.81 5.55 8.35 6.75 8.03 8ZM12 19.96C11.17 18.76 10.52 17.43 10.09 16H13.91C13.48 17.43 12.83 18.76 12 19.96ZM14.34 14H9.66C9.57 13.34 9.5 12.68 9.5 12C9.5 11.32 9.57 10.65 9.66 10H14.34C14.43 10.65 14.5 11.32 14.5 12C14.5 12.68 14.43 13.34 14.34 14ZM14.59 19.56C15.19 18.45 15.65 17.25 15.97 16H18.92C17.96 17.65 16.43 18.93 14.59 19.56ZM16.36 14C16.44 13.34 16.5 12.68 16.5 12C16.5 11.32 16.44 10.66 16.36 10H19.74C19.9 10.64 20 11.31 20 12C20 12.69 19.9 13.36 19.74 14H16.36Z" />
</svg>
`;

const analytics = `<svg viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19 3H5C3.9 3 3 3.9 3 5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V5C21 3.9 20.1 3 19 3ZM8 17C7.45 17 7 16.55 7 16V13C7 12.45 7.45 12 8 12C8.55 12 9 12.45 9 13V16C9 16.55 8.55 17 8 17ZM12 17C11.45 17 11 16.55 11 16V15C11 14.45 11.45 14 12 14C12.55 14 13 14.45 13 15V16C13 16.55 12.55 17 12 17ZM12 12C11.45 12 11 11.55 11 11C11 10.45 11.45 10 12 10C12.55 10 13 10.45 13 11C13 11.55 12.55 12 12 12ZM16 17C15.45 17 15 16.55 15 16V8C15 7.45 15.45 7 16 7C16.55 7 17 7.45 17 8V16C17 16.55 16.55 17 16 17Z" />
</svg>
`;

const delete_icon = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M6 19C6 20.1 6.9 21 8 21H16C17.1 21 18 20.1 18 19V9C18 7.9 17.1 7 16 7H8C6.9 7 6 7.9 6 9V19ZM18 4H15.5L14.79 3.29C14.61 3.11 14.35 3 14.09 3H9.91C9.65 3 9.39 3.11 9.21 3.29L8.5 4H6C5.45 4 5 4.45 5 5C5 5.55 5.45 6 6 6H18C18.55 6 19 5.55 19 5C19 4.45 18.55 4 18 4Z" />
</svg>
`;

const speedX3 = `<svg  viewBox="0 0 36 36"  xmlns="http://www.w3.org/2000/svg">
<path d="M13.6057 17.3501H12.2107L12.0307 19.5101H13.5307C14.01 19.48 14.484 19.6238 14.8657 19.9151C15.0459 20.0904 15.1841 20.3044 15.2698 20.5408C15.3556 20.7772 15.3866 21.0299 15.3607 21.2801C15.364 21.4872 15.3244 21.6927 15.2444 21.8838C15.1644 22.0748 15.0457 22.2472 14.8957 22.3901C14.5516 22.6677 14.1228 22.8191 13.6807 22.8191C13.2386 22.8191 12.8098 22.6677 12.4657 22.3901C12.3189 22.2639 12.2013 22.1074 12.121 21.9312C12.0407 21.7551 11.9996 21.5636 12.0007 21.3701H9.00071C8.98668 22.0516 9.18024 22.7212 9.55571 23.2901C9.95711 23.8866 10.526 24.3511 11.1907 24.6251C11.9234 24.9465 12.7156 25.11 13.5157 25.1051C14.7552 25.1673 15.9784 24.8019 16.9807 24.0701C17.406 23.7531 17.7482 23.3378 17.9781 22.8598C18.208 22.3818 18.3187 21.8552 18.3007 21.3251C18.3183 20.6572 18.1124 20.0026 17.7157 19.4651C17.3063 18.9469 16.7533 18.5608 16.1257 18.3551C16.7225 18.0939 17.2399 17.68 17.6257 17.1551C17.9402 16.7165 18.1177 16.1945 18.1357 15.6551C18.1545 15.1447 18.053 14.6371 17.8393 14.1733C17.6256 13.7095 17.3058 13.3024 16.9057 12.9851C15.9329 12.2799 14.7449 11.9351 13.5457 12.0101C12.7929 11.9959 12.0459 12.1443 11.3557 12.4451C10.7535 12.7187 10.2356 13.1486 9.85571 13.6901C9.48226 14.2149 9.28767 14.8461 9.30071 15.4901H12.3007C12.3001 15.3233 12.3392 15.1587 12.4149 15.01C12.4905 14.8613 12.6005 14.7328 12.7357 14.6351C13.0258 14.4061 13.3861 14.2842 13.7557 14.2901C13.961 14.2768 14.1668 14.306 14.3603 14.3756C14.5538 14.4453 14.731 14.554 14.8807 14.6951C15.011 14.8301 15.1127 14.9901 15.1797 15.1653C15.2467 15.3406 15.2776 15.5276 15.2707 15.7151C15.2923 15.9378 15.2638 16.1625 15.1874 16.3727C15.1109 16.583 14.9883 16.7735 14.8287 16.9302C14.6691 17.087 14.4764 17.2061 14.2648 17.2787C14.0532 17.3513 13.828 17.3757 13.6057 17.3501ZM25.1857 15.4751L23.8057 18.1001L22.5607 15.4751H19.4407L21.9457 20.1101L19.3057 24.9851H22.3057L23.8057 22.1801L25.3057 24.9851H28.4257L25.8007 20.1101L28.3057 15.4751H25.1857Z" />
</svg>
`;

const success = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M12 22C6.4875 22 2 17.5125 2 12C2 6.4875 6.4875 2 12 2C17.5125 2 22 6.4875 22 12C22 17.5125 17.5125 22 12 22ZM15.8825 8.2925L10.0025 14.1725L8.12251 12.2925C7.73251 11.9025 7.10251 11.9025 6.71251 12.2925C6.32251 12.6825 6.32251 13.3125 6.71251 13.7025L9.30251 16.2925C9.69251 16.6825 10.3225 16.6825 10.7125 16.2925L17.3025 9.7025C17.6925 9.3125 17.6925 8.6825 17.3025 8.2925C16.9125 7.9025 16.2725 7.9025 15.8825 8.2925Z" />
</svg>
`;

const thumbs_down = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M10.8799 21.94L16.4099 16.4C16.7799 16.03 16.9899 15.52 16.9899 14.99V5C16.9899 3.9 16.0899 3 14.9899 3H5.9999C5.1999 3 4.4799 3.48 4.1699 4.21L0.9099 11.82C0.0598996 13.8 1.5099 16 3.6599 16H9.3099L8.3599 20.58C8.2599 21.08 8.4099 21.59 8.7699 21.95C9.3599 22.53 10.2999 22.53 10.8799 21.94ZM20.9999 3C19.8999 3 18.9999 3.9 18.9999 5V13C18.9999 14.1 19.8999 15 20.9999 15C22.0999 15 22.9999 14.1 22.9999 13V5C22.9999 3.9 22.0999 3 20.9999 3Z" />
</svg>
`;

const clear_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M16.3 16.3C15.91 16.69 15.28 16.69 14.89 16.3L12 13.41L9.11 16.3C8.72 16.69 8.09 16.69 7.7 16.3C7.31 15.91 7.31 15.28 7.7 14.89L10.59 12L7.7 9.10997C7.31 8.71997 7.31 8.08997 7.7 7.69997C8.09 7.30997 8.72 7.30997 9.11 7.69997L12 10.59L14.89 7.69997C15.28 7.30997 15.91 7.30997 16.3 7.69997C16.69 8.08997 16.69 8.71997 16.3 9.10997L13.41 12L16.3 14.89C16.68 15.27 16.68 15.91 16.3 16.3Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M2 12C2 6.47 6.47 2 12 2C17.53 2 22 6.47 22 12C22 17.53 17.53 22 12 22C6.47 22 2 17.53 2 12ZM4 12C4 16.41 7.59 20 12 20C16.41 20 20 16.41 20 12C20 7.59 16.41 4 12 4C7.59 4 4 7.59 4 12Z" />
</svg>
`;

const sync = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11.99 4.00003V2.21003C11.99 1.76003 11.45 1.54003 11.14 1.86003L8.34001 4.65003C8.14001 4.85003 8.14001 5.16003 8.34001 5.36003L11.13 8.15003C11.45 8.46003 11.99 8.24003 11.99 7.79003V6.00003C15.3 6.00003 17.99 8.69003 17.99 12C17.99 12.79 17.84 13.56 17.55 14.25C17.4 14.61 17.51 15.02 17.78 15.29C18.29 15.8 19.15 15.62 19.42 14.95C19.79 14.04 19.99 13.04 19.99 12C19.99 7.58003 16.41 4.00003 11.99 4.00003ZM11.99 18C8.68001 18 5.99001 15.31 5.99001 12C5.99001 11.21 6.14001 10.44 6.43001 9.75003C6.58001 9.39003 6.47001 8.98003 6.20001 8.71003C5.69001 8.20003 4.83001 8.38003 4.56001 9.05003C4.19001 9.96003 3.99001 10.96 3.99001 12C3.99001 16.42 7.57001 20 11.99 20V21.79C11.99 22.24 12.53 22.46 12.84 22.14L15.63 19.35C15.83 19.15 15.83 18.84 15.63 18.64L12.84 15.85C12.53 15.54 11.99 15.76 11.99 16.21V18Z" />
</svg>
`;

const reorder = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M4 15H20C20.55 15 21 14.55 21 14C21 13.45 20.55 13 20 13H4C3.45 13 3 13.45 3 14C3 14.55 3.45 15 4 15ZM4 19H20C20.55 19 21 18.55 21 18C21 17.45 20.55 17 20 17H4C3.45 17 3 17.45 3 18C3 18.55 3.45 19 4 19ZM4 11H20C20.55 11 21 10.55 21 10C21 9.45 20.55 9 20 9H4C3.45 9 3 9.45 3 10C3 10.55 3.45 11 4 11ZM3 6C3 6.55 3.45 7 4 7H20C20.55 7 21 6.55 21 6C21 5.45 20.55 5 20 5H4C3.45 5 3 5.45 3 6Z" />
</svg>
`;

const location$1 = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C8.13 2 5 5.13 5 9C5 14.25 12 22 12 22C12 22 19 14.25 19 9C19 5.13 15.87 2 12 2ZM12 11.5C10.62 11.5 9.5 10.38 9.5 9C9.5 7.62 10.62 6.5 12 6.5C13.38 6.5 14.5 7.62 14.5 9C14.5 10.38 13.38 11.5 12 11.5Z" />
</svg>
`;

const notification_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19.8765 16.79L18.5865 15.5V10.5C18.5865 7.43 16.9465 4.86 14.0865 4.18V3.5C14.0865 2.67 13.4165 2 12.5865 2C11.7565 2 11.0865 2.67 11.0865 3.5V4.18C8.21648 4.86 6.58648 7.42 6.58648 10.5V15.5L5.29648 16.79C4.66648 17.42 5.10648 18.5 5.99648 18.5H19.1665C20.0665 18.5 20.5065 17.42 19.8765 16.79ZM16.5865 16.5H8.58648V10.5C8.58648 8.02 10.0965 6 12.5865 6C15.0765 6 16.5865 8.02 16.5865 10.5V16.5ZM12.5865 21.5C13.6865 21.5 14.5865 20.6 14.5865 19.5H10.5865C10.5865 20.6 11.4765 21.5 12.5865 21.5Z" />
</svg>
`;

const speedX2 = `<svg  viewBox="0 0 36 36"  xmlns="http://www.w3.org/2000/svg">
<path  d="M9.31509 24.8201H18.3151L18.1951 22.7351H13.1551L14.8201 20.8151C15.5013 20.1585 16.1377 19.4569 16.7251 18.7151C17.0829 18.2576 17.3756 17.7528 17.5951 17.2151C17.7884 16.7389 17.8853 16.229 17.8801 15.7151C17.9119 15.2001 17.8273 14.6846 17.6325 14.2067C17.4378 13.7289 17.1379 13.3011 16.7551 12.9551C15.8359 12.2711 14.7035 11.9362 13.5601 12.0101C12.7461 11.9981 11.942 12.1888 11.2201 12.5651C10.5534 12.9137 9.98967 13.4308 9.58509 14.0651C9.19712 14.7239 8.99495 15.4756 9.0001 16.2401H12.0001C11.975 15.7079 12.1223 15.1819 12.4201 14.7401C12.5456 14.5628 12.712 14.4184 12.9053 14.3192C13.0985 14.2199 13.3129 14.1688 13.5301 14.1701C13.7246 14.1565 13.9196 14.1888 14.0994 14.2643C14.2792 14.3399 14.4387 14.4566 14.5651 14.6051C14.8281 14.9647 14.9556 15.4057 14.9251 15.8501C14.7455 16.9112 14.2177 17.8822 13.4251 18.6101L9.31509 22.9301V24.8201ZM25.0651 15.3551L23.6851 17.9801L22.4401 15.3101H19.3201L21.8251 19.9451L19.1851 24.8201H22.1851L23.6851 22.0001L25.1851 24.8201H28.2901L25.6801 19.9901L28.1851 15.3551H25.0651Z" fill-rule="nonzero" stroke="none" />
</svg>
`;

const keyboard_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M13 8H11V10H13V8Z" />
<path d="M13 11H11V13H13V11Z" />
<path d="M10 8H8V10H10V8Z" />
<path d="M10 11H8V13H10V11Z" />
<path d="M7 11H5V13H7V11Z" />
<path d="M7 8H5V10H7V8Z" />
<path d="M16 11H14V13H16V11Z" />
<path d="M16 8H14V10H16V8Z" />
<path d="M19 11H17V13H19V11Z" />
<path d="M19 8H17V10H19V8Z" />
<path d="M15 16H9C8.45 16 8 15.55 8 15C8 14.45 8.45 14 9 14H15C15.55 14 16 14.45 16 15C16 15.55 15.55 16 15 16Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M4 5H20C21.1 5 22 5.9 22 7V17C22 18.1 21.1 19 20 19H4C2.9 19 2 18.1 2 17L2.01 7C2.01 5.9 2.9 5 4 5ZM20 17V7H4V17H20Z" />
</svg>
`;

const visibility_off_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 6.00001C15.79 6.00001 19.17 8.13001 20.82 11.5C20.23 12.72 19.4 13.77 18.41 14.62L19.82 16.03C21.21 14.8 22.31 13.26 23 11.5C21.27 7.11001 17 4.00001 12 4.00001C10.73 4.00001 9.51 4.20001 8.36 4.57001L10.01 6.22001C10.66 6.09001 11.32 6.00001 12 6.00001ZM10.93 7.14001L13 9.21001C13.57 9.46001 14.03 9.92001 14.28 10.49L16.35 12.56C16.43 12.22 16.49 11.86 16.49 11.49C16.5 9.01001 14.48 7.00001 12 7.00001C11.63 7.00001 11.28 7.05001 10.93 7.14001ZM2.63998 4.5L4.69 6.55001C3.06 7.83001 1.77 9.53001 1 11.5C2.73 15.89 7 19 12 19C13.52 19 14.98 18.71 16.32 18.18L19.14 21C19.14 21 19.84 21.5 20.445 20.895C21.05 20.29 20.5 19.54 20.5 19.54L4 3.03001C4 3.03001 3.31006 2.56497 2.715 3.16001C2.11994 3.75505 2.63998 4.5 2.63998 4.5ZM9.51 11.37L12.12 13.98C12.08 13.99 12.04 14 12 14C10.62 14 9.5 12.88 9.5 11.5C9.5 11.45 9.51 11.42 9.51 11.37ZM6.11 7.97001L7.86 9.72001C7.63 10.27 7.5 10.87 7.5 11.5C7.5 13.98 9.52 16 12 16C12.63 16 13.23 15.87 13.77 15.64L14.75 16.62C13.87 16.86 12.95 17 12 17C8.21 17 4.83 14.87 3.18 11.5C3.88 10.07 4.9 8.89001 6.11 7.97001Z" />
</svg>
`;

const share = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 16.08C17.24 16.08 16.56 16.38 16.04 16.85L8.91 12.7C8.96 12.47 9 12.24 9 12C9 11.76 8.96 11.53 8.91 11.3L15.96 7.19C16.5 7.69 17.21 8 18 8C19.66 8 21 6.66 21 5C21 3.34 19.66 2 18 2C16.34 2 15 3.34 15 5C15 5.24 15.04 5.47 15.09 5.7L8.04 9.81C7.5 9.31 6.79 9 6 9C4.34 9 3 10.34 3 12C3 13.66 4.34 15 6 15C6.79 15 7.5 14.69 8.04 14.19L15.16 18.35C15.11 18.56 15.08 18.78 15.08 19C15.08 20.61 16.39 21.92 18 21.92C19.61 21.92 20.92 20.61 20.92 19C20.92 17.39 19.61 16.08 18 16.08Z" />
</svg>
`;

const wifi_off = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M20.06 10.14C20.62 10.6 21.44 10.56 21.95 10.05C22.54 9.45999 22.5 8.47999 21.85 7.94999C18.26 5.00998 13.65 3.91999 9.29998 4.68999L11.89 7.27999C14.78 7.24999 17.69 8.19999 20.06 10.14ZM17.79 11.97C17.01 11.4 16.16 10.97 15.27 10.67L18.22 13.62C18.46 13.04 18.32 12.35 17.79 11.97ZM13.95 16.23C12.73 15.6 11.27 15.6 10.04 16.23C9.44998 16.54 9.33998 17.35 9.80998 17.82L11.28 19.29C11.67 19.68 12.3 19.68 12.69 19.29L14.16 17.82C14.65 17.35 14.55 16.54 13.95 16.23ZM19.68 17.9L4.11997 2.33999C3.72997 1.94999 3.09998 1.94999 2.70998 2.33999C2.31998 2.72999 2.31998 3.35999 2.70998 3.74999L5.04998 6.09999C4.03998 6.59999 3.05998 7.20998 2.15998 7.94999C1.50998 8.47999 1.46997 9.45999 2.05997 10.05C2.56997 10.56 3.37998 10.61 3.92998 10.15C4.92998 9.32999 6.02997 8.68999 7.17998 8.21999L9.40998 10.45C8.27997 10.75 7.19998 11.25 6.21997 11.96C5.52997 12.46 5.48998 13.47 6.08998 14.07L6.09998 14.08C6.58998 14.57 7.35997 14.62 7.92998 14.21C9.11998 13.37 10.51 12.95 11.9 12.92L18.27 19.29C18.66 19.68 19.29 19.68 19.68 19.29C20.07 18.92 20.07 18.29 19.68 17.9Z" />
</svg>
`;

const schedule = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.5 2 2 6.5 2 12C2 17.5 6.5 22 12 22C17.5 22 22 17.5 22 12C22 6.5 17.5 2 12 2ZM15.55 15.8L11.47 13.29C11.17 13.11 10.99 12.79 10.99 12.44V7.75C11 7.34 11.34 7 11.75 7C12.16 7 12.5 7.34 12.5 7.75V12.2L16.34 14.51C16.7 14.73 16.82 15.2 16.6 15.56C16.38 15.91 15.91 16.02 15.55 15.8Z" />
</svg>
`;

const sort_ascending = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M2.16113 8.9841L5.12783 6.14501C5.32987 5.95166 5.67013 5.95166 5.87217 6.14501L8.83887 8.9841C9.17914 9.29955 8.9452 9.84906 8.4667 9.84906H6.56333V16.9824C6.56333 17.5421 6.08483 18 5.5 18C4.91517 18 4.43667 17.5421 4.43667 16.9824V9.84906H2.5333C2.0548 9.84906 1.82086 9.29955 2.16113 8.9841Z" />
<path d="M13 6H11C10.45 6 10 6.45 10 7C10 7.55 10.45 8 11 8H13C13.55 8 14 7.55 14 7C14 6.45 13.55 6 13 6Z" />
<path d="M11 16C10.45 16 10 16.45 10 17C10 17.55 10.45 18 11 18H21C21.55 18 22 17.55 22 17C22 16.45 21.55 16 21 16H11Z" />
<path d="M18 12C18 11.45 17.55 11 17 11H11C10.45 11 10 11.45 10 12C10 12.55 10.45 13 11 13H17C17.55 13 18 12.55 18 12Z" />
</svg>
`;

const remove = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 13H6C5.45 13 5 12.55 5 12C5 11.45 5.45 11 6 11H18C18.55 11 19 11.45 19 12C19 12.55 18.55 13 18 13Z" />
</svg>
`;

const swap_horizontal = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M6.14003 11.8601L3.36003 14.6501C3.17003 14.8501 3.17003 15.1601 3.36003 15.3601L6.14003 18.1501C6.45003 18.4701 6.99003 18.2401 6.99003 17.8001V16.0001H13C13.55 16.0001 14 15.5501 14 15.0001C14 14.4501 13.55 14.0001 13 14.0001H6.99003V12.2101C6.99003 11.7601 6.45003 11.5401 6.14003 11.8601ZM20.65 8.65009L17.87 5.86009C17.56 5.54009 17.02 5.77009 17.02 6.21009V8.00009H11C10.45 8.00009 10 8.45009 10 9.00009C10 9.55009 10.45 10.0001 11 10.0001H17.01V11.7901C17.01 12.2401 17.55 12.4601 17.86 12.1401L20.64 9.35009C20.84 9.16009 20.84 8.84009 20.65 8.65009Z" />
</svg>
`;

const undo = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12.5 8C9.85 8 7.45 8.99 5.6 10.6L3.71 8.71C3.08 8.08 2 8.52 2 9.41V15C2 15.55 2.45 16 3 16H8.59C9.48 16 9.93 14.92 9.3 14.29L7.39 12.38C8.78 11.22 10.55 10.5 12.51 10.5C15.67 10.5 18.4 12.34 19.7 15C19.97 15.56 20.61 15.84 21.2 15.64C21.91 15.41 22.27 14.6 21.95 13.92C20.23 10.42 16.65 8 12.5 8Z" />
</svg>
`;

const lock_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 8H17V6C17 3.24 14.76 1 12 1C9.24 1 7 3.24 7 6V8H6C4.9 8 4 8.9 4 10V20C4 21.1 4.9 22 6 22H18C19.1 22 20 21.1 20 20V10C20 8.9 19.1 8 18 8ZM9 6C9 4.34 10.34 3 12 3C13.66 3 15 4.34 15 6V8H9V6ZM18 20H6V10H18V20ZM12 17C13.1 17 14 16.1 14 15C14 13.9 13.1 13 12 13C10.9 13 10 13.9 10 15C10 16.1 10.9 17 12 17Z" />
</svg>
`;

const business = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 7V5C12 3.9 11.1 3 10 3H4C2.9 3 2 3.9 2 5V19C2 20.1 2.9 21 4 21H20C21.1 21 22 20.1 22 19V9C22 7.9 21.1 7 20 7H12ZM6 19H4V17H6V19ZM6 15H4V13H6V15ZM6 11H4V9H6V11ZM6 7H4V5H6V7ZM10 19H8V17H10V19ZM10 15H8V13H10V15ZM10 11H8V9H10V11ZM10 7H8V5H10V7ZM19 19H12V17H14V15H12V13H14V11H12V9H19C19.55 9 20 9.45 20 10V18C20 18.55 19.55 19 19 19ZM18 11H16V13H18V11ZM18 15H16V17H18V15Z" />
</svg>
`;

const filter = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M4.24993 5.61C6.26993 8.2 9.99993 13 9.99993 13V19C9.99993 19.55 10.4499 20 10.9999 20H12.9999C13.5499 20 13.9999 19.55 13.9999 19V13C13.9999 13 17.7199 8.2 19.7399 5.61C20.2499 4.95 19.7799 4 18.9499 4H5.03993C4.20993 4 3.73993 4.95 4.24993 5.61Z" />
</svg>
`;

const comment = `<svg viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
<path d="M20 4V16H5.17002L4.00002 17.17V4H20ZM20 2H4.00002C3.46958 2 2.96088 2.21071 2.5858 2.58579C2.21073 2.96086 2.00002 3.46957 2.00002 4V19.59C1.99886 19.7886 2.05688 19.9831 2.16668 20.1486C2.27649 20.3141 2.43309 20.4432 2.61654 20.5194C2.79998 20.5955 3.00195 20.6153 3.1967 20.5763C3.39145 20.5372 3.57015 20.441 3.71002 20.3L6.00002 18H20C20.5305 18 21.0392 17.7893 21.4142 17.4142C21.7893 17.0391 22 16.5304 22 16V4C22 3.46957 21.7893 2.96086 21.4142 2.58579C21.0392 2.21071 20.5305 2 20 2Z" />
<path d="M17.33 6.00067H14C13.8223 6.00067 13.6518 6.07126 13.5262 6.19691C13.4005 6.32256 13.33 6.49298 13.33 6.67067V12.0507L15.68 11.0507L18.03 12.0507V6.67067C18.03 6.5801 18.0118 6.49046 17.9762 6.40715C17.9407 6.32384 17.8887 6.2486 17.8232 6.18598C17.7578 6.12336 17.6804 6.07465 17.5956 6.0428C17.5108 6.01095 17.4204 5.99662 17.33 6.00067Z"/>
</svg>
`;

const unarchive_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9.53476 13.6647L10.388 13.6647L10.388 16.4441C10.388 16.7499 10.6295 17 10.9247 17H13.0713C13.3664 17 13.6079 16.7499 13.6079 16.4441V13.6647H14.4612C14.9388 13.6647 15.1803 13.0643 14.8422 12.7141L12.379 10.1626C12.1697 9.9458 11.8316 9.9458 11.6223 10.1626L9.1591 12.7141C8.82101 13.0643 9.05714 13.6647 9.53476 13.6647Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M20.54 5.23L19.15 3.55C18.88 3.21 18.47 3 18 3H6C5.53 3 5.12 3.21 4.84 3.55L3.46 5.23C3.17 5.57 3 6.02 3 6.5V19C3 20.1 3.9 21 5 21H19C20.1 21 21 20.1 21 19V6.5C21 6.02 20.83 5.57 20.54 5.23ZM6.24 5H17.76L18.57 5.97H5.44L6.24 5ZM5 19V8H19V19H5Z" />
</svg>
`;

const location_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M14.5 9C14.5 10.3807 13.3807 11.5 12 11.5C10.6193 11.5 9.5 10.3807 9.5 9C9.5 7.61929 10.6193 6.5 12 6.5C13.3807 6.5 14.5 7.61929 14.5 9Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M5 9C5 5.13 8.13 2 12 2C15.87 2 19 5.13 19 9C19 14.25 12 22 12 22C12 22 5 14.25 5 9ZM12 4C9.24 4 7 6.24 7 9C7 11.85 9.92 16.21 12 18.88C14.12 16.19 17 11.88 17 9C17 6.24 14.76 4 12 4Z" />
</svg>
`;

const speedX1 = `<svg viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
<path  d="M7.94 16.53H9.94L9.92 8H9.74L6 9.29V10.79L7.94 10.22V16.53ZM16.02 10.19L15.1 11.93L14.27 10.2H12.19L13.86 13.29L12.1 16.54H14.1L15.1 14.66L16.1 16.53H18.18L16.43 13.28L18.1 10.19H16.02Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const home_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M9.99998 14V19C9.99998 19.55 9.54998 20 8.99998 20H5.99998C5.44998 20 4.99998 19.55 4.99998 19V12H3.29998C2.83998 12 2.62998 11.43 2.96998 11.13L11.33 3.6C11.71 3.26 12.29 3.26 12.67 3.6L21.03 11.13C21.38 11.43 21.16 12 20.7 12H19V19C19 19.55 18.55 20 18 20H15C14.45 20 14 19.55 14 19V14H9.99998ZM12 5.5L17.5 10.5V18.31H15.5V12.31H8.49997V18.31H6.49997V10.5L12 5.5Z" />
</svg>
`;

const volumeOff = `<svg viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
<path d="M3.63 3.63C3.45563 3.81546 3.35854 4.06044 3.35854 4.315C3.35854 4.56956 3.45563 4.81454 3.63 5L7.29 8.7L7 9H4C3.73478 9 3.48043 9.10536 3.29289 9.29289C3.10536 9.48043 3 9.73478 3 10V14C3 14.2652 3.10536 14.5196 3.29289 14.7071C3.48043 14.8946 3.73478 15 4 15H7L10.29 18.29C10.4299 18.431 10.6086 18.5272 10.8033 18.5663C10.9981 18.6054 11.2 18.5855 11.3835 18.5094C11.5669 18.4332 11.7235 18.3041 11.8333 18.1386C11.9431 17.9731 12.0012 17.7786 12 17.58V13.41L16.18 17.59C15.6902 17.9641 15.152 18.2703 14.58 18.5C14.3373 18.6074 14.1473 18.8068 14.0516 19.0544C13.956 19.3019 13.9626 19.5773 14.07 19.82C14.1774 20.0627 14.3768 20.2527 14.6244 20.3484C14.8719 20.444 15.1473 20.4374 15.39 20.33C16.1902 19.9959 16.9379 19.548 17.61 19L19 20.36C19.0752 20.4952 19.1808 20.6112 19.3084 20.6987C19.436 20.7862 19.5822 20.8429 19.7355 20.8643C19.8887 20.8857 20.0448 20.8713 20.1916 20.8221C20.3383 20.773 20.4716 20.6904 20.581 20.581C20.6904 20.4716 20.773 20.3383 20.8221 20.1916C20.8713 20.0448 20.8857 19.8887 20.8643 19.7355C20.8429 19.5822 20.7862 19.436 20.6987 19.3084C20.6112 19.1808 20.4952 19.0752 20.36 19L5.05 3.63C4.95704 3.53627 4.84644 3.46188 4.72458 3.41111C4.60272 3.36034 4.47201 3.3342 4.34 3.3342C4.20799 3.3342 4.07728 3.36034 3.95542 3.41111C3.83356 3.46188 3.72296 3.53627 3.63 3.63ZM19 12C18.9977 12.7977 18.859 13.5891 18.59 14.34L20.12 15.87C20.6533 14.7497 20.9491 13.5313 20.989 12.2912C21.0289 11.0512 20.812 9.81624 20.3518 8.66401C19.8917 7.51178 19.1983 6.46714 18.3152 5.59568C17.432 4.72422 16.3782 4.04477 15.22 3.6C15.0822 3.55007 14.9344 3.53416 14.7891 3.55363C14.6439 3.57309 14.5055 3.62735 14.3857 3.71179C14.2659 3.79623 14.1683 3.90835 14.1011 4.03862C14.034 4.16889 13.9993 4.31345 14 4.46V4.65C14.0033 4.83687 14.0634 5.01831 14.1724 5.17015C14.2814 5.322 14.434 5.43705 14.61 5.5C15.9071 6.02123 17.0185 6.91891 17.8009 8.07738C18.5833 9.23585 19.001 10.6021 19 12ZM10.29 5.71L10.12 5.88L12 7.76V6.41C11.9992 6.21223 11.9397 6.01914 11.8292 5.85516C11.7186 5.69117 11.5619 5.56366 11.3789 5.48873C11.1958 5.41381 10.9947 5.39484 10.8009 5.43422C10.6071 5.47361 10.4293 5.56958 10.29 5.71ZM16.5 12C16.4942 11.1672 16.2575 10.3524 15.8161 9.64619C15.3747 8.93998 14.746 8.37011 14 8V9.76L16.48 12.24C16.4916 12.1605 16.4983 12.0803 16.5 12Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const document_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9 14H15C15.55 14 16 13.55 16 13C16 12.45 15.55 12 15 12H9C8.45 12 8 12.45 8 13C8 13.55 8.45 14 9 14Z" />
<path d="M9 18H15C15.55 18 16 17.55 16 17C16 16.45 15.55 16 15 16H9C8.45 16 8 16.45 8 17C8 17.55 8.45 18 9 18Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M6 2H14L20 8V20C20 21.1 19.1 22 18 22H5.99C4.89 22 4 21.1 4 20V4C4 2.9 4.9 2 6 2ZM6 20H18V9H14C13.45 9 13 8.55 13 8V4H6V20Z" />
</svg>
`;

const add_circle = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM16 13H13V16C13 16.55 12.55 17 12 17C11.45 17 11 16.55 11 16V13H8C7.45 13 7 12.55 7 12C7 11.45 7.45 11 8 11H11V8C11 7.45 11.45 7 12 7C12.55 7 13 7.45 13 8V11H16C16.55 11 17 11.45 17 12C17 12.55 16.55 13 16 13Z" />
</svg>
`;

const thumbs_up_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M18 21H9.01001C7.91001 21 7.01001 20.1 7.01001 19L7.01001 9.01C7.01001 8.48 7.22001 7.97 7.59001 7.6L13.12 2.06C13.41 1.77 13.8 1.62 14.18 1.62C14.56 1.62 14.94 1.76 15.23 2.05C15.59 2.41 15.74 2.92 15.64 3.42L14.69 8L20.34 8C22.49 8 23.94 10.2 23.09 12.18L19.83 19.79C19.52 20.52 18.8 21 18 21ZM12.73 7.59L13.34 4.67L9.01001 9.01L9.01001 19H18L21.25 11.4C21.44 10.96 21.28 10.62 21.17 10.45C21.06 10.28 20.81 10 20.34 10L12.23 10L12.73 7.59Z" />
<path d="M5 19C5 20.1 4.1 21 3 21C1.9 21 1 20.1 1 19L1 11C1 9.9 1.9 9 3 9C4.1 9 5 9.9 5 11L5 19Z" />
</svg>
`;

const information_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M13 9V7H11V9H13Z" />
<path d="M12 17C11.45 17 11 16.55 11 16V12C11 11.45 11.45 11 12 11C12.55 11 13 11.45 13 12V16C13 16.55 12.55 17 12 17Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M2 12C2 6.48 6.48 2 12 2C17.52 2 22 6.48 22 12C22 17.52 17.52 22 12 22C6.48 22 2 17.52 2 12ZM4 12C4 16.41 7.59 20 12 20C16.41 20 20 16.41 20 12C20 7.59 16.41 4 12 4C7.59 4 4 7.59 4 12Z" />
</svg>
`;

const cloud = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M5.35 8.04C6.6 5.64 9.11 4 12 4C15.64 4 18.67 6.59 19.35 10.04C21.95 10.22 24 12.36 24 15C24 17.76 21.76 20 19 20H6C2.69 20 0 17.31 0 14C0 10.91 2.34 8.36 5.35 8.04Z" />
</svg>
`;

const error = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM12 13C11.45 13 11 12.55 11 12V8C11 7.45 11.45 7 12 7C12.55 7 13 7.45 13 8V12C13 12.55 12.55 13 12 13ZM13 17H11V15H13V17Z" />
</svg>
`;

const school_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12.9577 3.52228C12.3607 3.19667 11.6392 3.19667 11.0423 3.52229L2.61014 8.12164C1.91513 8.50073 1.91531 9.49875 2.61044 9.8776L4.99999 11.1799V15.9929C4.99999 16.7247 5.39961 17.398 6.04194 17.7485L11.0419 20.4771C11.6391 20.8029 12.3609 20.8029 12.958 20.4771L17.958 17.7485C18.6004 17.398 19 16.7247 19 15.9929V11.1799L21 10.0899V15.9999C21 16.5522 21.4477 16.9999 22 16.9999C22.5523 16.9999 23 16.5522 23 15.9999V9.59353C23 9.22759 22.8001 8.89087 22.4788 8.71564L12.9577 3.52228ZM18.82 8.9999L12 12.7199L5.17999 8.9999L12 5.2799L18.82 8.9999ZM17 15.9899L12 18.7199L6.99999 15.9899V12.2699L11.0415 14.4766C11.6389 14.8027 12.3611 14.8027 12.9584 14.4766L17 12.2699V15.9899Z" />
</svg>
`;

const cloud_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 6C14.62 6 16.88 7.86 17.39 10.43L17.69 11.93L19.22 12.04C20.78 12.14 22 13.45 22 15C22 16.65 20.65 18 19 18H6C3.79 18 2 16.21 2 14C2 11.95 3.53 10.24 5.56 10.03L6.63 9.92L7.13 8.97C8.08 7.14 9.94 6 12 6ZM12 4C9.11 4 6.6 5.64 5.35 8.04C2.34 8.36 0 10.91 0 14C0 17.31 2.69 20 6 20H19C21.76 20 24 17.76 24 15C24 12.36 21.95 10.22 19.35 10.04C18.67 6.59 15.64 4 12 4Z" />
</svg>
`;

const format_bold = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15.6 10.79C16.57 10.12 17.25 9.02 17.25 8C17.25 5.74 15.5 4 13.25 4H8C7.45 4 7 4.45 7 5V17C7 17.55 7.45 18 8 18H13.78C15.85 18 17.74 16.31 17.75 14.23C17.76 12.7 16.9 11.39 15.6 10.79ZM10 6.5H13C13.83 6.5 14.5 7.17 14.5 8C14.5 8.83 13.83 9.5 13 9.5H10V6.5ZM13.5 15.5H10V12.5H13.5C14.33 12.5 15 13.17 15 14C15 14.83 14.33 15.5 13.5 15.5Z" />
</svg>
`;

const upload = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M16.2975 6.8825C16.6875 7.2725 16.6875 7.9025 16.2975 8.2925C15.9175 8.6725 15.2775 8.6825 14.8875 8.2925L13.0075 6.4125L13.0075 15.0825C13.0075 15.6325 12.5575 16.0825 12.0075 16.0825C11.4575 16.0825 11.0075 15.6325 11.0075 15.0825L11.0075 6.4125L9.11754 8.2925C8.72754 8.6825 8.09754 8.6825 7.70754 8.2925C7.31754 7.9025 7.31754 7.2725 7.70754 6.8825L11.2975 3.2925C11.6875 2.9025 12.3175 2.9025 12.7075 3.2925L16.2975 6.8825Z" />
<path d="M19 15C18.4477 15 18 15.4477 18 16V18H6V16C6 15.4477 5.55228 15 5 15C4.44772 15 4 15.4477 4 16V18C4 19.1 4.9 20 6 20H18C19.1 20 20 19.1 20 18V16C20 15.4477 19.5523 15 19 15Z" />
</svg>
`;

const drag_handle = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M19 9H5C4.45 9 4 9.45 4 10C4 10.55 4.45 11 5 11H19C19.55 11 20 10.55 20 10C20 9.45 19.55 9 19 9ZM5 15H19C19.55 15 20 14.55 20 14C20 13.45 19.55 13 19 13H5C4.45 13 4 13.45 4 14C4 14.55 4.45 15 5 15Z" />
</svg>
`;

const pause = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M8 19C8.53043 19 9.03914 18.7893 9.41421 18.4142C9.78929 18.0391 10 17.5304 10 17V7C10 6.46957 9.78929 5.96086 9.41421 5.58579C9.03914 5.21071 8.53043 5 8 5C7.46957 5 6.96086 5.21071 6.58579 5.58579C6.21071 5.96086 6 6.46957 6 7V17C6 17.5304 6.21071 18.0391 6.58579 18.4142C6.96086 18.7893 7.46957 19 8 19ZM14 7V17C14 17.5304 14.2107 18.0391 14.5858 18.4142C14.9609 18.7893 15.4696 19 16 19C16.5304 19 17.0391 18.7893 17.4142 18.4142C17.7893 18.0391 18 17.5304 18 17V7C18 6.46957 17.7893 5.96086 17.4142 5.58579C17.0391 5.21071 16.5304 5 16 5C15.4696 5 14.9609 5.21071 14.5858 5.58579C14.2107 5.96086 14 6.46957 14 7Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const volumeUp = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M3 10.46V14.46C3 14.7252 3.10536 14.9796 3.29289 15.1671C3.48043 15.3547 3.73478 15.46 4 15.46H7L10.29 18.75C10.4299 18.8911 10.6086 18.9872 10.8033 19.0263C10.9981 19.0654 11.2 19.0456 11.3835 18.9694C11.5669 18.8932 11.7235 18.7642 11.8333 18.5986C11.9431 18.4331 12.0012 18.2386 12 18.04V6.87002C12.0012 6.6714 11.9431 6.47693 11.8333 6.31141C11.7235 6.14589 11.5669 6.01682 11.3835 5.94065C11.2 5.86449 10.9981 5.84467 10.8033 5.88374C10.6086 5.92281 10.4299 6.01899 10.29 6.16002L7 9.46002H4C3.73478 9.46002 3.48043 9.56538 3.29289 9.75292C3.10536 9.94045 3 10.1948 3 10.46V10.46ZM16.5 12.46C16.4942 11.6273 16.2575 10.8124 15.8161 10.1062C15.3747 9.4 14.746 8.83013 14 8.46002V16.46C14.7482 16.0927 15.3788 15.5235 15.8206 14.8166C16.2623 14.1098 16.4977 13.2935 16.5 12.46V12.46ZM14 4.91002V5.11002C14.0039 5.29537 14.0631 5.47532 14.17 5.62678C14.2769 5.77823 14.4267 5.89428 14.6 5.96002C15.8994 6.47938 17.0132 7.37626 17.7979 8.53488C18.5825 9.69351 19.0019 11.0607 19.0019 12.46C19.0019 13.8593 18.5825 15.2265 17.7979 16.3852C17.0132 17.5438 15.8994 18.4407 14.6 18.96C14.4259 19.0246 14.2754 19.1403 14.1683 19.2921C14.0612 19.4438 14.0025 19.6243 14 19.81V20.01C13.9992 20.1553 14.0336 20.2987 14.1002 20.4278C14.1668 20.5569 14.2637 20.668 14.3826 20.7516C14.5016 20.8351 14.6389 20.8886 14.783 20.9075C14.9271 20.9264 15.0736 20.9101 15.21 20.86C16.9079 20.2069 18.3679 19.0547 19.3978 17.5551C20.4276 16.0556 20.9789 14.2792 20.9789 12.46C20.9789 10.6409 20.4276 8.86447 19.3978 7.36492C18.3679 5.86538 16.9079 4.71311 15.21 4.06002C15.0736 4.00997 14.9271 3.99369 14.783 4.01258C14.6389 4.03147 14.5016 4.08497 14.3826 4.16849C14.2637 4.25202 14.1668 4.3631 14.1002 4.49223C14.0336 4.62137 13.9992 4.76471 14 4.91002V4.91002Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const arrow_forward = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M5 13H16.17L11.29 17.88C10.9 18.27 10.9 18.91 11.29 19.3C11.68 19.69 12.31 19.69 12.7 19.3L19.29 12.71C19.68 12.32 19.68 11.69 19.29 11.3L12.71 4.69997C12.32 4.30997 11.69 4.30997 11.3 4.69997C10.91 5.08997 10.91 5.71997 11.3 6.10997L16.17 11H5C4.45 11 4 11.45 4 12C4 12.55 4.45 13 5 13Z" />
</svg>
`;

const speedX5 = `<svg viewBox="0 0 36 36" xmlns="http://www.w3.org/2000/svg">
<path d="M10.0353 12L9.24032 18.54L11.6553 19.095C11.8345 18.8732 12.0641 18.6975 12.3251 18.5827C12.5861 18.4679 12.8708 18.4172 13.1553 18.435C14.3553 18.435 15.0153 18.975 15.0153 20.445C15.0153 21.915 14.5053 22.65 13.5153 22.65C13.1209 22.6603 12.7382 22.5148 12.4503 22.245C12.168 21.9375 12.008 21.5374 12.0003 21.12H9.00032C8.99074 21.8193 9.19484 22.5048 9.58532 23.085C10.0101 23.6694 10.5784 24.1344 11.2353 24.435C11.9412 24.7764 12.7162 24.9509 13.5003 24.945C14.318 24.9635 15.1274 24.7779 15.8553 24.405C16.4888 24.0591 17.0094 23.5384 17.3553 22.905C17.7625 22.2294 17.9849 21.4587 18.0003 20.67C18.0769 19.5235 17.7119 18.3911 16.9803 17.505C16.5939 17.1074 16.1251 16.7992 15.6068 16.6023C15.0885 16.4053 14.5333 16.3243 13.9803 16.365C13.6403 16.3718 13.3025 16.4222 12.9753 16.515C12.6848 16.5812 12.4064 16.6925 12.1503 16.845L12.4353 14.28H17.5353V12H10.0353ZM24.8553 15.285L23.3553 17.895L22.1103 15.3H18.9903L21.4953 19.935L18.8553 24.81H21.8553L23.3553 21.99L24.8553 24.795H27.9753L25.3503 19.92L27.8553 15.285H24.8553Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const bookmark = `<svg viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
<path d="M17 3H7C5.9 3 5 3.9 5 5V21L12 18L19 21V5C19 3.9 18.1 3 17 3Z" />
</svg>
`;

const help = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M2 12C2 6.48 6.48 2 12 2C17.52 2 22 6.48 22 12C22 17.52 17.52 22 12 22C6.48 22 2 17.52 2 12ZM12.8607 16.0039H10.8607V18.0039H12.8607V16.0039ZM8.04069 8.83393C8.59069 7.01393 10.4107 5.74393 12.4707 6.04393C14.2107 6.30393 15.5807 7.77393 15.8207 9.51393C16.0488 11.1275 15.1564 11.906 14.2951 12.6575C14.1369 12.7955 13.9797 12.9327 13.8307 13.0739C13.7107 13.1839 13.6007 13.2939 13.5007 13.4139C13.4957 13.4189 13.4907 13.4264 13.4857 13.4339C13.4807 13.4414 13.4757 13.4489 13.4707 13.4539C13.3707 13.5739 13.2707 13.7039 13.1907 13.8439C13.1807 13.8589 13.1732 13.8739 13.1657 13.8889C13.1582 13.9039 13.1507 13.9189 13.1407 13.9339C12.9707 14.2339 12.8607 14.5839 12.8607 15.0039H10.8607C10.8607 14.5039 10.9407 14.0939 11.0607 13.7539C11.0651 13.7408 11.0675 13.7295 11.0698 13.7194C11.0726 13.7064 11.0751 13.6952 11.0807 13.6839C11.0857 13.6689 11.0932 13.6564 11.1007 13.6439C11.1082 13.6314 11.1157 13.6189 11.1207 13.6039C11.1907 13.4239 11.2807 13.2539 11.3707 13.1039C11.3757 13.0939 11.3807 13.0864 11.3857 13.0789C11.3907 13.0714 11.3957 13.0639 11.4007 13.0539C11.4007 13.0489 11.4032 13.0464 11.4057 13.0439C11.4082 13.0414 11.4107 13.0389 11.4107 13.0339C11.7513 12.521 12.208 12.1697 12.6352 11.8412C13.249 11.3691 13.8017 10.9441 13.8607 10.1539C13.9407 9.18393 13.2407 8.25393 12.2907 8.05393C11.2607 7.83393 10.3107 8.44393 9.99069 9.33393C9.85069 9.71393 9.52069 10.0039 9.11069 10.0039H8.91069C8.30069 10.0039 7.86069 9.41393 8.04069 8.83393Z" />
</svg>
`;

const speedX4 = `<svg viewBox="0 0 36 36"  xmlns="http://www.w3.org/2000/svg">
<path  d="M18.435 19.77H17.13V12H14.13L9 20.235L9.18 22.05H14.13V24.765H17.13V22.05H18.435V19.77ZM14.175 19.77H11.865L13.98 16.125L14.175 15.825V19.77ZM24.99 15.255L23.61 17.88L22.365 15.255H19.245L21.75 19.89L19.11 24.765H22.11L23.61 21.96L25.11 24.765H28.215L25.59 19.89L28.11 15.255H24.99Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const warning_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M11.5314 4.9975L19.0614 18.0075H4.00137L11.5314 4.9975ZM2.27137 17.0075C1.50137 18.3375 2.46137 20.0075 4.00137 20.0075H19.0614C20.6014 20.0075 21.5614 18.3375 20.7914 17.0075L13.2614 3.9975C12.4914 2.6675 10.5714 2.6675 9.80137 3.9975L2.27137 17.0075ZM10.5314 10.0075V12.0075C10.5314 12.5575 10.9814 13.0075 11.5314 13.0075C12.0814 13.0075 12.5314 12.5575 12.5314 12.0075V10.0075C12.5314 9.4575 12.0814 9.0075 11.5314 9.0075C10.9814 9.0075 10.5314 9.4575 10.5314 10.0075ZM10.5314 15.0075H12.5314V17.0075H10.5314V15.0075Z" />
</svg>
`;

const help_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM12 20C7.59 20 4 16.41 4 12C4 7.59 7.59 4 12 4C16.41 4 20 7.59 20 12C20 16.41 16.41 20 12 20ZM11 16H13V18H11V16ZM12.61 6.04C10.55 5.74 8.73 7.01 8.18 8.83C8 9.41 8.44 10 9.05 10H9.25C9.66 10 9.99 9.71 10.13 9.33C10.45 8.44 11.4 7.83 12.43 8.05C13.38 8.25 14.08 9.18 14 10.15C13.9 11.49 12.38 11.78 11.55 13.03C11.55 13.04 11.54 13.04 11.54 13.05C11.53 13.07 11.52 13.08 11.51 13.1C11.42 13.25 11.33 13.42 11.26 13.6C11.25 13.63 11.23 13.65 11.22 13.68C11.21 13.7 11.21 13.72 11.2 13.75C11.08 14.09 11 14.5 11 15H13C13 14.58 13.11 14.23 13.28 13.93C13.3 13.9 13.31 13.87 13.33 13.84C13.41 13.7 13.51 13.57 13.61 13.45C13.62 13.44 13.63 13.42 13.64 13.41C13.74 13.29 13.85 13.18 13.97 13.07C14.93 12.16 16.23 11.42 15.96 9.51C15.72 7.77 14.35 6.3 12.61 6.04Z" />
</svg>
`;

const menu = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M4 18H20C20.55 18 21 17.55 21 17C21 16.45 20.55 16 20 16H4C3.45 16 3 16.45 3 17C3 17.55 3.45 18 4 18ZM4 13H20C20.55 13 21 12.55 21 12C21 11.45 20.55 11 20 11H4C3.45 11 3 11.45 3 12C3 12.55 3.45 13 4 13ZM3 7C3 7.55 3.45 8 4 8H20C20.55 8 21 7.55 21 7C21 6.45 20.55 6 20 6H4C3.45 6 3 6.45 3 7Z" />
</svg>
`;

const block = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM4 12C4 7.58 7.58 4 12 4C13.85 4 15.55 4.63 16.9 5.69L5.69 16.9C4.63 15.55 4 13.85 4 12ZM12 20C10.15 20 8.45 19.37 7.1 18.31L18.31 7.1C19.37 8.45 20 10.15 20 12C20 16.42 16.42 20 12 20Z" />
</svg>
`;

const zoom_out = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15.5001 14H14.7101L14.4301 13.73C15.6301 12.33 16.2501 10.42 15.9101 8.39C15.4401 5.61 13.1201 3.39 10.3201 3.05C6.09014 2.53 2.53014 6.09 3.05014 10.32C3.39014 13.12 5.61014 15.44 8.39014 15.91C10.4201 16.25 12.3301 15.63 13.7301 14.43L14.0001 14.71V15.5L18.2601 19.75C18.6701 20.16 19.3301 20.16 19.7401 19.75L19.7501 19.74C20.1601 19.33 20.1601 18.67 19.7501 18.26L15.5001 14ZM9.50014 14C7.01014 14 5.00014 11.99 5.00014 9.5C5.00014 7.01 7.01014 5 9.50014 5C11.9901 5 14.0001 7.01 14.0001 9.5C14.0001 11.99 11.9901 14 9.50014 14ZM7.50014 9H11.5001C11.7801 9 12.0001 9.22 12.0001 9.5C12.0001 9.78 11.7801 10 11.5001 10H7.50014C7.22014 10 7.00014 9.78 7.00014 9.5C7.00014 9.22 7.22014 9 7.50014 9Z" />
</svg>
`;

const label_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M16 5C16.67 5 17.27 5.33 17.63 5.84L21.59 11.42C21.84 11.77 21.84 12.23 21.59 12.58L17.63 18.16C17.27 18.67 16.67 19 16 19L5 18.99C3.9 18.99 3 18.1 3 17V7C3 5.9 3.9 5.01 5 5.01L16 5ZM16 17H5V7H16L19.55 12L16 17Z" />
</svg>
`;

const groups_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M4 13C5.1 13 6 12.1 6 11C6 9.9 5.1 9 4 9C2.9 9 2 9.9 2 11C2 12.1 2.9 13 4 13ZM5.13 14.1C4.76 14.04 4.39 14 4 14C3.01 14 2.07 14.21 1.22 14.58C0.48 14.9 0 15.62 0 16.43V18H4.5V16.39C4.5 15.56 4.73 14.78 5.13 14.1ZM20 13C21.1 13 22 12.1 22 11C22 9.9 21.1 9 20 9C18.9 9 18 9.9 18 11C18 12.1 18.9 13 20 13ZM24 16.43C24 15.62 23.52 14.9 22.78 14.58C21.93 14.21 20.99 14 20 14C19.61 14 19.24 14.04 18.87 14.1C19.27 14.78 19.5 15.56 19.5 16.39V18H24V16.43ZM16.24 13.65C15.07 13.13 13.63 12.75 12 12.75C10.37 12.75 8.93 13.14 7.76 13.65C6.68 14.13 6 15.21 6 16.39V18H18V16.39C18 15.21 17.32 14.13 16.24 13.65ZM8.07 16C8.16 15.77 8.2 15.61 8.98 15.31C9.95 14.93 10.97 14.75 12 14.75C13.03 14.75 14.05 14.93 15.02 15.31C15.79 15.61 15.83 15.77 15.93 16H8.07ZM12 8C12.55 8 13 8.45 13 9C13 9.55 12.55 10 12 10C11.45 10 11 9.55 11 9C11 8.45 11.45 8 12 8ZM12 6C10.34 6 9 7.34 9 9C9 10.66 10.34 12 12 12C13.66 12 15 10.66 15 9C15 7.34 13.66 6 12 6Z" />
</svg>
`;

const thumbs_down_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M5.9999 3H14.9899C16.0899 3 16.9899 3.9 16.9899 5V14.99C16.9899 15.52 16.7799 16.03 16.4099 16.4L10.8799 21.94C10.5899 22.23 10.1999 22.38 9.8199 22.38C9.4399 22.38 9.0599 22.24 8.7699 21.95C8.4099 21.59 8.2599 21.08 8.3599 20.58L9.3099 16H3.6599C1.5099 16 0.0598996 13.8 0.9099 11.82L4.1699 4.21C4.4799 3.48 5.1999 3 5.9999 3ZM11.2699 16.41L10.6599 19.33L14.9899 14.99V5H5.9999L2.7499 12.6C2.5599 13.04 2.7199 13.38 2.8299 13.55C2.9399 13.72 3.1899 14 3.6599 14H11.7699L11.2699 16.41Z" />
<path d="M18.9999 5C18.9999 3.9 19.8999 3 20.9999 3C22.0999 3 22.9999 3.9 22.9999 5V13C22.9999 14.1 22.0999 15 20.9999 15C19.8999 15 18.9999 14.1 18.9999 13V5Z" />
</svg>
`;

const speedX6 = `<svg viewBox="0 0 36 36"  xmlns="http://www.w3.org/2000/svg">
<path d="M16.174 14.3257V12.0008H15.799C14.5467 11.9817 13.3128 12.3032 12.229 12.9307C11.2025 13.4907 10.3589 14.3343 9.79896 15.3607C9.23677 16.4645 8.96326 17.6927 9.00396 18.9307V20.1007C9.00259 21.0212 9.21302 21.9296 9.61896 22.7557C9.99437 23.497 10.5783 24.1122 11.299 24.5257C12.0227 24.9466 12.8467 25.1643 13.684 25.1558C14.487 25.1649 15.2783 24.9632 15.979 24.5707C16.6496 24.1979 17.2048 23.6479 17.584 22.9808C17.9649 22.2979 18.1614 21.5276 18.154 20.7457C18.2065 19.6003 17.8621 18.4717 17.179 17.5508C16.8608 17.1573 16.455 16.8439 15.994 16.6355C15.5329 16.4271 15.0295 16.3296 14.524 16.3507C14.0575 16.3342 13.5926 16.412 13.1569 16.5795C12.7213 16.7471 12.3241 17.0009 11.989 17.3258C12.121 16.4454 12.5954 15.6529 13.309 15.1207C14.1047 14.5585 15.0657 14.2786 16.039 14.3257H16.174ZM12.514 18.9007C12.8085 18.7115 13.1541 18.6173 13.504 18.6307C13.7406 18.6301 13.9741 18.6855 14.1853 18.7924C14.3964 18.8993 14.5793 19.0547 14.719 19.2457C15.0388 19.6789 15.2027 20.2076 15.184 20.7457C15.2014 21.2814 15.0434 21.8081 14.734 22.2457C14.6104 22.4307 14.443 22.5823 14.2468 22.6869C14.0505 22.7916 13.8314 22.8462 13.609 22.8458C12.484 22.8458 11.929 22.0507 11.929 20.4307V19.5607C12.0598 19.2913 12.2622 19.063 12.514 18.9007ZM24.799 15.4657L23.299 18.0907L22.054 15.4207H18.934L21.439 20.0557L18.799 24.9307H21.799L23.299 22.1107L24.799 24.9307H27.919L25.294 20.1007L27.799 15.4657H24.799Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const history = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M13.26 3C8.17003 2.86 4.00003 6.95 4.00003 12H2.21003C1.76003 12 1.54003 12.54 1.86003 12.85L4.65003 15.65C4.85003 15.85 5.16003 15.85 5.36003 15.65L8.15003 12.85C8.46003 12.54 8.24003 12 7.79003 12H6.00003C6.00003 8.1 9.18003 4.95 13.1 5C16.82 5.05 19.95 8.18 20 11.9C20.05 15.81 16.9 19 13 19C11.39 19 9.90003 18.45 8.72003 17.52C8.32003 17.21 7.76003 17.24 7.40003 17.6C6.98003 18.02 7.01003 18.73 7.48003 19.09C9.00003 20.29 10.91 21 13 21C18.05 21 22.14 16.83 22 11.74C21.87 7.05 17.95 3.13 13.26 3ZM12.75 8C12.34 8 12 8.34 12 8.75V12.43C12 12.78 12.19 13.11 12.49 13.29L15.61 15.14C15.97 15.35 16.43 15.23 16.64 14.88C16.85 14.52 16.73 14.06 16.38 13.85L13.5 12.14V8.74C13.5 8.34 13.16 8 12.75 8Z" />
</svg>
`;

const alarm = `<svg  viewBox="0 0 24 24"   xmlns="http://www.w3.org/2000/svg">
<path d="M18.1 2.44998L21.18 5.00998C21.6 5.36998 21.66 5.99998 21.3 6.41998C20.94 6.84998 20.31 6.89998 19.89 6.54998L16.82 3.98998C16.4 3.62998 16.34 2.99998 16.69 2.57998C17.05 2.14998 17.68 2.09998 18.1 2.44998Z" />
<path d="M7.17001 3.98998L4.10001 6.54998C3.68001 6.89998 3.05001 6.84998 2.70001 6.41998C2.34001 5.99998 2.40001 5.36998 2.82001 5.00998L5.90001 2.44998C6.32001 2.09998 6.95001 2.14998 7.30001 2.57998C7.66001 2.99998 7.60001 3.62998 7.17001 3.98998Z"  />
<path d="M3.00001 13C3.00001 8.02998 7.03001 3.99998 12 3.99998C16.97 3.99998 21 8.02998 21 13C21 17.97 16.97 22 12 22C7.03001 22 3.00001 17.97 3.00001 13ZM16.1849 15.6267C16.1303 15.4728 16.0231 15.3375 15.87 15.25L12.5 13.25V8.71996C12.5 8.31996 12.18 7.99996 11.78 7.99996H11.72C11.4246 7.99996 11.1729 8.17445 11.0614 8.42679C11.0408 8.47346 11.025 8.5228 11.0145 8.5742C11.005 8.62122 11 8.66996 11 8.71996V13.44C11 13.44 11 13.44 11 13.44C11 13.5712 11.0253 13.6997 11.0733 13.8184C11.1533 14.0164 11.2963 14.1875 11.49 14.3L15.14 16.49C15.48 16.69 15.92 16.59 16.12 16.25C16.2381 16.0531 16.255 15.8246 16.1849 15.6267Z"  />
</svg>
`;

const fullscreenExit = `<svg viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg">
<path d="M6 16H8V18C8 18.2652 8.10536 18.5196 8.29289 18.7071C8.48043 18.8946 8.73478 19 9 19C9.26522 19 9.51957 18.8946 9.70711 18.7071C9.89464 18.5196 10 18.2652 10 18V15C10 14.7348 9.89464 14.4804 9.70711 14.2929C9.51957 14.1054 9.26522 14 9 14H6C5.73478 14 5.48043 14.1054 5.29289 14.2929C5.10536 14.4804 5 14.7348 5 15C5 15.2652 5.10536 15.5196 5.29289 15.7071C5.48043 15.8946 5.73478 16 6 16ZM8 8H6C5.73478 8 5.48043 8.10536 5.29289 8.29289C5.10536 8.48043 5 8.73478 5 9C5 9.26522 5.10536 9.51957 5.29289 9.70711C5.48043 9.89464 5.73478 10 6 10H9C9.26522 10 9.51957 9.89464 9.70711 9.70711C9.89464 9.51957 10 9.26522 10 9V6C10 5.73478 9.89464 5.48043 9.70711 5.29289C9.51957 5.10536 9.26522 5 9 5C8.73478 5 8.48043 5.10536 8.29289 5.29289C8.10536 5.48043 8 5.73478 8 6V8ZM15 19C15.2652 19 15.5196 18.8946 15.7071 18.7071C15.8946 18.5196 16 18.2652 16 18V16H18C18.2652 16 18.5196 15.8946 18.7071 15.7071C18.8946 15.5196 19 15.2652 19 15C19 14.7348 18.8946 14.4804 18.7071 14.2929C18.5196 14.1054 18.2652 14 18 14H15C14.7348 14 14.4804 14.1054 14.2929 14.2929C14.1054 14.4804 14 14.7348 14 15V18C14 18.2652 14.1054 18.5196 14.2929 18.7071C14.4804 18.8946 14.7348 19 15 19ZM16 8V6C16 5.73478 15.8946 5.48043 15.7071 5.29289C15.5196 5.10536 15.2652 5 15 5C14.7348 5 14.4804 5.10536 14.2929 5.29289C14.1054 5.48043 14 5.73478 14 6V9C14 9.26522 14.1054 9.51957 14.2929 9.70711C14.4804 9.89464 14.7348 10 15 10H18C18.2652 10 18.5196 9.89464 18.7071 9.70711C18.8946 9.51957 19 9.26522 19 9C19 8.73478 18.8946 8.48043 18.7071 8.29289C18.5196 8.10536 18.2652 8 18 8H16Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const folder_shared_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15 13C16.1 13 17 12.1 17 11C17 9.9 16.1 9 15 9C13.9 9 13 9.9 13 11C13 12.1 13.9 13 15 13Z" />
<path d="M11 16V17H19V16C19 14.67 16.33 14 15 14C13.67 14 11 14.67 11 16Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M20 6H12L10.59 4.59C10.21 4.21 9.7 4 9.17 4H4C2.9 4 2.01 4.9 2.01 6L2 18C2 19.1 2.9 20 4 20H20C21.1 20 22 19.1 22 18V8C22 6.9 21.1 6 20 6ZM4 18H20V8H11.17L9.17 6H4V18Z" />
</svg>
`;

const remove_circle = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M12 2C6.48 2 2 6.48 2 12C2 17.52 6.48 22 12 22C17.52 22 22 17.52 22 12C22 6.48 17.52 2 12 2ZM16 13H8C7.45 13 7 12.55 7 12C7 11.45 7.45 11 8 11H16C16.55 11 17 11.45 17 12C17 12.55 16.55 13 16 13Z" />
</svg>
`;

const print = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M18 4V7H6V4C6 3.45 6.45 3 7 3H17C17.55 3 18 3.45 18 4Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M5 8H19C20.66 8 22 9.34 22 11V16C22 16.55 21.55 17 21 17H18V19C18 20.1 17.1 21 16 21H8C6.9 21 6 20.1 6 19V17H3C2.45 17 2 16.55 2 16V11C2 9.34 3.34 8 5 8ZM8 19H16V15H8V19ZM17 11.5C17 12.05 17.45 12.5 18 12.5C18.55 12.5 19 12.05 19 11.5C19 10.95 18.55 10.5 18 10.5C17.45 10.5 17 10.95 17 11.5Z" />
</svg>
`;

const unarchive = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M19.15 3.55L20.54 5.23C20.83 5.57 21 6.02 21 6.5V19C21 20.1 20.1 21 19 21H5C3.9 21 3 20.1 3 19V6.5C3 6.02 3.17 5.57 3.46 5.23L4.84 3.55C5.12 3.21 5.53 3 6 3H18C18.47 3 18.88 3.21 19.15 3.55ZM17.76 5H6.24L5.44 5.97H18.57L17.76 5ZM10.388 13.6647L9.53476 13.6647C9.05714 13.6647 8.82101 13.0643 9.1591 12.7141L11.6223 10.1626C11.8316 9.9458 12.1697 9.9458 12.379 10.1626L14.8422 12.7141C15.1803 13.0643 14.9388 13.6647 14.4612 13.6647H13.6079V16.4441C13.6079 16.7499 13.3664 17 13.0713 17H10.9247C10.6295 17 10.388 16.7499 10.388 16.4441L10.388 13.6647Z" />
</svg>
`;

const lock_clock_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path fill-rule="evenodd" clip-rule="evenodd" d="M6 10V20H11.29C11.51 20.72 11.84 21.4 12.26 22H6C4.9 22 4 21.1 4 20V10C4 8.9 4.9 8 6 8H7V6C7 3.24 9.24 1 12 1C14.76 1 17 3.24 17 6V8H18C19.1 8 20 8.9 20 10V11.29C19.37 11.1 18.7 11 18 11V10H6ZM12 3C10.34 3 9 4.34 9 6V8H15V6C15 4.34 13.66 3 12 3Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M13 18C13 15.24 15.24 13 18 13C20.76 13 23 15.24 23 18C23 20.76 20.76 23 18 23C15.24 23 13 20.76 13 18ZM17.5 18.2L19.65 20.35L20.35 19.64L18.5 17.79V15H17.5V18.2Z" />
</svg>
`;

const speedX7 = `<svg viewBox="0 0 36 36"   xmlns="http://www.w3.org/2000/svg">
<path d="M13.44 24.72L18.225 13.5V12H9V14.22H15.105L10.305 24.72H13.44ZM25.11 15.2249L23.61 17.8499L22.365 15.2249H19.245L21.75 19.8599L19.11 24.7349H22.11L23.61 21.9299L25.11 24.7349H28.23L25.605 19.8599L28.11 15.2249H25.11Z" fill-rule="nonzero" stroke="none"/>
</svg>
`;

const auto_fix_outline = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M9.44 4.94002L8.95 6.00002C8.78 6.39002 8.22 6.39002 8.05 6.00002L7.56 4.95002L6.5 4.46002C6.11 4.28002 6.11 3.73002 6.5 3.55002L7.56 3.06002L8.05 2.00002C8.22 1.61002 8.78 1.61002 8.95 2.00002L9.44 3.06002L10.5 3.54002C10.89 3.72002 10.89 4.27002 10.5 4.45002L9.44 4.94002Z" />
<path d="M20.94 4.94002L20.45 6.00002C20.28 6.39002 19.72 6.39002 19.55 6.00002L19.06 4.95002L18 4.46002C17.61 4.28002 17.61 3.73002 18 3.55002L19.05 3.06002L19.54 2.00002C19.72 1.61002 20.27 1.61002 20.45 2.00002L20.94 3.05002L22 3.54002C22.39 3.72002 22.39 4.27002 22 4.45002L20.94 4.94002Z" />
<path d="M19.55 13.5001L19.06 14.5601L18 15.0501C17.61 15.2301 17.61 15.7801 18 15.9601L19.06 16.4501L19.55 17.5101C19.73 17.9001 20.28 17.9001 20.46 17.5101L20.95 16.4501L22 15.9501C22.39 15.7701 22.39 15.2201 22 15.0401L20.94 14.5501L20.45 13.4901C20.28 13.1101 19.72 13.1101 19.55 13.5001Z" />
<path fill-rule="evenodd" clip-rule="evenodd" d="M14.88 6.29L17.71 9.12C18.1 9.51 18.1 10.15 17.71 10.54L6.54 21.71C6.34 21.9 6.09 22 5.83 22C5.57 22 5.32 21.9 5.12 21.7L2.29 18.87C1.9 18.48 1.9 17.85 2.29 17.46L13.46 6.29C13.66 6.1 13.91 6 14.17 6C14.43 6 14.68 6.1 14.88 6.29ZM15.58 9.83L14.17 8.42L13 9.59L14.41 11L15.58 9.83ZM4.42 18.18L5.83 19.59L13 12.41L11.59 11L4.42 18.18Z" />
</svg>
`;

const insights = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M15 9L15.94 6.93L18 6L15.94 5.07L15 3L14.08 5.07L12 6L14.08 6.93L15 9Z" />
<path d="M21 8C19.55 8 18.74 9.44 19.07 10.51L15.52 14.07C15.22 13.98 14.78 13.98 14.48 14.07L11.93 11.52C12.27 10.45 11.46 9 10 9C8.55 9 7.73 10.44 8.07 11.52L3.51 16.07C2.44 15.74 1 16.55 1 18C1 19.1 1.9 20 3 20C4.45 20 5.26 18.56 4.93 17.49L9.48 12.93C9.78 13.02 10.22 13.02 10.52 12.93L13.07 15.48C12.73 16.55 13.54 18 15 18C16.45 18 17.27 16.56 16.93 15.48L20.49 11.93C21.56 12.26 23 11.45 23 10C23 8.9 22.1 8 21 8Z" />
<path d="M4 9L3.5 11L3 9L1 8.5L3 8L3.5 6L4 8L6 8.5L4 9Z" />
</svg>
`;

const heart = `<svg  viewBox="0 0 24 24"  xmlns="http://www.w3.org/2000/svg">
<path d="M13.35 20.13C12.59 20.82 11.42 20.82 10.66 20.12L10.55 20.02C5.30003 15.27 1.87003 12.16 2.00003 8.27998C2.06003 6.57998 2.93003 4.94998 4.34003 3.98998C6.98003 2.18998 10.24 3.02998 12 5.08998C13.76 3.02998 17.02 2.17998 19.66 3.98998C21.07 4.94998 21.94 6.57998 22 8.27998C22.14 12.16 18.7 15.27 13.45 20.04L13.35 20.13Z" />
</svg>
`;

const Icons = {
  edit_outline,
  push_pin,
  auto_awesome_outline,
  search,
  notes,
  light_mode,
  link_add,
  list,
  bookmark_outline,
  auto_fix,
  light_mode_outline,
  information,
  arrow_drop_up,
  cloud_download_outline,
  hourglass,
  schedule_outline,
  translate,
  visibility_outline,
  chat_outline,
  laptop_computer,
  account,
  fullscreen,
  remove_circle_outline,
  speedX8,
  copy_outline,
  desktop_computer,
  home,
  smartphone,
  format_align_center,
  logout,
  group_outline,
  thumbs_up,
  radio_unselected,
  person_outline,
  export_icon,
  tag,
  dashboard_outline,
  arrow_back,
  visibility,
  cloud_download,
  analytics_outline,
  wifi_locked,
  label,
  microphone,
  zoom_in,
  format_align_left,
  clear,
  format_quote,
  calculate_outline,
  cloud_done,
  keyboard,
  lock,
  plagiarism_outline,
  rewindX10,
  hourglass_outline,
  calender,
  alarm_outline,
  arrow_left,
  plagiarism,
  link,
  forwardX10,
  cloud_upload,
  table_chart_outline,
  group,
  settings,
  perspn,
  format_italic,
  archive,
  add_circle_outline,
  school,
  download,
  expand,
  import_icon,
  apps,
  flag_outline,
  bolt,
  cloud_done_outline,
  checkbox_unselected,
  collapse,
  print_outline,
  arrow_up,
  foldor_outline,
  error_outline,
  calculate,
  camera_outline,
  cloud_upload_outline,
  dashboard,
  chevron_right,
  code,
  flag,
  chevron_left,
  preview,
  push_pin_outline,
  dark_mode,
  arrow_right,
  support,
  work,
  settings_outline,
  account_outline,
  trophy,
  document: document$1,
  check,
  table_chart,
  warning,
  rewindX15,
  format_align_right,
  headphones,
  functions,
  lock_open,
  open_new_window,
  email,
  wifi,
  forwardX15,
  drag_indicator,
  heart_outline,
  add,
  bar_graph,
  close,
  trophy_outline,
  auto_awesome,
  delete_outline,
  email_outline,
  copy,
  refresh,
  checkbox_selected,
  calender_outline,
  image,
  sort_descending,
  save,
  chevron_up,
  arrow_drop_down,
  share_outline,
  swap_vertical,
  folder_shared,
  column_outline,
  image_outline,
  arrow_down,
  play,
  radio_selected,
  chat,
  notification,
  work_outline,
  save_outline,
  camera,
  checkbox_indeterminate,
  redo,
  groups,
  more,
  headphones_outline,
  attachment,
  lock_open_outline,
  dark_mode_outline,
  business_outline,
  microphone_outline,
  star_outline,
  success_outline,
  accessible,
  star,
  column,
  visibility_off,
  edit,
  foldor,
  chevron_down,
  filter_outline,
  lock_clock,
  archive_outline,
  attach_file,
  language,
  analytics,
  delete_icon,
  speedX3,
  success,
  thumbs_down,
  clear_outline,
  sync,
  reorder,
  location: location$1,
  notification_outline,
  speedX2,
  keyboard_outline,
  visibility_off_outline,
  share,
  wifi_off,
  schedule,
  sort_ascending,
  remove,
  swap_horizontal,
  undo,
  lock_outline,
  business,
  filter,
  comment,
  unarchive_outline,
  location_outline,
  speedX1,
  home_outline,
  volumeOff,
  document_outline,
  add_circle,
  thumbs_up_outline,
  information_outline,
  cloud,
  error,
  school_outline,
  cloud_outline,
  format_bold,
  upload,
  drag_handle,
  pause,
  volumeUp,
  arrow_forward,
  speedX5,
  bookmark,
  help,
  speedX4,
  warning_outline,
  help_outline,
  menu,
  block,
  zoom_out,
  label_outline,
  groups_outline,
  thumbs_down_outline,
  speedX6,
  history,
  alarm,
  fullscreenExit,
  folder_shared_outline,
  remove_circle,
  print,
  unarchive,
  lock_clock_outline,
  speedX7,
  auto_fix_outline,
  insights,
  heart,
};

const peIconCss = ":host{display:inline;vertical-align:middle}svg{display:inline;width:inherit;height:inherit;fill:inherit;stroke:inherit;max-height:200px}";

let PeIcon = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  iconNameChanged(newIconName) {
    this.name = newIconName;
  }
  render() {
    return (h(Host, null, h("div", { innerHTML: Icons[this.name] })));
  }
  static get assetsDirs() { return ["assets"]; }
  static get watchers() { return {
    "name": ["iconNameChanged"]
  }; }
};
PeIcon.style = peIconCss;

function secondsToHours(value) {
  if (value < 0)
    return '';
  let date = new Date(0);
  date.setSeconds(value);
  return date.toISOString().substring(11, 19);
}

const peIncidentListCss = ":host{display:block;font-family:\"Noto Sans\", sans-serif}table{width:100%;text-align:left;font-weight:normal;max-width:469px;}thead{font-size:12px;line-height:18px;color:#191919;background:#f3f3f3;height:26px}thead th{border-top:1px solid #cdcdcd;border-bottom:1px solid #cdcdcd}tbody{font-size:14px}tbody tr{height:50px;background:#e5e5e5}td,th{padding:0 10px}tbody tr:nth-child(even){background:#f3f3f3}.time{color:#191919;border:0;background:transparent;text-decoration:underline;cursor:pointer}.type-icon{display:block;width:32px;height:32px;border-radius:4px}.type-icon.event{background:#dbf0ff;fill:#006dba}.type-icon.risk{background:#fceec6;fill:#b54b00}.type-icon.breach{background:#ffeaea;fill:#cd0022}";

let PeIncidentList = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    return (h(Host, null, h("table", { cellspacing: "0" }, h("thead", null, h("tr", null, h("th", null, "Type"), h("th", null, "Description"), h("th", null, "Start Time"), h("th", null, "End Time"), h("th", null))), h("tbody", null, Array.isArray(this.incidentList) &&
      this.incidentList.map(item => (h("tr", null, h("td", null, h("span", { class: `type-icon ${item.breachDictionaryItem.severity}` }, h("pe-icon", { name: item.breachDictionaryItem.icon }))), h("td", null, item.comment), h("td", null, h("button", { onClick: () => {
          this.jumptoIncidentTime(item.start_offset);
        }, class: "time" }, secondsToHours(item.start_offset))), h("td", null, h("button", { onClick: () => {
          this.jumptoIncidentTime(item.end_offset);
        }, class: "time" }, secondsToHours(item.end_offset))), h("td", null, h("pe-button", { onClick: () => {
          this.handleEdit(item);
        }, iconName: "edit", color: "primary", iconOnly: true })))))))));
  }
};
PeIncidentList.style = peIncidentListCss;

const peNavbarCss = ":host{display:-ms-flexbox;display:flex;background:#f9f9f9;padding:0 21px;height:74px;-ms-flex-pack:justify;justify-content:space-between;border-bottom:1px solid #cdcdcd;-ms-flex-align:center;align-items:center}.right-side{display:-ms-flexbox;display:flex}.right-side pe-button{margin-left:16px}";

let PeNavbar = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
  }
  render() {
    return (h(Host, null, h("div", null, h("img", { src: getAssetPath('assets/logo.svg'), alt: "Review Studio Logo" })), h("div", { class: "right-side" }, h("pe-button", { color: "action", variant: "outline" }, "Mark as unreviewable"), h("pe-button", { color: "action", variant: "filled" }, "Complete review"), h("pe-button", { iconName: "logout", iconOnly: true, color: "action", variant: "outline" }))));
  }
  static get assetsDirs() { return ["assets"]; }
};
PeNavbar.style = peNavbarCss;

var bind = function bind(fn, thisArg) {
  return function wrap() {
    var args = new Array(arguments.length);
    for (var i = 0; i < args.length; i++) {
      args[i] = arguments[i];
    }
    return fn.apply(thisArg, args);
  };
};

// utils is a library of generic helper functions non-specific to axios

var toString = Object.prototype.toString;

/**
 * Determine if a value is an Array
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an Array, otherwise false
 */
function isArray(val) {
  return Array.isArray(val);
}

/**
 * Determine if a value is undefined
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if the value is undefined, otherwise false
 */
function isUndefined(val) {
  return typeof val === 'undefined';
}

/**
 * Determine if a value is a Buffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Buffer, otherwise false
 */
function isBuffer(val) {
  return val !== null && !isUndefined(val) && val.constructor !== null && !isUndefined(val.constructor)
    && typeof val.constructor.isBuffer === 'function' && val.constructor.isBuffer(val);
}

/**
 * Determine if a value is an ArrayBuffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an ArrayBuffer, otherwise false
 */
function isArrayBuffer(val) {
  return toString.call(val) === '[object ArrayBuffer]';
}

/**
 * Determine if a value is a FormData
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an FormData, otherwise false
 */
function isFormData(val) {
  return toString.call(val) === '[object FormData]';
}

/**
 * Determine if a value is a view on an ArrayBuffer
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a view on an ArrayBuffer, otherwise false
 */
function isArrayBufferView(val) {
  var result;
  if ((typeof ArrayBuffer !== 'undefined') && (ArrayBuffer.isView)) {
    result = ArrayBuffer.isView(val);
  } else {
    result = (val) && (val.buffer) && (isArrayBuffer(val.buffer));
  }
  return result;
}

/**
 * Determine if a value is a String
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a String, otherwise false
 */
function isString(val) {
  return typeof val === 'string';
}

/**
 * Determine if a value is a Number
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Number, otherwise false
 */
function isNumber(val) {
  return typeof val === 'number';
}

/**
 * Determine if a value is an Object
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is an Object, otherwise false
 */
function isObject(val) {
  return val !== null && typeof val === 'object';
}

/**
 * Determine if a value is a plain Object
 *
 * @param {Object} val The value to test
 * @return {boolean} True if value is a plain Object, otherwise false
 */
function isPlainObject(val) {
  if (toString.call(val) !== '[object Object]') {
    return false;
  }

  var prototype = Object.getPrototypeOf(val);
  return prototype === null || prototype === Object.prototype;
}

/**
 * Determine if a value is a Date
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Date, otherwise false
 */
function isDate(val) {
  return toString.call(val) === '[object Date]';
}

/**
 * Determine if a value is a File
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a File, otherwise false
 */
function isFile(val) {
  return toString.call(val) === '[object File]';
}

/**
 * Determine if a value is a Blob
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Blob, otherwise false
 */
function isBlob(val) {
  return toString.call(val) === '[object Blob]';
}

/**
 * Determine if a value is a Function
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Function, otherwise false
 */
function isFunction(val) {
  return toString.call(val) === '[object Function]';
}

/**
 * Determine if a value is a Stream
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a Stream, otherwise false
 */
function isStream(val) {
  return isObject(val) && isFunction(val.pipe);
}

/**
 * Determine if a value is a URLSearchParams object
 *
 * @param {Object} val The value to test
 * @returns {boolean} True if value is a URLSearchParams object, otherwise false
 */
function isURLSearchParams(val) {
  return toString.call(val) === '[object URLSearchParams]';
}

/**
 * Trim excess whitespace off the beginning and end of a string
 *
 * @param {String} str The String to trim
 * @returns {String} The String freed of excess whitespace
 */
function trim(str) {
  return str.trim ? str.trim() : str.replace(/^\s+|\s+$/g, '');
}

/**
 * Determine if we're running in a standard browser environment
 *
 * This allows axios to run in a web worker, and react-native.
 * Both environments support XMLHttpRequest, but not fully standard globals.
 *
 * web workers:
 *  typeof window -> undefined
 *  typeof document -> undefined
 *
 * react-native:
 *  navigator.product -> 'ReactNative'
 * nativescript
 *  navigator.product -> 'NativeScript' or 'NS'
 */
function isStandardBrowserEnv() {
  if (typeof navigator !== 'undefined' && (navigator.product === 'ReactNative' ||
                                           navigator.product === 'NativeScript' ||
                                           navigator.product === 'NS')) {
    return false;
  }
  return (
    typeof window !== 'undefined' &&
    typeof document !== 'undefined'
  );
}

/**
 * Iterate over an Array or an Object invoking a function for each item.
 *
 * If `obj` is an Array callback will be called passing
 * the value, index, and complete array for each item.
 *
 * If 'obj' is an Object callback will be called passing
 * the value, key, and complete object for each property.
 *
 * @param {Object|Array} obj The object to iterate
 * @param {Function} fn The callback to invoke for each item
 */
function forEach(obj, fn) {
  // Don't bother if no value provided
  if (obj === null || typeof obj === 'undefined') {
    return;
  }

  // Force an array if not already something iterable
  if (typeof obj !== 'object') {
    /*eslint no-param-reassign:0*/
    obj = [obj];
  }

  if (isArray(obj)) {
    // Iterate over array values
    for (var i = 0, l = obj.length; i < l; i++) {
      fn.call(null, obj[i], i, obj);
    }
  } else {
    // Iterate over object keys
    for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        fn.call(null, obj[key], key, obj);
      }
    }
  }
}

/**
 * Accepts varargs expecting each argument to be an object, then
 * immutably merges the properties of each object and returns result.
 *
 * When multiple objects contain the same key the later object in
 * the arguments list will take precedence.
 *
 * Example:
 *
 * ```js
 * var result = merge({foo: 123}, {foo: 456});
 * console.log(result.foo); // outputs 456
 * ```
 *
 * @param {Object} obj1 Object to merge
 * @returns {Object} Result of all merge properties
 */
function merge(/* obj1, obj2, obj3, ... */) {
  var result = {};
  function assignValue(val, key) {
    if (isPlainObject(result[key]) && isPlainObject(val)) {
      result[key] = merge(result[key], val);
    } else if (isPlainObject(val)) {
      result[key] = merge({}, val);
    } else if (isArray(val)) {
      result[key] = val.slice();
    } else {
      result[key] = val;
    }
  }

  for (var i = 0, l = arguments.length; i < l; i++) {
    forEach(arguments[i], assignValue);
  }
  return result;
}

/**
 * Extends object a by mutably adding to it the properties of object b.
 *
 * @param {Object} a The object to be extended
 * @param {Object} b The object to copy properties from
 * @param {Object} thisArg The object to bind function to
 * @return {Object} The resulting value of object a
 */
function extend(a, b, thisArg) {
  forEach(b, function assignValue(val, key) {
    if (thisArg && typeof val === 'function') {
      a[key] = bind(val, thisArg);
    } else {
      a[key] = val;
    }
  });
  return a;
}

/**
 * Remove byte order marker. This catches EF BB BF (the UTF-8 BOM)
 *
 * @param {string} content with BOM
 * @return {string} content value without BOM
 */
function stripBOM(content) {
  if (content.charCodeAt(0) === 0xFEFF) {
    content = content.slice(1);
  }
  return content;
}

var utils = {
  isArray: isArray,
  isArrayBuffer: isArrayBuffer,
  isBuffer: isBuffer,
  isFormData: isFormData,
  isArrayBufferView: isArrayBufferView,
  isString: isString,
  isNumber: isNumber,
  isObject: isObject,
  isPlainObject: isPlainObject,
  isUndefined: isUndefined,
  isDate: isDate,
  isFile: isFile,
  isBlob: isBlob,
  isFunction: isFunction,
  isStream: isStream,
  isURLSearchParams: isURLSearchParams,
  isStandardBrowserEnv: isStandardBrowserEnv,
  forEach: forEach,
  merge: merge,
  extend: extend,
  trim: trim,
  stripBOM: stripBOM
};

function encode(val) {
  return encodeURIComponent(val).
    replace(/%3A/gi, ':').
    replace(/%24/g, '$').
    replace(/%2C/gi, ',').
    replace(/%20/g, '+').
    replace(/%5B/gi, '[').
    replace(/%5D/gi, ']');
}

/**
 * Build a URL by appending params to the end
 *
 * @param {string} url The base of the url (e.g., http://www.google.com)
 * @param {object} [params] The params to be appended
 * @returns {string} The formatted url
 */
var buildURL = function buildURL(url, params, paramsSerializer) {
  /*eslint no-param-reassign:0*/
  if (!params) {
    return url;
  }

  var serializedParams;
  if (paramsSerializer) {
    serializedParams = paramsSerializer(params);
  } else if (utils.isURLSearchParams(params)) {
    serializedParams = params.toString();
  } else {
    var parts = [];

    utils.forEach(params, function serialize(val, key) {
      if (val === null || typeof val === 'undefined') {
        return;
      }

      if (utils.isArray(val)) {
        key = key + '[]';
      } else {
        val = [val];
      }

      utils.forEach(val, function parseValue(v) {
        if (utils.isDate(v)) {
          v = v.toISOString();
        } else if (utils.isObject(v)) {
          v = JSON.stringify(v);
        }
        parts.push(encode(key) + '=' + encode(v));
      });
    });

    serializedParams = parts.join('&');
  }

  if (serializedParams) {
    var hashmarkIndex = url.indexOf('#');
    if (hashmarkIndex !== -1) {
      url = url.slice(0, hashmarkIndex);
    }

    url += (url.indexOf('?') === -1 ? '?' : '&') + serializedParams;
  }

  return url;
};

function InterceptorManager() {
  this.handlers = [];
}

/**
 * Add a new interceptor to the stack
 *
 * @param {Function} fulfilled The function to handle `then` for a `Promise`
 * @param {Function} rejected The function to handle `reject` for a `Promise`
 *
 * @return {Number} An ID used to remove interceptor later
 */
InterceptorManager.prototype.use = function use(fulfilled, rejected, options) {
  this.handlers.push({
    fulfilled: fulfilled,
    rejected: rejected,
    synchronous: options ? options.synchronous : false,
    runWhen: options ? options.runWhen : null
  });
  return this.handlers.length - 1;
};

/**
 * Remove an interceptor from the stack
 *
 * @param {Number} id The ID that was returned by `use`
 */
InterceptorManager.prototype.eject = function eject(id) {
  if (this.handlers[id]) {
    this.handlers[id] = null;
  }
};

/**
 * Iterate over all the registered interceptors
 *
 * This method is particularly useful for skipping over any
 * interceptors that may have become `null` calling `eject`.
 *
 * @param {Function} fn The function to call for each interceptor
 */
InterceptorManager.prototype.forEach = function forEach(fn) {
  utils.forEach(this.handlers, function forEachHandler(h) {
    if (h !== null) {
      fn(h);
    }
  });
};

var InterceptorManager_1 = InterceptorManager;

var normalizeHeaderName = function normalizeHeaderName(headers, normalizedName) {
  utils.forEach(headers, function processHeader(value, name) {
    if (name !== normalizedName && name.toUpperCase() === normalizedName.toUpperCase()) {
      headers[normalizedName] = value;
      delete headers[name];
    }
  });
};

/**
 * Update an Error with the specified config, error code, and response.
 *
 * @param {Error} error The error to update.
 * @param {Object} config The config.
 * @param {string} [code] The error code (for example, 'ECONNABORTED').
 * @param {Object} [request] The request.
 * @param {Object} [response] The response.
 * @returns {Error} The error.
 */
var enhanceError = function enhanceError(error, config, code, request, response) {
  error.config = config;
  if (code) {
    error.code = code;
  }

  error.request = request;
  error.response = response;
  error.isAxiosError = true;

  error.toJSON = function toJSON() {
    return {
      // Standard
      message: this.message,
      name: this.name,
      // Microsoft
      description: this.description,
      number: this.number,
      // Mozilla
      fileName: this.fileName,
      lineNumber: this.lineNumber,
      columnNumber: this.columnNumber,
      stack: this.stack,
      // Axios
      config: this.config,
      code: this.code,
      status: this.response && this.response.status ? this.response.status : null
    };
  };
  return error;
};

var transitional = {
  silentJSONParsing: true,
  forcedJSONParsing: true,
  clarifyTimeoutError: false
};

/**
 * Create an Error with the specified message, config, error code, request and response.
 *
 * @param {string} message The error message.
 * @param {Object} config The config.
 * @param {string} [code] The error code (for example, 'ECONNABORTED').
 * @param {Object} [request] The request.
 * @param {Object} [response] The response.
 * @returns {Error} The created error.
 */
var createError = function createError(message, config, code, request, response) {
  var error = new Error(message);
  return enhanceError(error, config, code, request, response);
};

/**
 * Resolve or reject a Promise based on response status.
 *
 * @param {Function} resolve A function that resolves the promise.
 * @param {Function} reject A function that rejects the promise.
 * @param {object} response The response.
 */
var settle = function settle(resolve, reject, response) {
  var validateStatus = response.config.validateStatus;
  if (!response.status || !validateStatus || validateStatus(response.status)) {
    resolve(response);
  } else {
    reject(createError(
      'Request failed with status code ' + response.status,
      response.config,
      null,
      response.request,
      response
    ));
  }
};

var cookies = (
  utils.isStandardBrowserEnv() ?

  // Standard browser envs support document.cookie
    (function standardBrowserEnv() {
      return {
        write: function write(name, value, expires, path, domain, secure) {
          var cookie = [];
          cookie.push(name + '=' + encodeURIComponent(value));

          if (utils.isNumber(expires)) {
            cookie.push('expires=' + new Date(expires).toGMTString());
          }

          if (utils.isString(path)) {
            cookie.push('path=' + path);
          }

          if (utils.isString(domain)) {
            cookie.push('domain=' + domain);
          }

          if (secure === true) {
            cookie.push('secure');
          }

          document.cookie = cookie.join('; ');
        },

        read: function read(name) {
          var match = document.cookie.match(new RegExp('(^|;\\s*)(' + name + ')=([^;]*)'));
          return (match ? decodeURIComponent(match[3]) : null);
        },

        remove: function remove(name) {
          this.write(name, '', Date.now() - 86400000);
        }
      };
    })() :

  // Non standard browser env (web workers, react-native) lack needed support.
    (function nonStandardBrowserEnv() {
      return {
        write: function write() {},
        read: function read() { return null; },
        remove: function remove() {}
      };
    })()
);

/**
 * Determines whether the specified URL is absolute
 *
 * @param {string} url The URL to test
 * @returns {boolean} True if the specified URL is absolute, otherwise false
 */
var isAbsoluteURL = function isAbsoluteURL(url) {
  // A URL is considered absolute if it begins with "<scheme>://" or "//" (protocol-relative URL).
  // RFC 3986 defines scheme name as a sequence of characters beginning with a letter and followed
  // by any combination of letters, digits, plus, period, or hyphen.
  return /^([a-z][a-z\d+\-.]*:)?\/\//i.test(url);
};

/**
 * Creates a new URL by combining the specified URLs
 *
 * @param {string} baseURL The base URL
 * @param {string} relativeURL The relative URL
 * @returns {string} The combined URL
 */
var combineURLs = function combineURLs(baseURL, relativeURL) {
  return relativeURL
    ? baseURL.replace(/\/+$/, '') + '/' + relativeURL.replace(/^\/+/, '')
    : baseURL;
};

/**
 * Creates a new URL by combining the baseURL with the requestedURL,
 * only when the requestedURL is not already an absolute URL.
 * If the requestURL is absolute, this function returns the requestedURL untouched.
 *
 * @param {string} baseURL The base URL
 * @param {string} requestedURL Absolute or relative URL to combine
 * @returns {string} The combined full path
 */
var buildFullPath = function buildFullPath(baseURL, requestedURL) {
  if (baseURL && !isAbsoluteURL(requestedURL)) {
    return combineURLs(baseURL, requestedURL);
  }
  return requestedURL;
};

// Headers whose duplicates are ignored by node
// c.f. https://nodejs.org/api/http.html#http_message_headers
var ignoreDuplicateOf = [
  'age', 'authorization', 'content-length', 'content-type', 'etag',
  'expires', 'from', 'host', 'if-modified-since', 'if-unmodified-since',
  'last-modified', 'location', 'max-forwards', 'proxy-authorization',
  'referer', 'retry-after', 'user-agent'
];

/**
 * Parse headers into an object
 *
 * ```
 * Date: Wed, 27 Aug 2014 08:58:49 GMT
 * Content-Type: application/json
 * Connection: keep-alive
 * Transfer-Encoding: chunked
 * ```
 *
 * @param {String} headers Headers needing to be parsed
 * @returns {Object} Headers parsed into an object
 */
var parseHeaders = function parseHeaders(headers) {
  var parsed = {};
  var key;
  var val;
  var i;

  if (!headers) { return parsed; }

  utils.forEach(headers.split('\n'), function parser(line) {
    i = line.indexOf(':');
    key = utils.trim(line.substr(0, i)).toLowerCase();
    val = utils.trim(line.substr(i + 1));

    if (key) {
      if (parsed[key] && ignoreDuplicateOf.indexOf(key) >= 0) {
        return;
      }
      if (key === 'set-cookie') {
        parsed[key] = (parsed[key] ? parsed[key] : []).concat([val]);
      } else {
        parsed[key] = parsed[key] ? parsed[key] + ', ' + val : val;
      }
    }
  });

  return parsed;
};

var isURLSameOrigin = (
  utils.isStandardBrowserEnv() ?

  // Standard browser envs have full support of the APIs needed to test
  // whether the request URL is of the same origin as current location.
    (function standardBrowserEnv() {
      var msie = /(msie|trident)/i.test(navigator.userAgent);
      var urlParsingNode = document.createElement('a');
      var originURL;

      /**
    * Parse a URL to discover it's components
    *
    * @param {String} url The URL to be parsed
    * @returns {Object}
    */
      function resolveURL(url) {
        var href = url;

        if (msie) {
        // IE needs attribute set twice to normalize properties
          urlParsingNode.setAttribute('href', href);
          href = urlParsingNode.href;
        }

        urlParsingNode.setAttribute('href', href);

        // urlParsingNode provides the UrlUtils interface - http://url.spec.whatwg.org/#urlutils
        return {
          href: urlParsingNode.href,
          protocol: urlParsingNode.protocol ? urlParsingNode.protocol.replace(/:$/, '') : '',
          host: urlParsingNode.host,
          search: urlParsingNode.search ? urlParsingNode.search.replace(/^\?/, '') : '',
          hash: urlParsingNode.hash ? urlParsingNode.hash.replace(/^#/, '') : '',
          hostname: urlParsingNode.hostname,
          port: urlParsingNode.port,
          pathname: (urlParsingNode.pathname.charAt(0) === '/') ?
            urlParsingNode.pathname :
            '/' + urlParsingNode.pathname
        };
      }

      originURL = resolveURL(window.location.href);

      /**
    * Determine if a URL shares the same origin as the current location
    *
    * @param {String} requestURL The URL to test
    * @returns {boolean} True if URL shares the same origin, otherwise false
    */
      return function isURLSameOrigin(requestURL) {
        var parsed = (utils.isString(requestURL)) ? resolveURL(requestURL) : requestURL;
        return (parsed.protocol === originURL.protocol &&
            parsed.host === originURL.host);
      };
    })() :

  // Non standard browser envs (web workers, react-native) lack needed support.
    (function nonStandardBrowserEnv() {
      return function isURLSameOrigin() {
        return true;
      };
    })()
);

/**
 * A `Cancel` is an object that is thrown when an operation is canceled.
 *
 * @class
 * @param {string=} message The message.
 */
function Cancel(message) {
  this.message = message;
}

Cancel.prototype.toString = function toString() {
  return 'Cancel' + (this.message ? ': ' + this.message : '');
};

Cancel.prototype.__CANCEL__ = true;

var Cancel_1 = Cancel;

var xhr = function xhrAdapter(config) {
  return new Promise(function dispatchXhrRequest(resolve, reject) {
    var requestData = config.data;
    var requestHeaders = config.headers;
    var responseType = config.responseType;
    var onCanceled;
    function done() {
      if (config.cancelToken) {
        config.cancelToken.unsubscribe(onCanceled);
      }

      if (config.signal) {
        config.signal.removeEventListener('abort', onCanceled);
      }
    }

    if (utils.isFormData(requestData)) {
      delete requestHeaders['Content-Type']; // Let the browser set it
    }

    var request = new XMLHttpRequest();

    // HTTP basic authentication
    if (config.auth) {
      var username = config.auth.username || '';
      var password = config.auth.password ? unescape(encodeURIComponent(config.auth.password)) : '';
      requestHeaders.Authorization = 'Basic ' + btoa(username + ':' + password);
    }

    var fullPath = buildFullPath(config.baseURL, config.url);
    request.open(config.method.toUpperCase(), buildURL(fullPath, config.params, config.paramsSerializer), true);

    // Set the request timeout in MS
    request.timeout = config.timeout;

    function onloadend() {
      if (!request) {
        return;
      }
      // Prepare the response
      var responseHeaders = 'getAllResponseHeaders' in request ? parseHeaders(request.getAllResponseHeaders()) : null;
      var responseData = !responseType || responseType === 'text' ||  responseType === 'json' ?
        request.responseText : request.response;
      var response = {
        data: responseData,
        status: request.status,
        statusText: request.statusText,
        headers: responseHeaders,
        config: config,
        request: request
      };

      settle(function _resolve(value) {
        resolve(value);
        done();
      }, function _reject(err) {
        reject(err);
        done();
      }, response);

      // Clean up request
      request = null;
    }

    if ('onloadend' in request) {
      // Use onloadend if available
      request.onloadend = onloadend;
    } else {
      // Listen for ready state to emulate onloadend
      request.onreadystatechange = function handleLoad() {
        if (!request || request.readyState !== 4) {
          return;
        }

        // The request errored out and we didn't get a response, this will be
        // handled by onerror instead
        // With one exception: request that using file: protocol, most browsers
        // will return status as 0 even though it's a successful request
        if (request.status === 0 && !(request.responseURL && request.responseURL.indexOf('file:') === 0)) {
          return;
        }
        // readystate handler is calling before onerror or ontimeout handlers,
        // so we should call onloadend on the next 'tick'
        setTimeout(onloadend);
      };
    }

    // Handle browser request cancellation (as opposed to a manual cancellation)
    request.onabort = function handleAbort() {
      if (!request) {
        return;
      }

      reject(createError('Request aborted', config, 'ECONNABORTED', request));

      // Clean up request
      request = null;
    };

    // Handle low level network errors
    request.onerror = function handleError() {
      // Real errors are hidden from us by the browser
      // onerror should only fire if it's a network error
      reject(createError('Network Error', config, null, request));

      // Clean up request
      request = null;
    };

    // Handle timeout
    request.ontimeout = function handleTimeout() {
      var timeoutErrorMessage = config.timeout ? 'timeout of ' + config.timeout + 'ms exceeded' : 'timeout exceeded';
      var transitional$1 = config.transitional || transitional;
      if (config.timeoutErrorMessage) {
        timeoutErrorMessage = config.timeoutErrorMessage;
      }
      reject(createError(
        timeoutErrorMessage,
        config,
        transitional$1.clarifyTimeoutError ? 'ETIMEDOUT' : 'ECONNABORTED',
        request));

      // Clean up request
      request = null;
    };

    // Add xsrf header
    // This is only done if running in a standard browser environment.
    // Specifically not if we're in a web worker, or react-native.
    if (utils.isStandardBrowserEnv()) {
      // Add xsrf header
      var xsrfValue = (config.withCredentials || isURLSameOrigin(fullPath)) && config.xsrfCookieName ?
        cookies.read(config.xsrfCookieName) :
        undefined;

      if (xsrfValue) {
        requestHeaders[config.xsrfHeaderName] = xsrfValue;
      }
    }

    // Add headers to the request
    if ('setRequestHeader' in request) {
      utils.forEach(requestHeaders, function setRequestHeader(val, key) {
        if (typeof requestData === 'undefined' && key.toLowerCase() === 'content-type') {
          // Remove Content-Type if data is undefined
          delete requestHeaders[key];
        } else {
          // Otherwise add header to the request
          request.setRequestHeader(key, val);
        }
      });
    }

    // Add withCredentials to request if needed
    if (!utils.isUndefined(config.withCredentials)) {
      request.withCredentials = !!config.withCredentials;
    }

    // Add responseType to request if needed
    if (responseType && responseType !== 'json') {
      request.responseType = config.responseType;
    }

    // Handle progress if needed
    if (typeof config.onDownloadProgress === 'function') {
      request.addEventListener('progress', config.onDownloadProgress);
    }

    // Not all browsers support upload events
    if (typeof config.onUploadProgress === 'function' && request.upload) {
      request.upload.addEventListener('progress', config.onUploadProgress);
    }

    if (config.cancelToken || config.signal) {
      // Handle cancellation
      // eslint-disable-next-line func-names
      onCanceled = function(cancel) {
        if (!request) {
          return;
        }
        reject(!cancel || (cancel && cancel.type) ? new Cancel_1('canceled') : cancel);
        request.abort();
        request = null;
      };

      config.cancelToken && config.cancelToken.subscribe(onCanceled);
      if (config.signal) {
        config.signal.aborted ? onCanceled() : config.signal.addEventListener('abort', onCanceled);
      }
    }

    if (!requestData) {
      requestData = null;
    }

    // Send the request
    request.send(requestData);
  });
};

var DEFAULT_CONTENT_TYPE = {
  'Content-Type': 'application/x-www-form-urlencoded'
};

function setContentTypeIfUnset(headers, value) {
  if (!utils.isUndefined(headers) && utils.isUndefined(headers['Content-Type'])) {
    headers['Content-Type'] = value;
  }
}

function getDefaultAdapter() {
  var adapter;
  if (typeof XMLHttpRequest !== 'undefined') {
    // For browsers use XHR adapter
    adapter = xhr;
  } else if (typeof process !== 'undefined' && Object.prototype.toString.call(process) === '[object process]') {
    // For node use HTTP adapter
    adapter = xhr;
  }
  return adapter;
}

function stringifySafely(rawValue, parser, encoder) {
  if (utils.isString(rawValue)) {
    try {
      (parser || JSON.parse)(rawValue);
      return utils.trim(rawValue);
    } catch (e) {
      if (e.name !== 'SyntaxError') {
        throw e;
      }
    }
  }

  return (encoder || JSON.stringify)(rawValue);
}

var defaults = {

  transitional: transitional,

  adapter: getDefaultAdapter(),

  transformRequest: [function transformRequest(data, headers) {
    normalizeHeaderName(headers, 'Accept');
    normalizeHeaderName(headers, 'Content-Type');

    if (utils.isFormData(data) ||
      utils.isArrayBuffer(data) ||
      utils.isBuffer(data) ||
      utils.isStream(data) ||
      utils.isFile(data) ||
      utils.isBlob(data)
    ) {
      return data;
    }
    if (utils.isArrayBufferView(data)) {
      return data.buffer;
    }
    if (utils.isURLSearchParams(data)) {
      setContentTypeIfUnset(headers, 'application/x-www-form-urlencoded;charset=utf-8');
      return data.toString();
    }
    if (utils.isObject(data) || (headers && headers['Content-Type'] === 'application/json')) {
      setContentTypeIfUnset(headers, 'application/json');
      return stringifySafely(data);
    }
    return data;
  }],

  transformResponse: [function transformResponse(data) {
    var transitional = this.transitional || defaults.transitional;
    var silentJSONParsing = transitional && transitional.silentJSONParsing;
    var forcedJSONParsing = transitional && transitional.forcedJSONParsing;
    var strictJSONParsing = !silentJSONParsing && this.responseType === 'json';

    if (strictJSONParsing || (forcedJSONParsing && utils.isString(data) && data.length)) {
      try {
        return JSON.parse(data);
      } catch (e) {
        if (strictJSONParsing) {
          if (e.name === 'SyntaxError') {
            throw enhanceError(e, this, 'E_JSON_PARSE');
          }
          throw e;
        }
      }
    }

    return data;
  }],

  /**
   * A timeout in milliseconds to abort a request. If set to 0 (default) a
   * timeout is not created.
   */
  timeout: 0,

  xsrfCookieName: 'XSRF-TOKEN',
  xsrfHeaderName: 'X-XSRF-TOKEN',

  maxContentLength: -1,
  maxBodyLength: -1,

  validateStatus: function validateStatus(status) {
    return status >= 200 && status < 300;
  },

  headers: {
    common: {
      'Accept': 'application/json, text/plain, */*'
    }
  }
};

utils.forEach(['delete', 'get', 'head'], function forEachMethodNoData(method) {
  defaults.headers[method] = {};
});

utils.forEach(['post', 'put', 'patch'], function forEachMethodWithData(method) {
  defaults.headers[method] = utils.merge(DEFAULT_CONTENT_TYPE);
});

var defaults_1 = defaults;

/**
 * Transform the data for a request or a response
 *
 * @param {Object|String} data The data to be transformed
 * @param {Array} headers The headers for the request or response
 * @param {Array|Function} fns A single function or Array of functions
 * @returns {*} The resulting transformed data
 */
var transformData = function transformData(data, headers, fns) {
  var context = this || defaults_1;
  /*eslint no-param-reassign:0*/
  utils.forEach(fns, function transform(fn) {
    data = fn.call(context, data, headers);
  });

  return data;
};

var isCancel = function isCancel(value) {
  return !!(value && value.__CANCEL__);
};

/**
 * Throws a `Cancel` if cancellation has been requested.
 */
function throwIfCancellationRequested(config) {
  if (config.cancelToken) {
    config.cancelToken.throwIfRequested();
  }

  if (config.signal && config.signal.aborted) {
    throw new Cancel_1('canceled');
  }
}

/**
 * Dispatch a request to the server using the configured adapter.
 *
 * @param {object} config The config that is to be used for the request
 * @returns {Promise} The Promise to be fulfilled
 */
var dispatchRequest = function dispatchRequest(config) {
  throwIfCancellationRequested(config);

  // Ensure headers exist
  config.headers = config.headers || {};

  // Transform request data
  config.data = transformData.call(
    config,
    config.data,
    config.headers,
    config.transformRequest
  );

  // Flatten headers
  config.headers = utils.merge(
    config.headers.common || {},
    config.headers[config.method] || {},
    config.headers
  );

  utils.forEach(
    ['delete', 'get', 'head', 'post', 'put', 'patch', 'common'],
    function cleanHeaderConfig(method) {
      delete config.headers[method];
    }
  );

  var adapter = config.adapter || defaults_1.adapter;

  return adapter(config).then(function onAdapterResolution(response) {
    throwIfCancellationRequested(config);

    // Transform response data
    response.data = transformData.call(
      config,
      response.data,
      response.headers,
      config.transformResponse
    );

    return response;
  }, function onAdapterRejection(reason) {
    if (!isCancel(reason)) {
      throwIfCancellationRequested(config);

      // Transform response data
      if (reason && reason.response) {
        reason.response.data = transformData.call(
          config,
          reason.response.data,
          reason.response.headers,
          config.transformResponse
        );
      }
    }

    return Promise.reject(reason);
  });
};

/**
 * Config-specific merge-function which creates a new config-object
 * by merging two configuration objects together.
 *
 * @param {Object} config1
 * @param {Object} config2
 * @returns {Object} New object resulting from merging config2 to config1
 */
var mergeConfig = function mergeConfig(config1, config2) {
  // eslint-disable-next-line no-param-reassign
  config2 = config2 || {};
  var config = {};

  function getMergedValue(target, source) {
    if (utils.isPlainObject(target) && utils.isPlainObject(source)) {
      return utils.merge(target, source);
    } else if (utils.isPlainObject(source)) {
      return utils.merge({}, source);
    } else if (utils.isArray(source)) {
      return source.slice();
    }
    return source;
  }

  // eslint-disable-next-line consistent-return
  function mergeDeepProperties(prop) {
    if (!utils.isUndefined(config2[prop])) {
      return getMergedValue(config1[prop], config2[prop]);
    } else if (!utils.isUndefined(config1[prop])) {
      return getMergedValue(undefined, config1[prop]);
    }
  }

  // eslint-disable-next-line consistent-return
  function valueFromConfig2(prop) {
    if (!utils.isUndefined(config2[prop])) {
      return getMergedValue(undefined, config2[prop]);
    }
  }

  // eslint-disable-next-line consistent-return
  function defaultToConfig2(prop) {
    if (!utils.isUndefined(config2[prop])) {
      return getMergedValue(undefined, config2[prop]);
    } else if (!utils.isUndefined(config1[prop])) {
      return getMergedValue(undefined, config1[prop]);
    }
  }

  // eslint-disable-next-line consistent-return
  function mergeDirectKeys(prop) {
    if (prop in config2) {
      return getMergedValue(config1[prop], config2[prop]);
    } else if (prop in config1) {
      return getMergedValue(undefined, config1[prop]);
    }
  }

  var mergeMap = {
    'url': valueFromConfig2,
    'method': valueFromConfig2,
    'data': valueFromConfig2,
    'baseURL': defaultToConfig2,
    'transformRequest': defaultToConfig2,
    'transformResponse': defaultToConfig2,
    'paramsSerializer': defaultToConfig2,
    'timeout': defaultToConfig2,
    'timeoutMessage': defaultToConfig2,
    'withCredentials': defaultToConfig2,
    'adapter': defaultToConfig2,
    'responseType': defaultToConfig2,
    'xsrfCookieName': defaultToConfig2,
    'xsrfHeaderName': defaultToConfig2,
    'onUploadProgress': defaultToConfig2,
    'onDownloadProgress': defaultToConfig2,
    'decompress': defaultToConfig2,
    'maxContentLength': defaultToConfig2,
    'maxBodyLength': defaultToConfig2,
    'transport': defaultToConfig2,
    'httpAgent': defaultToConfig2,
    'httpsAgent': defaultToConfig2,
    'cancelToken': defaultToConfig2,
    'socketPath': defaultToConfig2,
    'responseEncoding': defaultToConfig2,
    'validateStatus': mergeDirectKeys
  };

  utils.forEach(Object.keys(config1).concat(Object.keys(config2)), function computeConfigValue(prop) {
    var merge = mergeMap[prop] || mergeDeepProperties;
    var configValue = merge(prop);
    (utils.isUndefined(configValue) && merge !== mergeDirectKeys) || (config[prop] = configValue);
  });

  return config;
};

var data = {
  "version": "0.26.1"
};

var VERSION = data.version;

var validators$1 = {};

// eslint-disable-next-line func-names
['object', 'boolean', 'number', 'function', 'string', 'symbol'].forEach(function(type, i) {
  validators$1[type] = function validator(thing) {
    return typeof thing === type || 'a' + (i < 1 ? 'n ' : ' ') + type;
  };
});

var deprecatedWarnings = {};

/**
 * Transitional option validator
 * @param {function|boolean?} validator - set to false if the transitional option has been removed
 * @param {string?} version - deprecated version / removed since version
 * @param {string?} message - some message with additional info
 * @returns {function}
 */
validators$1.transitional = function transitional(validator, version, message) {
  function formatMessage(opt, desc) {
    return '[Axios v' + VERSION + '] Transitional option \'' + opt + '\'' + desc + (message ? '. ' + message : '');
  }

  // eslint-disable-next-line func-names
  return function(value, opt, opts) {
    if (validator === false) {
      throw new Error(formatMessage(opt, ' has been removed' + (version ? ' in ' + version : '')));
    }

    if (version && !deprecatedWarnings[opt]) {
      deprecatedWarnings[opt] = true;
      // eslint-disable-next-line no-console
      console.warn(
        formatMessage(
          opt,
          ' has been deprecated since v' + version + ' and will be removed in the near future'
        )
      );
    }

    return validator ? validator(value, opt, opts) : true;
  };
};

/**
 * Assert object's properties type
 * @param {object} options
 * @param {object} schema
 * @param {boolean?} allowUnknown
 */

function assertOptions(options, schema, allowUnknown) {
  if (typeof options !== 'object') {
    throw new TypeError('options must be an object');
  }
  var keys = Object.keys(options);
  var i = keys.length;
  while (i-- > 0) {
    var opt = keys[i];
    var validator = schema[opt];
    if (validator) {
      var value = options[opt];
      var result = value === undefined || validator(value, opt, options);
      if (result !== true) {
        throw new TypeError('option ' + opt + ' must be ' + result);
      }
      continue;
    }
    if (allowUnknown !== true) {
      throw Error('Unknown option ' + opt);
    }
  }
}

var validator = {
  assertOptions: assertOptions,
  validators: validators$1
};

var validators = validator.validators;
/**
 * Create a new instance of Axios
 *
 * @param {Object} instanceConfig The default config for the instance
 */
function Axios(instanceConfig) {
  this.defaults = instanceConfig;
  this.interceptors = {
    request: new InterceptorManager_1(),
    response: new InterceptorManager_1()
  };
}

/**
 * Dispatch a request
 *
 * @param {Object} config The config specific for this request (merged with this.defaults)
 */
Axios.prototype.request = function request(configOrUrl, config) {
  /*eslint no-param-reassign:0*/
  // Allow for axios('example/url'[, config]) a la fetch API
  if (typeof configOrUrl === 'string') {
    config = config || {};
    config.url = configOrUrl;
  } else {
    config = configOrUrl || {};
  }

  config = mergeConfig(this.defaults, config);

  // Set config.method
  if (config.method) {
    config.method = config.method.toLowerCase();
  } else if (this.defaults.method) {
    config.method = this.defaults.method.toLowerCase();
  } else {
    config.method = 'get';
  }

  var transitional = config.transitional;

  if (transitional !== undefined) {
    validator.assertOptions(transitional, {
      silentJSONParsing: validators.transitional(validators.boolean),
      forcedJSONParsing: validators.transitional(validators.boolean),
      clarifyTimeoutError: validators.transitional(validators.boolean)
    }, false);
  }

  // filter out skipped interceptors
  var requestInterceptorChain = [];
  var synchronousRequestInterceptors = true;
  this.interceptors.request.forEach(function unshiftRequestInterceptors(interceptor) {
    if (typeof interceptor.runWhen === 'function' && interceptor.runWhen(config) === false) {
      return;
    }

    synchronousRequestInterceptors = synchronousRequestInterceptors && interceptor.synchronous;

    requestInterceptorChain.unshift(interceptor.fulfilled, interceptor.rejected);
  });

  var responseInterceptorChain = [];
  this.interceptors.response.forEach(function pushResponseInterceptors(interceptor) {
    responseInterceptorChain.push(interceptor.fulfilled, interceptor.rejected);
  });

  var promise;

  if (!synchronousRequestInterceptors) {
    var chain = [dispatchRequest, undefined];

    Array.prototype.unshift.apply(chain, requestInterceptorChain);
    chain = chain.concat(responseInterceptorChain);

    promise = Promise.resolve(config);
    while (chain.length) {
      promise = promise.then(chain.shift(), chain.shift());
    }

    return promise;
  }


  var newConfig = config;
  while (requestInterceptorChain.length) {
    var onFulfilled = requestInterceptorChain.shift();
    var onRejected = requestInterceptorChain.shift();
    try {
      newConfig = onFulfilled(newConfig);
    } catch (error) {
      onRejected(error);
      break;
    }
  }

  try {
    promise = dispatchRequest(newConfig);
  } catch (error) {
    return Promise.reject(error);
  }

  while (responseInterceptorChain.length) {
    promise = promise.then(responseInterceptorChain.shift(), responseInterceptorChain.shift());
  }

  return promise;
};

Axios.prototype.getUri = function getUri(config) {
  config = mergeConfig(this.defaults, config);
  return buildURL(config.url, config.params, config.paramsSerializer).replace(/^\?/, '');
};

// Provide aliases for supported request methods
utils.forEach(['delete', 'get', 'head', 'options'], function forEachMethodNoData(method) {
  /*eslint func-names:0*/
  Axios.prototype[method] = function(url, config) {
    return this.request(mergeConfig(config || {}, {
      method: method,
      url: url,
      data: (config || {}).data
    }));
  };
});

utils.forEach(['post', 'put', 'patch'], function forEachMethodWithData(method) {
  /*eslint func-names:0*/
  Axios.prototype[method] = function(url, data, config) {
    return this.request(mergeConfig(config || {}, {
      method: method,
      url: url,
      data: data
    }));
  };
});

var Axios_1 = Axios;

/**
 * A `CancelToken` is an object that can be used to request cancellation of an operation.
 *
 * @class
 * @param {Function} executor The executor function.
 */
function CancelToken(executor) {
  if (typeof executor !== 'function') {
    throw new TypeError('executor must be a function.');
  }

  var resolvePromise;

  this.promise = new Promise(function promiseExecutor(resolve) {
    resolvePromise = resolve;
  });

  var token = this;

  // eslint-disable-next-line func-names
  this.promise.then(function(cancel) {
    if (!token._listeners) return;

    var i;
    var l = token._listeners.length;

    for (i = 0; i < l; i++) {
      token._listeners[i](cancel);
    }
    token._listeners = null;
  });

  // eslint-disable-next-line func-names
  this.promise.then = function(onfulfilled) {
    var _resolve;
    // eslint-disable-next-line func-names
    var promise = new Promise(function(resolve) {
      token.subscribe(resolve);
      _resolve = resolve;
    }).then(onfulfilled);

    promise.cancel = function reject() {
      token.unsubscribe(_resolve);
    };

    return promise;
  };

  executor(function cancel(message) {
    if (token.reason) {
      // Cancellation has already been requested
      return;
    }

    token.reason = new Cancel_1(message);
    resolvePromise(token.reason);
  });
}

/**
 * Throws a `Cancel` if cancellation has been requested.
 */
CancelToken.prototype.throwIfRequested = function throwIfRequested() {
  if (this.reason) {
    throw this.reason;
  }
};

/**
 * Subscribe to the cancel signal
 */

CancelToken.prototype.subscribe = function subscribe(listener) {
  if (this.reason) {
    listener(this.reason);
    return;
  }

  if (this._listeners) {
    this._listeners.push(listener);
  } else {
    this._listeners = [listener];
  }
};

/**
 * Unsubscribe from the cancel signal
 */

CancelToken.prototype.unsubscribe = function unsubscribe(listener) {
  if (!this._listeners) {
    return;
  }
  var index = this._listeners.indexOf(listener);
  if (index !== -1) {
    this._listeners.splice(index, 1);
  }
};

/**
 * Returns an object that contains a new `CancelToken` and a function that, when called,
 * cancels the `CancelToken`.
 */
CancelToken.source = function source() {
  var cancel;
  var token = new CancelToken(function executor(c) {
    cancel = c;
  });
  return {
    token: token,
    cancel: cancel
  };
};

var CancelToken_1 = CancelToken;

/**
 * Syntactic sugar for invoking a function and expanding an array for arguments.
 *
 * Common use case would be to use `Function.prototype.apply`.
 *
 *  ```js
 *  function f(x, y, z) {}
 *  var args = [1, 2, 3];
 *  f.apply(null, args);
 *  ```
 *
 * With `spread` this example can be re-written.
 *
 *  ```js
 *  spread(function(x, y, z) {})([1, 2, 3]);
 *  ```
 *
 * @param {Function} callback
 * @returns {Function}
 */
var spread = function spread(callback) {
  return function wrap(arr) {
    return callback.apply(null, arr);
  };
};

/**
 * Determines whether the payload is an error thrown by Axios
 *
 * @param {*} payload The value to test
 * @returns {boolean} True if the payload is an error thrown by Axios, otherwise false
 */
var isAxiosError = function isAxiosError(payload) {
  return utils.isObject(payload) && (payload.isAxiosError === true);
};

/**
 * Create an instance of Axios
 *
 * @param {Object} defaultConfig The default config for the instance
 * @return {Axios} A new instance of Axios
 */
function createInstance(defaultConfig) {
  var context = new Axios_1(defaultConfig);
  var instance = bind(Axios_1.prototype.request, context);

  // Copy axios.prototype to instance
  utils.extend(instance, Axios_1.prototype, context);

  // Copy context to instance
  utils.extend(instance, context);

  // Factory for creating new instances
  instance.create = function create(instanceConfig) {
    return createInstance(mergeConfig(defaultConfig, instanceConfig));
  };

  return instance;
}

// Create the default instance to be exported
var axios$1 = createInstance(defaults_1);

// Expose Axios class to allow class inheritance
axios$1.Axios = Axios_1;

// Expose Cancel & CancelToken
axios$1.Cancel = Cancel_1;
axios$1.CancelToken = CancelToken_1;
axios$1.isCancel = isCancel;
axios$1.VERSION = data.version;

// Expose all/spread
axios$1.all = function all(promises) {
  return Promise.all(promises);
};
axios$1.spread = spread;

// Expose isAxiosError
axios$1.isAxiosError = isAxiosError;

var axios_1 = axios$1;

// Allow use of default import syntax in TypeScript
var _default = axios$1;
axios_1.default = _default;

var axios = axios_1;

const axiosInstance = axios.create({
  // baseURL: 'http://localhost:4000/api/',
  baseURL: 'https://my-json-server.typicode.com/ahakem/api-mock/',
});
const API = {
  // incidentList : (sessionid) => `/sessions/${sessionid}/incident-list`,
  // breachDictionaryItems : (breachDictionaryId) => `/breach-dictionary/${breachDictionaryId}`,
  incidentList: 'incidents',
  breachDictionaryItems: 'breachDictionaryItems',
};

const peReviewStudioCss = ":host{display:block}div#container{display:-ms-flexbox;display:flex;-ms-flex-wrap:wrap;flex-wrap:wrap}div#navbar{height:74px;width:100%;background-color:#f3f3f3;border-bottom:1px solid #cdcdcd}div#sidebar{width:59px;height:calc(100vh - 74px);background-color:#f3f3f3;border-right:1px solid #cdcdcd}div#side-panel{width:468px;height:calc(100vh - 74px);background:#f9f9f9;border-right:1px solid #cdcdcd}div#video-player{width:calc(100vw - 529px);height:calc(100vh - 74px)}div#video-player.fullscreen{width:calc(100vw - 60px);height:100vh}.sidebar-tab{height:60px;width:59px;fill:#1a5059;border:0;border-bottom:1px solid #cdcdcd;cursor:pointer;position:relative}.sidebar-tab span{width:20px;height:20px;display:inherit;pointer-events:none}.sidebar-tab::after{position:absolute;height:2px;bottom:0;width:100%;background:#1a5059;content:\"\";left:0;visibility:hidden}.sidebar-tab:hover,.sidebar-tab.active{background:#e5ebec}.sidebar-tab:hover::after,.sidebar-tab.active::after{visibility:visible}";

let PeReviewStudio = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.isFullscreen = false;
    /**
     * changing the active Tab
     */
    this.activeTab = 'incident';
    /**
     * incident List content
     */
    this.content = [];
    /**
     * breachDictionaryItems
     */
    this.breachDictionaryItems = [];
  }
  connectedCallback() {
    this.changeTab = this.changeTab.bind(this);
  }
  mobileVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.mobileVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.mobileVideoUris = [];
    }
  }
  screenshareVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.screenshareVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.screenshareVideoUris = [];
    }
  }
  webcamVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.webcamVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.webcamVideoUris = [];
    }
  }
  peVideoFullscreenHandler(event) {
    this.isFullscreen = event.detail;
  }
  changeTab(event) {
    const tabName = event.target.dataset['tab'];
    this.activeTab = tabName;
  }
  setCurrentTime(time) {
    const videos = document
      .querySelector('pe-review-studio')
      .shadowRoot.querySelector('pe-video-player');
    videos.setCurrentTime(time);
  }
  editIncident(id) {
    // to write the logic for editing incident
    console.log(id);
  }
  componentWillLoad() {
    this.mobileVideoUrisChanged(this.mobileVideoUris);
    this.webcamVideoUrisChanged(this.webcamVideoUris);
    this.screenshareVideoUrisChanged(this.screenshareVideoUris);
    const that = this;
    const incidentList = axiosInstance.get(API.incidentList);
    const breachDictionaryItems = axiosInstance.get(API.breachDictionaryItems);
    return Promise.all([incidentList, breachDictionaryItems]).then(values => {
      // this is the final code when we have the final API
      // that.breachDictionaryItems = values[1].data.breachDictionaryItems;
      // that.content = values[0].data.incidents.map(incident => {
      //   return {
      //     ...incident,
      //     breachDictionaryItem: values[1].data.breachDictionaryItems.find(item => item.id === incident.breachDictionaryId)
      //   }
      // })
      // this code to handle fake api as it's not the same as the final strucure as the service is limited
      that.breachDictionaryItems = values[1].data;
      that.content = values[0].data.map(incident => {
        return Object.assign(Object.assign({}, incident), { breachDictionaryItem: values[1].data.find(item => item.id === incident.breachDictionaryId) });
      });
    });
  }
  render() {
    return (h(Host, null, h("div", { id: "container" }, h("div", { id: "navbar" }, h("pe-navbar", null)), h("div", { id: "sidebar" }, h("button", { "data-tab": "incident", onClick: this.changeTab, class: `sidebar-tab ${this.activeTab == 'incident' ? 'active' : ''}` }, h("span", null, h("pe-icon", { name: "comment" }))), h("button", { "data-tab": "info", onClick: this.changeTab, class: `sidebar-tab ${this.activeTab == 'info' ? 'active' : ''}` }, h("span", null, h("pe-icon", { name: "information_outline" }))), h("button", { "data-tab": "shortcuts", onClick: this.changeTab, class: `sidebar-tab ${this.activeTab == 'shortcuts' ? 'active' : ''}` }, h("span", null, h("pe-icon", { name: "keyboard_outline" }))), h("button", { "data-tab": "help", onClick: this.changeTab, class: `sidebar-tab ${this.activeTab == 'help' ? 'active' : ''}` }, h("span", null, h("pe-icon", { name: "help_outline" })))), h("div", { id: "side-panel" }, this.activeTab == 'incident' && (h("div", null, h("pe-incident-list", { incidentList: this.content, handleEdit: this.editIncident, jumptoIncidentTime: this.setCurrentTime }))), this.activeTab == 'info' && (h("div", null, "Session Information Component goes here")), this.activeTab == 'shortcuts' && h("div", null, "Shortcuts"), this.activeTab == 'help' && h("div", null, "Help Component goes here")), h("div", { id: "video-player", class: this.isFullscreen ? 'fullscreen' : '' }, h("pe-video-player", { webcamVideoUris: this.webcamVideoUris, screenshareVideoUris: this.screenshareVideoUris, mobileVideoUris: this.mobileVideoUris })))));
  }
  static get watchers() { return {
    "mobileVideoUris": ["mobileVideoUrisChanged"],
    "screenshareVideoUris": ["screenshareVideoUrisChanged"],
    "webcamVideoUris": ["webcamVideoUrisChanged"]
  }; }
};
PeReviewStudio.style = peReviewStudioCss;

const peVideoCss = ":host{display:block;position:relative}video.loading{-webkit-filter:blur(10px);filter:blur(10px)}video{width:100%;height:100%;background-color:black}.tag{display:-ms-flexbox;display:flex;-ms-flex-pack:center;justify-content:center;-ms-flex-align:center;align-items:center;height:28px;position:absolute;left:0;bottom:0;z-index:2;margin:12px;padding:0px 12px;background-color:#f3f3f3;border:1px solid #cdcdcd;-webkit-box-shadow:0.5px 1px 2px rgba(0, 0, 0, 0.2);box-shadow:0.5px 1px 2px rgba(0, 0, 0, 0.2);border-radius:8px;cursor:default;color:#4d4d4d;font-weight:500;font-size:12px;line-height:18px}";

let PeVideo = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.peVideoTimeUpdate = createEvent(this, "peVideoTimeUpdate", 7);
    this.peVideoLoadedData = createEvent(this, "peVideoLoadedData", 7);
    this.peVideoCanPlayThrough = createEvent(this, "peVideoCanPlayThrough", 7);
    this.peVideoOnWaiting = createEvent(this, "peVideoOnWaiting", 7);
    this.peVideoSourceChanged = createEvent(this, "peVideoSourceChanged", 7);
    this.peVideoClick = createEvent(this, "peVideoClick", 7);
    this.peVideoEnded = createEvent(this, "peVideoEnded", 7);
    /**
     * Determines if this is the component responsible for bubble events.
     */
    this.isEventSource = false;
    /**
     * Determines media playback.
     * Triggers play() or pause() on HTMLMediaElement.
     */
    this.isPlaying = false;
    /**
     * Determines audio is muted or not.
     * Sets muted property of HTMLMediaElement.
     */
    this.isMuted = false;
    /**
     * Determines playback speed for video.
     * Sets playbackRate of HTMLMediaElement.
     */
    this.playbackRate = 1.0;
  }
  connectedCallback() {
    this.handleClick = this.handleClick.bind(this);
    this.handleWaiting = this.handleWaiting.bind(this);
    this.handleCanPlayThrough = this.handleCanPlayThrough.bind(this);
    this.handleTimeUpdate = this.handleTimeUpdate.bind(this);
    this.handleLoadedData = this.handleLoadedData.bind(this);
    this.handleEnded = this.handleEnded.bind(this);
    this.handleSuspend = this.handleSuspend.bind(this);
    this.handleStalled = this.handleStalled.bind(this);
  }
  componentDidLoad() {
    // Setting default props
    this.videoElement.muted = this.isMuted;
    this.videoElement.playbackRate = this.playbackRate;
  }
  async handleSourceChanged(newValue) {
    this.source = newValue;
    await this.videoElement.load();
    if (this.isPlaying && this.videoElement.paused)
      await this.videoElement.play();
    this.peVideoSourceChanged.emit(this.name);
  }
  async watchIsPlayingHandler(newIsPlaying) {
    if (newIsPlaying == false && !this.videoElement.paused) {
      await this.videoElement.pause();
    }
    else {
      if (this.videoElement.ended)
        return;
      if (this.videoElement.paused)
        await this.videoElement.play();
      // Make sure playback rate preserved between different video sources
      if (this.videoElement.playbackRate != this.playbackRate)
        this.videoElement.playbackRate = this.playbackRate;
    }
  }
  watchIsMutedHandler(newIsMuted) {
    this.videoElement.muted = newIsMuted;
  }
  watchPlaybackRateHandler(newPlaybackRate) {
    this.videoElement.playbackRate = newPlaybackRate;
  }
  peVideoTimeUpdateHandler(event) {
    this.peVideoTimeUpdate.emit(event);
  }
  peVideoLoadedDataHandler(event) {
    this.peVideoLoadedData.emit(event);
  }
  async peVideoCanPlayThroughHandler(event) {
    this.peVideoCanPlayThrough.emit(event);
  }
  async peVideoOnWaitingHandler(event) {
    this.peVideoOnWaiting.emit(event);
  }
  async peVideoClickHandler(event) {
    this.peVideoClick.emit(event);
  }
  async peVideoEndedHandler(event) {
    this.peVideoEnded.emit(event);
  }
  /**
   * @param time
   */
  async seek(time) {
    this.videoElement.classList.add('loading');
    this.videoElement.currentTime = this.videoElement.currentTime + time;
  }
  /**
   * @param time
   */
  async setCurrentTime(time) {
    this.videoElement.classList.add('loading');
    this.videoElement.currentTime = time;
  }
  handleClick(event) {
    this.peVideoClickHandler(event);
  }
  handleWaiting(event) {
    this.videoElement.classList.add('loading'); // Blurs video element while its loading
    this.peVideoOnWaitingHandler(event);
  }
  handleCanPlayThrough(event) {
    this.videoElement.classList.remove('loading'); // Removes blur from loaded video element
    this.peVideoCanPlayThroughHandler(event);
  }
  handleTimeUpdate(event) {
    this.peVideoTimeUpdateHandler(event);
  }
  handleLoadedData(event) {
    this.peVideoLoadedDataHandler(event);
  }
  handleEnded(event) {
    this.peVideoEndedHandler(event);
  }
  async handleSuspend() {
    this.fixStuckVideo();
  }
  async handleStalled() {
    this.fixStuckVideo();
  }
  async fixStuckVideo() {
    const video = this.videoElement;
    if (video.seeking && video.paused) {
      if (video.networkState == 1 && video.readyState == 1) {
        setTimeout(async (_this) => {
          if (!video.ended &&
            video.paused &&
            video.networkState <= 2 &&
            video.readyState <= 1) {
            await video.load();
            await video.play();
          }
        }, 5000, this);
      }
    }
  }
  render() {
    return (h(Host, { onClick: this.handleClick }, this.tag && h("div", { class: "tag" }, this.tag), h("video", { id: this.name, part: "video", preload: "auto", onWaiting: this.handleWaiting, onCanPlayThrough: this.handleCanPlayThrough, onTimeUpdate: this.isEventSource == true ? this.handleTimeUpdate : null, onLoadedData: this.isEventSource == true ? this.handleLoadedData : null, onEnded: this.handleEnded, onSuspend: this.handleSuspend, onStalled: this.handleStalled, src: this.source, ref: el => (this.videoElement = el) })));
  }
  static get watchers() { return {
    "source": ["handleSourceChanged"],
    "isPlaying": ["watchIsPlayingHandler"],
    "isMuted": ["watchIsMutedHandler"],
    "playbackRate": ["watchPlaybackRateHandler"]
  }; }
};
PeVideo.style = peVideoCss;

const peVideoControlsCss = ":host{display:block;background-color:white;}#controls-container{display:-ms-flexbox;display:flex;-ms-flex:1;flex:1;-ms-flex-pack:justify;justify-content:space-between}#progress-container progress{width:100%}#progress-container input{width:100%}#time-container{display:-ms-flexbox;display:flex;-ms-flex:1;flex:1;-ms-flex-pack:justify;justify-content:space-between}div#controls-container{margin-top:20px;margin-bottom:15px}div#time-container{margin-top:5px}span.btn-group{display:-ms-inline-flexbox;display:inline-flex;-webkit-column-gap:10px;-moz-column-gap:10px;column-gap:10px}input[type=range]{height:4px;-webkit-appearance:none}input[type=range]{--range:calc(var(--max) - var(--min));--ratio:calc((var(--value) - var(--min)) / var(--range));--sx:calc(0.5 * 14px + var(--ratio) * (100% - 14px))}input[type=range]:focus{outline:none}input[type=range]::-webkit-slider-thumb{-webkit-appearance:none;width:14px;height:14px;border-radius:1000px;background:#fff;border:4px solid #0095ff;-webkit-box-shadow:0 0 2px black;box-shadow:0 0 2px black;margin-top:-5px}input[type=range]::-webkit-slider-runnable-track{height:4px;border:none;border-radius:0;background:#e5e5e5;-webkit-box-shadow:none;box-shadow:none}input[type=range]::-webkit-slider-thumb:hover{background:#fff}input[type=range]:hover::-webkit-slider-runnable-track{background:#e5e5e5}input[type=range]::-webkit-slider-thumb:active{background:#fff}input[type=range]:active::-webkit-slider-runnable-track{background:#e5e5e5}input[type=range]::-webkit-slider-runnable-track{background:-webkit-gradient(linear, left top, left bottom, from(#0095ff), to(#0095ff)) 0/var(--sx) 100% no-repeat, #e5e5e5;background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]:hover::-webkit-slider-runnable-track{background:-webkit-gradient(linear, left top, left bottom, from(#0095ff), to(#0095ff)) 0/var(--sx) 100% no-repeat, #e5e5e5;background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]:active::-webkit-slider-runnable-track{background:-webkit-gradient(linear, left top, left bottom, from(#0095ff), to(#0095ff)) 0/var(--sx) 100% no-repeat, #e5e5e5;background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]::-moz-range-thumb{width:6px;height:6px;border-radius:1000px;background:#fff;border:4px solid #0095ff;box-shadow:0 0 2px black}input[type=range]::-moz-range-track{height:4px;border:none;border-radius:0;background:#e5e5e5;box-shadow:none}input[type=range]::-moz-range-thumb:hover{background:#fff}input[type=range]:hover::-moz-range-track{background:#e5e5e5}input[type=range]::-moz-range-thumb:active{background:#fff}input[type=range]:active::-moz-range-track{background:#e5e5e5}input[type=range]::-moz-range-track{background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]:hover::-moz-range-track{background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]:active::-moz-range-track{background:linear-gradient(#0095ff, #0095ff) 0/var(--sx) 100% no-repeat, #e5e5e5}input[type=range]::-ms-fill-upper{background:transparent;border-color:transparent}input[type=range]::-ms-fill-lower{background:transparent;border-color:transparent}input[type=range]::-ms-thumb{width:14px;height:14px;border-radius:1000px;background:#fff;border:4px solid #0095ff;box-shadow:0 0 2px black;margin-top:0;box-sizing:border-box}input[type=range]::-ms-track{height:4px;border-radius:0;background:#e5e5e5;border:none;box-shadow:none;box-sizing:border-box}input[type=range]::-ms-thumb:hover{background:#fff}input[type=range]:hover::-ms-track{background:#e5e5e5}input[type=range]::-ms-thumb:active{background:#fff}input[type=range]:active::-ms-track{background:#e5e5e5}input[type=range]::-ms-fill-lower{height:4px;border-radius:0px 0 0 0px;margin:-undefined 0 -undefined -undefined;background:#0095ff;border:none;border-right-width:0}input[type=range]:hover::-ms-fill-lower{background:#0095ff}input[type=range]:active::-ms-fill-lower{background:#0095ff}";

let PeVideoControls = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.peVideoPlay = createEvent(this, "peVideoPlay", 7);
    this.peVideoRewind = createEvent(this, "peVideoRewind", 7);
    this.peVideoSpeed = createEvent(this, "peVideoSpeed", 7);
    this.peVideoMute = createEvent(this, "peVideoMute", 7);
    this.peVideoSeek = createEvent(this, "peVideoSeek", 7);
    this.peVideoFullscreen = createEvent(this, "peVideoFullscreen", 7);
    this.speedIndex = 0;
    this.isMuted = false;
    this.isPlaying = false;
    /**
     * Determines current value of fullscreen toggle.
     */
    this.isFullscreen = false;
    /**
     * Determines current time of progress bar.
     */
    this.currentTime = 0.0;
    /**
     * Determines total duration of progress bar.
     */
    this.totalDuration = 0.0;
    /**
     * Determines available playback speeds.
     */
    this.availableSpeeds = [1, 2, 4, 6];
  }
  connectedCallback() {
    this.handleClickPlay = this.handleClickPlay.bind(this);
    this.handleClickRewind = this.handleClickRewind.bind(this);
    this.handleClickSpeed = this.handleClickSpeed.bind(this);
    this.handleInputSeek = this.handleInputSeek.bind(this);
    this.handleClickFullscreen = this.handleClickFullscreen.bind(this);
    this.handleClickMute = this.handleClickMute.bind(this);
  }
  currentTimeChanged() {
    this.updateInputStyle();
  }
  totalDurationChanged() {
    this.updateInputStyle();
  }
  availableSpeedsChanged(newAvailableSpeeds) {
    if (typeof newAvailableSpeeds === 'string') {
      this.availableSpeeds = JSON.parse(newAvailableSpeeds);
    }
    else if (newAvailableSpeeds === null ||
      newAvailableSpeeds === undefined) {
      this.availableSpeeds = [1, 2, 4, 6];
    }
    else {
      this.availableSpeeds = newAvailableSpeeds;
    }
  }
  peVideoPlayHandler(isPlaying) {
    this.peVideoPlay.emit(isPlaying);
  }
  peVideoRewindHandler(time) {
    this.peVideoRewind.emit(time);
  }
  peVideoSpeedHandler(speed) {
    this.peVideoSpeed.emit(speed);
  }
  peVideoMuteHandler(isMuted) {
    this.peVideoMute.emit(isMuted);
  }
  peVideoSeekHandler(time) {
    this.peVideoSeek.emit(time);
  }
  peVideoFullscreenHandler(isFullscreen) {
    this.peVideoFullscreen.emit(isFullscreen);
  }
  fullscreenchangeHandler() {
    if (document.fullscreenElement == null) {
      this.peVideoFullscreen.emit(false);
    }
  }
  // Click handlers
  handleClickMute() {
    this.isMuted = !this.isMuted;
    this.peVideoMuteHandler(this.isMuted);
  }
  handleClickRewind(event) {
    const time = event.target.dataset['time'];
    this.peVideoRewindHandler(+time);
  }
  handleClickPlay() {
    this.isPlaying = !this.isPlaying;
    this.peVideoPlayHandler(this.isPlaying);
  }
  handleClickFullscreen() {
    this.peVideoFullscreenHandler(!this.isFullscreen);
  }
  handleClickSpeed() {
    this.speedIndex = (this.speedIndex + 1) % this.availableSpeeds.length;
    this.peVideoSpeedHandler(this.availableSpeeds[this.speedIndex]);
  }
  // Input handlers
  handleInputSeek(event) {
    const time = event.target.value;
    this.peVideoSeekHandler(time);
  }
  updateInputStyle() {
    // to style progress of range input
    if (this.totalDuration !== 0.0) {
      this.inputElement.style.setProperty('--value', this.inputElement.value);
      this.inputElement.style.setProperty('--max', ['', '0'].includes(this.inputElement.max)
        ? '100'
        : this.inputElement.max);
      this.inputElement.style.setProperty('--min', this.inputElement.min == '' ? '0' : this.inputElement.min);
      this.inputElement.addEventListener('input', () => this.inputElement.style.setProperty('--value', this.inputElement.value));
    }
  }
  componentWillLoad() {
    this.availableSpeedsChanged(this.availableSpeeds);
  }
  componentDidLoad() {
    this.updateInputStyle();
  }
  componentDidUpdate() {
    this.updateInputStyle();
  }
  render() {
    return (h(Host, null, h("div", { id: "controls-container" }, h("span", null, h("pe-button", { id: "mute-btn", iconName: this.isMuted ? 'volumeOff' : 'volumeUp', color: "primary", variant: "filled", circled: true, iconOnly: true, onClick: this.handleClickMute })), h("span", { class: "btn-group" }, h("pe-button", { id: "rewind-btn", iconName: "rewindX15", color: "primary", variant: "filled", circled: true, iconOnly: true, "data-time": -15, onClick: this.handleClickRewind }), h("pe-button", { id: "play-btn", iconName: this.isPlaying ? 'pause' : 'play', color: "player", variant: "filled", circled: true, iconOnly: true, onClick: this.handleClickPlay }), h("pe-button", { id: "forward-btn", iconName: "forwardX15", color: "primary", variant: "filled", circled: true, iconOnly: true, "data-time": 15, onClick: this.handleClickRewind }), h("pe-button", { id: "speed-btn", iconName: `speedX${this.availableSpeeds[this.speedIndex].toString()}`, color: "primary", variant: "filled", circled: true, iconOnly: true, onClick: this.handleClickSpeed })), h("span", null, h("pe-button", { id: "fullscreen-btn", iconName: this.isFullscreen ? 'fullscreenExit' : 'fullscreen', color: "primary", variant: "filled", circled: true, iconOnly: true, onClick: this.handleClickFullscreen }))), h("div", { id: "progress-container" }, h("input", { ref: el => (this.inputElement = el), onInput: this.handleInputSeek, type: "range", max: this.totalDuration, value: this.currentTime })), h("div", { id: "time-container" }, h("span", { id: "current-time-text" }, secondsToHours(this.currentTime)), h("span", { id: "total-duration-text" }, secondsToHours(this.totalDuration)))));
  }
  static get watchers() { return {
    "currentTime": ["currentTimeChanged"],
    "totalDuration": ["totalDurationChanged"],
    "availableSpeeds": ["availableSpeedsChanged"]
  }; }
};
PeVideoControls.style = peVideoControlsCss;

const peVideoPlayerCss = ":host{display:block;background-color:white;padding:10px}:host(.loading){-webkit-filter:blur(10px);filter:blur(10px);pointer-events:none}div#video-container pe-video{-webkit-animation:bottom-to-top 0.2s;animation:bottom-to-top 0.2s}div#small-video-container pe-video{-webkit-animation:top-to-bottom 0.2s;animation:top-to-bottom 0.2s}@-webkit-keyframes bottom-to-top{from{-webkit-transform:translateY(10%);transform:translateY(10%)}}@keyframes bottom-to-top{from{-webkit-transform:translateY(10%);transform:translateY(10%)}}@-webkit-keyframes top-to-bottom{from{-webkit-transform:translateY(-10%);transform:translateY(-10%)}}@keyframes top-to-bottom{from{-webkit-transform:translateY(-10%);transform:translateY(-10%)}}#video-container{display:-ms-flexbox;display:flex;-ms-flex-direction:row;flex-direction:row;-ms-flex-wrap:wrap;flex-wrap:wrap;gap:12px}#small-video-container{display:-ms-flexbox;display:flex;-ms-flex-direction:row;flex-direction:row;gap:12px}#video-container>pe-video:nth-of-type(1){width:100%}#small-video-container>pe-video:nth-of-type(1){width:35%}#small-video-container>pe-video:nth-of-type(2){width:35%}.fullscreen #small-video-container{-ms-flex:1;flex:1;display:-ms-flexbox;display:flex;-ms-flex-direction:column;flex-direction:column}.fullscreen #video-container>pe-video:nth-of-type(1){width:80%}.fullscreen #small-video-container>pe-video:nth-of-type(1){width:100%;height:25%}.fullscreen #small-video-container>pe-video:nth-of-type(2){width:100%;height:25%}.fullscreen div#video-container pe-video{-webkit-animation:left-to-right 0.2s;animation:left-to-right 0.2s}.fullscreen div#small-video-container pe-video{-webkit-animation:right-to-left 0.2s;animation:right-to-left 0.2s}@-webkit-keyframes left-to-right{from{-webkit-transform:translateX(10%);transform:translateX(10%)}}@keyframes left-to-right{from{-webkit-transform:translateX(10%);transform:translateX(10%)}}@-webkit-keyframes right-to-left{from{-webkit-transform:translateX(-10%);transform:translateX(-10%)}}@keyframes right-to-left{from{-webkit-transform:translateX(-10%);transform:translateX(-10%)}}";

let PeVideoPlayer = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.videoElements = [];
    this.debugEnabled = false;
    this.isPreparing = true;
    this.eventSourceStream = '';
    this.isPlaying = false;
    this.isBusy = true;
    this.isMuted = false;
    this.isFullscreen = false;
    this.canMobileVideoPlayThrough = false;
    this.canScreenshareVideoPlayThrough = false;
    this.canWebcamVideoPlayThrough = false;
    this.playbackRate = 1.0;
    this.currentTime = 0.0;
    this.totalDuration = 0.0;
    this.videoDurations = {};
    this.mobileVideoIndex = 0;
    this.screenshareVideoIndex = 0;
    this.webcamVideoIndex = 0;
    this.mobileVideoDurations = [];
    this.screenshareVideoDurations = [];
    this.webcamVideoDurations = [];
    this.mobileVideoStartTimes = [];
    this.screenshareVideoStartTimes = [];
    this.webcamVideoStartTimes = [];
    this.determineVideoDuration = uri => new Promise((resolve, reject) => {
      try {
        let video = document.createElement('video');
        video.src = uri;
        video.preload = 'metadata';
        video.onloadedmetadata = () => {
          resolve(video.duration);
        };
      }
      catch (e) {
        reject(e);
      }
    });
  }
  mobileVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.mobileVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.mobileVideoUris = [];
    }
    this.calculateVideoDurations(this.mobileVideoUris);
  }
  screenshareVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.screenshareVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.screenshareVideoUris = [];
    }
    this.calculateVideoDurations(this.screenshareVideoUris);
  }
  webcamVideoUrisChanged(newValue) {
    if (typeof newValue === 'string') {
      this.webcamVideoUris = JSON.parse(newValue);
    }
    else if (newValue === undefined) {
      this.webcamVideoUris = [];
    }
    this.calculateVideoDurations(this.webcamVideoUris);
  }
  peVideoOnWaitingHandler(event) {
    var _a, _b;
    const id = (_b = (_a = event === null || event === void 0 ? void 0 : event.detail) === null || _a === void 0 ? void 0 : _a.target) === null || _b === void 0 ? void 0 : _b.id;
    switch (id) {
      case 'mobile-video':
        this.canMobileVideoPlayThrough = false;
        break;
      case 'screenshare-video':
        this.canScreenshareVideoPlayThrough = false;
        break;
      case 'webcam-video':
        this.canWebcamVideoPlayThrough = false;
        break;
      default:
        console.error('Unknown onWaiting event.');
        break;
    }
    this.determineIsBusy();
  }
  peVideoSourceChangedHandler() {
    this.setCurrentTimeForEachStream();
  }
  peVideoCanPlayThroughHandler(event) {
    var _a, _b;
    const id = (_b = (_a = event === null || event === void 0 ? void 0 : event.detail) === null || _a === void 0 ? void 0 : _a.target) === null || _b === void 0 ? void 0 : _b.id;
    switch (id) {
      case 'mobile-video':
        this.canMobileVideoPlayThrough = true;
        break;
      case 'screenshare-video':
        this.canScreenshareVideoPlayThrough = true;
        break;
      case 'webcam-video':
        this.canWebcamVideoPlayThrough = true;
        break;
      default:
        console.error('Unknown canPlayThrough event.');
        break;
    }
    this.determineIsBusy();
  }
  peVideoPlayHandler(event) {
    this.isPlaying = event.detail;
  }
  peVideoRewindHandler(event) {
    const timeToRewind = event.detail;
    const time = this.currentTime + timeToRewind < 0 ? 0 : this.currentTime + timeToRewind;
    this.setCurrentTime(time);
  }
  peVideoMuteHandler() {
    this.isMuted = !this.isMuted;
  }
  peVideoSpeedHandler(event) {
    const playbackRate = event.detail;
    this.playbackRate = playbackRate;
  }
  peVideoEndedHandler(event) {
    const id = event.detail.target.id;
    switch (id) {
      case 'mobile-video':
        if (this.mobileVideoUris[this.mobileVideoIndex + 1] !== undefined)
          this.mobileVideoIndex = this.mobileVideoIndex + 1;
        break;
      case 'screenshare-video':
        if (this.screenshareVideoUris[this.screenshareVideoIndex + 1] !==
          undefined)
          this.screenshareVideoIndex = this.screenshareVideoIndex + 1;
        break;
      case 'webcam-video':
        if (this.webcamVideoUris[this.webcamVideoIndex + 1] !== undefined)
          this.webcamVideoIndex = this.webcamVideoIndex + 1;
        break;
      default:
        console.error('Unknown peVideoEnded event.');
        break;
    }
  }
  peVideoTimeUpdateHandler(event) {
    const time = event.detail.target.currentTime || 0;
    if (time < 0.01) {
      return;
    } // magic :(
    let calculatedCurrentTime;
    switch (this.eventSourceStream) {
      case 'mobile':
        calculatedCurrentTime =
          this.mobileVideoIndex > 0
            ? this.mobileVideoStartTimes[this.mobileVideoIndex] + time
            : time;
        break;
      case 'webcam':
        calculatedCurrentTime =
          this.webcamVideoIndex > 0
            ? this.webcamVideoStartTimes[this.webcamVideoIndex] + time
            : time;
        break;
      case 'screenshare':
        calculatedCurrentTime =
          this.screenshareVideoIndex > 0
            ? this.screenshareVideoStartTimes[this.screenshareVideoIndex] + time
            : time;
        break;
    }
    this.currentTime = calculatedCurrentTime;
  }
  peVideoLoadedDataHandler() {
    this.setCurrentTimeForEachStream();
  }
  peVideoSeekHandler(event) {
    const time = event.detail;
    this.setCurrentTime(time);
  }
  peVideoFullscreenHandler(event) {
    this.isFullscreen = event.detail;
    if (this.isFullscreen == true && document.fullscreenElement == null) {
      this.videoPlayerElement.requestFullscreen();
    }
    else if (this.isFullscreen == false &&
      document.fullscreenElement != null) {
      document.exitFullscreen();
    }
  }
  /**
   * Moves clicked video to highlighted area.
   * Nothing happens if clicked on already highlighted video.
   */
  peVideoClickHandler(event) {
    const videoElement = event.detail.target;
    if (videoElement === this.highlightedVideo)
      return;
    const previouslyHighlightedVideo = this.highlightedVideo;
    this.highlightedVideo = videoElement;
    const indexOfSelected = Array.from(videoElement.parentElement.children).indexOf(videoElement);
    previouslyHighlightedVideo.after(videoElement);
    if (indexOfSelected == 0) {
      this.smallVideoContainer.insertAdjacentElement('afterbegin', previouslyHighlightedVideo);
    }
    else {
      this.smallVideoContainer.insertAdjacentElement('beforeend', previouslyHighlightedVideo);
    }
    this.handleBoxSizeChanges({
      inlineSize: this.videoPlayerElement.parentElement.clientWidth,
      blockSize: this.videoPlayerElement.parentElement.clientHeight,
    });
  }
  /**
   * @param time
   */
  async setCurrentTime(time) {
    const wasPlaying = this.isPlaying;
    // Stopping player first
    this.isPlaying = false;
    // Setting current time
    this.currentTime = time;
    // Calculate current time for each stream
    this.setCurrentTimeForEachStream();
    // Playing video again after seek finished
    // only if it was already playing
    if (wasPlaying)
      this.isPlaying = true;
  }
  /**
   * Returns current time from seekbar
   */
  async getCurrentTime() {
    return this.currentTime;
  }
  async setCurrentTimeForEachStream() {
    if (this.mobileVideoStartTimes.length === 0 &&
      this.webcamVideoStartTimes.length === 0 &&
      this.screenshareVideoStartTimes.length === 0)
      return;
    // Set correct index for each stream
    const newMobileVideoIndex = this.mobileVideoStartTimes.indexOf(this.mobileVideoStartTimes
      .filter(range => this.currentTime >= range)
      .at(-1));
    const newWebcamVideoIndex = this.webcamVideoStartTimes.indexOf(this.webcamVideoStartTimes
      .filter(range => this.currentTime >= range)
      .at(-1));
    const newScreenshareVideoIndex = this.screenshareVideoStartTimes.indexOf(this.screenshareVideoStartTimes
      .filter(range => this.currentTime >= range)
      .at(-1));
    const atLeastOneSourceChanged = newMobileVideoIndex != this.mobileVideoIndex ||
      newWebcamVideoIndex != this.webcamVideoIndex ||
      newScreenshareVideoIndex != this.screenshareVideoIndex;
    if (newMobileVideoIndex != this.mobileVideoIndex) {
      this.mobileVideoIndex = newMobileVideoIndex;
    }
    if (newWebcamVideoIndex != this.webcamVideoIndex) {
      this.webcamVideoIndex = newWebcamVideoIndex;
    }
    if (newScreenshareVideoIndex != this.screenshareVideoIndex) {
      this.screenshareVideoIndex = newScreenshareVideoIndex;
    }
    if (atLeastOneSourceChanged) {
      await this.waitEvent('peVideoSourceChanged');
    }
    // Calculate correct current time for each stream
    const mobileVideoTime = this.mobileVideoIndex == 0
      ? this.currentTime
      : this.currentTime - this.mobileVideoStartTimes[this.mobileVideoIndex];
    const webcamVideoTime = this.webcamVideoIndex == 0
      ? this.currentTime
      : this.currentTime - this.webcamVideoStartTimes[this.webcamVideoIndex];
    const screenshareVideoTime = this.screenshareVideoIndex == 0
      ? this.currentTime
      : this.currentTime -
        this.screenshareVideoStartTimes[this.screenshareVideoIndex];
    // Set correct current time for each stream
    this.videoElements.forEach(videoElement => {
      switch (videoElement.name) {
        case 'mobile-video':
          videoElement.setCurrentTime(mobileVideoTime);
          break;
        case 'screenshare-video':
          videoElement.setCurrentTime(screenshareVideoTime);
          break;
        case 'webcam-video':
          videoElement.setCurrentTime(webcamVideoTime);
          break;
        default:
          console.error('Unknown peVideoEnded event.');
          break;
      }
    });
  }
  /**
   * Checks if all provided medias are ready to play,
   * and then sets 'isBusy' state.
   */
  determineIsBusy() {
    var _a, _b, _c, _d;
    if (((_a = this.webcamVideoUris) === null || _a === void 0 ? void 0 : _a.length) > 0 && ((_b = this.mobileVideoUris) === null || _b === void 0 ? void 0 : _b.length) > 0) {
      this.isBusy = !(this.canMobileVideoPlayThrough &&
        this.canScreenshareVideoPlayThrough &&
        this.canWebcamVideoPlayThrough);
    }
    else if (((_c = this.webcamVideoUris) === null || _c === void 0 ? void 0 : _c.length) > 0) {
      this.isBusy = !(this.canScreenshareVideoPlayThrough && this.canWebcamVideoPlayThrough);
    }
    else if (((_d = this.mobileVideoUris) === null || _d === void 0 ? void 0 : _d.length) > 0) {
      this.isBusy = !(this.canScreenshareVideoPlayThrough && this.canMobileVideoPlayThrough);
    }
    else {
      this.isBusy = !this.canScreenshareVideoPlayThrough;
    }
  }
  calculateVideoDurations(videoUris) {
    videoUris.forEach(uri => {
      if (this.videoDurations.hasOwnProperty(uri))
        return;
      this.determineVideoDuration(uri).then(duration => {
        this.videoDurations[uri] = duration;
        if (Object.keys(this.videoDurations).length ===
          [
            ...new Set([
              ...this.screenshareVideoUris,
              ...this.webcamVideoUris,
              ...this.mobileVideoUris,
            ]),
          ].length) {
          this.mobileVideoDurations = this.mobileVideoUris.map(key => this.videoDurations[key]);
          this.webcamVideoDurations = this.webcamVideoUris.map(key => this.videoDurations[key]);
          this.screenshareVideoDurations = this.screenshareVideoUris.map(key => this.videoDurations[key]);
          this.calculateVideoStartTimes();
        }
      });
    });
  }
  calculateVideoStartTimes() {
    // determine starting time for each mobile video source
    this.mobileVideoStartTimes = [
      ...[0],
      ...Array.from(this.mobileVideoDurations, (_item, index) => this.mobileVideoDurations.slice(0, index + 1).reduce((a, b) => a + b)).slice(0, -1),
    ];
    // determine starting time for each webcam video source
    this.webcamVideoStartTimes = [
      ...[0],
      ...Array.from(this.webcamVideoDurations, (_item, index) => this.webcamVideoDurations.slice(0, index + 1).reduce((a, b) => a + b)).slice(0, -1),
    ];
    // determine starting time for each screenshare video source
    this.screenshareVideoStartTimes = [
      ...[0],
      ...Array.from(this.screenshareVideoDurations, (_item, index) => this.screenshareVideoDurations
        .slice(0, index + 1)
        .reduce((a, b) => a + b)).slice(0, -1),
    ];
    this.calculateTotalDuration();
    this.determineEventSource();
    this.determineIsPreparing();
  }
  determineIsPreparing() {
    const startTimesCalculated = [
      ...this.mobileVideoStartTimes,
      ...this.webcamVideoStartTimes,
      ...this.screenshareVideoStartTimes,
    ].length >=
      [
        ...this.mobileVideoUris,
        ...this.webcamVideoUris,
        ...this.screenshareVideoUris,
      ].length;
    if (startTimesCalculated) {
      this.isPreparing = false;
      this.setupResizeObserver();
    }
    else {
      this.isPreparing = true;
    }
  }
  calculateTotalDuration() {
    this.totalDuration = Math.max(this.mobileVideoStartTimes.at(-1) + this.mobileVideoDurations.at(-1) || 0, this.webcamVideoStartTimes.at(-1) + this.webcamVideoDurations.at(-1) || 0, this.screenshareVideoStartTimes.at(-1) +
      this.screenshareVideoDurations.at(-1) || 0, ...[0]);
  }
  handleBoxSizeChanges(boxSize) {
    const width = boxSize.inlineSize;
    const height = boxSize.blockSize;
    let bottomGap = 0;
    let actualHeight = 0;
    if (this.isFullscreen) {
      // fullscreen mode
      bottomGap = this.videoControls.clientHeight + 20 + 25;
      actualHeight = height - bottomGap;
      this.highlightedVideo.style.height = actualHeight.toString() + 'px';
      this.highlightedVideo.style.width = '80%';
      this.smallVideoContainer
        .querySelectorAll('pe-video')
        .forEach(videoElement => {
        videoElement.style.height = '25%';
        videoElement.style.width = '100%';
      });
    }
    else {
      // default view
      bottomGap = this.videoControls.clientHeight + 20 + 25 + 15;
      actualHeight = height - bottomGap;
      this.highlightedVideo.style.height =
        (actualHeight * 0.75).toString() + 'px';
      this.highlightedVideo.style.width = '100%';
      this.smallVideoContainer
        .querySelectorAll('pe-video')
        .forEach(videoElement => {
        videoElement.style.height = (actualHeight * 0.25).toString() + 'px';
        videoElement.style.width = (width * 0.35).toString() + 'px';
      });
    }
  }
  determineEventSource() {
    const durationSums = [
      [...[0], ...this.mobileVideoDurations].reduce((a, b) => a + b),
      [...[0], ...this.screenshareVideoDurations].reduce((a, b) => a + b),
      [...[0], ...this.webcamVideoDurations].reduce((a, b) => a + b),
    ];
    const streamTypes = ['mobile', 'screenshare', 'webcam'];
    this.eventSourceStream =
      streamTypes[durationSums.indexOf(Math.max(...durationSums))];
  }
  setupResizeObserver() {
    const parentElement = this.videoPlayerElement.parentElement;
    const resizeObserver = new ResizeObserver(entries => {
      for (let entry of entries) {
        if (entry.contentBoxSize !== null) {
          const contentBoxSize = Array.isArray(entry.contentBoxSize)
            ? entry.contentBoxSize[0]
            : entry.contentBoxSize;
          this.handleBoxSizeChanges(contentBoxSize);
        }
      }
    });
    resizeObserver.observe(parentElement);
    // Set highlighted video only once in here.
    this.highlightedVideo = this.screenshareVideo;
    // Add all available videos to video elements array
    if (this.screenshareVideo != undefined)
      this.videoElements.push(this.screenshareVideo);
    if (this.mobileVideo != undefined)
      this.videoElements.push(this.mobileVideo);
    if (this.webcamVideo != undefined)
      this.videoElements.push(this.webcamVideo);
  }
  async waitEvent(name) {
    return new Promise(function (resolve) {
      document.addEventListener(name, function () {
        resolve(true); // resolves when the event fires
      });
    });
  }
  componentWillLoad() {
    this.mobileVideoUrisChanged(this.mobileVideoUris);
    this.webcamVideoUrisChanged(this.webcamVideoUris);
    this.screenshareVideoUrisChanged(this.screenshareVideoUris);
  }
  componentDidLoad() {
    // set feature flags
    const params = new URLSearchParams(location.search);
    this.debugEnabled = params.has('debugger');
  }
  render() {
    var _a, _b, _c, _d;
    return (h(Host, { class: this.isPreparing ? 'loading' : '', ref: el => (this.videoPlayerElement = el) }, ((_a = this.screenshareVideoUris) === null || _a === void 0 ? void 0 : _a.length) > 0 && (h("span", { class: this.isFullscreen ? 'fullscreen' : '' }, h("div", { id: "video-container" }, h("pe-video", { ref: el => (this.screenshareVideo = el), name: "screenshare-video", tag: "Screenshare", playbackRate: this.playbackRate, isMuted: true, isPlaying: this.isBusy ? false : this.isPlaying, isEventSource: this.eventSourceStream == 'screenshare', source: this.screenshareVideoUris[this.screenshareVideoIndex] }), h("div", { ref: el => (this.smallVideoContainer = el), id: "small-video-container" }, ((_b = this.webcamVideoUris) === null || _b === void 0 ? void 0 : _b.length) > 0 && (h("pe-video", { ref: el => (this.webcamVideo = el), name: "webcam-video", tag: "Webcam", playbackRate: this.playbackRate, isMuted: this.isMuted, isPlaying: this.isBusy ? false : this.isPlaying, isEventSource: this.eventSourceStream == 'webcam', source: this.webcamVideoUris[this.webcamVideoIndex] })), ((_c = this.mobileVideoUris) === null || _c === void 0 ? void 0 : _c.length) > 0 && (h("pe-video", { ref: el => (this.mobileVideo = el), name: "mobile-video", tag: "Mobile", playbackRate: this.playbackRate, isMuted: true, isPlaying: this.isBusy ? false : this.isPlaying, isEventSource: this.eventSourceStream == 'mobile', source: this.mobileVideoUris[this.mobileVideoIndex] })))), h("pe-video-controls", { ref: el => (this.videoControls = el), currentTime: this.currentTime, totalDuration: this.totalDuration, isFullscreen: this.isFullscreen }))), ((_d = this.screenshareVideoUris) === null || _d === void 0 ? void 0 : _d.length) == 0 && (h("h1", null, "Screensharing source is required.")), this.debugEnabled && (h("pe-debug-panel", { content: {
        screenshareVideoUris: this.screenshareVideoUris,
        webcamVideoUris: this.webcamVideoUris,
        mobileVideoUris: this.mobileVideoUris,
        videoDurations: [
          `screenshare: ${this.screenshareVideoDurations}`,
          `webcam: ${this.webcamVideoDurations}`,
          `mobile: ${this.mobileVideoDurations}`,
        ],
        videoIndexes: [
          `screenshare: ${this.screenshareVideoIndex}`,
          `webcam: ${this.webcamVideoIndex}`,
          `mobile: ${this.mobileVideoIndex}`,
        ],
        videoCanPlayThrough: [
          `screenshare: ${this.canScreenshareVideoPlayThrough}`,
          `webcam: ${this.canWebcamVideoPlayThrough}`,
          `mobile: ${this.canMobileVideoPlayThrough}`,
        ],
        eventSource: [this.eventSourceStream],
      } }))));
  }
  static get watchers() { return {
    "mobileVideoUris": ["mobileVideoUrisChanged"],
    "screenshareVideoUris": ["screenshareVideoUrisChanged"],
    "webcamVideoUris": ["webcamVideoUrisChanged"]
  }; }
};
PeVideoPlayer.style = peVideoPlayerCss;

export { PeButton as pe_button, PeDebugPanel as pe_debug_panel, PeIcon as pe_icon, PeIncidentList as pe_incident_list, PeNavbar as pe_navbar, PeReviewStudio as pe_review_studio, PeVideo as pe_video, PeVideoControls as pe_video_controls, PeVideoPlayer as pe_video_player };
